/* All billing codes required for MIPS
 * Copyright (C) 2015 - 2017      Suncoast Connection
 * 
 * LICENSE: This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0
 * See the Mozilla Public License for more details. 
 * If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
 * 
 * @author  Art Eaton <art@suncoastconnection.com>
 * @author  Bryan lee <leebc@suncoastconnection.com>
 * @package LibreHealthEHR 
 * @link    http://suncoastconnection.com
 * @link    http://librehealth.io
 *
 * Please support this product by sharing your changes with the LibreHealth.io community.
 */
DROP TABLE IF EXISTS `code_types`;
CREATE TABLE `code_types` (
  `ct_key` varchar(15) NOT NULL COMMENT 'short alphanumeric name',
  `ct_id` int(11) NOT NULL COMMENT 'numeric identifier',
  `ct_seq` int(11) NOT NULL DEFAULT '0' COMMENT 'sort order',
  `ct_mod` int(11) NOT NULL DEFAULT '0' COMMENT 'length of modifier field',
  `ct_just` varchar(15) NOT NULL DEFAULT '' COMMENT 'ct_key of justify type, if any',
  `ct_mask` varchar(9) NOT NULL DEFAULT '' COMMENT 'formatting mask for code values',
  `ct_fee` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if fees are used',
  `ct_rel` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if can relate to other code types',
  `ct_nofs` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if to be hidden in the fee sheet',
  `ct_diag` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a diagnosis type',
  `ct_active` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1 if this is active',
  `ct_label` varchar(31) NOT NULL DEFAULT '' COMMENT 'label of this code type',
  `ct_external` tinyint(1) NOT NULL DEFAULT '0' COMMENT '0 if stored codes in codes tables, 1 or greater if codes stored in external tables',
  `ct_claim` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is used in claims',
  `ct_proc` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a procedure type',
  `ct_term` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this is a clinical term',
  `ct_problem` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this code type is used as a medical problem',
  `ct_drug` tinyint(1) NOT NULL DEFAULT '0' COMMENT '1 if this code type is used as a medication'
);


INSERT INTO `code_types` (`ct_key`, `ct_id`, `ct_seq`, `ct_mod`, `ct_just`, `ct_mask`, `ct_fee`, `ct_rel`, `ct_nofs`, `ct_diag`, `ct_active`, `ct_label`, `ct_external`, `ct_claim`, `ct_proc`, `ct_term`, `ct_problem`, `ct_drug`) VALUES
('CPT4', 1, 2, 12, 'ICD10', '', 1, 0, 0, 0, 1, 'CPT4 Procedure/Service', 0, 1, 1, 0, 0, 0),
('HCPCS', 3, 3, 12, 'ICD10', '', 1, 0, 0, 0, 1, 'HCPCS Procedure/Service', 0, 1, 1, 0, 0, 0),
('CVX', 100, 100, 0, '', '', 0, 0, 0, 0, 1, 'CVX Immunization', 0, 0, 0, 0, 0, 0),
('ICD10', 102, 102, 0, '', '', 0, 0, 0, 1, 1, 'ICD10 Diagnosis', 1, 1, 0, 0, 1, 0),
('CPTII', 104, 104, 2, 'ICD10', '', 0, 0, 0, 0, 1, 'CPTII Performance Measures', 0, 1, 0, 0, 0, 0),
('ICD10-PCS', 106, 106, 12, 'ICD10', '', 1, 0, 0, 0, 1, 'ICD10 Procedure/Service', 6, 1, 1, 0, 0, 0),
('RXCUI', 109, 109, 0, '', '', 0, 0, 1, 0, 0, 'RXCUI Medication', 0, 0, 0, 0, 0, 1),
('LOINC', 110, 110, 0, '', '', 0, 0, 1, 0, 1, 'LOINC', 0, 0, 0, 0, 0, 0),
('PHIN Questions', 111, 111, 0, '', '', 0, 0, 1, 0, 1, 'PHIN Questions', 0, 0, 0, 0, 0, 0);


--
ALTER TABLE `code_types`
  ADD PRIMARY KEY (`ct_key`),
  ADD UNIQUE KEY `ct_id` (`ct_id`);




DROP TABLE IF EXISTS `codes`;

CREATE TABLE IF NOT EXISTS `codes` (
  `id` int(11) NOT NULL auto_increment,
  `code_text` varchar(255) NOT NULL default '',
  `code_text_short` varchar(24) NOT NULL default '',
  `code` varchar(10) NOT NULL default '',
  `code_type` smallint(6) default NULL,
  `modifier` varchar(12) NOT NULL default '',
  `units` tinyint(3) default NULL,
  `fee` decimal(12,2) default NULL,
  `superbill` varchar(31) NOT NULL default '',
  `related_code` varchar(255) NOT NULL default '',
  `taxrates` varchar(255) NOT NULL default '',
  `cyp_factor` float NOT NULL default '0' COMMENT 'quantity representing a years supply',
  `active` tinyint(1) default '1' COMMENT '0 = inactive, 1 = active',
  `reportable` tinyint(1) default '0' COMMENT '0 = non-reportable, 1 = reportable',
  `financial_reporting` tinyint(1) default '0' COMMENT '0 = negative, 1 = considered important code in financial reporting',
  PRIMARY KEY  (`id`),
  KEY `code` (`code`),
  KEY `code_type` (`code_type`)
) AUTO_INCREMENT=16643 ;

--
-- Dumping data for table `codes`
--



INSERT INTO `codes` (`id`, `code_text`, `code_text_short`, `code`, `code_type`, `modifier`, `units`, `fee`, `superbill`, `related_code`, `taxrates`, `cyp_factor`, `active`, `reportable`, `financial_reporting`) VALUES
(1, 'diphtheria, tetanus toxoids and pertussis vaccine', 'DTP', '1', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(2, 'poliovirus vaccine, live, oral', 'OPV', '2', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(3, 'measles, mumps and rubella virus vaccine', 'MMR', '3', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(4, 'measles and rubella virus vaccine', 'M/R', '4', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(5, 'measles virus vaccine', 'measles', '5', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(6, 'rubella virus vaccine', 'rubella', '6', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(7, 'mumps virus vaccine', 'mumps', '7', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(8, 'hepatitis B vaccine, pediatric or pediatric/adolescent dosage', 'Hep B, adolescent or ped', '8', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(9, 'tetanus and diphtheria toxoids, adsorbed, for adult use', 'Td (adult), adsorbed', '9', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(10, 'poliovirus vaccine, inactivated', 'IPV', '10', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(11, 'pertussis vaccine', 'pertussis', '11', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(12, 'diphtheria antitoxin', 'diphtheria antitoxin', '12', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(13, 'tetanus immune globulin', 'TIG', '13', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(14, 'immune globulin, unspecified formulation', 'IG, unspecified formulat', '14', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(15, 'influenza virus vaccine, split virus (incl. purified surface antigen)-retired CODE', 'influenza, split (incl. ', '15', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(16, 'influenza virus vaccine, whole virus', 'influenza, whole', '16', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(17, 'Haemophilus influenzae type b vaccine, conjugate unspecified formulation', 'Hib, unspecified formula', '17', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(18, 'rabies vaccine, for intramuscular injection', 'rabies, intramuscular in', '18', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(19, 'Bacillus Calmette-Guerin vaccine', 'BCG', '19', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(20, 'diphtheria, tetanus toxoids and acellular pertussis vaccine', 'DTaP', '20', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(21, 'varicella virus vaccine', 'varicella', '21', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(22, 'DTP-Haemophilus influenzae type b conjugate vaccine', 'DTP-Hib', '22', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(23, 'plague vaccine', 'plague', '23', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(24, 'anthrax vaccine', 'anthrax', '24', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(25, 'typhoid vaccine, live, oral', 'typhoid, oral', '25', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(26, 'cholera vaccine', 'cholera', '26', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(27, 'botulinum antitoxin', 'botulinum antitoxin', '27', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(28, 'diphtheria and tetanus toxoids, adsorbed for pediatric use', 'DT (pediatric)', '28', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(29, 'cytomegalovirus immune globulin, intravenous', 'CMVIG', '29', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(30, 'hepatitis B immune globulin', 'HBIG', '30', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(31, 'hepatitis A vaccine, pediatric dosage, unspecified formulation', 'Hep A, pediatric, unspec', '31', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(32, 'meningococcal polysaccharide vaccine (MPSV4)', 'meningococcal MPSV4', '32', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(33, 'pneumococcal polysaccharide vaccine, 23 valent', 'pneumococcal polysacchar', '33', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(34, 'rabies immune globulin', 'RIG', '34', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(35, 'tetanus toxoid, adsorbed', 'tetanus toxoid, adsorbed', '35', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(36, 'varicella zoster immune globulin', 'VZIG', '36', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(37, 'yellow fever vaccine', 'yellow fever', '37', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(38, 'rubella and mumps virus vaccine', 'rubella/mumps', '38', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(39, 'Japanese Encephalitis Vaccine SC', 'Japanese encephalitis SC', '39', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(40, 'rabies vaccine, for intradermal injection', 'rabies, intradermal inje', '40', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(41, 'typhoid vaccine, parenteral, other than acetone-killed, dried', 'typhoid, parenteral', '41', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(42, 'hepatitis B vaccine, adolescent/high risk infant dosage', 'Hep B, adolescent/high r', '42', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(43, 'hepatitis B vaccine, adult dosage', 'Hep B, adult', '43', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(44, 'hepatitis B vaccine, dialysis patient dosage', 'Hep B, dialysis', '44', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(45, 'hepatitis B vaccine, unspecified formulation', 'Hep B, unspecified formu', '45', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(46, 'Haemophilus influenzae type b vaccine, PRP-D conjugate', 'Hib (PRP-D)', '46', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(47, 'Haemophilus influenzae type b vaccine, HbOC conjugate', 'Hib (HbOC)', '47', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(48, 'Haemophilus influenzae type b vaccine, PRP-T conjugate', 'Hib (PRP-T)', '48', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(49, 'Haemophilus influenzae type b vaccine, PRP-OMP conjugate', 'Hib (PRP-OMP)', '49', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(50, 'DTaP-Haemophilus influenzae type b conjugate vaccine', 'DTaP-Hib', '50', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(51, 'Haemophilus influenzae type b conjugate and Hepatitis B vaccine', 'Hib-Hep B', '51', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(52, 'hepatitis A vaccine, adult dosage', 'Hep A, adult', '52', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(53, 'typhoid vaccine, parenteral, acetone-killed, dried (U.S. military)', 'typhoid, parenteral, AKD', '53', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(54, 'adenovirus vaccine, type 4, live, oral', 'adenovirus, type 4', '54', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(55, 'adenovirus vaccine, type 7, live, oral', 'adenovirus, type 7', '55', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(56, 'dengue fever vaccine', 'dengue fever', '56', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(57, 'hantavirus vaccine', 'hantavirus', '57', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(58, 'hepatitis C vaccine', 'Hep C', '58', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(59, 'hepatitis E vaccine', 'Hep E', '59', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(60, 'herpes simplex virus, type 2 vaccine', 'herpes simplex 2', '60', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(61, 'human immunodeficiency virus vaccine', 'HIV', '61', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(62, 'human papilloma virus vaccine, quadrivalent', 'HPV, quadrivalent', '62', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(63, 'Junin virus vaccine', 'Junin virus', '63', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(64, 'leishmaniasis vaccine', 'leishmaniasis', '64', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(65, 'leprosy vaccine', 'leprosy', '65', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(66, 'Lyme disease vaccine', 'Lyme disease', '66', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(67, 'malaria vaccine', 'malaria', '67', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(68, 'melanoma vaccine', 'melanoma', '68', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(69, 'parainfluenza-3 virus vaccine', 'parainfluenza-3', '69', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(70, 'Q fever vaccine', 'Q fever', '70', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(71, 'respiratory syncytial virus immune globulin, intravenous', 'RSV-IGIV', '71', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(72, 'rheumatic fever vaccine', 'rheumatic fever', '72', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(73, 'Rift Valley fever vaccine', 'Rift Valley fever', '73', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(74, 'rotavirus, live, tetravalent vaccine', 'rotavirus, tetravalent', '74', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(75, 'vaccinia (smallpox) vaccine', 'vaccinia (smallpox)', '75', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(76, 'Staphylococcus bacteriophage lysate', 'Staphylococcus bacterio ', '76', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(77, 'tick-borne encephalitis vaccine', 'tick-borne encephalitis', '77', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(78, 'tularemia vaccine', 'tularemia vaccine', '78', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(79, 'vaccinia immune globulin', 'vaccinia immune globulin', '79', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(80, 'Venezuelan equine encephalitis, live, attenuated', 'VEE, live', '80', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(81, 'Venezuelan equine encephalitis, inactivated', 'VEE, inactivated', '81', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(82, 'adenovirus vaccine, unspecified formulation', 'adenovirus, unspecified ', '82', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(83, 'hepatitis A vaccine, pediatric/adolescent dosage, 2 dose schedule', 'Hep A, ped/adol, 2 dose', '83', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(84, 'hepatitis A vaccine, pediatric/adolescent dosage, 3 dose schedule', 'Hep A, ped/adol, 3 dose', '84', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(85, 'hepatitis A vaccine, unspecified formulation', 'Hep A, unspecified formu', '85', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(86, 'immune globulin, intramuscular', 'IG', '86', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(87, 'immune globulin, intravenous', 'IGIV', '87', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(88, 'influenza virus vaccine, unspecified formulation', 'influenza, unspecified f', '88', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(89, 'poliovirus vaccine, unspecified formulation', 'polio, unspecified formu', '89', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(90, 'rabies vaccine, unspecified formulation', 'rabies, unspecified form', '90', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(91, 'typhoid vaccine, unspecified formulation', 'typhoid, unspecified for', '91', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(92, 'Venezuelan equine encephalitis vaccine, unspecified formulation', 'VEE, unspecified formula', '92', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(93, 'respiratory syncytial virus monoclonal antibody (palivizumab), intramuscular', 'RSV-MAb', '93', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(94, 'measles, mumps, rubella, and varicella virus vaccine', 'MMRV', '94', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(95, 'tuberculin skin test; old tuberculin, multipuncture device', 'TST-OT tine test', '95', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(96, 'tuberculin skin test; purified protein derivative solution, intradermal', 'TST-PPD intradermal', '96', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(97, 'tuberculin skin test; purified protein derivative, multipuncture device', 'TST-PPD tine test', '97', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(98, 'tuberculin skin test; unspecified formulation', 'TST, unspecified formula', '98', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(99, 'RESERVED - do not use', 'RESERVED - do not use', '99', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(100, 'pneumococcal conjugate vaccine, 7 valent', 'pneumococcal conjugate P', '100', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(101, 'typhoid Vi capsular polysaccharide vaccine', 'typhoid, ViCPs', '101', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(102, 'DTP- Haemophilus influenzae type b conjugate and hepatitis b vaccine', 'DTP-Hib-Hep B', '102', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(103, 'meningococcal C conjugate vaccine', 'meningococcal C conjugat', '103', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(104, 'hepatitis A and hepatitis B vaccine', 'Hep A-Hep B', '104', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(105, 'vaccinia (smallpox) vaccine, diluted', 'vaccinia (smallpox) dilu', '105', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(106, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, 5 pertussis antigens', 'DTaP, 5 pertussis antige', '106', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(107, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, unspecified formulation', 'DTaP, unspecified formul', '107', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(108, 'meningococcal vaccine, unspecified formulation', 'meningococcal, unspecifi', '108', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(109, 'pneumococcal vaccine, unspecified formulation', 'pneumococcal, unspecifie', '109', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(110, 'DTaP-hepatitis B and poliovirus vaccine', 'DTaP-Hep B-IPV', '110', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(111, 'influenza virus vaccine, live, attenuated, for intranasal use', 'influenza, live, intrana', '111', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(112, 'tetanus toxoid, unspecified formulation', 'tetanus toxoid, unspecif', '112', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(113, 'tetanus and diphtheria toxoids, adsorbed, preservative free, for adult use', 'Td (adult) preservative ', '113', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(114, 'meningococcal polysaccharide (groups A, C, Y and W-135) diphtheria toxoid conjugate vaccine (MCV4P)', 'meningococcal MCV4P', '114', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(115, 'tetanus toxoid, reduced diphtheria toxoid, and acellular pertussis vaccine, adsorbed', 'Tdap', '115', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(116, 'rotavirus, live, pentavalent vaccine', 'rotavirus, pentavalent', '116', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(117, 'varicella zoster immune globulin (Investigational New Drug)', 'VZIG (IND)', '117', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(118, 'human papilloma virus vaccine, bivalent', 'HPV, bivalent', '118', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(119, 'rotavirus, live, monovalent vaccine', 'rotavirus, monovalent', '119', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(120, 'diphtheria, tetanus toxoids and acellular pertussis vaccine, Haemophilus influenzae type b conjugate, and poliovirus vaccine, inactivated (DTaP-Hib-IPV)', 'DTaP-Hib-IPV', '120', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(121, 'zoster vaccine, live', 'zoster', '121', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(122, 'rotavirus vaccine, unspecified formulation', 'rotavirus, unspecified f', '122', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(123, 'influenza virus vaccine, H5N1, A/Vietnam/1203/2004 (national stockpile)', 'influenza, H5N1-1203', '123', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(124, 'Novel Influenza-H1N1-09, live virus for nasal administration', 'Novel Influenza-H1N1-09,', '125', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(125, 'Novel influenza-H1N1-09, preservative-free, injectable', 'Novel influenza-H1N1-09,', '126', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(126, 'Novel influenza-H1N1-09, injectable', 'Novel influenza-H1N1-09', '127', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(127, 'Novel influenza-H1N1-09, all formulations', 'Novel Influenza-H1N1-09,', '128', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(128, 'Japanese Encephalitis vaccine, unspecified formulation', 'Japanese Encephalitis, u', '129', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(129, 'Diphtheria, tetanus toxoids and acellular pertussis vaccine, and poliovirus vaccine, inactivated', 'DTaP-IPV', '130', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(130, 'Historical record of a typhus vaccination', 'typhus, historical', '131', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(131, 'Historical record of vaccine containing, diphtheria, tetanus toxoids and acellular pertussis, poliovirus, inactivated, Haemophilus influenzae type b conjugate, Hepatitis B (DTaP-Hib-IPV)', 'DTaP-IPV-HIB-HEP B, hist', '132', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(132, 'pneumococcal conjugate vaccine, 13 valent', 'Pneumococcal conjugate P', '133', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(133, 'Japanese Encephalitis vaccine for intramuscular administration', 'Japanese Encephalitis IM', '134', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(134, 'influenza, high dose seasonal, preservative-free', 'Influenza, high dose sea', '135', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(135, 'meningococcal oligosaccharide (groups A, C, Y and W-135) diphtheria toxoid conjugate vaccine (MCV4O)', 'Meningococcal MCV4O', '136', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(136, 'HPV, unspecified formulation', 'HPV, unspecified formula', '137', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(137, 'tetanus and diphtheria toxoids, not adsorbed, for adult use', 'Td (adult)', '138', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(138, 'Td(adult) unspecified formulation', 'Td(adult) unspecified fo', '139', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(139, 'Influenza, seasonal, injectable, preservative free', 'Influenza, seasonal, inj', '140', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(140, 'Influenza, seasonal, injectable', 'Influenza, seasonal, inj', '141', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(141, 'tetanus toxoid, not adsorbed', 'tetanus toxoid, not adso', '142', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(142, 'Adenovirus, type 4 and type 7, live, oral', 'Adenovirus types 4 and 7', '143', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(143, 'no vaccine administered', 'no vaccine administered', '998', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(144, 'unknown vaccine or immune globulin', 'unknown', '999', 100, '', 0, 0.00, '', '', '', 0, 1, 0, 0),
(145,'ANESTHESIA SALIVARY GLANDS WITH BIOPSY','ANESTHESIA SALIVARY GLANDS WITH BIOPSY','00100','1','','1','0','','','',0, 1, 0, 0),
(146,'ANESTHESIA CLEFT LIP INVOLVING PLASTIC REPAIR','ANESTHESIA CLEFT LIP INVOLVING PLASTIC REPAIR','00102','1','','1','0','','','',0, 1, 0, 0),
(147,'ANESTHESIA EYELID RECONSTRUCTIVE PROCEDURE','ANESTHESIA EYELID RECONSTRUCTIVE PROCEDURE','00103','1','','1','0','','','',0, 1, 0, 0),
(148,'ANESTHESIA ELECTROCONVULSIVE THERAPY','ANESTHESIA ELECTROCONVULSIVE THERAPY','00104','1','','1','0','','','',0, 1, 0, 0),
(149,'ANESTHESIA EXTERNAL MIDDLE & INNER EAR W/BX NOS','ANESTHESIA EXTERNAL MIDDLE & INNER EAR W/BX NOS','00120','1','','1','0','','','',0, 1, 0, 0),
(150,'ANES EXTERNAL MIDDLE & INNER EAR W/BX OTOSCOPY','ANES EXTERNAL MIDDLE & INNER EAR W/BX OTOSCOPY','00124','1','','1','0','','','',0, 1, 0, 0),
(151,'ANES XTRNL MID & INNER EAR W/BX TYMPANOTOMY','ANES XTRNL MID & INNER EAR W/BX TYMPANOTOMY','00126','1','','1','0','','','',0, 1, 0, 0),
(152,'ANESTHESIA EYE NOT OTHERWISE SPECIFIED','ANESTHESIA EYE NOT OTHERWISE SPECIFIED','00140','1','','1','0','','','',0, 1, 0, 0),
(153,'ANESTHESIA EYE LENS SURGERY','ANESTHESIA EYE LENS SURGERY','00142','1','','1','0','','','',0, 1, 0, 0),
(154,'ANESTHESIA EYE CORNEAL TRANSPLANT','ANESTHESIA EYE CORNEAL TRANSPLANT','00144','1','','1','0','','','',0, 1, 0, 0),
(155,'ANESTHESIA EYE VITREORETINAL SURGERY','ANESTHESIA EYE VITREORETINAL SURGERY','00145','1','','1','0','','','',0, 1, 0, 0),
(156,'ANESTHESIA EYE IRIDECTOMY','ANESTHESIA EYE IRIDECTOMY','00147','1','','1','0','','','',0, 1, 0, 0),
(157,'ANESTHESIA EYE OPHTHALMOSCOPY','ANESTHESIA EYE OPHTHALMOSCOPY','00148','1','','1','0','','','',0, 1, 0, 0),
(158,'ANESTHESIA NOSE & ACCESSORY SINUSES NOS','ANESTHESIA NOSE & ACCESSORY SINUSES NOS','00160','1','','1','0','','','',0, 1, 0, 0),
(159,'ANES NOSE & ACCESSORY SINUSES RADICAL SURGERY','ANES NOSE & ACCESSORY SINUSES RADICAL SURGERY','00162','1','','1','0','','','',0, 1, 0, 0),
(160,'ANES NOSE & ACCESSORY SINUSES BIOPSY SOFT TISSUE','ANES NOSE & ACCESSORY SINUSES BIOPSY SOFT TISSUE','00164','1','','1','0','','','',0, 1, 0, 0),
(161,'ANESTHESIA INTRAORAL WITH BIOPSY NOS','ANESTHESIA INTRAORAL WITH BIOPSY NOS','00170','1','','1','0','','','',0, 1, 0, 0),
(162,'ANES INTRAORAL W/BIOPSY REPAIR CLEFT PALATE','ANES INTRAORAL W/BIOPSY REPAIR CLEFT PALATE','00172','1','','1','0','','','',0, 1, 0, 0),
(163,'ANES INTRAORAL W/BX EXC RETROPHARYNGEAL TUMOR','ANES INTRAORAL W/BX EXC RETROPHARYNGEAL TUMOR','00174','1','','1','0','','','',0, 1, 0, 0),
(164,'ANESTHESIA INTRAORAL W/BIOPSY RADICAL SURGERY','ANESTHESIA INTRAORAL W/BIOPSY RADICAL SURGERY','00176','1','','1','0','','','',0, 1, 0, 0),
(165,'ANESTHESIA FACIAL BONES OR SKULL NOS','ANESTHESIA FACIAL BONES OR SKULL NOS','00190','1','','1','0','','','',0, 1, 0, 0),
(166,'ANES FACIAL BONES/SKULL RAD SURG W/PROGNATHISM','ANES FACIAL BONES/SKULL RAD SURG W/PROGNATHISM','00192','1','','1','0','','','',0, 1, 0, 0),
(167,'ANESTHESIA INTRACRANIAL PROCEDURE NOS','ANESTHESIA INTRACRANIAL PROCEDURE NOS','00210','1','','1','0','','','',0, 1, 0, 0),
(168,'ANES INTRACRANIAL CRANIOTOMY/CRANIECTOMY HMTMA','ANES INTRACRANIAL CRANIOTOMY/CRANIECTOMY HMTMA','00211','1','','1','0','','','',0, 1, 0, 0),
(169,'ANESTHESIA INTRACRANIAL PROCEDURE SUBDURAL TAPS','ANESTHESIA INTRACRANIAL PROCEDURE SUBDURAL TAPS','00212','1','','1','0','','','',0, 1, 0, 0),
(170,'ANES INTRACRANIAL BURR HOLES W/VENTRICULOGRAPHY','ANES INTRACRANIAL BURR HOLES W/VENTRICULOGRAPHY','00214','1','','1','0','','','',0, 1, 0, 0),
(171,'ANES INTRACRANIAL/ELEVATION DEPRSD SKULL FX XDRL','ANES INTRACRANIAL/ELEVATION DEPRSD SKULL FX XDRL','00215','1','','1','0','','','',0, 1, 0, 0),
(172,'ANESTHESIA INTRACRANIAL VASCULAR PROCEDURE','ANESTHESIA INTRACRANIAL VASCULAR PROCEDURE','00216','1','','1','0','','','',0, 1, 0, 0),
(173,'ANES INTRACRANIAL PROCEDURE IN SITTING POSITION','ANES INTRACRANIAL PROCEDURE IN SITTING POSITION','00218','1','','1','0','','','',0, 1, 0, 0),
(174,'ANES INTRACRANIAL CEREBROSPINAL FLUID SHUNTING','ANES INTRACRANIAL CEREBROSPINAL FLUID SHUNTING','00220','1','','1','0','','','',0, 1, 0, 0),
(175,'ANES INTRACRANIAL ELECTROCOAGULATION ICRA NERVE','ANES INTRACRANIAL ELECTROCOAGULATION ICRA NERVE','00222','1','','1','0','','','',0, 1, 0, 0),
(176,'ANES INTEG MUSC & NRV HEAD NECK&POSTERIOR TRUNK','ANES INTEG MUSC & NRV HEAD NECK&POSTERIOR TRUNK','00300','1','','1','0','','','',0, 1, 0, 0),
(177,'ANES ESOPH THYRD LARYNX TRACH & LYMPH NECK 1YR','ANES ESOPH THYRD LARYNX TRACH & LYMPH NECK 1YR','00320','1','','1','0','','','',0, 1, 0, 0),
(178,'ANES ESOPH THYRD LARX TRACH & LYMPH NCK BX THYRD','ANES ESOPH THYRD LARX TRACH & LYMPH NCK BX THYRD','00322','1','','1','0','','','',0, 1, 0, 0),
(179,'ANESTHESIA LARYNX & TRACHEA CHILDREN <1 YEAR','ANESTHESIA LARYNX & TRACHEA CHILDREN <1 YEAR','00326','1','','1','0','','','',0, 1, 0, 0),
(180,'ANESTHESIA MAJOR VESSELS NECK NOS','ANESTHESIA MAJOR VESSELS NECK NOS','00350','1','','1','0','','','',0, 1, 0, 0),
(181,'ANESTHESIA MAJOR VESSELS NECK SIMPLE LIGATION','ANESTHESIA MAJOR VESSELS NECK SIMPLE LIGATION','00352','1','','1','0','','','',0, 1, 0, 0),
(182,'ANES INTEG EXTREMITIES ANT TRUNK & PERINEUM NOS','ANES INTEG EXTREMITIES ANT TRUNK & PERINEUM NOS','00400','1','','1','0','','','',0, 1, 0, 0),
(183,'ANESTHESIA RECONSTRUCTION BREAST','ANESTHESIA RECONSTRUCTION BREAST','00402','1','','1','0','','','',0, 1, 0, 0),
(184,'ANESTHESIA RADICAL/MODIFIED RADICAL BREAST','ANESTHESIA RADICAL/MODIFIED RADICAL BREAST','00404','1','','1','0','','','',0, 1, 0, 0),
(185,'ANES RADICAL/MODIFIED RADICAL BREAST W/NODES','ANES RADICAL/MODIFIED RADICAL BREAST W/NODES','00406','1','','1','0','','','',0, 1, 0, 0),
(186,'ANES INTEG SYS ELEC CONVERSION ARRHYTHMIAS','ANES INTEG SYS ELEC CONVERSION ARRHYTHMIAS','00410','1','','1','0','','','',0, 1, 0, 0),
(187,'ANESTHESIA CLAVICLE AND SCAPULA NOS','ANESTHESIA CLAVICLE AND SCAPULA NOS','00450','1','','1','0','','','',0, 1, 0, 0),
(188,'ANESTHESIA CLAVICLE & SCAPULA BIOPSY CLAVICLE','ANESTHESIA CLAVICLE & SCAPULA BIOPSY CLAVICLE','00454','1','','1','0','','','',0, 1, 0, 0),
(189,'ANESTHESIA PARTIAL RIB RESECTION NOS','ANESTHESIA PARTIAL RIB RESECTION NOS','00470','1','','1','0','','','',0, 1, 0, 0),
(190,'ANESTHESIA PARTIAL RIB RESECTION THORACOPLASTY','ANESTHESIA PARTIAL RIB RESECTION THORACOPLASTY','00472','1','','1','0','','','',0, 1, 0, 0),
(191,'ANESTHESIA PARTIAL RIB RESECTION RADICAL','ANESTHESIA PARTIAL RIB RESECTION RADICAL','00474','1','','1','0','','','',0, 1, 0, 0),
(192,'ANESTHESIA ESOPHAGUS','ANESTHESIA ESOPHAGUS','00500','1','','1','0','','','',0, 1, 0, 0),
(193,'ANESTHESIA CLOSED CHEST W/BRONCHOSCOPY NOS','ANESTHESIA CLOSED CHEST W/BRONCHOSCOPY NOS','00520','1','','1','0','','','',0, 1, 0, 0),
(194,'ANESTHESIA CLOSED CHEST NEEDLE BIOPSY PLEURA','ANESTHESIA CLOSED CHEST NEEDLE BIOPSY PLEURA','00522','1','','1','0','','','',0, 1, 0, 0),
(195,'ANESTHESIA CLOSED CHEST PNEUMOCENTESIS','ANESTHESIA CLOSED CHEST PNEUMOCENTESIS','00524','1','','1','0','','','',0, 1, 0, 0),
(196,'ANES MEDIASTINOSCOPY&THORACSCOPY W/O 1 LUNG VNTJ','ANES MEDIASTINOSCOPY&THORACSCOPY W/O 1 LUNG VNTJ','00528','1','','1','0','','','',0, 1, 0, 0),
(197,'ANES MEDIASTINOSCOPY&THORACOSCOPY W/1 LUNG VNT','ANES MEDIASTINOSCOPY&THORACOSCOPY W/1 LUNG VNT','00529','1','','1','0','','','',0, 1, 0, 0),
(198,'ANES PERMANENT TRANSVENOUS PACEMAKER INSERTION','ANES PERMANENT TRANSVENOUS PACEMAKER INSERTION','00530','1','','1','0','','','',0, 1, 0, 0),
(199,'ANESTHESIA ACCESS CENTRAL VENOUS CIRCULATION','ANESTHESIA ACCESS CENTRAL VENOUS CIRCULATION','00532','1','','1','0','','','',0, 1, 0, 0),
(200,'ANES TRANSVENOUS INSJ/REPLACEMENT PACING CVDFB','ANES TRANSVENOUS INSJ/REPLACEMENT PACING CVDFB','00534','1','','1','0','','','',0, 1, 0, 0),
(201,'ANES CARDIAC ELECTROPHYSIOL STDY W/RF ABLATION','ANES CARDIAC ELECTROPHYSIOL STDY W/RF ABLATION','00537','1','','1','0','','','',0, 1, 0, 0),
(202,'ANESTHESIA TRACHEOBRONCHIAL RECONSTRUCTION','ANESTHESIA TRACHEOBRONCHIAL RECONSTRUCTION','00539','1','','1','0','','','',0, 1, 0, 0),
(203,'ANES THORACOTOMY & THORACOSCOPY NOS','ANES THORACOTOMY & THORACOSCOPY NOS','00540','1','','1','0','','','',0, 1, 0, 0),
(204,'ANES THORACOTOMY & THORACOSCOPY W/1 LUNG VNTJ','ANES THORACOTOMY & THORACOSCOPY W/1 LUNG VNTJ','00541','1','','1','0','','','',0, 1, 0, 0),
(205,'ANES THORACOTOMY & THORACOSCOPY DECORTICATION','ANES THORACOTOMY & THORACOSCOPY DECORTICATION','00542','1','','1','0','','','',0, 1, 0, 0),
(206,'ANES THORACOTOMY & THORACOSCOPY PULMONARY RESC','ANES THORACOTOMY & THORACOSCOPY PULMONARY RESC','00546','1','','1','0','','','',0, 1, 0, 0),
(207,'ANES THORACOTOMY &THORACSCOPY TRACHEA & BRONCHI','ANES THORACOTOMY &THORACSCOPY TRACHEA & BRONCHI','00548','1','','1','0','','','',0, 1, 0, 0),
(208,'ANESTHESIA FOR STERNAL DEBRIDEMENT','ANESTHESIA FOR STERNAL DEBRIDEMENT','00550','1','','1','0','','','',0, 1, 0, 0),
(209,'ANES HRT PERICARDIAL SAC& GRT VESLS W/O PMP OXT','ANES HRT PERICARDIAL SAC& GRT VESLS W/O PMP OXT','00560','1','','1','0','','','',0, 1, 0, 0),
(210,'ANES HRT PERICARD SAC&GREAT VSLS W/PMP OXTJ <1YR','ANES HRT PERICARD SAC&GREAT VSLS W/PMP OXTJ <1YR','00561','1','','1','0','','','',0, 1, 0, 0),
(211,'ANES HRT PERICRD SAC&GRT VSLS W/PMP OXTJ >1MO PO','ANES HRT PERICRD SAC&GRT VSLS W/PMP OXTJ >1MO PO','00562','1','','1','0','','','',0, 1, 0, 0),
(212,'ANES HRT PRCRD SAC & GREAT VSL W/PUMP OXTJ HYPTH','ANES HRT PRCRD SAC & GREAT VSL W/PUMP OXTJ HYPTH','00563','1','','1','0','','','',0, 1, 0, 0),
(213,'ANES DIRECT CABG W/O PUMP OXYGENATOR','ANES DIRECT CABG W/O PUMP OXYGENATOR','00566','1','','1','0','','','',0, 1, 0, 0),
(214,'ANES DIRECT CABG W/PUMP OXYGENATOR','ANES DIRECT CABG W/PUMP OXYGENATOR','00567','1','','1','0','','','',0, 1, 0, 0),
(215,'ANES HEART TRANSPLANT/HEART/LUNG TRANSPLANT','ANES HEART TRANSPLANT/HEART/LUNG TRANSPLANT','00580','1','','1','0','','','',0, 1, 0, 0),
(216,'ANESTHESIA CERVICAL SPINE & CORD NOS','ANESTHESIA CERVICAL SPINE & CORD NOS','00600','1','','1','0','','','',0, 1, 0, 0),
(217,'ANES CERVICAL SPINE & CORD W/PATIENT SITTING','ANES CERVICAL SPINE & CORD W/PATIENT SITTING','00604','1','','1','0','','','',0, 1, 0, 0),
(218,'ANESTHESIA THORACIC SPINE & CORD NOS','ANESTHESIA THORACIC SPINE & CORD NOS','00620','1','','1','0','','','',0, 1, 0, 0),
(219,'ANES THRC SPINE & CORD ANT APPR W/O 1 LUNG VENTJ','ANES THRC SPINE & CORD ANT APPR W/O 1 LUNG VENTJ','00625','1','','1','0','','','',0, 1, 0, 0),
(220,'ANES THORACIC SPINE & CORD ANT APPR W/1 LNG VENT','ANES THORACIC SPINE & CORD ANT APPR W/1 LNG VENT','00626','1','','1','0','','','',0, 1, 0, 0),
(221,'ANESTHESIA LUMBAR REGION NOS','ANESTHESIA LUMBAR REGION NOS','00630','1','','1','0','','','',0, 1, 0, 0),
(222,'ANESTHESIA LUMBAR REGION LUMBAR SYMPATHECTOMY','ANESTHESIA LUMBAR REGION LUMBAR SYMPATHECTOMY','00632','1','','1','0','','','',0, 1, 0, 0),
(223,'ANES DIAGNOSTIC/THERAPEUTIC LUMBAR PUNCTURE','ANES DIAGNOSTIC/THERAPEUTIC LUMBAR PUNCTURE','00635','1','','1','0','','','',0, 1, 0, 0),
(224,'ANES MANIPULATE SPINE/CLSD CRV THORC/LUMBR SPINE','ANES MANIPULATE SPINE/CLSD CRV THORC/LUMBR SPINE','00640','1','','1','0','','','',0, 1, 0, 0),
(225,'ANESTHESIA EXTENSIVE SPINE & SPINAL CORD','ANESTHESIA EXTENSIVE SPINE & SPINAL CORD','00670','1','','1','0','','','',0, 1, 0, 0),
(226,'ANESTHESIA UPPER ANTERIOR ABDOMINAL WALL NOS','ANESTHESIA UPPER ANTERIOR ABDOMINAL WALL NOS','00700','1','','1','0','','','',0, 1, 0, 0),
(227,'ANES UPR ANT ABDL WALL PERCUTANEOUS LIVER BX','ANES UPR ANT ABDL WALL PERCUTANEOUS LIVER BX','00702','1','','1','0','','','',0, 1, 0, 0),
(228,'ANESTHESIA UPPER POSTERIOR ABDOMINAL WALL','ANESTHESIA UPPER POSTERIOR ABDOMINAL WALL','00730','1','','1','0','','','',0, 1, 0, 0),
(229,'ANES UPPER GI ENDOSCOPY PROXIMAL TO DUODENUM','ANES UPPER GI ENDOSCOPY PROXIMAL TO DUODENUM','00740','1','','1','0','','','',0, 1, 0, 0),
(230,'ANESTHESIA HERNIA REPAIR UPPER ABDOMEN NOS','ANESTHESIA HERNIA REPAIR UPPER ABDOMEN NOS','00750','1','','1','0','','','',0, 1, 0, 0),
(231,'ANES HRNA RPR UPR ABD LMBR&VENTRAL HERNIA&DEHISC','ANES HRNA RPR UPR ABD LMBR&VENTRAL HERNIA&DEHISC','00752','1','','1','0','','','',0, 1, 0, 0),
(232,'ANES HERNIA REPAIR UPPER ABDOMEN OMPHALOCELE','ANES HERNIA REPAIR UPPER ABDOMEN OMPHALOCELE','00754','1','','1','0','','','',0, 1, 0, 0),
(233,'ANES HRNA REPAIR UPR ABD TABDL RPR DIPHRG HRNA','ANES HRNA REPAIR UPR ABD TABDL RPR DIPHRG HRNA','00756','1','','1','0','','','',0, 1, 0, 0),
(234,'ANESTHESIA MAJOR ABDOMINAL BLOOD VESSELS','ANESTHESIA MAJOR ABDOMINAL BLOOD VESSELS','00770','1','','1','0','','','',0, 1, 0, 0),
(235,'ANES INTRAPERITONEAL UPPER ABDOMEN W/LAPS NOS','ANES INTRAPERITONEAL UPPER ABDOMEN W/LAPS NOS','00790','1','','1','0','','','',0, 1, 0, 0),
(236,'ANES LAPS PARTIAL HEPATECTOMY W/MGMT LIVER HEMOR','ANES LAPS PARTIAL HEPATECTOMY W/MGMT LIVER HEMOR','00792','1','','1','0','','','',0, 1, 0, 0),
(237,'ANES LAPAROSCOPIC PARTIAL/TOTAL PANCREATECTOMY','ANES LAPAROSCOPIC PARTIAL/TOTAL PANCREATECTOMY','00794','1','','1','0','','','',0, 1, 0, 0),
(238,'ANES LAPAROSCOPIC LIVER TRANSPLANT','ANES LAPAROSCOPIC LIVER TRANSPLANT','00796','1','','1','0','','','',0, 1, 0, 0),
(239,'ANES IPR UPPER ABDOMEN LAPS GASTRIC RSTCV MO','ANES IPR UPPER ABDOMEN LAPS GASTRIC RSTCV MO','00797','1','','1','0','','','',0, 1, 0, 0),
(240,'ANESTHESIA LOWER ANTERIOR ABDOMINAL WALL NOS','ANESTHESIA LOWER ANTERIOR ABDOMINAL WALL NOS','00800','1','','1','0','','','',0, 1, 0, 0),
(241,'ANES LOWER ANT ABDOMINAL WALL PANNICULECTOMY','ANES LOWER ANT ABDOMINAL WALL PANNICULECTOMY','00802','1','','1','0','','','',0, 1, 0, 0),
(242,'ANES LOWER INTESTINE ENDOSCOPY DISTAL DUODENUM','ANES LOWER INTESTINE ENDOSCOPY DISTAL DUODENUM','00810','1','','1','0','','','',0, 1, 0, 0),
(243,'ANESTHESIA LOWER POSTERIOR ABDOMINAL WALL','ANESTHESIA LOWER POSTERIOR ABDOMINAL WALL','00820','1','','1','0','','','',0, 1, 0, 0),
(244,'ANESTHESIA HERNIA REPAIR LOWER ABDOMEN NOS','ANESTHESIA HERNIA REPAIR LOWER ABDOMEN NOS','00830','1','','1','0','','','',0, 1, 0, 0),
(245,'ANES LWR ABD VENTRAL & INCISIONAL HERNIA REPAIR','ANES LWR ABD VENTRAL & INCISIONAL HERNIA REPAIR','00832','1','','1','0','','','',0, 1, 0, 0),
(246,'ANES HERNIA REPAIR LOWER ABDOMEN NOS & 1YR AGE','ANES HERNIA REPAIR LOWER ABDOMEN NOS & 1YR AGE','00834','1','','1','0','','','',0, 1, 0, 0),
(247,'ANES HRNA RPR LWR ABD NOS INFTS <37WK BRTH/50WK','ANES HRNA RPR LWR ABD NOS INFTS <37WK BRTH/50WK','00836','1','','1','0','','','',0, 1, 0, 0),
(248,'ANESTHESIA INTRAPERITONEAL LOWER ABD W/LAPS NOS','ANESTHESIA INTRAPERITONEAL LOWER ABD W/LAPS NOS','00840','1','','1','0','','','',0, 1, 0, 0),
(249,'ANES IPER LOWER ABDOMEN W/LAPS AMNIOCENTESIS','ANES IPER LOWER ABDOMEN W/LAPS AMNIOCENTESIS','00842','1','','1','0','','','',0, 1, 0, 0),
(250,'ANES IPER LOWER ABD W/LAPS ABDOMINOPRNL RESCJ','ANES IPER LOWER ABD W/LAPS ABDOMINOPRNL RESCJ','00844','1','','1','0','','','',0, 1, 0, 0),
(251,'ANES IPER LOWER ABD W/LAPS RAD HYSTERECTOMY','ANES IPER LOWER ABD W/LAPS RAD HYSTERECTOMY','00846','1','','1','0','','','',0, 1, 0, 0),
(252,'ANES IPER LOWER ABD W/LAPS PELVIC EXENTERATION','ANES IPER LOWER ABD W/LAPS PELVIC EXENTERATION','00848','1','','1','0','','','',0, 1, 0, 0),
(253,'ANES IPER LWR ABD W/LAPS TUBAL LIGATION/TRANSECT','ANES IPER LWR ABD W/LAPS TUBAL LIGATION/TRANSECT','00851','1','','1','0','','','',0, 1, 0, 0),
(254,'ANES EXTRAPERITONEAL LWR ABD W/URINARY TRACT NOS','ANES EXTRAPERITONEAL LWR ABD W/URINARY TRACT NOS','00860','1','','1','0','','','',0, 1, 0, 0),
(255,'ANES XTRPRTL LOWER ABD UR TRACT RENAL DON NFRCT','ANES XTRPRTL LOWER ABD UR TRACT RENAL DON NFRCT','00862','1','','1','0','','','',0, 1, 0, 0),
(256,'ANES XTRPRTL LWER ABD W/URINARY TRACT TOT CYSTEC','ANES XTRPRTL LWER ABD W/URINARY TRACT TOT CYSTEC','00864','1','','1','0','','','',0, 1, 0, 0),
(257,'ANES XTRPRTL LWR ABD W/URINARY TRACT RAD PRSTECT','ANES XTRPRTL LWR ABD W/URINARY TRACT RAD PRSTECT','00865','1','','1','0','','','',0, 1, 0, 0),
(258,'ANES XTRPRTL LOWER ABD W/URIN TRACT ADRENLECTOMY','ANES XTRPRTL LOWER ABD W/URIN TRACT ADRENLECTOMY','00866','1','','1','0','','','',0, 1, 0, 0),
(259,'ANES XTRPRTL LWR ABD W/URIN TRACT RENAL TRANSPL','ANES XTRPRTL LWR ABD W/URIN TRACT RENAL TRANSPL','00868','1','','1','0','','','',0, 1, 0, 0),
(260,'ANES XTRPRTL LWR ABD W/URIN TRACT CSTOLITHOTOMY','ANES XTRPRTL LWR ABD W/URIN TRACT CSTOLITHOTOMY','00870','1','','1','0','','','',0, 1, 0, 0),
(261,'ANES LITHOTRP XTRCORP SHOCK WAVE W/WATER BATH','ANES LITHOTRP XTRCORP SHOCK WAVE W/WATER BATH','00872','1','','1','0','','','',0, 1, 0, 0),
(262,'ANES LITHOTRP XTRCORP SHOCK WAVE W/O WATER BATH','ANES LITHOTRP XTRCORP SHOCK WAVE W/O WATER BATH','00873','1','','1','0','','','',0, 1, 0, 0),
(263,'ANESTHESIA MAJOR LOWER ABDOMINAL VESSELS NOS','ANESTHESIA MAJOR LOWER ABDOMINAL VESSELS NOS','00880','1','','1','0','','','',0, 1, 0, 0),
(264,'ANES MAJOR LOWER ABDOMINAL VESSELS IVC LIGATION','ANES MAJOR LOWER ABDOMINAL VESSELS IVC LIGATION','00882','1','','1','0','','','',0, 1, 0, 0),
(265,'ANESTHESIA ANORECTAL PROCEDURE','ANESTHESIA ANORECTAL PROCEDURE','00902','1','','1','0','','','',0, 1, 0, 0),
(266,'ANESTHESIA RADICAL PERINEAL PROCEDURE','ANESTHESIA RADICAL PERINEAL PROCEDURE','00904','1','','1','0','','','',0, 1, 0, 0),
(267,'ANESTHESIA VULVECTOMY','ANESTHESIA VULVECTOMY','00906','1','','1','0','','','',0, 1, 0, 0),
(268,'ANESTHESIA PERINEAL PROSTATECTOMY','ANESTHESIA PERINEAL PROSTATECTOMY','00908','1','','1','0','','','',0, 1, 0, 0),
(269,'ANES TRANSURETHRAL W/URETHROCYSTOSCOPY NOS','ANES TRANSURETHRAL W/URETHROCYSTOSCOPY NOS','00910','1','','1','0','','','',0, 1, 0, 0),
(270,'ANES TRANSURETHRAL RESECTION OF BLADDER TUMOR','ANES TRANSURETHRAL RESECTION OF BLADDER TUMOR','00912','1','','1','0','','','',0, 1, 0, 0),
(271,'ANESTHESIA TRANSURETHRAL RESECTION OF PROSTATE','ANESTHESIA TRANSURETHRAL RESECTION OF PROSTATE','00914','1','','1','0','','','',0, 1, 0, 0),
(272,'ANES TRURL POST-TRURL RESECTION BLEEDING','ANES TRURL POST-TRURL RESECTION BLEEDING','00916','1','','1','0','','','',0, 1, 0, 0),
(273,'ANES TRURL FRAGMNTJ MANJ&/RMVL URETERAL CALCULUS','ANES TRURL FRAGMNTJ MANJ&/RMVL URETERAL CALCULUS','00918','1','','1','0','','','',0, 1, 0, 0),
(274,'ANESTHESIA MALE GENITALIA INCL OPEN URETHRAL PX','ANESTHESIA MALE GENITALIA INCL OPEN URETHRAL PX','00920','1','','1','0','','','',0, 1, 0, 0),
(275,'ANES VASECTOMY UNI/BI INCL OPEN URETHRAL PX','ANES VASECTOMY UNI/BI INCL OPEN URETHRAL PX','00921','1','','1','0','','','',0, 1, 0, 0),
(276,'ANES SEMINAL VESICLES INCL OPEN URETHRAL PX','ANES SEMINAL VESICLES INCL OPEN URETHRAL PX','00922','1','','1','0','','','',0, 1, 0, 0),
(277,'ANES UNDSCND TESTIS UNI/BI INCL OPEN URTL PX','ANES UNDSCND TESTIS UNI/BI INCL OPEN URTL PX','00924','1','','1','0','','','',0, 1, 0, 0),
(278,'ANES RAD ORCHIECTOMY INGUN INCL OPEN URTL PX','ANES RAD ORCHIECTOMY INGUN INCL OPEN URTL PX','00926','1','','1','0','','','',0, 1, 0, 0),
(279,'ANES RAD ORCHIECTOMY ABDOMINAL INCL OPN URTL','ANES RAD ORCHIECTOMY ABDOMINAL INCL OPN URTL','00928','1','','1','0','','','',0, 1, 0, 0),
(280,'ANES ORCHIOPEXY UNI/BI INCL OPEN URETHRAL PX','ANES ORCHIOPEXY UNI/BI INCL OPEN URETHRAL PX','00930','1','','1','0','','','',0, 1, 0, 0),
(281,'ANES COMPLETE AMPUTATION PENIS INCL OPEN URTL','ANES COMPLETE AMPUTATION PENIS INCL OPEN URTL','00932','1','','1','0','','','',0, 1, 0, 0),
(282,'ANES RAD AMP PENIS W/BI INGUINAL LYMPH NODE RMVL','ANES RAD AMP PENIS W/BI INGUINAL LYMPH NODE RMVL','00934','1','','1','0','','','',0, 1, 0, 0),
(283,'ANES RAD AMP PENIS W/BI INGUNL&ILIAC LYMPH RMOVL','ANES RAD AMP PENIS W/BI INGUNL&ILIAC LYMPH RMOVL','00936','1','','1','0','','','',0, 1, 0, 0),
(284,'ANES INSJ PENILE PROSTH PRNL INCL OPEN URTL','ANES INSJ PENILE PROSTH PRNL INCL OPEN URTL','00938','1','','1','0','','','',0, 1, 0, 0),
(285,'ANESTHESIA VAGINAL PROCEDURE W/BIOPSY NOS','ANESTHESIA VAGINAL PROCEDURE W/BIOPSY NOS','00940','1','','1','0','','','',0, 1, 0, 0),
(286,'ANES COLPTMY VAGNC COLPRPHY INCL BX W/OPN URTL','ANES COLPTMY VAGNC COLPRPHY INCL BX W/OPN URTL','00942','1','','1','0','','','',0, 1, 0, 0),
(287,'ANESTHESIA VAGINAL HYSTERECTOMY INCL BIOPSY','ANESTHESIA VAGINAL HYSTERECTOMY INCL BIOPSY','00944','1','','1','0','','','',0, 1, 0, 0),
(288,'ANESTHESIA CERVICAL CERCLAGE INCLUDING BIOPSY','ANESTHESIA CERVICAL CERCLAGE INCLUDING BIOPSY','00948','1','','1','0','','','',0, 1, 0, 0),
(289,'ANESTHESIA CULDOSCOPY INCLUDING BIOPSY','ANESTHESIA CULDOSCOPY INCLUDING BIOPSY','00950','1','','1','0','','','',0, 1, 0, 0),
(290,'ANES HYSTEROSCOPY&/HYSTEROSALPINGOGRAPHY W/BX','ANES HYSTEROSCOPY&/HYSTEROSALPINGOGRAPHY W/BX','00952','1','','1','0','','','',0, 1, 0, 0),
(291,'ANES BONE MARROW ASPIR&/BX ANT/PST ILIAC CREST','ANES BONE MARROW ASPIR&/BX ANT/PST ILIAC CREST','01112','1','','1','0','','','',0, 1, 0, 0),
(292,'ANESTHESIA ON BONY PELVIS','ANESTHESIA ON BONY PELVIS','01120','1','','1','0','','','',0, 1, 0, 0),
(293,'ANESTHESIA BODY CAST APPLICATION OR REVISION','ANESTHESIA BODY CAST APPLICATION OR REVISION','01130','1','','1','0','','','',0, 1, 0, 0),
(294,'ANESTHESIA INTERPELVI ABDOMINAL AMPUTATION','ANESTHESIA INTERPELVI ABDOMINAL AMPUTATION','01140','1','','1','0','','','',0, 1, 0, 0),
(295,'ANES RADICAL TUMOR PELVIS XCP HINDQUARTER AMP','ANES RADICAL TUMOR PELVIS XCP HINDQUARTER AMP','01150','1','','1','0','','','',0, 1, 0, 0),
(296,'ANES CLOSED SYMPHYSIS PUBIS/SACROILIAC JOINT','ANES CLOSED SYMPHYSIS PUBIS/SACROILIAC JOINT','01160','1','','1','0','','','',0, 1, 0, 0),
(297,'ANES OPEN SYMPHYSIS PUBIS/SACROILIAC JOINT','ANES OPEN SYMPHYSIS PUBIS/SACROILIAC JOINT','01170','1','','1','0','','','',0, 1, 0, 0),
(298,'ANES OPN RPR DISRPJ PELVIS/COLUMN FX ACETABULUM','ANES OPN RPR DISRPJ PELVIS/COLUMN FX ACETABULUM','01173','1','','1','0','','','',0, 1, 0, 0),
(299,'ANESTHESIA OBTURATOR NEURECTOMY EXTRAPELVIC','ANESTHESIA OBTURATOR NEURECTOMY EXTRAPELVIC','01180','1','','1','0','','','',0, 1, 0, 0),
(300,'ANESTHESIA OBTURATOR NEURECTOMY INTRAPELVIC','ANESTHESIA OBTURATOR NEURECTOMY INTRAPELVIC','01190','1','','1','0','','','',0, 1, 0, 0),
(301,'ANESTHESIA CLOSED HIP JOINT PROCEDURE','ANESTHESIA CLOSED HIP JOINT PROCEDURE','01200','1','','1','0','','','',0, 1, 0, 0),
(302,'ANESTHESIA ARTHROSCOPIC HIP JOINT PROCEDURE','ANESTHESIA ARTHROSCOPIC HIP JOINT PROCEDURE','01202','1','','1','0','','','',0, 1, 0, 0),
(303,'ANESTHESIA OPEN HIP JOINT PROCEDURE NOS','ANESTHESIA OPEN HIP JOINT PROCEDURE NOS','01210','1','','1','0','','','',0, 1, 0, 0),
(304,'ANESTHESIA OPEN HIP JOINT DISARTICULATION','ANESTHESIA OPEN HIP JOINT DISARTICULATION','01212','1','','1','0','','','',0, 1, 0, 0),
(305,'ANESTHESIA OPEN TOTAL HIP ARTHROPLASTY','ANESTHESIA OPEN TOTAL HIP ARTHROPLASTY','01214','1','','1','0','','','',0, 1, 0, 0),
(306,'ANESTHESIA OPEN REVISION TOTAL HIP ARTHROPLASTY','ANESTHESIA OPEN REVISION TOTAL HIP ARTHROPLASTY','01215','1','','1','0','','','',0, 1, 0, 0),
(307,'ANESTHESIA CLOSED PROCEDURES UPPER 2/3 FEMUR','ANESTHESIA CLOSED PROCEDURES UPPER 2/3 FEMUR','01220','1','','1','0','','','',0, 1, 0, 0),
(308,'ANESTHESIA OPEN PROCEDURES UPPER 2/3 FEMUR NOS','ANESTHESIA OPEN PROCEDURES UPPER 2/3 FEMUR NOS','01230','1','','1','0','','','',0, 1, 0, 0),
(309,'ANESTHESIA UPPER 2/3 FEMUR AMPUTATION','ANESTHESIA UPPER 2/3 FEMUR AMPUTATION','01232','1','','1','0','','','',0, 1, 0, 0),
(310,'ANES UPPER 2/3 FEMUR RADICAL RESCECTION','ANES UPPER 2/3 FEMUR RADICAL RESCECTION','01234','1','','1','0','','','',0, 1, 0, 0),
(311,'ANES NERVE MUSC TENDON FASCIA & BURSAE UPPER LEG','ANES NERVE MUSC TENDON FASCIA & BURSAE UPPER LEG','01250','1','','1','0','','','',0, 1, 0, 0),
(312,'ANES VEINS OF UPPER LEG INCLUDING EXPLORATION','ANES VEINS OF UPPER LEG INCLUDING EXPLORATION','01260','1','','1','0','','','',0, 1, 0, 0),
(313,'ANESTHESIA ARTERIES UPPER LEG INCL BYPASS GRAFT','ANESTHESIA ARTERIES UPPER LEG INCL BYPASS GRAFT','01270','1','','1','0','','','',0, 1, 0, 0),
(314,'ANES ART UPPER LEG W/BYPASS GRAFT FEM ART LIG','ANES ART UPPER LEG W/BYPASS GRAFT FEM ART LIG','01272','1','','1','0','','','',0, 1, 0, 0),
(315,'ANES UPPER LEG W/BYPASS GRFT FEM ART EMBOLECTOMY','ANES UPPER LEG W/BYPASS GRFT FEM ART EMBOLECTOMY','01274','1','','1','0','','','',0, 1, 0, 0),
(316,'ANES NERVE MUSC TENDON FASCIA&BURSA KNEE&/POPLT','ANES NERVE MUSC TENDON FASCIA&BURSA KNEE&/POPLT','01320','1','','1','0','','','',0, 1, 0, 0),
(317,'ANESTHESIA CLOSED PROCEDURES LOWER 1/3 FEMUR','ANESTHESIA CLOSED PROCEDURES LOWER 1/3 FEMUR','01340','1','','1','0','','','',0, 1, 0, 0),
(318,'ANESTHESIA OPEN PROCEDURES LOWER 1/3 FEMUR','ANESTHESIA OPEN PROCEDURES LOWER 1/3 FEMUR','01360','1','','1','0','','','',0, 1, 0, 0),
(319,'ANESTHESIA CLOSED PROCEDURES KNEE JOINT','ANESTHESIA CLOSED PROCEDURES KNEE JOINT','01380','1','','1','0','','','',0, 1, 0, 0),
(320,'ANESTH DIAGNOSTIC ARTHROSCOPIC PROC KNEE JOINT','ANESTH DIAGNOSTIC ARTHROSCOPIC PROC KNEE JOINT','01382','1','','1','0','','','',0, 1, 0, 0),
(321,'ANES CLOSED PROC UPPER END TIBIA FIBULA/PATELLA','ANES CLOSED PROC UPPER END TIBIA FIBULA/PATELLA','01390','1','','1','0','','','',0, 1, 0, 0),
(322,'ANES OPEN PROC UPPER ENDS TIBIA FIBULA&/PATELLA','ANES OPEN PROC UPPER ENDS TIBIA FIBULA&/PATELLA','01392','1','','1','0','','','',0, 1, 0, 0),
(323,'ANES OPEN/SURG ARTHROSCOPIC PROC KNEE JOINT NOS','ANES OPEN/SURG ARTHROSCOPIC PROC KNEE JOINT NOS','01400','1','','1','0','','','',0, 1, 0, 0),
(324,'ANESTH OPEN/SURG ARTHRS TOTAL KNEE ARTHROPLASTY','ANESTH OPEN/SURG ARTHRS TOTAL KNEE ARTHROPLASTY','01402','1','','1','0','','','',0, 1, 0, 0),
(325,'ANESTH OPEN/SURG ARTHRS KNEE DISARTICULATION','ANESTH OPEN/SURG ARTHRS KNEE DISARTICULATION','01404','1','','1','0','','','',0, 1, 0, 0),
(326,'ANES CAST APPLICATION REMOVAL/REPAIR KNEE JOINT','ANES CAST APPLICATION REMOVAL/REPAIR KNEE JOINT','01420','1','','1','0','','','',0, 1, 0, 0),
(327,'ANESTHESIA VEINS KNEE & POPLITEAL AREA NOS','ANESTHESIA VEINS KNEE & POPLITEAL AREA NOS','01430','1','','1','0','','','',0, 1, 0, 0),
(328,'ANES KNEE & POPLITEAL ARTERY VEIN FISTULA NOS','ANES KNEE & POPLITEAL ARTERY VEIN FISTULA NOS','01432','1','','1','0','','','',0, 1, 0, 0),
(329,'ANES ARTERIES OF KNEE & POPLITEAL AREA NOS','ANES ARTERIES OF KNEE & POPLITEAL AREA NOS','01440','1','','1','0','','','',0, 1, 0, 0),
(330,'ANES ART KNEE POPLITEAL TEAEC W/WO PATCH GRAFT','ANES ART KNEE POPLITEAL TEAEC W/WO PATCH GRAFT','01442','1','','1','0','','','',0, 1, 0, 0),
(331,'ANES ART KNEE POPLITEAL EXC&GRF/RPR OCCLS/ARYS','ANES ART KNEE POPLITEAL EXC&GRF/RPR OCCLS/ARYS','01444','1','','1','0','','','',0, 1, 0, 0),
(332,'ANESTHESIA CLOSED PROC LOWER LEG ANKLE & FOOT','ANESTHESIA CLOSED PROC LOWER LEG ANKLE & FOOT','01462','1','','1','0','','','',0, 1, 0, 0),
(333,'ANESTHESIA ARTHROSCOPIC PROCEDURE ANKLE & FOOT','ANESTHESIA ARTHROSCOPIC PROCEDURE ANKLE & FOOT','01464','1','','1','0','','','',0, 1, 0, 0),
(334,'ANES NRV/MUS/TND/FASC LOWER LEG/ANKLE/FOOT NOS','ANES NRV/MUS/TND/FASC LOWER LEG/ANKLE/FOOT NOS','01470','1','','1','0','','','',0, 1, 0, 0),
(335,'ANES RPR RUPTURED ACHILLES TENDON W/WO GRAFT','ANES RPR RUPTURED ACHILLES TENDON W/WO GRAFT','01472','1','','1','0','','','',0, 1, 0, 0),
(336,'ANESTHESIA GASTROCNEMIUS RECESSION','ANESTHESIA GASTROCNEMIUS RECESSION','01474','1','','1','0','','','',0, 1, 0, 0),
(337,'ANES OPEN PROC BONES LOWER LEG/ANKLE/FOOT NOS','ANES OPEN PROC BONES LOWER LEG/ANKLE/FOOT NOS','01480','1','','1','0','','','',0, 1, 0, 0),
(338,'ANES RADICAL RESECJ INCL BELOW KNEE AMPUTATION','ANES RADICAL RESECJ INCL BELOW KNEE AMPUTATION','01482','1','','1','0','','','',0, 1, 0, 0),
(339,'ANES OPEN OSTEOTOMY/OSTEOPLASTY TIBIA&/FIBULA','ANES OPEN OSTEOTOMY/OSTEOPLASTY TIBIA&/FIBULA','01484','1','','1','0','','','',0, 1, 0, 0),
(340,'ANESTHESIA OPEN TOTAL ANKLE REPLACEMENT','ANESTHESIA OPEN TOTAL ANKLE REPLACEMENT','01486','1','','1','0','','','',0, 1, 0, 0),
(341,'ANES LOWER LEG CAST APPLICATION REMOVAL/REPAIR','ANES LOWER LEG CAST APPLICATION REMOVAL/REPAIR','01490','1','','1','0','','','',0, 1, 0, 0),
(342,'ANESTHESIA ARTERIES LOWER LEG W/BYPASS GRAFT NOS','ANESTHESIA ARTERIES LOWER LEG W/BYPASS GRAFT NOS','01500','1','','1','0','','','',0, 1, 0, 0),
(343,'ANES ART LOWER LEG W/BYP GRAFT EMBLC DIR/W/CATH','ANES ART LOWER LEG W/BYP GRAFT EMBLC DIR/W/CATH','01502','1','','1','0','','','',0, 1, 0, 0),
(344,'ANESTHESIA VEINS OF LOWER LEG NOS','ANESTHESIA VEINS OF LOWER LEG NOS','01520','1','','1','0','','','',0, 1, 0, 0),
(345,'ANES VEINS LOWER LEG VENOUS THRMBC DIR/W/CATH','ANES VEINS LOWER LEG VENOUS THRMBC DIR/W/CATH','01522','1','','1','0','','','',0, 1, 0, 0),
(346,'ANES NRV MUSC TNDN FSCIA BURSA SHOULDER & AXILLA','ANES NRV MUSC TNDN FSCIA BURSA SHOULDER & AXILLA','01610','1','','1','0','','','',0, 1, 0, 0),
(347,'ANES CLOSED HUMRL H/N STRNCLAV JOINT& SHO JOINT','ANES CLOSED HUMRL H/N STRNCLAV JOINT& SHO JOINT','01620','1','','1','0','','','',0, 1, 0, 0),
(348,'ANES DIAG ARTHROSCOPIC SHOULDER JOINT PROC NOS','ANES DIAG ARTHROSCOPIC SHOULDER JOINT PROC NOS','01622','1','','1','0','','','',0, 1, 0, 0),
(349,'ANES ARTHRS HUMERAL H/N STRNCLAV & SHOULDER NOS','ANES ARTHRS HUMERAL H/N STRNCLAV & SHOULDER NOS','01630','1','','1','0','','','',0, 1, 0, 0),
(350,'ANESTHESIA ARTHROSCOPIC SHOULDER DISARTICULATION','ANESTHESIA ARTHROSCOPIC SHOULDER DISARTICULATION','01634','1','','1','0','','','',0, 1, 0, 0),
(351,'ANES ARTHRS INTERTHORACOSCAPULAR AMPUTATION','ANES ARTHRS INTERTHORACOSCAPULAR AMPUTATION','01636','1','','1','0','','','',0, 1, 0, 0),
(352,'ANES ARTHROSCOPIC TOTAL SHOULDER REPLACEMENT','ANES ARTHROSCOPIC TOTAL SHOULDER REPLACEMENT','01638','1','','1','0','','','',0, 1, 0, 0),
(353,'ANESTHESIA ARTERIES SHOULDER & AXILLA NOS','ANESTHESIA ARTERIES SHOULDER & AXILLA NOS','01650','1','','1','0','','','',0, 1, 0, 0),
(354,'ANESTHESIA AXILLARY-BRACHIAL ANEURYSM','ANESTHESIA AXILLARY-BRACHIAL ANEURYSM','01652','1','','1','0','','','',0, 1, 0, 0),
(355,'ANES ARTERIES SHOULDER & AXILLA BYPASS GRAFT','ANES ARTERIES SHOULDER & AXILLA BYPASS GRAFT','01654','1','','1','0','','','',0, 1, 0, 0),
(356,'ANESTHESIA AXILLARY-FEMORAL BYPASS GRAFT','ANESTHESIA AXILLARY-FEMORAL BYPASS GRAFT','01656','1','','1','0','','','',0, 1, 0, 0),
(357,'ANESTHESIA VEINS SHOULDER & AXILLA','ANESTHESIA VEINS SHOULDER & AXILLA','01670','1','','1','0','','','',0, 1, 0, 0),
(358,'ANES SHOULDER CAST APPL REMOVAL/REPAIR NOS','ANES SHOULDER CAST APPL REMOVAL/REPAIR NOS','01680','1','','1','0','','','',0, 1, 0, 0),
(359,'ANES SHOULDER SPICA APPLICATION REMOVAL/REPAIR','ANES SHOULDER SPICA APPLICATION REMOVAL/REPAIR','01682','1','','1','0','','','',0, 1, 0, 0),
(360,'ANES NRV MUSC TDN FSCA&BRS UPR ARM/ELBOW NOS','ANES NRV MUSC TDN FSCA&BRS UPR ARM/ELBOW NOS','01710','1','','1','0','','','',0, 1, 0, 0),
(361,'ANESTHESIA OPEN TENOTOMY ELBOW TO SHOULDER','ANESTHESIA OPEN TENOTOMY ELBOW TO SHOULDER','01712','1','','1','0','','','',0, 1, 0, 0),
(362,'ANESTHESIA TENOPLASTY ELBOW TO SHOULDER','ANESTHESIA TENOPLASTY ELBOW TO SHOULDER','01714','1','','1','0','','','',0, 1, 0, 0),
(363,'ANESTHESIA BICEPS TENODESIS RUPTURE LONG TENDON','ANESTHESIA BICEPS TENODESIS RUPTURE LONG TENDON','01716','1','','1','0','','','',0, 1, 0, 0),
(364,'ANESTHESIA CLOSED PROCEDURES HUMERUS & ELBOW','ANESTHESIA CLOSED PROCEDURES HUMERUS & ELBOW','01730','1','','1','0','','','',0, 1, 0, 0),
(365,'ANESTHESIA ELBOW JOINT DIAGNOSTIC ARTHROSCOPIC','ANESTHESIA ELBOW JOINT DIAGNOSTIC ARTHROSCOPIC','01732','1','','1','0','','','',0, 1, 0, 0),
(366,'ANES OPEN/SURG ARTHROSCOPIC ELBOW PROC NOS','ANES OPEN/SURG ARTHROSCOPIC ELBOW PROC NOS','01740','1','','1','0','','','',0, 1, 0, 0),
(367,'ANESTHESIA OPEN/SURG ARTHRS OSTEOTOMY HUMERUS','ANESTHESIA OPEN/SURG ARTHRS OSTEOTOMY HUMERUS','01742','1','','1','0','','','',0, 1, 0, 0),
(368,'ANES OPEN/SURG ARTHRS REPRS NON/MALUNION HUMERUS','ANES OPEN/SURG ARTHRS REPRS NON/MALUNION HUMERUS','01744','1','','1','0','','','',0, 1, 0, 0),
(369,'ANESTHESIA OPEN/SURG ARTHRS RADICAL PROC ELBOW','ANESTHESIA OPEN/SURG ARTHRS RADICAL PROC ELBOW','01756','1','','1','0','','','',0, 1, 0, 0),
(370,'ANESTH OPEN/SURG ARTHRS EXC CYST/TUMOR HUMERUS','ANESTH OPEN/SURG ARTHRS EXC CYST/TUMOR HUMERUS','01758','1','','1','0','','','',0, 1, 0, 0),
(371,'ANESTH OPEN/SURG ARTHRS TOTAL ELBOW REPLACEMENT','ANESTH OPEN/SURG ARTHRS TOTAL ELBOW REPLACEMENT','01760','1','','1','0','','','',0, 1, 0, 0),
(372,'ANESTHESIA ARTERIES UPPER ARM & ELBOW NOS','ANESTHESIA ARTERIES UPPER ARM & ELBOW NOS','01770','1','','1','0','','','',0, 1, 0, 0),
(373,'ANESTHESIA ARTERIES UPPER ARM&ELBOW EMBOLECTOM','ANESTHESIA ARTERIES UPPER ARM&ELBOW EMBOLECTOM','01772','1','','1','0','','','',0, 1, 0, 0),
(374,'ANESTH CLOSED PROC RADIUS ULNA WRIST/HAND BONES','ANESTH CLOSED PROC RADIUS ULNA WRIST/HAND BONES','01780','1','','1','0','','','',0, 1, 0, 0),
(375,'ANESTHESIA VEINS UPPER ARM & ELBOW PHLEBORRHAPHY','ANESTHESIA VEINS UPPER ARM & ELBOW PHLEBORRHAPHY','01782','1','','1','0','','','',0, 1, 0, 0),
(376,'ANES NERVE MUSCLE TDN FASCIA&BURSA FOREARM WRIST','ANES NERVE MUSCLE TDN FASCIA&BURSA FOREARM WRIST','01810','1','','1','0','','','',0, 1, 0, 0),
(377,'ANES RADIUS ULNA WRIST/HAND BONES CLOSED PX','ANES RADIUS ULNA WRIST/HAND BONES CLOSED PX','01820','1','','1','0','','','',0, 1, 0, 0),
(378,'ANESTHESIA DIAGNOSTIC ARTHROSCOPIC PROC WRIST','ANESTHESIA DIAGNOSTIC ARTHROSCOPIC PROC WRIST','01829','1','','1','0','','','',0, 1, 0, 0),
(379,'ANES ARTHRS/ENDSCPY DSTL RADIUS ULNA/WRIST/HAND','ANES ARTHRS/ENDSCPY DSTL RADIUS ULNA/WRIST/HAND','01830','1','','1','0','','','',0, 1, 0, 0),
(380,'ANESTHESIA ARTHRS/ENDOSCPIC TOTAL WRIST REPLCMT','ANESTHESIA ARTHRS/ENDOSCPIC TOTAL WRIST REPLCMT','01832','1','','1','0','','','',0, 1, 0, 0),
(381,'ANESTHESIA ARTERIES FOREARM WRIST & HAND NOS','ANESTHESIA ARTERIES FOREARM WRIST & HAND NOS','01840','1','','1','0','','','',0, 1, 0, 0),
(382,'ANES ARTERIES FOREARM WRIST & HAND EMBOLECTOMY','ANES ARTERIES FOREARM WRIST & HAND EMBOLECTOMY','01842','1','','1','0','','','',0, 1, 0, 0),
(383,'ANESTHESIA VASCULAR SHUNT/SHUNT REVISION','ANESTHESIA VASCULAR SHUNT/SHUNT REVISION','01844','1','','1','0','','','',0, 1, 0, 0),
(384,'ANESTHESIA VEINS FOREARM WRIST & HAND NOS','ANESTHESIA VEINS FOREARM WRIST & HAND NOS','01850','1','','1','0','','','',0, 1, 0, 0),
(385,'ANES VEINS FOREARM WRIST & HAND PHLEBORRHAPHY','ANES VEINS FOREARM WRIST & HAND PHLEBORRHAPHY','01852','1','','1','0','','','',0, 1, 0, 0),
(386,'ANES FOREARM WRIST/HAND CAST APPL RMVL/REPAIR','ANES FOREARM WRIST/HAND CAST APPL RMVL/REPAIR','01860','1','','1','0','','','',0, 1, 0, 0),
(387,'ANESTHESIA DIAGNOSTIC ARTERIOGRAPHY/VENOGRAPH','ANESTHESIA DIAGNOSTIC ARTERIOGRAPHY/VENOGRAPH','01916','1','','1','0','','','',0, 1, 0, 0),
(388,'ANES C-CATHJ W/C ANGIOGRAPHY & VENTRICULOGRAPHY','ANES C-CATHJ W/C ANGIOGRAPHY & VENTRICULOGRAPHY','01920','1','','1','0','','','',0, 1, 0, 0),
(389,'ANES NON-INVASIVE IMAGING/RADIATION THERAPY','ANES NON-INVASIVE IMAGING/RADIATION THERAPY','01922','1','','1','0','','','',0, 1, 0, 0),
(390,'ANESTHESIA THER IVNTL RADIOLOGICAL ARTERIAL','ANESTHESIA THER IVNTL RADIOLOGICAL ARTERIAL','01924','1','','1','0','','','',0, 1, 0, 0),
(391,'ANESTHESIA CAROTID/CORONARY THER IVNTL RAD','ANESTHESIA CAROTID/CORONARY THER IVNTL RAD','01925','1','','1','0','','','',0, 1, 0, 0),
(392,'ANES ICRA ICAR/AORTIC THER IVNTL RAD ARTL','ANES ICRA ICAR/AORTIC THER IVNTL RAD ARTL','01926','1','','1','0','','','',0, 1, 0, 0),
(393,'ANES VENOUS/LYMPHATIC NOS THER IVNTL RAD NOS','ANES VENOUS/LYMPHATIC NOS THER IVNTL RAD NOS','01930','1','','1','0','','','',0, 1, 0, 0),
(394,'ANESTHESIA INTRAHEPATIC/PORTAL THER IVNTL RAD','ANESTHESIA INTRAHEPATIC/PORTAL THER IVNTL RAD','01931','1','','1','0','','','',0, 1, 0, 0),
(395,'ANESTHESIA INTRATHORACIC/JUGULAR THER IVNTL RAD','ANESTHESIA INTRATHORACIC/JUGULAR THER IVNTL RAD','01932','1','','1','0','','','',0, 1, 0, 0),
(396,'ANES INTRACRANIAL THER IVNTL RAD VENS/LYMPHTC','ANES INTRACRANIAL THER IVNTL RAD VENS/LYMPHTC','01933','1','','1','0','','','',0, 1, 0, 0),
(397,'ANESTHESIA PERQ IMAGE GUIDED SPINE DIAGNOSTIC','ANESTHESIA PERQ IMAGE GUIDED SPINE DIAGNOSTIC','01935','1','','1','0','','','',0, 1, 0, 0),
(398,'ANESTHESIA PERQ IMAGE GUIDED SPINE THERAPEUTIC','ANESTHESIA PERQ IMAGE GUIDED SPINE THERAPEUTIC','01936','1','','1','0','','','',0, 1, 0, 0),
(399,'ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRFT 4 % TBSA','ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRFT 4 % TBSA','01951','1','','1','0','','','',0, 1, 0, 0),
(400,'ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRFT 4-9 % TBSA','ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRFT 4-9 % TBSA','01952','1','','1','0','','','',0, 1, 0, 0),
(401,'ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRF EA 9% TBS','ANES 2/3 DGR BRN EXC/DBRDMT W/WO GRF EA 9% TBS','01953','1','','1','0','','','',0, 1, 0, 0),
(402,'ANESTHESIA EXTERNAL CEPHALIC VERSION','ANESTHESIA EXTERNAL CEPHALIC VERSION','01958','1','','1','0','','','',0, 1, 0, 0),
(403,'ANESTHESIA VAGINAL DELIVERY ONLY','ANESTHESIA VAGINAL DELIVERY ONLY','01960','1','','1','0','','','',0, 1, 0, 0),
(404,'ANESTHESIA CESAREAN DELIVERY ONLY','ANESTHESIA CESAREAN DELIVERY ONLY','01961','1','','1','0','','','',0, 1, 0, 0),
(405,'ANES URGENT HYSTERECTOMY FOLLOWING DELIVERY','ANES URGENT HYSTERECTOMY FOLLOWING DELIVERY','01962','1','','1','0','','','',0, 1, 0, 0),
(406,'ANESTHESIA C HYST W/O ANY LABOR ANALG/ANES CARE','ANESTHESIA C HYST W/O ANY LABOR ANALG/ANES CARE','01963','1','','1','0','','','',0, 1, 0, 0),
(407,'ANESTHESIA INCOMPLETE/MISSED ABORTION','ANESTHESIA INCOMPLETE/MISSED ABORTION','01965','1','','1','0','','','',0, 1, 0, 0),
(408,'ANESTHESIA INDUCED ABORTION','ANESTHESIA INDUCED ABORTION','01966','1','','1','0','','','',0, 1, 0, 0),
(409,'NEURAXIAL LABOR ANALG/ANES PLND VAGINAL DELIVERY','NEURAXIAL LABOR ANALG/ANES PLND VAGINAL DELIVERY','01967','1','','1','0','','','',0, 1, 0, 0),
(410,'ANES CESARN DLVR FLWG NEURAXIAL LABOR ANALG/ANES','ANES CESARN DLVR FLWG NEURAXIAL LABOR ANALG/ANES','01968','1','','1','0','','','',0, 1, 0, 0),
(411,'ANES CESARN HYST FLWG NEURAXIAL LABOR ANALG/ANES','ANES CESARN HYST FLWG NEURAXIAL LABOR ANALG/ANES','01969','1','','1','0','','','',0, 1, 0, 0),
(412,'PHYSIOL SUPPORT HARVEST ORGAN FROM BRAIN-DEAD PT','PHYSIOL SUPPORT HARVEST ORGAN FROM BRAIN-DEAD PT','01990','1','','1','0','','','',0, 1, 0, 0),
(413,'ANES DX/THER NRV BLK/NJX OTH/THN PRONE POS','ANES DX/THER NRV BLK/NJX OTH/THN PRONE POS','01991','1','','1','0','','','',0, 1, 0, 0),
(414,'ANES DX/THER NERVE BLOCK/INJECTION PRONE POS','ANES DX/THER NERVE BLOCK/INJECTION PRONE POS','01992','1','','1','0','','','',0, 1, 0, 0),
(415,'DAILY HOSP MGMT EDRL/SARACH CONT DRUG ADMN','DAILY HOSP MGMT EDRL/SARACH CONT DRUG ADMN','01996','1','','1','0','','','',0, 1, 0, 0),
(416,'UNLISTED ANESTHESIA PROCEDURE','UNLISTED ANESTHESIA PROCEDURE','01999','1','','1','0','','','',0, 1, 0, 0),
(417,'FINE NEEDLE ASPIRATION W/O IMAGING GUIDANCE','FINE NEEDLE ASPIRATION W/O IMAGING GUIDANCE','10021','1','','1','0','','','',0, 1, 0, 0),
(418,'FINE NEEDLE ASPIRATION WITH IMAGING GUIDANCE','FINE NEEDLE ASPIRATION WITH IMAGING GUIDANCE','10022','1','','1','0','','','',0, 1, 0, 0),
(419,'IMAGE-GUIDED CATHETER FLUID COLLECTION DRAINAGE','IMAGE-GUIDED CATHETER FLUID COLLECTION DRAINAGE','10030','1','','1','0','','','',0, 1, 0, 0),
(420,'PERQ SFT TISS LOC DEVICE PLMT 1ST LES W/GDNCE','PERQ SFT TISS LOC DEVICE PLMT 1ST LES W/GDNCE','10035','1','','1','0','','','',0, 1, 0, 0),
(421,'PERQ SFT TISS LOC DEVICE PLMT ADD LES W/GDNCE','PERQ SFT TISS LOC DEVICE PLMT ADD LES W/GDNCE','10036','1','','1','0','','','',0, 1, 0, 0),
(422,'ACNE SURGERY','ACNE SURGERY','10040','1','','1','0','','','',0, 1, 0, 0),
(423,'INCISION & DRAINAGE ABSCESS SIMPLE/SINGLE','INCISION & DRAINAGE ABSCESS SIMPLE/SINGLE','10060','1','','1','0','','','',0, 1, 0, 0),
(424,'INCISION & DRAINAGE ABSCESS COMPLICATED/MULTIPLE','INCISION & DRAINAGE ABSCESS COMPLICATED/MULTIPLE','10061','1','','1','0','','','',0, 1, 0, 0),
(425,'INCISION & DRAINAGE PILONIDAL CYST SIMPLE','INCISION & DRAINAGE PILONIDAL CYST SIMPLE','10080','1','','1','0','','','',0, 1, 0, 0),
(426,'INCISION & DRAINAGE PILONIDAL CYST COMPLICATED','INCISION & DRAINAGE PILONIDAL CYST COMPLICATED','10081','1','','1','0','','','',0, 1, 0, 0),
(427,'INCISION & REMOVAL FOREIGN BODY SUBQ TISS SIMPLE','INCISION & REMOVAL FOREIGN BODY SUBQ TISS SIMPLE','10120','1','','1','0','','','',0, 1, 0, 0),
(428,'INCISION & REMOVAL FOREIGN BODY SUBQ TISS COMPL','INCISION & REMOVAL FOREIGN BODY SUBQ TISS COMPL','10121','1','','1','0','','','',0, 1, 0, 0),
(429,'I&D HEMATOMA SEROMA/FLUID COLLECTION','I&D HEMATOMA SEROMA/FLUID COLLECTION','10140','1','','1','0','','','',0, 1, 0, 0),
(430,'PUNCTURE ASPIRATION ABSCESS HEMATOMA BULLA/CYST','PUNCTURE ASPIRATION ABSCESS HEMATOMA BULLA/CYST','10160','1','','1','0','','','',0, 1, 0, 0),
(431,'INCISION & DRAINAGE COMPLEX PO WOUND INFECTION','INCISION & DRAINAGE COMPLEX PO WOUND INFECTION','10180','1','','1','0','','','',0, 1, 0, 0),
(432,'DBRDMT EXTENSV ECZEMA/INFECT SKN UP 10% BDY SURF','DBRDMT EXTENSV ECZEMA/INFECT SKN UP 10% BDY SURF','11000','1','','1','0','','','',0, 1, 0, 0),
(433,'DBRDMT EXTNSVE ECZEMA/INFECT SKN EA 10% BDY SURF','DBRDMT EXTNSVE ECZEMA/INFECT SKN EA 10% BDY SURF','11001','1','','1','0','','','',0, 1, 0, 0),
(434,'DBRDMT SKN SUBQ T/M/F NECRO INFCTJ GENT&PR','DBRDMT SKN SUBQ T/M/F NECRO INFCTJ GENT&PR','11004','1','','1','0','','','',0, 1, 0, 0),
(435,'DBRDMT SKN SUBQ T/M/F NECRO INFCTJ ABDL WALL','DBRDMT SKN SUBQ T/M/F NECRO INFCTJ ABDL WALL','11005','1','','1','0','','','',0, 1, 0, 0),
(436,'DBRDMT SKN SUBQ T/M/F NECRO INFCTJ GENT/ABDL','DBRDMT SKN SUBQ T/M/F NECRO INFCTJ GENT/ABDL','11006','1','','1','0','','','',0, 1, 0, 0),
(437,'REMOVAL PROSTHETIC MATRL ABDL WALL FOR INFECTION','REMOVAL PROSTHETIC MATRL ABDL WALL FOR INFECTION','11008','1','','1','0','','','',0, 1, 0, 0),
(438,'DBRDMT W/RMVL FM FX&/DISLC SKIN&SUBQ TISSUS','DBRDMT W/RMVL FM FX&/DISLC SKIN&SUBQ TISSUS','11010','1','','1','0','','','',0, 1, 0, 0),
(439,'DBRDMT W/RMVL FM FX&/DISLC SKN SUBQ T/M/F MUSC','DBRDMT W/RMVL FM FX&/DISLC SKN SUBQ T/M/F MUSC','11011','1','','1','0','','','',0, 1, 0, 0),
(440,'DBRDMT FX&/DISLC SUBQ T/M/F BONE','DBRDMT FX&/DISLC SUBQ T/M/F BONE','11012','1','','1','0','','','',0, 1, 0, 0),
(441,'DEBRIDEMENT SUBCUTANEOUS TISSUE 20 SQ CM/<','DEBRIDEMENT SUBCUTANEOUS TISSUE 20 SQ CM/<','11042','1','','1','0','','','',0, 1, 0, 0),
(442,'DEBRIDEMENT MUSCLE & FASCIA 20 SQ CM/<','DEBRIDEMENT MUSCLE & FASCIA 20 SQ CM/<','11043','1','','1','0','','','',0, 1, 0, 0),
(443,'DEBRIDEMENT BONE MUSCLE &/FASCIA 20 SQ CM/<','DEBRIDEMENT BONE MUSCLE &/FASCIA 20 SQ CM/<','11044','1','','1','0','','','',0, 1, 0, 0),
(444,'DBRDMT SUBCUTANEOUS TISSUE EA ADDL 20 SQ CM','DBRDMT SUBCUTANEOUS TISSUE EA ADDL 20 SQ CM','11045','1','','1','0','','','',0, 1, 0, 0),
(445,'DEBRIDEMENT MUSCLE &/FASCIA EA ADDL 20 SQ CM','DEBRIDEMENT MUSCLE &/FASCIA EA ADDL 20 SQ CM','11046','1','','1','0','','','',0, 1, 0, 0),
(446,'DEBRIDEMENT BONE EACH ADDITIONAL 20 SQ CM','DEBRIDEMENT BONE EACH ADDITIONAL 20 SQ CM','11047','1','','1','0','','','',0, 1, 0, 0),
(447,'PARING/CUTTING BENIGN HYPERKERATOTIC LESION 1','PARING/CUTTING BENIGN HYPERKERATOTIC LESION 1','11055','1','','1','0','','','',0, 1, 0, 0),
(448,'PARING/CUTTING BENIGN HYPERKERATOTIC LESION 2-4','PARING/CUTTING BENIGN HYPERKERATOTIC LESION 2-4','11056','1','','1','0','','','',0, 1, 0, 0),
(449,'PARING/CUTTING BENIGN HYPERKERATOTIC LESION >4','PARING/CUTTING BENIGN HYPERKERATOTIC LESION >4','11057','1','','1','0','','','',0, 1, 0, 0),
(450,'BX SKIN SUBCUTANEOUS&/MUCOUS MEMBRANE 1 LESION','BX SKIN SUBCUTANEOUS&/MUCOUS MEMBRANE 1 LESION','11100','1','','1','0','','','',0, 1, 0, 0),
(451,'BIOPSY SKIN SUBQ&/MUCOUS MEMBRANE EA ADDL LESN','BIOPSY SKIN SUBQ&/MUCOUS MEMBRANE EA ADDL LESN','11101','1','','1','0','','','',0, 1, 0, 0),
(452,'REMOVAL SKN TAGS MLT FIBRQ TAGS ANY AREA UPW/15','REMOVAL SKN TAGS MLT FIBRQ TAGS ANY AREA UPW/15','11200','1','','1','0','','','',0, 1, 0, 0),
(453,'REMOVAL SK TGS MLT FIBRQ TAGS ANY AREA EA 10','REMOVAL SK TGS MLT FIBRQ TAGS ANY AREA EA 10','11201','1','','1','0','','','',0, 1, 0, 0),
(454,'SHAVING SKIN LESION 1 TRUNK/ARM/LEG DIAM 0.5CM/<','SHAVING SKIN LESION 1 TRUNK/ARM/LEG DIAM 0.5CM/<','11300','1','','1','0','','','',0, 1, 0, 0),
(455,'SHVG SKIN LESION 1 TRUNK/ARM/LEG DIAM 0.6-1.0 CM','SHVG SKIN LESION 1 TRUNK/ARM/LEG DIAM 0.6-1.0 CM','11301','1','','1','0','','','',0, 1, 0, 0),
(456,'SHVG SKN LESION 1 TRUNK/ARM/LEG DIAM 1.1-2.0 CM','SHVG SKN LESION 1 TRUNK/ARM/LEG DIAM 1.1-2.0 CM','11302','1','','1','0','','','',0, 1, 0, 0),
(457,'SHVG SKIN LESION 1 TRUNK/ARM/LEG DIAM >2.0 CM','SHVG SKIN LESION 1 TRUNK/ARM/LEG DIAM >2.0 CM','11303','1','','1','0','','','',0, 1, 0, 0),
(458,'SHAVING SKIN LESION 1 S/N/H/F/G DIAM 0.5 CM/<','SHAVING SKIN LESION 1 S/N/H/F/G DIAM 0.5 CM/<','11305','1','','1','0','','','',0, 1, 0, 0),
(459,'SHAVING SKIN LESION 1 S/N/H/F/G DIAM 0.6-1.0 CM','SHAVING SKIN LESION 1 S/N/H/F/G DIAM 0.6-1.0 CM','11306','1','','1','0','','','',0, 1, 0, 0),
(460,'SHAVING SKIN LESION 1 S/N/H/F/G DIAM 1.1-2.0 CM','SHAVING SKIN LESION 1 S/N/H/F/G DIAM 1.1-2.0 CM','11307','1','','1','0','','','',0, 1, 0, 0),
(461,'SHAVING SKIN LESION 1 S/N/H/F/G DIAM >2.0 CM','SHAVING SKIN LESION 1 S/N/H/F/G DIAM >2.0 CM','11308','1','','1','0','','','',0, 1, 0, 0),
(462,'SHAVING SKIN LESION 1 F/E/E/N/L/M DIAM 0.5 CM/<','SHAVING SKIN LESION 1 F/E/E/N/L/M DIAM 0.5 CM/<','11310','1','','1','0','','','',0, 1, 0, 0),
(463,'SHVG SKIN LESION 1 F/E/E/N/L/M DIAM 0.6-1.0 CM','SHVG SKIN LESION 1 F/E/E/N/L/M DIAM 0.6-1.0 CM','11311','1','','1','0','','','',0, 1, 0, 0),
(464,'SHVG SKIN LESION 1 F/E/E/N/L/M DIAM 1.1-2.0 CM','SHVG SKIN LESION 1 F/E/E/N/L/M DIAM 1.1-2.0 CM','11312','1','','1','0','','','',0, 1, 0, 0),
(465,'SHAVING SKIN LESION 1 F/E/E/N/L/M DIAM >2.0 CM','SHAVING SKIN LESION 1 F/E/E/N/L/M DIAM >2.0 CM','11313','1','','1','0','','','',0, 1, 0, 0),
(466,'EXC B9 LESION MRGN XCP SK TG T/A/L 0.5 CM/<','EXC B9 LESION MRGN XCP SK TG T/A/L 0.5 CM/<','11400','1','','1','0','','','',0, 1, 0, 0),
(467,'EXC B9 LESION MRGN XCP SK TG T/A/L 0.6-1.0 CM','EXC B9 LESION MRGN XCP SK TG T/A/L 0.6-1.0 CM','11401','1','','1','0','','','',0, 1, 0, 0),
(468,'EXC B9 LESION MRGN XCP SK TG T/A/L 1.1-2.0 CM','EXC B9 LESION MRGN XCP SK TG T/A/L 1.1-2.0 CM','11402','1','','1','0','','','',0, 1, 0, 0),
(469,'EXC B9 LESION MRGN XCP SK TG T/A/L 2.1-3.0 CM/<','EXC B9 LESION MRGN XCP SK TG T/A/L 2.1-3.0 CM/<','11403','1','','1','0','','','',0, 1, 0, 0),
(470,'EXC B9 LESION MRGN XCP SK TG T/A/L 3.1-4.0 CM','EXC B9 LESION MRGN XCP SK TG T/A/L 3.1-4.0 CM','11404','1','','1','0','','','',0, 1, 0, 0),
(471,'EXC B9 LESION MRGN XCP SK TG T/A/L >4.0 CM','EXC B9 LESION MRGN XCP SK TG T/A/L >4.0 CM','11406','1','','1','0','','','',0, 1, 0, 0),
(472,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 0.5 CM/<','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 0.5 CM/<','11420','1','','1','0','','','',0, 1, 0, 0),
(473,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 0.6-1.0CM','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 0.6-1.0CM','11421','1','','1','0','','','',0, 1, 0, 0),
(474,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 1.1-2.0CM','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 1.1-2.0CM','11422','1','','1','0','','','',0, 1, 0, 0),
(475,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 2.1-3.0CM','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 2.1-3.0CM','11423','1','','1','0','','','',0, 1, 0, 0),
(476,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 3.1-4.0CM','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G 3.1-4.0CM','11424','1','','1','0','','','',0, 1, 0, 0),
(477,'EXC B9 LESION MRGN XCP SK TG S/N/H/F/G > 4.0CM','EXC B9 LESION MRGN XCP SK TG S/N/H/F/G > 4.0CM','11426','1','','1','0','','','',0, 1, 0, 0),
(478,'EXC B9 LESION MRGN XCP SK TG F/E/E/N/L/M 0.5CM/<','EXC B9 LESION MRGN XCP SK TG F/E/E/N/L/M 0.5CM/<','11440','1','','1','0','','','',0, 1, 0, 0),
(479,'EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 0.6-1.0CM','EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 0.6-1.0CM','11441','1','','1','0','','','',0, 1, 0, 0),
(480,'EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 1.1-2.0CM','EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 1.1-2.0CM','11442','1','','1','0','','','',0, 1, 0, 0),
(481,'EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 2.1-3.0CM','EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 2.1-3.0CM','11443','1','','1','0','','','',0, 1, 0, 0),
(482,'EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 3.1-4.0CM','EXC B9 LES MRGN XCP SK TG F/E/E/N/L/M 3.1-4.0CM','11444','1','','1','0','','','',0, 1, 0, 0),
(483,'EXC B9 LESION MRGN XCP SK TG F/E/E/N/L/M > 4.0CM','EXC B9 LESION MRGN XCP SK TG F/E/E/N/L/M > 4.0CM','11446','1','','1','0','','','',0, 1, 0, 0),
(484,'EXCISION HIDRADENITIS AXILLARY SMPL/INTRM RPR','EXCISION HIDRADENITIS AXILLARY SMPL/INTRM RPR','11450','1','','1','0','','','',0, 1, 0, 0),
(485,'EXCISION HIDRADENITIS AXILLARY COMPLEX REPAIR','EXCISION HIDRADENITIS AXILLARY COMPLEX REPAIR','11451','1','','1','0','','','',0, 1, 0, 0),
(486,'EXCISION HIDRADENITIS INGUINAL SMPL/INTRM RPR','EXCISION HIDRADENITIS INGUINAL SMPL/INTRM RPR','11462','1','','1','0','','','',0, 1, 0, 0),
(487,'EXCISION HIDRADENITIS INGUINAL COMPLEX REPAIR','EXCISION HIDRADENITIS INGUINAL COMPLEX REPAIR','11463','1','','1','0','','','',0, 1, 0, 0),
(488,'EXCISION H/P/P/U SIMPLE/INTERMEDIATE REPAIR','EXCISION H/P/P/U SIMPLE/INTERMEDIATE REPAIR','11470','1','','1','0','','','',0, 1, 0, 0),
(489,'EXCISION H/P/P/U COMPLEX REPAIR','EXCISION H/P/P/U COMPLEX REPAIR','11471','1','','1','0','','','',0, 1, 0, 0),
(490,'EXCISION MAL LESION TRUNK/ARM/LEG 0.5 CM/<','EXCISION MAL LESION TRUNK/ARM/LEG 0.5 CM/<','11600','1','','1','0','','','',0, 1, 0, 0),
(491,'EXCISION MAL LESION TRUNK/ARM/LEG 0.6-1.0 CM','EXCISION MAL LESION TRUNK/ARM/LEG 0.6-1.0 CM','11601','1','','1','0','','','',0, 1, 0, 0),
(492,'EXCISION MAL LESION TRUNK/ARM/LEG 1.1-2.0 CM','EXCISION MAL LESION TRUNK/ARM/LEG 1.1-2.0 CM','11602','1','','1','0','','','',0, 1, 0, 0),
(493,'EXCISION MAL LESION TRUNK/ARM/LEG 2.1-3.0 CM/<','EXCISION MAL LESION TRUNK/ARM/LEG 2.1-3.0 CM/<','11603','1','','1','0','','','',0, 1, 0, 0),
(494,'EXCISION MAL LESION TRUNK/ARM/LEG 3.1-4.0 CM','EXCISION MAL LESION TRUNK/ARM/LEG 3.1-4.0 CM','11604','1','','1','0','','','',0, 1, 0, 0),
(495,'EXCISION MALIGNANT LESION TRUNK/ARM/LEG > 4.0 CM','EXCISION MALIGNANT LESION TRUNK/ARM/LEG > 4.0 CM','11606','1','','1','0','','','',0, 1, 0, 0),
(496,'EXCISION MALIGNANT LESION S/N/H/F/G 0.5 CM/<','EXCISION MALIGNANT LESION S/N/H/F/G 0.5 CM/<','11620','1','','1','0','','','',0, 1, 0, 0),
(497,'EXCISION MALIGNANT LESION S/N/H/F/G 0.6-1.0 CM','EXCISION MALIGNANT LESION S/N/H/F/G 0.6-1.0 CM','11621','1','','1','0','','','',0, 1, 0, 0),
(498,'EXCISION MALIGNANT LESION S/N/H/F/G 1.1-2.0 CM','EXCISION MALIGNANT LESION S/N/H/F/G 1.1-2.0 CM','11622','1','','1','0','','','',0, 1, 0, 0),
(499,'EXCISION MALIGNANT LESION S/N/H/F/G 2.1-3.0 CM/<','EXCISION MALIGNANT LESION S/N/H/F/G 2.1-3.0 CM/<','11623','1','','1','0','','','',0, 1, 0, 0),
(500,'EXCISION MALIGNANT LESION S/N/H/F/G 3.1-4.0 CM','EXCISION MALIGNANT LESION S/N/H/F/G 3.1-4.0 CM','11624','1','','1','0','','','',0, 1, 0, 0),
(501,'EXCISION MALIGNANT LESION S/N/H/F/G >4.0 CM','EXCISION MALIGNANT LESION S/N/H/F/G >4.0 CM','11626','1','','1','0','','','',0, 1, 0, 0),
(502,'EXCISION MALIGNANT LESION F/E/E/N/L 0.5 CM/<','EXCISION MALIGNANT LESION F/E/E/N/L 0.5 CM/<','11640','1','','1','0','','','',0, 1, 0, 0),
(503,'EXCISION MALIGNANT LESION F/E/E/N/L 0.6-1.0 CM','EXCISION MALIGNANT LESION F/E/E/N/L 0.6-1.0 CM','11641','1','','1','0','','','',0, 1, 0, 0),
(504,'EXCISION MALIGNANT LESION F/E/E/N/L 1.1-2.0 CM','EXCISION MALIGNANT LESION F/E/E/N/L 1.1-2.0 CM','11642','1','','1','0','','','',0, 1, 0, 0),
(505,'EXCISION MALIGNANT LESION F/E/E/N/L 2.1-3.0 CM','EXCISION MALIGNANT LESION F/E/E/N/L 2.1-3.0 CM','11643','1','','1','0','','','',0, 1, 0, 0),
(506,'EXCISION MALIGNANT LESION F/E/E/N/L 3.1-4.0 CM','EXCISION MALIGNANT LESION F/E/E/N/L 3.1-4.0 CM','11644','1','','1','0','','','',0, 1, 0, 0),
(507,'EXCISION MALIGNANT LESION F/E/E/N/L >4.0 CM','EXCISION MALIGNANT LESION F/E/E/N/L >4.0 CM','11646','1','','1','0','','','',0, 1, 0, 0),
(508,'TRIMMING NONDYSTROPHIC NAILS ANY NUMBER','TRIMMING NONDYSTROPHIC NAILS ANY NUMBER','11719','1','','1','0','','','',0, 1, 0, 0),
(509,'DEBRIDEMENT NAIL ANY METHOD 1-5','DEBRIDEMENT NAIL ANY METHOD 1-5','11720','1','','1','0','','','',0, 1, 0, 0),
(510,'DEBRIDEMENT NAIL ANY METHOD 6/>','DEBRIDEMENT NAIL ANY METHOD 6/>','11721','1','','1','0','','','',0, 1, 0, 0),
(511,'AVULSION NAIL PLATE PARTIAL/COMPLETE SIMPLE 1','AVULSION NAIL PLATE PARTIAL/COMPLETE SIMPLE 1','11730','1','','1','0','','','',0, 1, 0, 0),
(512,'AVULSION NAIL PLATE PARTIAL/COMP SIMPLE EA ADDL','AVULSION NAIL PLATE PARTIAL/COMP SIMPLE EA ADDL','11732','1','','1','0','','','',0, 1, 0, 0),
(513,'EVACUATION SUBUNGUAL HEMATOMA','EVACUATION SUBUNGUAL HEMATOMA','11740','1','','1','0','','','',0, 1, 0, 0),
(514,'EXCISION NAIL MATRIX PERMANENT REMOVAL','EXCISION NAIL MATRIX PERMANENT REMOVAL','11750','1','','1','0','','','',0, 1, 0, 0),
(515,'EXC NAIL MATRIX PRM RMVL W/AMP TUFT DSTL PHALANX','EXC NAIL MATRIX PRM RMVL W/AMP TUFT DSTL PHALANX','11752','1','','1','0','','','',0, 1, 0, 0),
(516,'BIOPSY NAIL UNIT SEPARATE PROCEDURE','BIOPSY NAIL UNIT SEPARATE PROCEDURE','11755','1','','1','0','','','',0, 1, 0, 0),
(517,'REPAIR NAIL BED','REPAIR NAIL BED','11760','1','','1','0','','','',0, 1, 0, 0),
(518,'RECONSTRUCTION NAIL BED W/GRAFT','RECONSTRUCTION NAIL BED W/GRAFT','11762','1','','1','0','','','',0, 1, 0, 0),
(519,'WEDGE EXCISION SKIN NAIL FOLD','WEDGE EXCISION SKIN NAIL FOLD','11765','1','','1','0','','','',0, 1, 0, 0),
(520,'EXCISION PILONIDAL CYST/SINUS SIMPLE','EXCISION PILONIDAL CYST/SINUS SIMPLE','11770','1','','1','0','','','',0, 1, 0, 0),
(521,'EXCISION PILONIDAL CYST/SINUS EXTENSIVE','EXCISION PILONIDAL CYST/SINUS EXTENSIVE','11771','1','','1','0','','','',0, 1, 0, 0),
(522,'EXCISION PILONIDAL CYST/SINUS COMPLICATED','EXCISION PILONIDAL CYST/SINUS COMPLICATED','11772','1','','1','0','','','',0, 1, 0, 0),
(523,'INJECTION INTRALESIONAL UP TO & INCLUD 7 LESIONS','INJECTION INTRALESIONAL UP TO & INCLUD 7 LESIONS','11900','1','','1','0','','','',0, 1, 0, 0),
(524,'INJECTION INTRALESIONAL >7 LESIONS','INJECTION INTRALESIONAL >7 LESIONS','11901','1','','1','0','','','',0, 1, 0, 0),
(525,'TATTOOING INCL MICROPIGMENTATION 6.0 CM/<','TATTOOING INCL MICROPIGMENTATION 6.0 CM/<','11920','1','','1','0','','','',0, 1, 0, 0),
(526,'TATTOOING INCL MICROPIGMENTATION 6.1-20.0 CM','TATTOOING INCL MICROPIGMENTATION 6.1-20.0 CM','11921','1','','1','0','','','',0, 1, 0, 0),
(527,'TATTOOING INCL MICROPIGMENTATION EA 20.0 CM','TATTOOING INCL MICROPIGMENTATION EA 20.0 CM','11922','1','','1','0','','','',0, 1, 0, 0),
(528,'SUBCUTANEOUS INJECTION FILLING MATERIAL 1 CC/<','SUBCUTANEOUS INJECTION FILLING MATERIAL 1 CC/<','11950','1','','1','0','','','',0, 1, 0, 0),
(529,'SUBCUTANEOUS INJECTION FILLING MATRL 1.1-5.0 CC','SUBCUTANEOUS INJECTION FILLING MATRL 1.1-5.0 CC','11951','1','','1','0','','','',0, 1, 0, 0),
(530,'SUBCUTANEOUS INJECTION FILLING MATRL 5.1-10.0CC','SUBCUTANEOUS INJECTION FILLING MATRL 5.1-10.0CC','11952','1','','1','0','','','',0, 1, 0, 0),
(531,'SUBCUTANEOUS INJECTION FILLING MATRL >10.0 CC','SUBCUTANEOUS INJECTION FILLING MATRL >10.0 CC','11954','1','','1','0','','','',0, 1, 0, 0),
(532,'INSERTION TISSUE EXPANDER INCL SBSQ XPNSJ','INSERTION TISSUE EXPANDER INCL SBSQ XPNSJ','11960','1','','1','0','','','',0, 1, 0, 0),
(533,'REPLACEMENT TISS EXPANDER PERMANENT PROSTHESIS','REPLACEMENT TISS EXPANDER PERMANENT PROSTHESIS','11970','1','','1','0','','','',0, 1, 0, 0),
(534,'REMOVAL TISS EXPANDER W/O INSERTION PROSTHESIS','REMOVAL TISS EXPANDER W/O INSERTION PROSTHESIS','11971','1','','1','0','','','',0, 1, 0, 0),
(535,'REMOVAL IMPLANTABLE CONTRACEPTIVE CAPSULES','REMOVAL IMPLANTABLE CONTRACEPTIVE CAPSULES','11976','1','','1','0','','','',0, 1, 0, 0),
(536,'SUBCUTANEOUS HORMONE PELLET IMPLANTATION','SUBCUTANEOUS HORMONE PELLET IMPLANTATION','11980','1','','1','0','','','',0, 1, 0, 0),
(537,'INSJ NON-BIODEGRADABLE DRUG DELIVERY IMPLANT','INSJ NON-BIODEGRADABLE DRUG DELIVERY IMPLANT','11981','1','','1','0','','','',0, 1, 0, 0),
(538,'REMOVAL NON-BIODEGRADABLE DRUG DELIVERY IMPLANT','REMOVAL NON-BIODEGRADABLE DRUG DELIVERY IMPLANT','11982','1','','1','0','','','',0, 1, 0, 0),
(539,'RMVL W/RINSJ NON-BIODEGRADABLE DRUG DLVR IMPLT','RMVL W/RINSJ NON-BIODEGRADABLE DRUG DLVR IMPLT','11983','1','','1','0','','','',0, 1, 0, 0),
(540,'SIMPLE REPAIR SCALP/NECK/AX/GENIT/TRUNK 2.5CM/<','SIMPLE REPAIR SCALP/NECK/AX/GENIT/TRUNK 2.5CM/<','12001','1','','1','0','','','',0, 1, 0, 0),
(541,'SMPL REPAIR SCALP/NECK/AX/GENIT/TRUNK 2.6-7.5CM','SMPL REPAIR SCALP/NECK/AX/GENIT/TRUNK 2.6-7.5CM','12002','1','','1','0','','','',0, 1, 0, 0),
(542,'SIMPLE RPR SCALP/NECK/AX/GENIT/TRUNK 7.6-12.5CM','SIMPLE RPR SCALP/NECK/AX/GENIT/TRUNK 7.6-12.5CM','12004','1','','1','0','','','',0, 1, 0, 0),
(543,'SMPL RPR SCALP/NECK/AX/GENIT/TRUNK 12.6-20.0CM','SMPL RPR SCALP/NECK/AX/GENIT/TRUNK 12.6-20.0CM','12005','1','','1','0','','','',0, 1, 0, 0),
(544,'SMPL RPR SCALP/NECK/AX/GENIT/TRUNK 20.1-30.0CM','SMPL RPR SCALP/NECK/AX/GENIT/TRUNK 20.1-30.0CM','12006','1','','1','0','','','',0, 1, 0, 0),
(545,'SIMPLE REPAIR SCALP/NECK/AX/GENIT/TRUNK >30.0CM','SIMPLE REPAIR SCALP/NECK/AX/GENIT/TRUNK >30.0CM','12007','1','','1','0','','','',0, 1, 0, 0),
(546,'SIMPLE REPAIR F/E/E/N/L/M 2.5CM/<','SIMPLE REPAIR F/E/E/N/L/M 2.5CM/<','12011','1','','1','0','','','',0, 1, 0, 0),
(547,'SIMPLE REPAIR F/E/E/N/L/M 2.6CM-5.0 CM','SIMPLE REPAIR F/E/E/N/L/M 2.6CM-5.0 CM','12013','1','','1','0','','','',0, 1, 0, 0),
(548,'SIMPLE REPAIR F/E/E/N/L/M 5.1CM-7.5 CM','SIMPLE REPAIR F/E/E/N/L/M 5.1CM-7.5 CM','12014','1','','1','0','','','',0, 1, 0, 0),
(549,'SIMPLE REPAIR F/E/E/N/L/M 7.6CM-12.5 CM','SIMPLE REPAIR F/E/E/N/L/M 7.6CM-12.5 CM','12015','1','','1','0','','','',0, 1, 0, 0),
(550,'SIMPLE REPAIR F/E/E/N/L/M 12.6CM-20.0 CM','SIMPLE REPAIR F/E/E/N/L/M 12.6CM-20.0 CM','12016','1','','1','0','','','',0, 1, 0, 0),
(551,'SIMPLE REPAIR F/E/E/N/L/M 20.1CM-30.0 CM','SIMPLE REPAIR F/E/E/N/L/M 20.1CM-30.0 CM','12017','1','','1','0','','','',0, 1, 0, 0),
(552,'SIMPLE REPAIR F/E/E/N/L/M >30.0 CM','SIMPLE REPAIR F/E/E/N/L/M >30.0 CM','12018','1','','1','0','','','',0, 1, 0, 0),
(553,'TX SUPERFICIAL WOUND DEHISCENCE SIMPLE CLOSURE','TX SUPERFICIAL WOUND DEHISCENCE SIMPLE CLOSURE','12020','1','','1','0','','','',0, 1, 0, 0),
(554,'TX SUPERFICIAL WOUND DEHISCENCE W/PACKING','TX SUPERFICIAL WOUND DEHISCENCE W/PACKING','12021','1','','1','0','','','',0, 1, 0, 0),
(555,'REPAIR INTERMEDIATE S/A/T/E 2.5 CM/<','REPAIR INTERMEDIATE S/A/T/E 2.5 CM/<','12031','1','','1','0','','','',0, 1, 0, 0),
(556,'REPAIR INTERMEDIATE S/A/T/E 2.6-7.5 CM','REPAIR INTERMEDIATE S/A/T/E 2.6-7.5 CM','12032','1','','1','0','','','',0, 1, 0, 0),
(557,'REPAIR INTERMEDIATE S/A/T/E 7.6-12.5 CM','REPAIR INTERMEDIATE S/A/T/E 7.6-12.5 CM','12034','1','','1','0','','','',0, 1, 0, 0),
(558,'REPAIR INTERMEDIATE S/A/T/E 12.6-20.0CM','REPAIR INTERMEDIATE S/A/T/E 12.6-20.0CM','12035','1','','1','0','','','',0, 1, 0, 0),
(559,'REPAIR INTERMEDIATE S/A/T/E 20.1-30.0 CM','REPAIR INTERMEDIATE S/A/T/E 20.1-30.0 CM','12036','1','','1','0','','','',0, 1, 0, 0),
(560,'REPAIR INTERMEDIATE S/A/T/E >30.0 CM','REPAIR INTERMEDIATE S/A/T/E >30.0 CM','12037','1','','1','0','','','',0, 1, 0, 0),
(561,'REPAIR INTERMEDIATE N/H/F/XTRNL GENT 2.5CM/<','REPAIR INTERMEDIATE N/H/F/XTRNL GENT 2.5CM/<','12041','1','','1','0','','','',0, 1, 0, 0),
(562,'REPAIR INTERMEDIATE N/H/F/XTRNL GENT 2.6-7.5 CM','REPAIR INTERMEDIATE N/H/F/XTRNL GENT 2.6-7.5 CM','12042','1','','1','0','','','',0, 1, 0, 0),
(563,'REPAIR INTERMEDIATE N/H/F/XTRNL GENT 7.6-12.5CM','REPAIR INTERMEDIATE N/H/F/XTRNL GENT 7.6-12.5CM','12044','1','','1','0','','','',0, 1, 0, 0),
(564,'REPAIR INTERMEDIATE N/H/F/XTRNL GENT 12.6-20 CM','REPAIR INTERMEDIATE N/H/F/XTRNL GENT 12.6-20 CM','12045','1','','1','0','','','',0, 1, 0, 0),
(565,'RPR INTERMEDIATE N/H/F/XTRNL GENT 20.1-30.0 CM','RPR INTERMEDIATE N/H/F/XTRNL GENT 20.1-30.0 CM','12046','1','','1','0','','','',0, 1, 0, 0),
(566,'REPAIR INTERMEDIATE N/H/F/XTRNL GENT >30.0 CM','REPAIR INTERMEDIATE N/H/F/XTRNL GENT >30.0 CM','12047','1','','1','0','','','',0, 1, 0, 0),
(567,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 2.5 CM/<','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 2.5 CM/<','12051','1','','1','0','','','',0, 1, 0, 0),
(568,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 2.6-5.0 CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 2.6-5.0 CM','12052','1','','1','0','','','',0, 1, 0, 0),
(569,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 5.1-7.5 CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 5.1-7.5 CM','12053','1','','1','0','','','',0, 1, 0, 0),
(570,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 7.6-12.5 CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 7.6-12.5 CM','12054','1','','1','0','','','',0, 1, 0, 0),
(571,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 12.6-20.0CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 12.6-20.0CM','12055','1','','1','0','','','',0, 1, 0, 0),
(572,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC 20.1-30.0CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC 20.1-30.0CM','12056','1','','1','0','','','',0, 1, 0, 0),
(573,'REPAIR INTERMEDIATE F/E/E/N/L&/MUC >30.0 CM','REPAIR INTERMEDIATE F/E/E/N/L&/MUC >30.0 CM','12057','1','','1','0','','','',0, 1, 0, 0),
(574,'REPAIR COMPLEX TRUNK 1.1-2.5 CM','REPAIR COMPLEX TRUNK 1.1-2.5 CM','13100','1','','1','0','','','',0, 1, 0, 0),
(575,'REPAIR COMPLEX TRUNK 2.6-7.5 CM','REPAIR COMPLEX TRUNK 2.6-7.5 CM','13101','1','','1','0','','','',0, 1, 0, 0),
(576,'REPAIR COMPLEX TRUNK EACH ADDITIONAL 5 CM/<','REPAIR COMPLEX TRUNK EACH ADDITIONAL 5 CM/<','13102','1','','1','0','','','',0, 1, 0, 0),
(577,'REPAIR COMPLEX SCALP/ARM/LEG 1.1-2.5 CM','REPAIR COMPLEX SCALP/ARM/LEG 1.1-2.5 CM','13120','1','','1','0','','','',0, 1, 0, 0),
(578,'REPAIR COMPLEX SCALP/ARM/LEG 2.6-7.5 CM','REPAIR COMPLEX SCALP/ARM/LEG 2.6-7.5 CM','13121','1','','1','0','','','',0, 1, 0, 0),
(579,'REPAIR COMPLEX SCALP/ARM/LEG EA ADDL 5 CM/<','REPAIR COMPLEX SCALP/ARM/LEG EA ADDL 5 CM/<','13122','1','','1','0','','','',0, 1, 0, 0),
(580,'REPAIR COMPLEX F/C/C/M/N/AX/G/H/F 1.1-2.5 CM','REPAIR COMPLEX F/C/C/M/N/AX/G/H/F 1.1-2.5 CM','13131','1','','1','0','','','',0, 1, 0, 0),
(581,'REPAIR COMPLEX F/C/C/M/N/AX/G/H/F 2.6-7.5 CM','REPAIR COMPLEX F/C/C/M/N/AX/G/H/F 2.6-7.5 CM','13132','1','','1','0','','','',0, 1, 0, 0),
(582,'REPAIR COMPLEX F/C/C/M/N/AX/G/H/F EA ADDL 5 CM/<','REPAIR COMPLEX F/C/C/M/N/AX/G/H/F EA ADDL 5 CM/<','13133','1','','1','0','','','',0, 1, 0, 0),
(583,'REPAIR COMPLEX EYELID/NOSE/EAR/LIP 1.1-2.5 CM','REPAIR COMPLEX EYELID/NOSE/EAR/LIP 1.1-2.5 CM','13151','1','','1','0','','','',0, 1, 0, 0),
(584,'REPAIR COMPLEX EYELID/NOSE/EAR/LIP 2.6-7.5 CM','REPAIR COMPLEX EYELID/NOSE/EAR/LIP 2.6-7.5 CM','13152','1','','1','0','','','',0, 1, 0, 0),
(585,'REPAIR COMPLX EYELID/NOSE/EAR/LIP EA ADDL 5 CM/<','REPAIR COMPLX EYELID/NOSE/EAR/LIP EA ADDL 5 CM/<','13153','1','','1','0','','','',0, 1, 0, 0),
(586,'SECONDARY CLOSURE SURG WOUND/DEHSN EXTSV/COMPLIC','SECONDARY CLOSURE SURG WOUND/DEHSN EXTSV/COMPLIC','13160','1','','1','0','','','',0, 1, 0, 0),
(587,'ADJACENT TISSUE TRANSFER/REARGMT TRUNK 10 SQCM/<','ADJACENT TISSUE TRANSFER/REARGMT TRUNK 10 SQCM/<','14000','1','','1','0','','','',0, 1, 0, 0),
(588,'ADJNT TIS TRANSFR/REARRANGE TRUNK 10.1-30.0 SQCM','ADJNT TIS TRANSFR/REARRANGE TRUNK 10.1-30.0 SQCM','14001','1','','1','0','','','',0, 1, 0, 0),
(589,'ADJT TIS TRNSFR/REARGMT SCALP/ARM/LEG 10 SQ CM/<','ADJT TIS TRNSFR/REARGMT SCALP/ARM/LEG 10 SQ CM/<','14020','1','','1','0','','','',0, 1, 0, 0),
(590,'ADJT/REARRGMT SCALP/ARM/LEG 10.1-30.0 SQ CM','ADJT/REARRGMT SCALP/ARM/LEG 10.1-30.0 SQ CM','14021','1','','1','0','','','',0, 1, 0, 0),
(591,'ADJT TIS TRNS/REARGMT F/C/C/M/N/A/G/H/F 10SQCM/<','ADJT TIS TRNS/REARGMT F/C/C/M/N/A/G/H/F 10SQCM/<','14040','1','','1','0','','','',0, 1, 0, 0),
(592,'ADJT/REARGMT F/C/C/M/N/AX/G/H/F 10.1-30.0 SQ CM','ADJT/REARGMT F/C/C/M/N/AX/G/H/F 10.1-30.0 SQ CM','14041','1','','1','0','','','',0, 1, 0, 0),
(593,'ADJT TIS TRNSFR/REARRGMT E/N/E/L DFCT 10 SQ CM/<','ADJT TIS TRNSFR/REARRGMT E/N/E/L DFCT 10 SQ CM/<','14060','1','','1','0','','','',0, 1, 0, 0),
(594,'ADJT TIS REARGMT EYE/NOSE/EAR/LIP 10.1-30.0 SQCM','ADJT TIS REARGMT EYE/NOSE/EAR/LIP 10.1-30.0 SQCM','14061','1','','1','0','','','',0, 1, 0, 0),
(595,'ADJNT TIS TRNSFR/REARGMT ANY AREA 30.1-60 SQ CM','ADJNT TIS TRNSFR/REARGMT ANY AREA 30.1-60 SQ CM','14301','1','','1','0','','','',0, 1, 0, 0),
(596,'ADJT TIS TRNSFR/REARGMT DEFEC EA ADDL 30 SQCM/<','ADJT TIS TRNSFR/REARGMT DEFEC EA ADDL 30 SQCM/<','14302','1','','1','0','','','',0, 1, 0, 0),
(597,'FILLETED FINGER/TOE FLAP W/PREPJ RECIPIENT SITE','FILLETED FINGER/TOE FLAP W/PREPJ RECIPIENT SITE','14350','1','','1','0','','','',0, 1, 0, 0),
(598,'PREP SITE TRUNK/ARM/LEG 1ST 100 SQ CM/1PCT','PREP SITE TRUNK/ARM/LEG 1ST 100 SQ CM/1PCT','15002','1','','1','0','','','',0, 1, 0, 0),
(599,'PREP SITE TRUNK/ARM/LEG ADDL 100 SQ CM/1PCT','PREP SITE TRUNK/ARM/LEG ADDL 100 SQ CM/1PCT','15003','1','','1','0','','','',0, 1, 0, 0),
(600,'PREP SITE F/S/N/H/F/G/M/D GT 1ST 100 SQ CM/1PCT','PREP SITE F/S/N/H/F/G/M/D GT 1ST 100 SQ CM/1PCT','15004','1','','1','0','','','',0, 1, 0, 0),
(601,'PREP SITE F/S/N/H/F/G/M/D GT ADDL 100 SQ CM/1PCT','PREP SITE F/S/N/H/F/G/M/D GT ADDL 100 SQ CM/1PCT','15005','1','','1','0','','','',0, 1, 0, 0),
(602,'HARVEST SKIN TISSUE CLTR SKIN AGRFT 100 CM/<','HARVEST SKIN TISSUE CLTR SKIN AGRFT 100 CM/<','15040','1','','1','0','','','',0, 1, 0, 0),
(603,'PINCH GRAFT 1/MLT SM ULCER TIP/OTH AREA 2CM','PINCH GRAFT 1/MLT SM ULCER TIP/OTH AREA 2CM','15050','1','','1','0','','','',0, 1, 0, 0),
(604,'SPLIT AGRFT T/A/L 1ST 100 CM/&/1% BDY INFT/CHLD','SPLIT AGRFT T/A/L 1ST 100 CM/&/1% BDY INFT/CHLD','15100','1','','1','0','','','',0, 1, 0, 0),
(605,'SPLIT AGRFT T/A/L EA 100 CM/EA 1% BDY INFT/CHLD','SPLIT AGRFT T/A/L EA 100 CM/EA 1% BDY INFT/CHLD','15101','1','','1','0','','','',0, 1, 0, 0),
(606,'EPIDRM AGRFT T/A/L 1ST 100 CM/&/1% BDY INFT/CHLD','EPIDRM AGRFT T/A/L 1ST 100 CM/&/1% BDY INFT/CHLD','15110','1','','1','0','','','',0, 1, 0, 0),
(607,'EPIDRM AGRFT T/A/L EA 100 CM/EA 1% BDY INFT/CHLD','EPIDRM AGRFT T/A/L EA 100 CM/EA 1% BDY INFT/CHLD','15111','1','','1','0','','','',0, 1, 0, 0),
(608,'EPIDERMAL AGRFT F/S/N/H/F/G/M/D GT 1ST 100 CM/<','EPIDERMAL AGRFT F/S/N/H/F/G/M/D GT 1ST 100 CM/<','15115','1','','1','0','','','',0, 1, 0, 0),
(609,'EPIDERMAL AGRFT F/S/N/H/F/G/M/D GT EA 100 CM','EPIDERMAL AGRFT F/S/N/H/F/G/M/D GT EA 100 CM','15116','1','','1','0','','','',0, 1, 0, 0),
(610,'SPLIT AGRFT F/S/N/H/F/G/M/D GT 1ST 100 CM/</1 %','SPLIT AGRFT F/S/N/H/F/G/M/D GT 1ST 100 CM/</1 %','15120','1','','1','0','','','',0, 1, 0, 0),
(611,'SPLIT AGRFT F/S/N/H/F/G/M/D GT EA 100 CM/EA 1 %','SPLIT AGRFT F/S/N/H/F/G/M/D GT EA 100 CM/EA 1 %','15121','1','','1','0','','','',0, 1, 0, 0),
(612,'DERMAL AUTOGRAFT TRUNK/ARM/LEG 1ST 100 CM','DERMAL AUTOGRAFT TRUNK/ARM/LEG 1ST 100 CM','15130','1','','1','0','','','',0, 1, 0, 0),
(613,'DERMAL AUTOGRAFT TRUNK/ARM/LEG EA 100 CM/EA','DERMAL AUTOGRAFT TRUNK/ARM/LEG EA 100 CM/EA','15131','1','','1','0','','','',0, 1, 0, 0),
(614,'DERMAL AUTOGRAFT F/S/N/H/F/G/M/D GT 1ST 100','DERMAL AUTOGRAFT F/S/N/H/F/G/M/D GT 1ST 100','15135','1','','1','0','','','',0, 1, 0, 0),
(615,'DERMAL AGRFT F/S/N/H/F/G/M/D GT EA 100 CM/EA','DERMAL AGRFT F/S/N/H/F/G/M/D GT EA 100 CM/EA','15136','1','','1','0','','','',0, 1, 0, 0),
(616,'CLTR SKIN AUTOGRAFT T/A/L 1ST 25 CM/<','CLTR SKIN AUTOGRAFT T/A/L 1ST 25 CM/<','15150','1','','1','0','','','',0, 1, 0, 0),
(617,'CLTR SKIN AGRFT T/A/L ADDL 1 CM-75 CM','CLTR SKIN AGRFT T/A/L ADDL 1 CM-75 CM','15151','1','','1','0','','','',0, 1, 0, 0),
(618,'CLTR SKIN AGRFT T/A/L EA 100 CM/EA 1%BODY AREA','CLTR SKIN AGRFT T/A/L EA 100 CM/EA 1%BODY AREA','15152','1','','1','0','','','',0, 1, 0, 0),
(619,'CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT 1ST 25CM/<','CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT 1ST 25CM/<','15155','1','','1','0','','','',0, 1, 0, 0),
(620,'CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT ADDL 1-75CM','CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT ADDL 1-75CM','15156','1','','1','0','','','',0, 1, 0, 0),
(621,'CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT EA 100 EA','CLTR SKIN AGRFT F/S/N/H/F/G/M/D GT EA 100 EA','15157','1','','1','0','','','',0, 1, 0, 0),
(622,'FTH/GFT FREE W/DIRECT CLOSURE TRUNK 20 CM/<','FTH/GFT FREE W/DIRECT CLOSURE TRUNK 20 CM/<','15200','1','','1','0','','','',0, 1, 0, 0),
(623,'FTH/GFT FR W/DIR CLSR TRNK EA ADDL 20 CM/<','FTH/GFT FR W/DIR CLSR TRNK EA ADDL 20 CM/<','15201','1','','1','0','','','',0, 1, 0, 0),
(624,'FTH/GFT FREE W/DIRECT CLOSURE S/A/L 20 CM/<','FTH/GFT FREE W/DIRECT CLOSURE S/A/L 20 CM/<','15220','1','','1','0','','','',0, 1, 0, 0),
(625,'FTH/GFT FR W/DIR CLSR S/A/L EA ADDL 20 CM/<','FTH/GFT FR W/DIR CLSR S/A/L EA ADDL 20 CM/<','15221','1','','1','0','','','',0, 1, 0, 0),
(626,'FTH/GFT FR W/DIR CLSR F/C/C/M/N/AX/G/H/F 20 CM/<','FTH/GFT FR W/DIR CLSR F/C/C/M/N/AX/G/H/F 20 CM/<','15240','1','','1','0','','','',0, 1, 0, 0),
(627,'FTH/GT FR W/DIR CLSR F/C/C/M/N/AX/G/H/F EA20CM/<','FTH/GT FR W/DIR CLSR F/C/C/M/N/AX/G/H/F EA20CM/<','15241','1','','1','0','','','',0, 1, 0, 0),
(628,'FTH/GFT FREE W/DIRECT CLOSURE N/E/E/L 20 SQ CM/<','FTH/GFT FREE W/DIRECT CLOSURE N/E/E/L 20 SQ CM/<','15260','1','','1','0','','','',0, 1, 0, 0),
(629,'FTH/GFT FREE W/DIR CLSR N/E/E/L EA 20 SQ CM/<','FTH/GFT FREE W/DIR CLSR N/E/E/L EA 20 SQ CM/<','15261','1','','1','0','','','',0, 1, 0, 0),
(630,'APP SKN SUB GRFT T/A/L AREA/100SQ CM /<1ST 25','APP SKN SUB GRFT T/A/L AREA/100SQ CM /<1ST 25','15271','1','','1','0','','','',0, 1, 0, 0),
(631,'APP SKN SUB GRFT T/A/L AREA/100SQ CM EA ADL 25SC','APP SKN SUB GRFT T/A/L AREA/100SQ CM EA ADL 25SC','15272','1','','1','0','','','',0, 1, 0, 0),
(632,'APP SKN SUBGRFT T/A/L AREA/100SQ CM 1ST 100SQ CM','APP SKN SUBGRFT T/A/L AREA/100SQ CM 1ST 100SQ CM','15273','1','','1','0','','','',0, 1, 0, 0),
(633,'APP SKN SUB GRFT T/A/L AREA>/=100SCM ADL 100SQCM','APP SKN SUB GRFT T/A/L AREA>/=100SCM ADL 100SQCM','15274','1','','1','0','','','',0, 1, 0, 0),
(634,'SUB GRFT F/S/N/H/F/G/M/D <100SQ CM 1ST 25 SQ CM','SUB GRFT F/S/N/H/F/G/M/D <100SQ CM 1ST 25 SQ CM','15275','1','','1','0','','','',0, 1, 0, 0),
(635,'SUB GRFT F/S/N/H/F/G/M/D<100SQ CM EA ADDL25SQ CM','SUB GRFT F/S/N/H/F/G/M/D<100SQ CM EA ADDL25SQ CM','15276','1','','1','0','','','',0, 1, 0, 0),
(636,'SUB GRFT F/S/N/H/F/G/M/D >/= 100SCM 1ST 100SQ CM','SUB GRFT F/S/N/H/F/G/M/D >/= 100SCM 1ST 100SQ CM','15277','1','','1','0','','','',0, 1, 0, 0),
(637,'SUB GRFT F/S/N/H/F/G/M/D >/= 100SCM ADL 100SQ CM','SUB GRFT F/S/N/H/F/G/M/D >/= 100SCM ADL 100SQ CM','15278','1','','1','0','','','',0, 1, 0, 0),
(638,'FRMJ DIRECT/TUBED PEDICLE W/WO TRANSFER TRUNK','FRMJ DIRECT/TUBED PEDICLE W/WO TRANSFER TRUNK','15570','1','','1','0','','','',0, 1, 0, 0),
(639,'FRMJ DIRECT/TUBE PEDICLE W/WO TR SCALP ARMS/LEGS','FRMJ DIRECT/TUBE PEDICLE W/WO TR SCALP ARMS/LEGS','15572','1','','1','0','','','',0, 1, 0, 0),
(640,'FRMJ DIR/TUBE PEDCL W/WOTR FH/CH/CH/M/N/AX/G/H/F','FRMJ DIR/TUBE PEDCL W/WOTR FH/CH/CH/M/N/AX/G/H/F','15574','1','','1','0','','','',0, 1, 0, 0),
(641,'FRMJ DIRECT/TUBED PEDICLE W/WOTR E/N/E/L/NTRORAL','FRMJ DIRECT/TUBED PEDICLE W/WOTR E/N/E/L/NTRORAL','15576','1','','1','0','','','',0, 1, 0, 0),
(642,'DELAY FLAP/SECTIONING FLAP TRUNK','DELAY FLAP/SECTIONING FLAP TRUNK','15600','1','','1','0','','','',0, 1, 0, 0),
(643,'DELAY FLAP/SECTIONING FLAP SCALP ARMS/LEGS','DELAY FLAP/SECTIONING FLAP SCALP ARMS/LEGS','15610','1','','1','0','','','',0, 1, 0, 0),
(644,'DELAY FLAP/SECTIONING FLAP F/C/C/N/AX/G/H/F','DELAY FLAP/SECTIONING FLAP F/C/C/N/AX/G/H/F','15620','1','','1','0','','','',0, 1, 0, 0),
(645,'DELAY FLAP/SCTJ FLAP EYELIDS NOSE EARS/LIPS','DELAY FLAP/SCTJ FLAP EYELIDS NOSE EARS/LIPS','15630','1','','1','0','','','',0, 1, 0, 0),
(646,'TRANSFER ANY PEDICLE FLAP ANY LOCATION','TRANSFER ANY PEDICLE FLAP ANY LOCATION','15650','1','','1','0','','','',0, 1, 0, 0),
(647,'FOREHEAD FLAP W/PRESERVATION VASCULAR PEDICLE','FOREHEAD FLAP W/PRESERVATION VASCULAR PEDICLE','15731','1','','1','0','','','',0, 1, 0, 0),
(648,'MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP HEAD&NC','MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP HEAD&NC','15732','1','','1','0','','','',0, 1, 0, 0),
(649,'MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP TRUNK','MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP TRUNK','15734','1','','1','0','','','',0, 1, 0, 0),
(650,'MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP UXTR','MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP UXTR','15736','1','','1','0','','','',0, 1, 0, 0),
(651,'MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP LXTR','MUSC MYOCUTANEOUS/FASCIOCUTANEOUS FLAP LXTR','15738','1','','1','0','','','',0, 1, 0, 0),
(652,'FLAP ISLAND PEDICLE ANATOMIC NAMED AXIAL ARTERY','FLAP ISLAND PEDICLE ANATOMIC NAMED AXIAL ARTERY','15740','1','','1','0','','','',0, 1, 0, 0),
(653,'FLAP NEUROVASCULAR PEDICLE','FLAP NEUROVASCULAR PEDICLE','15750','1','','1','0','','','',0, 1, 0, 0),
(654,'FREE MUSCLE/MYOCUTANEOUS FLAP W/MVASC ANAST','FREE MUSCLE/MYOCUTANEOUS FLAP W/MVASC ANAST','15756','1','','1','0','','','',0, 1, 0, 0),
(655,'FREE SKIN FLAP W/MICROVASCULAR ANASTOMOSIS','FREE SKIN FLAP W/MICROVASCULAR ANASTOMOSIS','15757','1','','1','0','','','',0, 1, 0, 0),
(656,'FREE FASCIAL FLAP W/MICROVASCULAR ANASTOMOSIS','FREE FASCIAL FLAP W/MICROVASCULAR ANASTOMOSIS','15758','1','','1','0','','','',0, 1, 0, 0),
(657,'GRAFT COMPOSITE W/PRIMARY CLOSURE DONOR AREA','GRAFT COMPOSITE W/PRIMARY CLOSURE DONOR AREA','15760','1','','1','0','','','',0, 1, 0, 0),
(658,'GRAFT DERMA-FAT-FASCIA','GRAFT DERMA-FAT-FASCIA','15770','1','','1','0','','','',0, 1, 0, 0),
(659,'PUNCH GRAFT HAIR TRANSPLANT 1-15 PUNCH GRAFTS','PUNCH GRAFT HAIR TRANSPLANT 1-15 PUNCH GRAFTS','15775','1','','1','0','','','',0, 1, 0, 0),
(660,'PUNCH GRAFT HAIR TRANSPLANT >15 PUNCH GRAFTS','PUNCH GRAFT HAIR TRANSPLANT >15 PUNCH GRAFTS','15776','1','','1','0','','','',0, 1, 0, 0),
(661,'IMPLNT BIO IMPLNT FOR SOFT TISSUE REINFORCEMENT','IMPLNT BIO IMPLNT FOR SOFT TISSUE REINFORCEMENT','15777','1','','1','0','','','',0, 1, 0, 0),
(662,'DERMABRASION TOTAL FACE','DERMABRASION TOTAL FACE','15780','1','','1','0','','','',0, 1, 0, 0),
(663,'DERMABRASION SEGMENTAL FACE','DERMABRASION SEGMENTAL FACE','15781','1','','1','0','','','',0, 1, 0, 0),
(664,'DERMABRASION REGIONAL OTHER THAN FACE','DERMABRASION REGIONAL OTHER THAN FACE','15782','1','','1','0','','','',0, 1, 0, 0),
(665,'DERMABRASION SUPERFICIAL ANY SITE','DERMABRASION SUPERFICIAL ANY SITE','15783','1','','1','0','','','',0, 1, 0, 0),
(666,'ABRASION 1 LESION','ABRASION 1 LESION','15786','1','','1','0','','','',0, 1, 0, 0),
(667,'ABRASION EACH ADDITIONAL 4 LESIONS OR LESS','ABRASION EACH ADDITIONAL 4 LESIONS OR LESS','15787','1','','1','0','','','',0, 1, 0, 0),
(668,'CHEMICAL PEEL FACIAL EPIDERMAL','CHEMICAL PEEL FACIAL EPIDERMAL','15788','1','','1','0','','','',0, 1, 0, 0),
(669,'CHEMICAL PEEL FACIAL DERMAL','CHEMICAL PEEL FACIAL DERMAL','15789','1','','1','0','','','',0, 1, 0, 0),
(670,'CHEMICAL PEEL NONFACIAL EPIDERMAL','CHEMICAL PEEL NONFACIAL EPIDERMAL','15792','1','','1','0','','','',0, 1, 0, 0),
(671,'CHEMICAL PEEL NONFACIAL DERMAL','CHEMICAL PEEL NONFACIAL DERMAL','15793','1','','1','0','','','',0, 1, 0, 0),
(672,'CERVICOPLASTY','CERVICOPLASTY','15819','1','','1','0','','','',0, 1, 0, 0),
(673,'BLEPHAROPLASTY LOWER EYELID','BLEPHAROPLASTY LOWER EYELID','15820','1','','1','0','','','',0, 1, 0, 0),
(674,'BLEPHAROPLASTY LOWER EYELID HERNIATED FAT PAD','BLEPHAROPLASTY LOWER EYELID HERNIATED FAT PAD','15821','1','','1','0','','','',0, 1, 0, 0),
(675,'BLEPHAROPLASTY UPPER EYELID','BLEPHAROPLASTY UPPER EYELID','15822','1','','1','0','','','',0, 1, 0, 0),
(676,'BLEPHAROPLASTY UPPER EYELID W/EXCESSIVE SKIN','BLEPHAROPLASTY UPPER EYELID W/EXCESSIVE SKIN','15823','1','','1','0','','','',0, 1, 0, 0),
(677,'RHYTIDECTOMY FOREHEAD','RHYTIDECTOMY FOREHEAD','15824','1','','1','0','','','',0, 1, 0, 0),
(678,'RHYTIDECTOMY NECK W/PLATYSMAL TIGHTENING','RHYTIDECTOMY NECK W/PLATYSMAL TIGHTENING','15825','1','','1','0','','','',0, 1, 0, 0),
(679,'RHYTIDECTOMY GLABELLAR FROWN LINES','RHYTIDECTOMY GLABELLAR FROWN LINES','15826','1','','1','0','','','',0, 1, 0, 0),
(680,'RHYTIDECTOMY CHEEK CHIN & NECK','RHYTIDECTOMY CHEEK CHIN & NECK','15828','1','','1','0','','','',0, 1, 0, 0),
(681,'RHYTIDECTOMY SMAS FLAP','RHYTIDECTOMY SMAS FLAP','15829','1','','1','0','','','',0, 1, 0, 0),
(682,'EXCISION SKIN ABD INFRAUMBILICAL PANNICULECTOMY','EXCISION SKIN ABD INFRAUMBILICAL PANNICULECTOMY','15830','1','','1','0','','','',0, 1, 0, 0),
(683,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE THIGH','EXCISION EXCESSIVE SKIN & SUBQ TISSUE THIGH','15832','1','','1','0','','','',0, 1, 0, 0),
(684,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE LEG','EXCISION EXCESSIVE SKIN & SUBQ TISSUE LEG','15833','1','','1','0','','','',0, 1, 0, 0),
(685,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE HIP','EXCISION EXCESSIVE SKIN & SUBQ TISSUE HIP','15834','1','','1','0','','','',0, 1, 0, 0),
(686,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE BUTTOCK','EXCISION EXCESSIVE SKIN & SUBQ TISSUE BUTTOCK','15835','1','','1','0','','','',0, 1, 0, 0),
(687,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE ARM','EXCISION EXCESSIVE SKIN & SUBQ TISSUE ARM','15836','1','','1','0','','','',0, 1, 0, 0),
(688,'EXC EXCESSIVE SKIN &SUBQ TISSUE FOREARM/HAND','EXC EXCESSIVE SKIN &SUBQ TISSUE FOREARM/HAND','15837','1','','1','0','','','',0, 1, 0, 0),
(689,'EXC EXCSV SKIN & SUBQ TISSUE SUBMENTAL FAT PAD','EXC EXCSV SKIN & SUBQ TISSUE SUBMENTAL FAT PAD','15838','1','','1','0','','','',0, 1, 0, 0),
(690,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE OTHER AREA','EXCISION EXCESSIVE SKIN & SUBQ TISSUE OTHER AREA','15839','1','','1','0','','','',0, 1, 0, 0),
(691,'GRAFT FACIAL NERVE PARALYSIS FREE FASCIAL GRAFT','GRAFT FACIAL NERVE PARALYSIS FREE FASCIAL GRAFT','15840','1','','1','0','','','',0, 1, 0, 0),
(692,'GRAFT FACIAL NERVE PARALYSIS FREE MUSCLE GRAFT','GRAFT FACIAL NERVE PARALYSIS FREE MUSCLE GRAFT','15841','1','','1','0','','','',0, 1, 0, 0),
(693,'GRF FACIAL NRV PALYSS FR MUSCLE FLAP MICROSURG','GRF FACIAL NRV PALYSS FR MUSCLE FLAP MICROSURG','15842','1','','1','0','','','',0, 1, 0, 0),
(694,'GRF FACIAL NERVE PARALYSIS REGIONAL MUSCLE TR','GRF FACIAL NERVE PARALYSIS REGIONAL MUSCLE TR','15845','1','','1','0','','','',0, 1, 0, 0),
(695,'EXCISION EXCESSIVE SKIN & SUBQ TISSUE ABDOMEN','EXCISION EXCESSIVE SKIN & SUBQ TISSUE ABDOMEN','15847','1','','1','0','','','',0, 1, 0, 0),
(696,'REMOVAL SUTURES UNDER ANESTHESIA SAME SURGEON','REMOVAL SUTURES UNDER ANESTHESIA SAME SURGEON','15850','1','','1','0','','','',0, 1, 0, 0),
(697,'REMOVAL SUTURES UNDER ANESTHESIA OTHER SURGEON','REMOVAL SUTURES UNDER ANESTHESIA OTHER SURGEON','15851','1','','1','0','','','',0, 1, 0, 0),
(698,'DRESSING CHANGE UNDER ANESTHESIA','DRESSING CHANGE UNDER ANESTHESIA','15852','1','','1','0','','','',0, 1, 0, 0),
(699,'IV INJECTION TEST VASCULAR FLOW FLAP/GRAFT','IV INJECTION TEST VASCULAR FLOW FLAP/GRAFT','15860','1','','1','0','','','',0, 1, 0, 0),
(700,'SUCTION ASSISTED LIPECTOMY HEAD & NECK','SUCTION ASSISTED LIPECTOMY HEAD & NECK','15876','1','','1','0','','','',0, 1, 0, 0),
(701,'SUCTION ASSISTED LIPECTOMY TRUNK','SUCTION ASSISTED LIPECTOMY TRUNK','15877','1','','1','0','','','',0, 1, 0, 0),
(702,'SUCTION ASSISTED LIPECTOMY UPPER EXTREMITY','SUCTION ASSISTED LIPECTOMY UPPER EXTREMITY','15878','1','','1','0','','','',0, 1, 0, 0),
(703,'SUCTION ASSISTED LIPECTOMY LOWER EXTREMITY','SUCTION ASSISTED LIPECTOMY LOWER EXTREMITY','15879','1','','1','0','','','',0, 1, 0, 0),
(704,'EXC COCCYGEAL PR ULC W/COCCYGECTOMY W/PRIM SUTR','EXC COCCYGEAL PR ULC W/COCCYGECTOMY W/PRIM SUTR','15920','1','','1','0','','','',0, 1, 0, 0),
(705,'EXC COCCYGEAL PR ULC W/COCCYGECTOMY W/FLAP CLSR','EXC COCCYGEAL PR ULC W/COCCYGECTOMY W/FLAP CLSR','15922','1','','1','0','','','',0, 1, 0, 0),
(706,'EXCISION SACRAL PRESSURE ULCER W/PRIMARY SUTURE','EXCISION SACRAL PRESSURE ULCER W/PRIMARY SUTURE','15931','1','','1','0','','','',0, 1, 0, 0),
(707,'EXC SACRAL PRESSURE ULC W/PRIM SUTR W/OSTECTOMY','EXC SACRAL PRESSURE ULC W/PRIM SUTR W/OSTECTOMY','15933','1','','1','0','','','',0, 1, 0, 0),
(708,'EXCISION SACRAL PRESSURE ULCER W/SKIN FLAP CLSR','EXCISION SACRAL PRESSURE ULCER W/SKIN FLAP CLSR','15934','1','','1','0','','','',0, 1, 0, 0),
(709,'EXC SACRAL PR ULCER W/SKN FLAP CLSR W/OSTECTOMY','EXC SACRAL PR ULCER W/SKN FLAP CLSR W/OSTECTOMY','15935','1','','1','0','','','',0, 1, 0, 0),
(710,'EXC SAC PR ULC PREPJ MUSC/MYOQ FLAP/SKN GRF CLSR','EXC SAC PR ULC PREPJ MUSC/MYOQ FLAP/SKN GRF CLSR','15936','1','','1','0','','','',0, 1, 0, 0),
(711,'EXC SAC PR ULC PREPJ MUSC/MYOQ FLAP/SKN GRF OSTC','EXC SAC PR ULC PREPJ MUSC/MYOQ FLAP/SKN GRF OSTC','15937','1','','1','0','','','',0, 1, 0, 0),
(712,'EXC ISCHIAL PRESSURE ULCER W/PRIMARY SUTURE','EXC ISCHIAL PRESSURE ULCER W/PRIMARY SUTURE','15940','1','','1','0','','','',0, 1, 0, 0),
(713,'EXC ISCHIAL PR ULC W/PRIM SUTR W/OSTC ISCHIECT','EXC ISCHIAL PR ULC W/PRIM SUTR W/OSTC ISCHIECT','15941','1','','1','0','','','',0, 1, 0, 0),
(714,'EXC ISCHIAL PRESSURE ULCER W/SKIN FLAP CLOSURE','EXC ISCHIAL PRESSURE ULCER W/SKIN FLAP CLOSURE','15944','1','','1','0','','','',0, 1, 0, 0),
(715,'EXC ISCHIAL PR ULC W/SKN FLAP CLSR W/OSTECTOMY','EXC ISCHIAL PR ULC W/SKN FLAP CLSR W/OSTECTOMY','15945','1','','1','0','','','',0, 1, 0, 0),
(716,'EXC ISCHIAL PR ULCER W/OSTC MUSC/MYOQ FLAP/SKIN','EXC ISCHIAL PR ULCER W/OSTC MUSC/MYOQ FLAP/SKIN','15946','1','','1','0','','','',0, 1, 0, 0),
(717,'EXC TROCHANTERIC PRESSURE ULCER W/PRIMARY SUTR','EXC TROCHANTERIC PRESSURE ULCER W/PRIMARY SUTR','15950','1','','1','0','','','',0, 1, 0, 0),
(718,'EXC TRCHNTRIC PR ULCER W/PRIM SUTR W/OSTECTOMY','EXC TRCHNTRIC PR ULCER W/PRIM SUTR W/OSTECTOMY','15951','1','','1','0','','','',0, 1, 0, 0),
(719,'EXC TROCHANTERIC PR ULCER W/SKIN FLAP CLOSURE','EXC TROCHANTERIC PR ULCER W/SKIN FLAP CLOSURE','15952','1','','1','0','','','',0, 1, 0, 0),
(720,'EXC TRCHNTRIC PR ULC W/SKN FLAP CLSR W/OSTECTOMY','EXC TRCHNTRIC PR ULC W/SKN FLAP CLSR W/OSTECTOMY','15953','1','','1','0','','','',0, 1, 0, 0),
(721,'EXC TROCHANTERIC PR ULCER MUSC/MYOQ FLAP/SKIN','EXC TROCHANTERIC PR ULCER MUSC/MYOQ FLAP/SKIN','15956','1','','1','0','','','',0, 1, 0, 0),
(722,'EXC TRCHNTRIC PR ULC MUSC/MYOQ FLAP/SKIN W/OSTC','EXC TRCHNTRIC PR ULC MUSC/MYOQ FLAP/SKIN W/OSTC','15958','1','','1','0','','','',0, 1, 0, 0),
(723,'UNLISTED PROCEDURE EXCISION PRESSURE ULCER','UNLISTED PROCEDURE EXCISION PRESSURE ULCER','15999','1','','1','0','','','',0, 1, 0, 0),
(724,'INITIAL TX 1ST DEGREE BURN LOCAL TX','INITIAL TX 1ST DEGREE BURN LOCAL TX','16000','1','','1','0','','','',0, 1, 0, 0),
(725,'DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ SMALL','DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ SMALL','16020','1','','1','0','','','',0, 1, 0, 0),
(726,'DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ MEDIUM','DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ MEDIUM','16025','1','','1','0','','','',0, 1, 0, 0),
(727,'DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ LARGE','DRS&/DBRDMT PRTL-THKNS BURNS 1ST/SBSQ LARGE','16030','1','','1','0','','','',0, 1, 0, 0),
(728,'ESCHAROTOMY FIRST INCISION','ESCHAROTOMY FIRST INCISION','16035','1','','1','0','','','',0, 1, 0, 0),
(729,'ESCHAROTOMY EACH ADDITIONAL INCISION','ESCHAROTOMY EACH ADDITIONAL INCISION','16036','1','','1','0','','','',0, 1, 0, 0),
(730,'DESTRUCTION PREMALIGNANT LESION 1ST','DESTRUCTION PREMALIGNANT LESION 1ST','17000','1','','1','0','','','',0, 1, 0, 0),
(731,'DESTRUCTION PREMALIGNANT LESION 2-14 EA','DESTRUCTION PREMALIGNANT LESION 2-14 EA','17003','1','','1','0','','','',0, 1, 0, 0),
(732,'DESTRUCTION PREMALIGNANT LESION 15/>','DESTRUCTION PREMALIGNANT LESION 15/>','17004','1','','1','0','','','',0, 1, 0, 0),
(733,'DESTRUCTION CUTANEOUS VASC PROLIFERATIVE <10CM','DESTRUCTION CUTANEOUS VASC PROLIFERATIVE <10CM','17106','1','','1','0','','','',0, 1, 0, 0),
(734,'DSTRJ CUTANEOUS VASCULAR LESIONS 10.0-50.0 SQ CM','DSTRJ CUTANEOUS VASCULAR LESIONS 10.0-50.0 SQ CM','17107','1','','1','0','','','',0, 1, 0, 0),
(735,'DSTRJ CUTANEOUS VASCULAR LESIONS >50.0 SQ CM','DSTRJ CUTANEOUS VASCULAR LESIONS >50.0 SQ CM','17108','1','','1','0','','','',0, 1, 0, 0),
(736,'DESTRUCTION BENIGN LESIONS UP TO 14','DESTRUCTION BENIGN LESIONS UP TO 14','17110','1','','1','0','','','',0, 1, 0, 0),
(737,'DESTRUCTION BENIGN LESIONS 15/>','DESTRUCTION BENIGN LESIONS 15/>','17111','1','','1','0','','','',0, 1, 0, 0),
(738,'CHEMICAL CAUTERIZATION GRANULATION TISSUE','CHEMICAL CAUTERIZATION GRANULATION TISSUE','17250','1','','1','0','','','',0, 1, 0, 0),
(739,'DESTRUCTION MALIGNANT LESION T/A/L 0.5 CM/<','DESTRUCTION MALIGNANT LESION T/A/L 0.5 CM/<','17260','1','','1','0','','','',0, 1, 0, 0),
(740,'DESTRUCTION MAL LESION TRUNK/ARM/LEG 0.6-1.0 CM','DESTRUCTION MAL LESION TRUNK/ARM/LEG 0.6-1.0 CM','17261','1','','1','0','','','',0, 1, 0, 0),
(741,'DESTRUCTION MAL LESION TRUNK/ARM/LEG 1.1-2.0CM','DESTRUCTION MAL LESION TRUNK/ARM/LEG 1.1-2.0CM','17262','1','','1','0','','','',0, 1, 0, 0),
(742,'DESTRUCTION MAL LESION TRUNK/ARM/LEG 2.1-3.0CM','DESTRUCTION MAL LESION TRUNK/ARM/LEG 2.1-3.0CM','17263','1','','1','0','','','',0, 1, 0, 0),
(743,'DESTRUCTION MAL LESION TRUNK/ARM/LEG 3.1-4.0CM','DESTRUCTION MAL LESION TRUNK/ARM/LEG 3.1-4.0CM','17264','1','','1','0','','','',0, 1, 0, 0),
(744,'DESTRUCTION MAL LESION TRUNK/ARM/LEG > 4.0 CM','DESTRUCTION MAL LESION TRUNK/ARM/LEG > 4.0 CM','17266','1','','1','0','','','',0, 1, 0, 0),
(745,'DESTRUCTION MALIGNANT LESION S/N/H/F/G 0.5 CM/>','DESTRUCTION MALIGNANT LESION S/N/H/F/G 0.5 CM/>','17270','1','','1','0','','','',0, 1, 0, 0),
(746,'DESTRUCTION MALIGNANT LESION S/N/H/F/G 0.6-1.0CM','DESTRUCTION MALIGNANT LESION S/N/H/F/G 0.6-1.0CM','17271','1','','1','0','','','',0, 1, 0, 0),
(747,'DESTRUCTION MALIGNANT LESION S/N/H/F/G 1.1-2.0CM','DESTRUCTION MALIGNANT LESION S/N/H/F/G 1.1-2.0CM','17272','1','','1','0','','','',0, 1, 0, 0),
(748,'DESTRUCTION MALIGNANT LESION S/N/H/F/G 2.1-3.0CM','DESTRUCTION MALIGNANT LESION S/N/H/F/G 2.1-3.0CM','17273','1','','1','0','','','',0, 1, 0, 0),
(749,'DESTRUCTION MALIGNANT LESION S/N/H/F/G 3.1-4.0CM','DESTRUCTION MALIGNANT LESION S/N/H/F/G 3.1-4.0CM','17274','1','','1','0','','','',0, 1, 0, 0),
(750,'DSTRJ MAL LESION S/N/H/F/G LESION DIAM > 4.0 CM','DSTRJ MAL LESION S/N/H/F/G LESION DIAM > 4.0 CM','17276','1','','1','0','','','',0, 1, 0, 0),
(751,'DESTRUCTION MALIGNANT LESION F/E/E/N/L/M 0.5CM/<','DESTRUCTION MALIGNANT LESION F/E/E/N/L/M 0.5CM/<','17280','1','','1','0','','','',0, 1, 0, 0),
(752,'DESTRUCTION MAL LESION F/E/E/N/L/M 0.6-1.0CM','DESTRUCTION MAL LESION F/E/E/N/L/M 0.6-1.0CM','17281','1','','1','0','','','',0, 1, 0, 0),
(753,'DESTRUCTION MAL LESION F/E/E/N/L/M 1.1-2.0CM','DESTRUCTION MAL LESION F/E/E/N/L/M 1.1-2.0CM','17282','1','','1','0','','','',0, 1, 0, 0),
(754,'DESTRUCTION MAL LESION F/E/E/N/L/M 2.1-3.0CM','DESTRUCTION MAL LESION F/E/E/N/L/M 2.1-3.0CM','17283','1','','1','0','','','',0, 1, 0, 0),
(755,'DESTRUCTION MAL LESION F/E/E/N/L/M 3.1-4.0CM','DESTRUCTION MAL LESION F/E/E/N/L/M 3.1-4.0CM','17284','1','','1','0','','','',0, 1, 0, 0),
(756,'DESTRUCTION MAL LESION F/E/E/N/L/M >4.0 CM','DESTRUCTION MAL LESION F/E/E/N/L/M >4.0 CM','17286','1','','1','0','','','',0, 1, 0, 0),
(757,'MOHS MICROGRAPHIC H/N/H/F/G 1ST STAGE 5 BLOCKS','MOHS MICROGRAPHIC H/N/H/F/G 1ST STAGE 5 BLOCKS','17311','1','','1','0','','','',0, 1, 0, 0),
(758,'MOHS MICROGRAPHIC H/N/H/F/G EACH ADDL STAGE','MOHS MICROGRAPHIC H/N/H/F/G EACH ADDL STAGE','17312','1','','1','0','','','',0, 1, 0, 0),
(759,'MOHS TRUNK/ARM/LEG 1ST STAGE 5 BLOCKS','MOHS TRUNK/ARM/LEG 1ST STAGE 5 BLOCKS','17313','1','','1','0','','','',0, 1, 0, 0),
(760,'MOHS TRUNK/ARM/LEG EA STAGE AFTER 1ST STAGE','MOHS TRUNK/ARM/LEG EA STAGE AFTER 1ST STAGE','17314','1','','1','0','','','',0, 1, 0, 0),
(761,'MOHS TRUNK/ARM/LEG EA ADDL BLOCK ANY STAGE','MOHS TRUNK/ARM/LEG EA ADDL BLOCK ANY STAGE','17315','1','','1','0','','','',0, 1, 0, 0),
(762,'CRYOTHERAPY CO2 SLUSH LIQUID N2 ACNE','CRYOTHERAPY CO2 SLUSH LIQUID N2 ACNE','17340','1','','1','0','','','',0, 1, 0, 0),
(763,'CHEMICAL EXFOLIATION ACNE','CHEMICAL EXFOLIATION ACNE','17360','1','','1','0','','','',0, 1, 0, 0),
(764,'ELECTROLYSIS EPILATION EACH 30 MINUTES','ELECTROLYSIS EPILATION EACH 30 MINUTES','17380','1','','1','0','','','',0, 1, 0, 0),
(765,'UNLISTED PX SKIN MUC MEMBRANE & SUBQ TISSUE','UNLISTED PX SKIN MUC MEMBRANE & SUBQ TISSUE','17999','1','','1','0','','','',0, 1, 0, 0),
(766,'PUNCTURE ASPIRATION CYST BREAST','PUNCTURE ASPIRATION CYST BREAST','19000','1','','1','0','','','',0, 1, 0, 0),
(767,'PUNCTURE ASPIRATION BREAST EACH ADDITIONAL CYST','PUNCTURE ASPIRATION BREAST EACH ADDITIONAL CYST','19001','1','','1','0','','','',0, 1, 0, 0),
(768,'MASTOTOMY W/EXPLORATION/DRAINAGE ABSCESS DEEP','MASTOTOMY W/EXPLORATION/DRAINAGE ABSCESS DEEP','19020','1','','1','0','','','',0, 1, 0, 0),
(769,'INJECTION MAMMARY DUCTOGRAM/GALACTOGRAM','INJECTION MAMMARY DUCTOGRAM/GALACTOGRAM','19030','1','','1','0','','','',0, 1, 0, 0),
(770,'BX BREAST W/DEVICE 1ST LESION STEREOTACTIC GUID','BX BREAST W/DEVICE 1ST LESION STEREOTACTIC GUID','19081','1','','1','0','','','',0, 1, 0, 0),
(771,'BX BREAST W/DEVICE ADDL LESION STEREOTACT GUID','BX BREAST W/DEVICE ADDL LESION STEREOTACT GUID','19082','1','','1','0','','','',0, 1, 0, 0),
(772,'BX BREAST W/DEVICE 1ST LESION ULTRASOUND GUID','BX BREAST W/DEVICE 1ST LESION ULTRASOUND GUID','19083','1','','1','0','','','',0, 1, 0, 0),
(773,'BX BREAST W/DEVICE ADDL LESION ULTRASOUND GUID','BX BREAST W/DEVICE ADDL LESION ULTRASOUND GUID','19084','1','','1','0','','','',0, 1, 0, 0),
(774,'BX BREAST W/DEVICE 1ST LESION MAGNETIC RES GUID','BX BREAST W/DEVICE 1ST LESION MAGNETIC RES GUID','19085','1','','1','0','','','',0, 1, 0, 0),
(775,'BX BREAST W/DEVICE ADDL LESION MAGNET RES GUID','BX BREAST W/DEVICE ADDL LESION MAGNET RES GUID','19086','1','','1','0','','','',0, 1, 0, 0),
(776,'BX BREAST NEEDLE CORE W/O IMAGING GUIDANCE SPX','BX BREAST NEEDLE CORE W/O IMAGING GUIDANCE SPX','19100','1','','1','0','','','',0, 1, 0, 0),
(777,'BIOPSY BREAST OPEN INCISIONAL','BIOPSY BREAST OPEN INCISIONAL','19101','1','','1','0','','','',0, 1, 0, 0),
(778,'ABLTJ CRYOSURGICAL W/US GID EA FIBROADENOMA','ABLTJ CRYOSURGICAL W/US GID EA FIBROADENOMA','19105','1','','1','0','','','',0, 1, 0, 0),
(779,'NIPPLE EXPLORATION','NIPPLE EXPLORATION','19110','1','','1','0','','','',0, 1, 0, 0),
(780,'EXCISION LACTIFEROUS DUCT FISTULA','EXCISION LACTIFEROUS DUCT FISTULA','19112','1','','1','0','','','',0, 1, 0, 0),
(781,'EXC CYST/ABERRANT BREAST TISSUE OPEN 1/> LESION','EXC CYST/ABERRANT BREAST TISSUE OPEN 1/> LESION','19120','1','','1','0','','','',0, 1, 0, 0),
(782,'EXC BREAST LES PREOP PLMT RAD MARKER OPEN 1 LES','EXC BREAST LES PREOP PLMT RAD MARKER OPEN 1 LES','19125','1','','1','0','','','',0, 1, 0, 0),
(783,'EXC BRST LES PREOP PLMT RAD MARKER OPN EA ADDL','EXC BRST LES PREOP PLMT RAD MARKER OPN EA ADDL','19126','1','','1','0','','','',0, 1, 0, 0),
(784,'EXCISION CHEST WALL TUMOR INCLUDING RIBS','EXCISION CHEST WALL TUMOR INCLUDING RIBS','19260','1','','1','0','','','',0, 1, 0, 0),
(785,'EXC CHEST TUMOR W/RCNSTJ W/O MEDSTNL LMPHADEC','EXC CHEST TUMOR W/RCNSTJ W/O MEDSTNL LMPHADEC','19271','1','','1','0','','','',0, 1, 0, 0),
(786,'EXC CHEST TUMOR W/RCNSTJ W/MEDSTNL LMPHADEC','EXC CHEST TUMOR W/RCNSTJ W/MEDSTNL LMPHADEC','19272','1','','1','0','','','',0, 1, 0, 0),
(787,'PERQ DEVICE PLACEMENT BREAST LOC 1ST LES W/GDNCE','PERQ DEVICE PLACEMENT BREAST LOC 1ST LES W/GDNCE','19281','1','','1','0','','','',0, 1, 0, 0),
(788,'PERQ DEVICE PLACEMT BREAST LOC EA LESION W/GDNCE','PERQ DEVICE PLACEMT BREAST LOC EA LESION W/GDNCE','19282','1','','1','0','','','',0, 1, 0, 0),
(789,'PERQ BREAST LOC DEVICE PLACEMT 1ST STRTCTC GDNCE','PERQ BREAST LOC DEVICE PLACEMT 1ST STRTCTC GDNCE','19283','1','','1','0','','','',0, 1, 0, 0),
(790,'PERQ BREAST LOC DEVICE PLACEMT EA LESION STRTCTC','PERQ BREAST LOC DEVICE PLACEMT EA LESION STRTCTC','19284','1','','1','0','','','',0, 1, 0, 0),
(791,'PERQ BREAST LOC DEVICE PLACEMT 1ST LESIO US IMAG','PERQ BREAST LOC DEVICE PLACEMT 1ST LESIO US IMAG','19285','1','','1','0','','','',0, 1, 0, 0),
(792,'PERQ BREAST LOC DEVICE PLACEMT EACH LES US IMAGE','PERQ BREAST LOC DEVICE PLACEMT EACH LES US IMAGE','19286','1','','1','0','','','',0, 1, 0, 0),
(793,'PERQ BREAST LOC DEVICE PLACEMT 1ST LESIO MR GUID','PERQ BREAST LOC DEVICE PLACEMT 1ST LESIO MR GUID','19287','1','','1','0','','','',0, 1, 0, 0),
(794,'PERQ BREAST LOC DEVICE PLACEMT ADD LESIO MR GUID','PERQ BREAST LOC DEVICE PLACEMT ADD LESIO MR GUID','19288','1','','1','0','','','',0, 1, 0, 0),
(795,'PLMT EXPANDABLE CATH BRST FOLLOWING PRTL MAST','PLMT EXPANDABLE CATH BRST FOLLOWING PRTL MAST','19296','1','','1','0','','','',0, 1, 0, 0),
(796,'PLMT EXPANDABLE CATH BRST CONCURRENT PRTL MAST','PLMT EXPANDABLE CATH BRST CONCURRENT PRTL MAST','19297','1','','1','0','','','',0, 1, 0, 0),
(797,'PLMT RADTHX BRACHYTX BRST FOLLOWING PRTL MAST','PLMT RADTHX BRACHYTX BRST FOLLOWING PRTL MAST','19298','1','','1','0','','','',0, 1, 0, 0),
(798,'MASTECTOMY GYNECOMASTIA','MASTECTOMY GYNECOMASTIA','19300','1','','1','0','','','',0, 1, 0, 0),
(799,'MASTECTOMY PARTIAL','MASTECTOMY PARTIAL','19301','1','','1','0','','','',0, 1, 0, 0),
(800,'MASTECTOMY PARTIAL W/AXILLARY LYMPHADENECTOMY','MASTECTOMY PARTIAL W/AXILLARY LYMPHADENECTOMY','19302','1','','1','0','','','',0, 1, 0, 0),
(801,'MASTECTOMY SIMPLE COMPLETE','MASTECTOMY SIMPLE COMPLETE','19303','1','','1','0','','','',0, 1, 0, 0),
(802,'MASTECTOMY SUBCUTANEOUS','MASTECTOMY SUBCUTANEOUS','19304','1','','1','0','','','',0, 1, 0, 0),
(803,'MAST RAD W/PECTORAL MUSCLES AXILLARY LYMPH NODES','MAST RAD W/PECTORAL MUSCLES AXILLARY LYMPH NODES','19305','1','','1','0','','','',0, 1, 0, 0),
(804,'MAST RAD W/PECTORAL MUSC AX INT MAM LYMPH NODES','MAST RAD W/PECTORAL MUSC AX INT MAM LYMPH NODES','19306','1','','1','0','','','',0, 1, 0, 0),
(805,'MAST MODF RAD W/AX LYMPH NOD W/WO PECT/ALIS MIN','MAST MODF RAD W/AX LYMPH NOD W/WO PECT/ALIS MIN','19307','1','','1','0','','','',0, 1, 0, 0),
(806,'MASTOPEXY','MASTOPEXY','19316','1','','1','0','','','',0, 1, 0, 0),
(807,'REDUCTION MAMMAPLASTY','REDUCTION MAMMAPLASTY','19318','1','','1','0','','','',0, 1, 0, 0),
(808,'MAMMAPLASTY AUGMENTATION W/O PROSTHETIC IMPLANT','MAMMAPLASTY AUGMENTATION W/O PROSTHETIC IMPLANT','19324','1','','1','0','','','',0, 1, 0, 0),
(809,'MAMMAPLASTY AUGMENTATION W/PROSTHETIC IMPLANT','MAMMAPLASTY AUGMENTATION W/PROSTHETIC IMPLANT','19325','1','','1','0','','','',0, 1, 0, 0),
(810,'REMOVAL INTACT MAMMARY IMPLANT','REMOVAL INTACT MAMMARY IMPLANT','19328','1','','1','0','','','',0, 1, 0, 0),
(811,'REMOVAL MAMMARY IMPLANT MATERIAL','REMOVAL MAMMARY IMPLANT MATERIAL','19330','1','','1','0','','','',0, 1, 0, 0),
(812,'IMMT INSJ BRST PROSTH FLWG MASTOPEXY MAST/RCNSTJ','IMMT INSJ BRST PROSTH FLWG MASTOPEXY MAST/RCNSTJ','19340','1','','1','0','','','',0, 1, 0, 0),
(813,'DLYD INSJ BRST PROSTH FLWG MASTOPEXY MAST/RCNSTJ','DLYD INSJ BRST PROSTH FLWG MASTOPEXY MAST/RCNSTJ','19342','1','','1','0','','','',0, 1, 0, 0),
(814,'NIPPLE/AREOLA RECONSTRUCTION','NIPPLE/AREOLA RECONSTRUCTION','19350','1','','1','0','','','',0, 1, 0, 0),
(815,'CORRECTION INVERTED NIPPLES','CORRECTION INVERTED NIPPLES','19355','1','','1','0','','','',0, 1, 0, 0),
(816,'BRST RCNSTJ IMMT/DLYD W/TISS EXPANDER SBSQ XPNSJ','BRST RCNSTJ IMMT/DLYD W/TISS EXPANDER SBSQ XPNSJ','19357','1','','1','0','','','',0, 1, 0, 0),
(817,'BRST RCNSTJ W/LATSMS D/SI FLAP WO PRSTHC IMPL','BRST RCNSTJ W/LATSMS D/SI FLAP WO PRSTHC IMPL','19361','1','','1','0','','','',0, 1, 0, 0),
(818,'BREAST RECONSTRUCTION FREE FLAP','BREAST RECONSTRUCTION FREE FLAP','19364','1','','1','0','','','',0, 1, 0, 0),
(819,'BREAST RECONSTRUCTION OTHER TECHNIQUE','BREAST RECONSTRUCTION OTHER TECHNIQUE','19366','1','','1','0','','','',0, 1, 0, 0),
(820,'BREAST RECONSTRUCTION TRAM FLAP 1 PEDICLE','BREAST RECONSTRUCTION TRAM FLAP 1 PEDICLE','19367','1','','1','0','','','',0, 1, 0, 0),
(821,'BREAST RECONSTRUCTION TRAM 1 PEDCL MVASC ANAST','BREAST RECONSTRUCTION TRAM 1 PEDCL MVASC ANAST','19368','1','','1','0','','','',0, 1, 0, 0),
(822,'BREAST RECONSTRUCTION TRAM FLAP DOUBLE PEDICLE','BREAST RECONSTRUCTION TRAM FLAP DOUBLE PEDICLE','19369','1','','1','0','','','',0, 1, 0, 0),
(823,'OPEN PERIPROSTHETIC CAPSULOTOMY BREAST','OPEN PERIPROSTHETIC CAPSULOTOMY BREAST','19370','1','','1','0','','','',0, 1, 0, 0),
(824,'PERIPROSTHETIC CAPSULECTOMY BREAST','PERIPROSTHETIC CAPSULECTOMY BREAST','19371','1','','1','0','','','',0, 1, 0, 0),
(825,'REVISION RECONSTRUCTED BREAST','REVISION RECONSTRUCTED BREAST','19380','1','','1','0','','','',0, 1, 0, 0),
(826,'PREPARATION MOULAGE CUSTOM BREAST IMPLANT','PREPARATION MOULAGE CUSTOM BREAST IMPLANT','19396','1','','1','0','','','',0, 1, 0, 0),
(827,'UNLISTED PROCEDURE BREAST','UNLISTED PROCEDURE BREAST','19499','1','','1','0','','','',0, 1, 0, 0),
(828,'I&D SOFT TISSUE ABSCESS SUBFASC','I&D SOFT TISSUE ABSCESS SUBFASC','20005','1','','1','0','','','',0, 1, 0, 0),
(829,'EXPLORATION PENETRATING WOUND SPX NECK','EXPLORATION PENETRATING WOUND SPX NECK','20100','1','','1','0','','','',0, 1, 0, 0),
(830,'EXPLORATION PENETRATING WOUND SPX CHEST','EXPLORATION PENETRATING WOUND SPX CHEST','20101','1','','1','0','','','',0, 1, 0, 0),
(831,'EXPL PENETRATING WOUND SPX ABDOMEN/FLANK/BACK','EXPL PENETRATING WOUND SPX ABDOMEN/FLANK/BACK','20102','1','','1','0','','','',0, 1, 0, 0),
(832,'EXPLORATION PENETRATING WOUND SPX EXTREMITY','EXPLORATION PENETRATING WOUND SPX EXTREMITY','20103','1','','1','0','','','',0, 1, 0, 0),
(833,'EXCISION EPIPHYSEAL BAR','EXCISION EPIPHYSEAL BAR','20150','1','','1','0','','','',0, 1, 0, 0),
(834,'BIOPSY MUSCLE SUPERFICIAL','BIOPSY MUSCLE SUPERFICIAL','20200','1','','1','0','','','',0, 1, 0, 0),
(835,'BIOPSY MUSCLE DEEP','BIOPSY MUSCLE DEEP','20205','1','','1','0','','','',0, 1, 0, 0),
(836,'BIOPSY MUSCLE PERCUTANEOUS NEEDLE','BIOPSY MUSCLE PERCUTANEOUS NEEDLE','20206','1','','1','0','','','',0, 1, 0, 0),
(837,'BIOPSY BONE TROCAR/NEEDLE SUPERFICIAL','BIOPSY BONE TROCAR/NEEDLE SUPERFICIAL','20220','1','','1','0','','','',0, 1, 0, 0),
(838,'BIOPSY BONE TROCAR/NEEDLE DEEP','BIOPSY BONE TROCAR/NEEDLE DEEP','20225','1','','1','0','','','',0, 1, 0, 0),
(839,'BIOPSY BONE OPEN SUPERFICIAL','BIOPSY BONE OPEN SUPERFICIAL','20240','1','','1','0','','','',0, 1, 0, 0),
(840,'BIOPSY BONE OPEN DEEP','BIOPSY BONE OPEN DEEP','20245','1','','1','0','','','',0, 1, 0, 0),
(841,'BIOPSY VERTEBRAL BODY OPEN THORACIC','BIOPSY VERTEBRAL BODY OPEN THORACIC','20250','1','','1','0','','','',0, 1, 0, 0),
(842,'BIOPSY VERTEBRAL BODY OPEN LUMBAR/CERVICAL','BIOPSY VERTEBRAL BODY OPEN LUMBAR/CERVICAL','20251','1','','1','0','','','',0, 1, 0, 0),
(843,'INJECTION SINUS TRACT THERAPEUTIC SEPARATE PROC','INJECTION SINUS TRACT THERAPEUTIC SEPARATE PROC','20500','1','','1','0','','','',0, 1, 0, 0),
(844,'INJECTION SINUS TRACT DIAGNOSTIC','INJECTION SINUS TRACT DIAGNOSTIC','20501','1','','1','0','','','',0, 1, 0, 0),
(845,'REMOVAL FOREIGN BODY MUSCLE/TENDON SHEATH SIMPLE','REMOVAL FOREIGN BODY MUSCLE/TENDON SHEATH SIMPLE','20520','1','','1','0','','','',0, 1, 0, 0),
(846,'RMVL FOREIGN BODY MUSCLE/TENDON SHEATH DEEP/COMP','RMVL FOREIGN BODY MUSCLE/TENDON SHEATH DEEP/COMP','20525','1','','1','0','','','',0, 1, 0, 0),
(847,'INJECTION THERAPEUTIC CARPAL TUNNEL','INJECTION THERAPEUTIC CARPAL TUNNEL','20526','1','','1','0','','','',0, 1, 0, 0),
(848,'INJECTION ENZYME PALMAR FASCIAL CORD','INJECTION ENZYME PALMAR FASCIAL CORD','20527','1','','1','0','','','',0, 1, 0, 0),
(849,'INJECTION 1 TENDON SHEATH/LIGAMENT APONEUROSIS','INJECTION 1 TENDON SHEATH/LIGAMENT APONEUROSIS','20550','1','','1','0','','','',0, 1, 0, 0),
(850,'INJECTION SINGLE TENDON ORIGIN/INSERTION','INJECTION SINGLE TENDON ORIGIN/INSERTION','20551','1','','1','0','','','',0, 1, 0, 0),
(851,'INJECTION SINGLE/MLT TRIGGER POINT 1/2 MUSCLES','INJECTION SINGLE/MLT TRIGGER POINT 1/2 MUSCLES','20552','1','','1','0','','','',0, 1, 0, 0),
(852,'INJECTION SINGLE/MLT TRIGGER POINT 3/> MUSCLES','INJECTION SINGLE/MLT TRIGGER POINT 3/> MUSCLES','20553','1','','1','0','','','',0, 1, 0, 0),
(853,'PLACEMENT NEEDLES MUSCLE SUBSEQUENT RADIOELEMENT','PLACEMENT NEEDLES MUSCLE SUBSEQUENT RADIOELEMENT','20555','1','','1','0','','','',0, 1, 0, 0),
(854,'ARTHROCENTESIS ASPIR&/INJ SMALL JT/BURSA W/O US','ARTHROCENTESIS ASPIR&/INJ SMALL JT/BURSA W/O US','20600','1','','1','0','','','',0, 1, 0, 0),
(855,'ARTHROCNT ASPIR&/INJ SMALL JT/BURSAW/US REC RPRT','ARTHROCNT ASPIR&/INJ SMALL JT/BURSAW/US REC RPRT','20604','1','','1','0','','','',0, 1, 0, 0),
(856,'ARTHROCENTESIS ASPIR&/INJ INTERM JT/BURS W/O US','ARTHROCENTESIS ASPIR&/INJ INTERM JT/BURS W/O US','20605','1','','1','0','','','',0, 1, 0, 0),
(857,'ARTHROCENTESIS ASPIR&/INJ INTERM JT/BURS W/US','ARTHROCENTESIS ASPIR&/INJ INTERM JT/BURS W/US','20606','1','','1','0','','','',0, 1, 0, 0),
(858,'ARTHROCENTESIS ASPIR&/INJ MAJOR JT/BURSA W/O US','ARTHROCENTESIS ASPIR&/INJ MAJOR JT/BURSA W/O US','20610','1','','1','0','','','',0, 1, 0, 0),
(859,'ARTHROCENTESIS ASPIR&/INJ MAJOR JT/BURSA W/US','ARTHROCENTESIS ASPIR&/INJ MAJOR JT/BURSA W/US','20611','1','','1','0','','','',0, 1, 0, 0),
(860,'ASPIRATION&/INJECTION GANGLION CYST ANY LOCATJ','ASPIRATION&/INJECTION GANGLION CYST ANY LOCATJ','20612','1','','1','0','','','',0, 1, 0, 0),
(861,'ASPIRATION & INJECTION TREATMENT BONE CYST','ASPIRATION & INJECTION TREATMENT BONE CYST','20615','1','','1','0','','','',0, 1, 0, 0),
(862,'INSERTION WIRE/PIN W/APPL SKELETAL TRACTION SPX','INSERTION WIRE/PIN W/APPL SKELETAL TRACTION SPX','20650','1','','1','0','','','',0, 1, 0, 0),
(863,'APPL CRANIAL TONG/STRTCTC FRAME W/REMOVAL SPX','APPL CRANIAL TONG/STRTCTC FRAME W/REMOVAL SPX','20660','1','','1','0','','','',0, 1, 0, 0),
(864,'APPLICATION HALO CRANIAL INCLUDING REMOVAL','APPLICATION HALO CRANIAL INCLUDING REMOVAL','20661','1','','1','0','','','',0, 1, 0, 0),
(865,'APPLICATION HALO PELVIC INCLUDING REMOVAL','APPLICATION HALO PELVIC INCLUDING REMOVAL','20662','1','','1','0','','','',0, 1, 0, 0),
(866,'APPLICATION HALO FEMORAL INCLUDING REMOVAL','APPLICATION HALO FEMORAL INCLUDING REMOVAL','20663','1','','1','0','','','',0, 1, 0, 0),
(867,'APPL HALO 6/> PINS THIN SKULL OSTEOLOGY','APPL HALO 6/> PINS THIN SKULL OSTEOLOGY','20664','1','','1','0','','','',0, 1, 0, 0),
(868,'REMOVAL TONG/HALO APPLIED BY ANOTHER INDIVIDUAL','REMOVAL TONG/HALO APPLIED BY ANOTHER INDIVIDUAL','20665','1','','1','0','','','',0, 1, 0, 0),
(869,'REMOVAL IMPLANT SUPERFICIAL SEPARATE PROCEDURE','REMOVAL IMPLANT SUPERFICIAL SEPARATE PROCEDURE','20670','1','','1','0','','','',0, 1, 0, 0),
(870,'REMOVAL IMPLANT DEEP','REMOVAL IMPLANT DEEP','20680','1','','1','0','','','',0, 1, 0, 0),
(871,'APPLICATION UNIPLANE EXTERNAL FIXATION SYSTEM','APPLICATION UNIPLANE EXTERNAL FIXATION SYSTEM','20690','1','','1','0','','','',0, 1, 0, 0),
(872,'APPLICATION MULTIPLANE EXTERNAL FIXATION SYSTEM','APPLICATION MULTIPLANE EXTERNAL FIXATION SYSTEM','20692','1','','1','0','','','',0, 1, 0, 0),
(873,'ADJUSTMENT/REVJ XTRNL FIXATION SYSTEM REQ ANES','ADJUSTMENT/REVJ XTRNL FIXATION SYSTEM REQ ANES','20693','1','','1','0','','','',0, 1, 0, 0),
(874,'REMOVAL EXTERNAL FIXATION SYSTEM UNDER ANES','REMOVAL EXTERNAL FIXATION SYSTEM UNDER ANES','20694','1','','1','0','','','',0, 1, 0, 0),
(875,'XTRNL FIXJ W/STEREOTACTIC ADJUSTMENT 1ST & SUBQ','XTRNL FIXJ W/STEREOTACTIC ADJUSTMENT 1ST & SUBQ','20696','1','','1','0','','','',0, 1, 0, 0),
(876,'XTRNL FIXJ W/STRTCTC ADJUSTMENT EXCHANGE STRUT','XTRNL FIXJ W/STRTCTC ADJUSTMENT EXCHANGE STRUT','20697','1','','1','0','','','',0, 1, 0, 0),
(877,'REPLANTATION ARM COMPLETE AMPUTATION','REPLANTATION ARM COMPLETE AMPUTATION','20802','1','','1','0','','','',0, 1, 0, 0),
(878,'REPLANTATION FOREARM COMPLETE AMPUTATION','REPLANTATION FOREARM COMPLETE AMPUTATION','20805','1','','1','0','','','',0, 1, 0, 0),
(879,'REPLANTATION HAND COMPLETE AMPUTATION','REPLANTATION HAND COMPLETE AMPUTATION','20808','1','','1','0','','','',0, 1, 0, 0),
(880,'RPLJ DGT EXCEPT THMB MTCARPHLNGL JT COMPL AMP','RPLJ DGT EXCEPT THMB MTCARPHLNGL JT COMPL AMP','20816','1','','1','0','','','',0, 1, 0, 0),
(881,'RPLJ DGT EXCLUDING THMB SUBLIMIS TDN COMPL AMP','RPLJ DGT EXCLUDING THMB SUBLIMIS TDN COMPL AMP','20822','1','','1','0','','','',0, 1, 0, 0),
(882,'RPLJ THMB CARP/MTCRPL JT MP JT COMPL AMPUTATION','RPLJ THMB CARP/MTCRPL JT MP JT COMPL AMPUTATION','20824','1','','1','0','','','',0, 1, 0, 0),
(883,'RPLJ THUMB DISTAL TIP MP JOINT COMPL AMPUTATION','RPLJ THUMB DISTAL TIP MP JOINT COMPL AMPUTATION','20827','1','','1','0','','','',0, 1, 0, 0),
(884,'REPLANTATION FOOT COMPLETE AMPUTATION','REPLANTATION FOOT COMPLETE AMPUTATION','20838','1','','1','0','','','',0, 1, 0, 0),
(885,'BONE GRAFT ANY DONOR AREA MINOR/SMALL','BONE GRAFT ANY DONOR AREA MINOR/SMALL','20900','1','','1','0','','','',0, 1, 0, 0),
(886,'BONE GRAFT ANY DONOR AREA MAJOR/LARGE','BONE GRAFT ANY DONOR AREA MAJOR/LARGE','20902','1','','1','0','','','',0, 1, 0, 0),
(887,'CARTILAGE GRAFT COSTOCHONDRAL','CARTILAGE GRAFT COSTOCHONDRAL','20910','1','','1','0','','','',0, 1, 0, 0),
(888,'CARTILAGE GRAFT NASAL SEPTUM','CARTILAGE GRAFT NASAL SEPTUM','20912','1','','1','0','','','',0, 1, 0, 0),
(889,'FASCIA LATA GRAFT BY STRIPPER','FASCIA LATA GRAFT BY STRIPPER','20920','1','','1','0','','','',0, 1, 0, 0),
(890,'FASCIA LATA GRAFT INCISION & AREA EXPOSURE','FASCIA LATA GRAFT INCISION & AREA EXPOSURE','20922','1','','1','0','','','',0, 1, 0, 0),
(891,'TENDON GRAFT FROM A DISTANCE','TENDON GRAFT FROM A DISTANCE','20924','1','','1','0','','','',0, 1, 0, 0),
(892,'TISSUE GRAFTS OTHER','TISSUE GRAFTS OTHER','20926','1','','1','0','','','',0, 1, 0, 0),
(893,'ALLOGRAFT FOR SPINE SURGERY ONLY MORSELIZED','ALLOGRAFT FOR SPINE SURGERY ONLY MORSELIZED','20930','1','','1','0','','','',0, 1, 0, 0),
(894,'ALLOGRAFT FOR SPINE SURGERY ONLY STRUCTURAL','ALLOGRAFT FOR SPINE SURGERY ONLY STRUCTURAL','20931','1','','1','0','','','',0, 1, 0, 0),
(895,'AUTOGRAFT SPINE SURGERY LOCAL FROM SAME INCISION','AUTOGRAFT SPINE SURGERY LOCAL FROM SAME INCISION','20936','1','','1','0','','','',0, 1, 0, 0),
(896,'AUTOGRAFT SPINE SURGERY MORSELIZED SEP INCISION','AUTOGRAFT SPINE SURGERY MORSELIZED SEP INCISION','20937','1','','1','0','','','',0, 1, 0, 0),
(897,'AUTOGRAFT SPINE SURGERY BICORT/TRICORT SEP INC','AUTOGRAFT SPINE SURGERY BICORT/TRICORT SEP INC','20938','1','','1','0','','','',0, 1, 0, 0),
(898,'MNTR INTERSTITIAL FLUID PRESSURE CMPRT SYNDROME','MNTR INTERSTITIAL FLUID PRESSURE CMPRT SYNDROME','20950','1','','1','0','','','',0, 1, 0, 0),
(899,'BONE GRAFT MICROVASCULAR ANASTOMOSIS FIBULA','BONE GRAFT MICROVASCULAR ANASTOMOSIS FIBULA','20955','1','','1','0','','','',0, 1, 0, 0),
(900,'BONE GRAFT MICROVASCULAR ANAST ILIAC CREST','BONE GRAFT MICROVASCULAR ANAST ILIAC CREST','20956','1','','1','0','','','',0, 1, 0, 0),
(901,'BONE GRAFT MICROVASCULAR ANAST METATARSAL','BONE GRAFT MICROVASCULAR ANAST METATARSAL','20957','1','','1','0','','','',0, 1, 0, 0),
(902,'BONE GRF W/MVASC ANAST OTH/THN ILIAC CREST/METAR','BONE GRF W/MVASC ANAST OTH/THN ILIAC CREST/METAR','20962','1','','1','0','','','',0, 1, 0, 0),
(903,'FREE OSTQ FLAP W/MVASC ANAST METAR/GREAT TOE','FREE OSTQ FLAP W/MVASC ANAST METAR/GREAT TOE','20969','1','','1','0','','','',0, 1, 0, 0),
(904,'FREE OSTQ FLAP W/MVASC ANASTOMOSIS ILIAC CREST','FREE OSTQ FLAP W/MVASC ANASTOMOSIS ILIAC CREST','20970','1','','1','0','','','',0, 1, 0, 0),
(905,'FREE OSTQ FLAP W/MVASC ANASTOMOSIS METATARSAL','FREE OSTQ FLAP W/MVASC ANASTOMOSIS METATARSAL','20972','1','','1','0','','','',0, 1, 0, 0),
(906,'FR OSTQ FLAP W/MVASC ANAST GRT TOE W/WEB SPACE','FR OSTQ FLAP W/MVASC ANAST GRT TOE W/WEB SPACE','20973','1','','1','0','','','',0, 1, 0, 0),
(907,'ELECTRICAL STIMULATION BONE HEALING NONINVASIVE','ELECTRICAL STIMULATION BONE HEALING NONINVASIVE','20974','1','','1','0','','','',0, 1, 0, 0),
(908,'ELECTRICAL STIMULATION BONE HEALING INVASIVE','ELECTRICAL STIMULATION BONE HEALING INVASIVE','20975','1','','1','0','','','',0, 1, 0, 0),
(909,'LOW INTENSITY US STIMJ BONE HEALING NONINVASIVE','LOW INTENSITY US STIMJ BONE HEALING NONINVASIVE','20979','1','','1','0','','','',0, 1, 0, 0),
(910,'ABLATION BONE TUMOR RF PERQ W/IMG GDN WHEN DONE','ABLATION BONE TUMOR RF PERQ W/IMG GDN WHEN DONE','20982','1','','1','0','','','',0, 1, 0, 0),
(911,'ABLATJ BONE TUMOR CRYO PERQ W/IMG GDN WHEN PRFMD','ABLATJ BONE TUMOR CRYO PERQ W/IMG GDN WHEN PRFMD','20983','1','','1','0','','','',0, 1, 0, 0),
(912,'CPTR-ASST SURGICAL NAVIGATION IMAGE-LESS','CPTR-ASST SURGICAL NAVIGATION IMAGE-LESS','20985','1','','1','0','','','',0, 1, 0, 0),
(913,'UNLISTED PROCEDURE MUSCSKELETAL SYSTEM GENERAL','UNLISTED PROCEDURE MUSCSKELETAL SYSTEM GENERAL','20999','1','','1','0','','','',0, 1, 0, 0),
(914,'ARTHROTOMY TEMPOROMANDIBULAR JOINT','ARTHROTOMY TEMPOROMANDIBULAR JOINT','21010','1','','1','0','','','',0, 1, 0, 0),
(915,'EXCISION TUMOR SOFT TISS FACE/SCALP SUBQ <2CM','EXCISION TUMOR SOFT TISS FACE/SCALP SUBQ <2CM','21011','1','','1','0','','','',0, 1, 0, 0),
(916,'EXCISION TUMOR SOFT TISS FACE/SCALP SUBQ 2 CM/>','EXCISION TUMOR SOFT TISS FACE/SCALP SUBQ 2 CM/>','21012','1','','1','0','','','',0, 1, 0, 0),
(917,'EXC TUMOR SOFT TISS FACE&SCALP SUBFASCIAL <2CM','EXC TUMOR SOFT TISS FACE&SCALP SUBFASCIAL <2CM','21013','1','','1','0','','','',0, 1, 0, 0),
(918,'EXC TUMOR SOFT TISS FACE&SCALP SUBFASCIAL 2 CM/>','EXC TUMOR SOFT TISS FACE&SCALP SUBFASCIAL 2 CM/>','21014','1','','1','0','','','',0, 1, 0, 0),
(919,'RAD RESECTION TUMOR SOFT TISS FACE/SCALP < 2CM','RAD RESECTION TUMOR SOFT TISS FACE/SCALP < 2CM','21015','1','','1','0','','','',0, 1, 0, 0),
(920,'RAD RESECTION TUMOR SOFT TISS FACE/SCALP 2 CM/>','RAD RESECTION TUMOR SOFT TISS FACE/SCALP 2 CM/>','21016','1','','1','0','','','',0, 1, 0, 0),
(921,'EXCISION BONE MANDIBLE','EXCISION BONE MANDIBLE','21025','1','','1','0','','','',0, 1, 0, 0),
(922,'EXCISION FACIAL BONE','EXCISION FACIAL BONE','21026','1','','1','0','','','',0, 1, 0, 0),
(923,'REMOVAL CONTOURING BENIGN TUMOR FACIAL BONE','REMOVAL CONTOURING BENIGN TUMOR FACIAL BONE','21029','1','','1','0','','','',0, 1, 0, 0),
(924,'EXC BENIGN TUMOR/CYST MAXL/ZYGOMA ENCL & CURTG','EXC BENIGN TUMOR/CYST MAXL/ZYGOMA ENCL & CURTG','21030','1','','1','0','','','',0, 1, 0, 0),
(925,'EXCISION TORUS MANDIBULARIS','EXCISION TORUS MANDIBULARIS','21031','1','','1','0','','','',0, 1, 0, 0),
(926,'EXCISION MAXILLARY TORUS PALATINUS','EXCISION MAXILLARY TORUS PALATINUS','21032','1','','1','0','','','',0, 1, 0, 0),
(927,'EXCISION MALIGNANT TUMOR MAXILLA/ZYGOMA','EXCISION MALIGNANT TUMOR MAXILLA/ZYGOMA','21034','1','','1','0','','','',0, 1, 0, 0),
(928,'EXCISION BENIGN TUMOR/CYST MANDIBLE ENCL & CURT','EXCISION BENIGN TUMOR/CYST MANDIBLE ENCL & CURT','21040','1','','1','0','','','',0, 1, 0, 0),
(929,'EXCISION MALIGNANT TUMOR MANDIBLE','EXCISION MALIGNANT TUMOR MANDIBLE','21044','1','','1','0','','','',0, 1, 0, 0),
(930,'EXCISION MALIGNANT TUMOR MANDIBLE RADICAL','EXCISION MALIGNANT TUMOR MANDIBLE RADICAL','21045','1','','1','0','','','',0, 1, 0, 0),
(931,'EXC BENIGN TUMOR/CYST MNDBL INTRA-ORAL OSTEOT','EXC BENIGN TUMOR/CYST MNDBL INTRA-ORAL OSTEOT','21046','1','','1','0','','','',0, 1, 0, 0),
(932,'EXC B9 TUM/CST MNDBL XTR-ORAL OSTEOT&PRTL MNDB','EXC B9 TUM/CST MNDBL XTR-ORAL OSTEOT&PRTL MNDB','21047','1','','1','0','','','',0, 1, 0, 0),
(933,'EXC BENIGN TUMOR/CYST MAXL INTRA-ORAL OSTEOT','EXC BENIGN TUMOR/CYST MAXL INTRA-ORAL OSTEOT','21048','1','','1','0','','','',0, 1, 0, 0),
(934,'EXC B9 TUM/CST MAXL XTR-ORAL OSTEOT&PRTL MAXLC','EXC B9 TUM/CST MAXL XTR-ORAL OSTEOT&PRTL MAXLC','21049','1','','1','0','','','',0, 1, 0, 0),
(935,'CONDYLECTOMY TEMPOROMANDIBULAR JOINT SPX','CONDYLECTOMY TEMPOROMANDIBULAR JOINT SPX','21050','1','','1','0','','','',0, 1, 0, 0),
(936,'MENISCECTOMY PRTL/COMPL TEMPOROMANDIBULAR JT SPX','MENISCECTOMY PRTL/COMPL TEMPOROMANDIBULAR JT SPX','21060','1','','1','0','','','',0, 1, 0, 0),
(937,'CORONOIDECTOMY SEPARATE PROCEDURE','CORONOIDECTOMY SEPARATE PROCEDURE','21070','1','','1','0','','','',0, 1, 0, 0),
(938,'MANIPULATION TMJ THERAPEUTIC REQUIRE ANESTHESIA','MANIPULATION TMJ THERAPEUTIC REQUIRE ANESTHESIA','21073','1','','1','0','','','',0, 1, 0, 0),
(939,'IMPRESSION&PREPARATION SURG OBTURATOR PROSTHES','IMPRESSION&PREPARATION SURG OBTURATOR PROSTHES','21076','1','','1','0','','','',0, 1, 0, 0),
(940,'IMPRESSION & PREPARATION ORBITAL PROSTHESIS','IMPRESSION & PREPARATION ORBITAL PROSTHESIS','21077','1','','1','0','','','',0, 1, 0, 0),
(941,'IMPRESSION & PREPARATION INTERIM OBTURATOR PROST','IMPRESSION & PREPARATION INTERIM OBTURATOR PROST','21079','1','','1','0','','','',0, 1, 0, 0),
(942,'IMPRESSION & PREPJ DEFINITIVE OBTURATOR PROSTHES','IMPRESSION & PREPJ DEFINITIVE OBTURATOR PROSTHES','21080','1','','1','0','','','',0, 1, 0, 0),
(943,'IMPRESSION & PREPJ MANDIBULAR RESECTION PROSTHES','IMPRESSION & PREPJ MANDIBULAR RESECTION PROSTHES','21081','1','','1','0','','','',0, 1, 0, 0),
(944,'IMPRESSION & PREPJ PALATAL AUGMENTATION PROSTHES','IMPRESSION & PREPJ PALATAL AUGMENTATION PROSTHES','21082','1','','1','0','','','',0, 1, 0, 0),
(945,'IMPRESSION & PREPARATION PALATAL LIFT PROSTHESIS','IMPRESSION & PREPARATION PALATAL LIFT PROSTHESIS','21083','1','','1','0','','','',0, 1, 0, 0),
(946,'IMPRESSION & PREPARATION SPEECH AID PROSTHESIS','IMPRESSION & PREPARATION SPEECH AID PROSTHESIS','21084','1','','1','0','','','',0, 1, 0, 0),
(947,'IMPRESSION & PREPARATION ORAL SURGICAL SPLINT','IMPRESSION & PREPARATION ORAL SURGICAL SPLINT','21085','1','','1','0','','','',0, 1, 0, 0),
(948,'IMPRESSION & PREPARATION AURICULAR PROSTHESIS','IMPRESSION & PREPARATION AURICULAR PROSTHESIS','21086','1','','1','0','','','',0, 1, 0, 0),
(949,'IMPRESSION & PREPARATION NASAL PROSTHESIS','IMPRESSION & PREPARATION NASAL PROSTHESIS','21087','1','','1','0','','','',0, 1, 0, 0),
(950,'IMPRESSION & PREPARATION FACIAL PROSTHESIS','IMPRESSION & PREPARATION FACIAL PROSTHESIS','21088','1','','1','0','','','',0, 1, 0, 0),
(951,'UNLISTED MAXILLOFACIAL PROSTHETIC PROCEDURE','UNLISTED MAXILLOFACIAL PROSTHETIC PROCEDURE','21089','1','','1','0','','','',0, 1, 0, 0),
(952,'APPL HALO APPLIANCE MAXILLOFACIAL FIXATION SPX','APPL HALO APPLIANCE MAXILLOFACIAL FIXATION SPX','21100','1','','1','0','','','',0, 1, 0, 0),
(953,'APPL INTERDENTAL FIXATION DEVICE NON-FX/DISLC','APPL INTERDENTAL FIXATION DEVICE NON-FX/DISLC','21110','1','','1','0','','','',0, 1, 0, 0),
(954,'INJECTION TEMPOROMANDIBULAR JOINT ARTHROGRAPHY','INJECTION TEMPOROMANDIBULAR JOINT ARTHROGRAPHY','21116','1','','1','0','','','',0, 1, 0, 0),
(955,'GENIOPLASTY AUGMENTATION','GENIOPLASTY AUGMENTATION','21120','1','','1','0','','','',0, 1, 0, 0),
(956,'GENIOPLASTY SLIDING OSTEOTOMY SINGLE PIECE','GENIOPLASTY SLIDING OSTEOTOMY SINGLE PIECE','21121','1','','1','0','','','',0, 1, 0, 0),
(957,'GENIOPLASTY 2/> SLIDING OSTEOTOMIES','GENIOPLASTY 2/> SLIDING OSTEOTOMIES','21122','1','','1','0','','','',0, 1, 0, 0),
(958,'GENIOP SLIDING AGMNTJ W/INTERPOSAL BONE GRAFTS','GENIOP SLIDING AGMNTJ W/INTERPOSAL BONE GRAFTS','21123','1','','1','0','','','',0, 1, 0, 0),
(959,'AGMNTJ MNDBLR BODY/ANGLE PROSTHETIC MATERIAL','AGMNTJ MNDBLR BODY/ANGLE PROSTHETIC MATERIAL','21125','1','','1','0','','','',0, 1, 0, 0),
(960,'AGMNTJ MNDBLR BDY/ANGL W/GRF ONLAY/INTERPOSAL','AGMNTJ MNDBLR BDY/ANGL W/GRF ONLAY/INTERPOSAL','21127','1','','1','0','','','',0, 1, 0, 0),
(961,'REDUCTION FOREHEAD CONTOURING ONLY','REDUCTION FOREHEAD CONTOURING ONLY','21137','1','','1','0','','','',0, 1, 0, 0),
(962,'RDCTJ FHD CNTRG & PROSTHETIC MATRL/BONE GRAFT','RDCTJ FHD CNTRG & PROSTHETIC MATRL/BONE GRAFT','21138','1','','1','0','','','',0, 1, 0, 0),
(963,'RDCTJ FHD CNTRG & SETBACK ANT FRONTAL SINUS WALL','RDCTJ FHD CNTRG & SETBACK ANT FRONTAL SINUS WALL','21139','1','','1','0','','','',0, 1, 0, 0),
(964,'RCNSTJ MIDFACE LEFORT I 1 PIECE W/O BONE GRAFT','RCNSTJ MIDFACE LEFORT I 1 PIECE W/O BONE GRAFT','21141','1','','1','0','','','',0, 1, 0, 0),
(965,'RCNSTJ MIDFACE LEFORT I 2 PIECES W/O BONE GRAFT','RCNSTJ MIDFACE LEFORT I 2 PIECES W/O BONE GRAFT','21142','1','','1','0','','','',0, 1, 0, 0),
(966,'RCNSTJ MIDFACE LEFORT I 3/> PIECE W/O BONE GRAFT','RCNSTJ MIDFACE LEFORT I 3/> PIECE W/O BONE GRAFT','21143','1','','1','0','','','',0, 1, 0, 0),
(967,'RCNSTJ MIDFACE LEFORT I 1 PIECE W/BONE GRAFTS','RCNSTJ MIDFACE LEFORT I 1 PIECE W/BONE GRAFTS','21145','1','','1','0','','','',0, 1, 0, 0),
(968,'RCNSTJ MIDFACE LEFORT I 2 PIECES W/BONE GRAFTS','RCNSTJ MIDFACE LEFORT I 2 PIECES W/BONE GRAFTS','21146','1','','1','0','','','',0, 1, 0, 0),
(969,'RCNSTJ MIDFACE LEFORT I 3/> PIECE W/BONE GRAFTS','RCNSTJ MIDFACE LEFORT I 3/> PIECE W/BONE GRAFTS','21147','1','','1','0','','','',0, 1, 0, 0),
(970,'RCNSTJ MIDFACE LEFORT II ANTERIOR INTRUSION','RCNSTJ MIDFACE LEFORT II ANTERIOR INTRUSION','21150','1','','1','0','','','',0, 1, 0, 0),
(971,'RCNSTJ MIDFACE LEFORT II W/BONE GRAFTS','RCNSTJ MIDFACE LEFORT II W/BONE GRAFTS','21151','1','','1','0','','','',0, 1, 0, 0),
(972,'RCNSTJ MIDFACE LEFORT III W/O LEFORT I','RCNSTJ MIDFACE LEFORT III W/O LEFORT I','21154','1','','1','0','','','',0, 1, 0, 0),
(973,'RCNSTJ MIDFACE LEFORT III W/LEFORT I','RCNSTJ MIDFACE LEFORT III W/LEFORT I','21155','1','','1','0','','','',0, 1, 0, 0),
(974,'RCNSTJ MIDFACE LEFORT III W/FHD W/O LEFORT I','RCNSTJ MIDFACE LEFORT III W/FHD W/O LEFORT I','21159','1','','1','0','','','',0, 1, 0, 0),
(975,'RCNSTJ MIDFACE LEFORT III W/FHD W/LEFORT I','RCNSTJ MIDFACE LEFORT III W/FHD W/LEFORT I','21160','1','','1','0','','','',0, 1, 0, 0),
(976,'RCNSTJ SUPERIOR-LATERAL ORBITAL RIM & LOWER FHD','RCNSTJ SUPERIOR-LATERAL ORBITAL RIM & LOWER FHD','21172','1','','1','0','','','',0, 1, 0, 0),
(977,'RCNSTJ BIFRONTAL SUPERIOR-LAT ORB RIMS & LWR FHD','RCNSTJ BIFRONTAL SUPERIOR-LAT ORB RIMS & LWR FHD','21175','1','','1','0','','','',0, 1, 0, 0),
(978,'RCNSTJ FOREHEAD &/ SUPRAORB RIMS W/ALGRF/PROSTC','RCNSTJ FOREHEAD &/ SUPRAORB RIMS W/ALGRF/PROSTC','21179','1','','1','0','','','',0, 1, 0, 0),
(979,'RCNSTJ FOREHEAD &/ SUPRAORBITAL RIMS W/AUTOGRAFT','RCNSTJ FOREHEAD &/ SUPRAORBITAL RIMS W/AUTOGRAFT','21180','1','','1','0','','','',0, 1, 0, 0),
(980,'RCNSTJ CONTOURING BENIGN TUMOR CRNL BONES XTRC','RCNSTJ CONTOURING BENIGN TUMOR CRNL BONES XTRC','21181','1','','1','0','','','',0, 1, 0, 0),
(981,'RCNSTJ ORBIT/FHD/NASETHMD EXCBONE TUM GRF<40SQCM','RCNSTJ ORBIT/FHD/NASETHMD EXCBONE TUM GRF<40SQCM','21182','1','','1','0','','','',0, 1, 0, 0),
(982,'RCNSTJ ORBIT/FHD/NASETHMD EXC BONE GRF>40 <80','RCNSTJ ORBIT/FHD/NASETHMD EXC BONE GRF>40 <80','21183','1','','1','0','','','',0, 1, 0, 0),
(983,'RCNSTJ ORBIT/FHD/NASETHMD EXC BONE TUM GRF>80SQ','RCNSTJ ORBIT/FHD/NASETHMD EXC BONE TUM GRF>80SQ','21184','1','','1','0','','','',0, 1, 0, 0),
(984,'RCNSTJ MDFC OTH/THN LEFORT OSTEOT & BONE GRAFTS','RCNSTJ MDFC OTH/THN LEFORT OSTEOT & BONE GRAFTS','21188','1','','1','0','','','',0, 1, 0, 0),
(985,'RCNSTJ MNDBLR RAMI HRZNTL/VER/C/L OSTEOT W/O GRF','RCNSTJ MNDBLR RAMI HRZNTL/VER/C/L OSTEOT W/O GRF','21193','1','','1','0','','','',0, 1, 0, 0),
(986,'RCNSTJ MNDBLR RAMI HRZNTL/VER/C/L OSTEOT W/GRAFT','RCNSTJ MNDBLR RAMI HRZNTL/VER/C/L OSTEOT W/GRAFT','21194','1','','1','0','','','',0, 1, 0, 0),
(987,'RCNSTJ MNDBLR RAMI&/BODY SGTL SPLT W/O INT RGD','RCNSTJ MNDBLR RAMI&/BODY SGTL SPLT W/O INT RGD','21195','1','','1','0','','','',0, 1, 0, 0),
(988,'RCNSTJ MNDBLR RAMI&/BDY SGTL SPLT W/INT RGD FI','RCNSTJ MNDBLR RAMI&/BDY SGTL SPLT W/INT RGD FI','21196','1','','1','0','','','',0, 1, 0, 0),
(989,'OSTEOTOMY MANDIBLE SEGMENTAL','OSTEOTOMY MANDIBLE SEGMENTAL','21198','1','','1','0','','','',0, 1, 0, 0),
(990,'OSTEOTOMY MANDIBLE SGMTL W/GENIOGLOSSUS ADVMNT','OSTEOTOMY MANDIBLE SGMTL W/GENIOGLOSSUS ADVMNT','21199','1','','1','0','','','',0, 1, 0, 0),
(991,'OSTEOTOMY MAXILLA SEGMENTAL','OSTEOTOMY MAXILLA SEGMENTAL','21206','1','','1','0','','','',0, 1, 0, 0),
(992,'OSTEOPLASTY FACIAL BONES AUGMENTATION','OSTEOPLASTY FACIAL BONES AUGMENTATION','21208','1','','1','0','','','',0, 1, 0, 0),
(993,'OSTEOPLASTY FACIAL BONES REDUCTION','OSTEOPLASTY FACIAL BONES REDUCTION','21209','1','','1','0','','','',0, 1, 0, 0),
(994,'GRAFT BONE NASAL/MAXILLARY/MALAR AREAS','GRAFT BONE NASAL/MAXILLARY/MALAR AREAS','21210','1','','1','0','','','',0, 1, 0, 0),
(995,'GRAFT BONE MANDIBLE','GRAFT BONE MANDIBLE','21215','1','','1','0','','','',0, 1, 0, 0),
(996,'GRAFT RIB CRTLG AUTOGENOUS FACE/CHIN/NOSE/EAR','GRAFT RIB CRTLG AUTOGENOUS FACE/CHIN/NOSE/EAR','21230','1','','1','0','','','',0, 1, 0, 0),
(997,'GRAFT EAR CRTLG AUTOGENOUS NOSE/EAR','GRAFT EAR CRTLG AUTOGENOUS NOSE/EAR','21235','1','','1','0','','','',0, 1, 0, 0),
(998,'ARTHRP TEMPOROMANDIBULAR JOINT W/WO AUTOGRAFT','ARTHRP TEMPOROMANDIBULAR JOINT W/WO AUTOGRAFT','21240','1','','1','0','','','',0, 1, 0, 0),
(999,'ARTHROPLASTY TEMPOROMANDIBULAR JT W/ALLOGRAFT','ARTHROPLASTY TEMPOROMANDIBULAR JT W/ALLOGRAFT','21242','1','','1','0','','','',0, 1, 0, 0),
(1000,'ARTHRP TMPRMAND JOINT W/PROSTHETIC REPLACEMENT','ARTHRP TMPRMAND JOINT W/PROSTHETIC REPLACEMENT','21243','1','','1','0','','','',0, 1, 0, 0),
(1001,'RCNSTJ MNDBL XTRORAL W/TRANSOSTEAL BONE PLATE','RCNSTJ MNDBL XTRORAL W/TRANSOSTEAL BONE PLATE','21244','1','','1','0','','','',0, 1, 0, 0),
(1002,'RCNSTJ MNDBL/MAXL SUBPRIOSTEAL IMPLANT PARTIAL','RCNSTJ MNDBL/MAXL SUBPRIOSTEAL IMPLANT PARTIAL','21245','1','','1','0','','','',0, 1, 0, 0),
(1003,'RCNSTJ MNDBL/MAXL SUBPRIOSTEAL IMPLANT COMPLETE','RCNSTJ MNDBL/MAXL SUBPRIOSTEAL IMPLANT COMPLETE','21246','1','','1','0','','','',0, 1, 0, 0),
(1004,'RCNSTJ MNDBLR CONDYLE W/BONE CARTLG AUTOGRAFTS','RCNSTJ MNDBLR CONDYLE W/BONE CARTLG AUTOGRAFTS','21247','1','','1','0','','','',0, 1, 0, 0),
(1005,'RCNSTJ MANDIBLE/MAXL ENDOSTEAL IMPLANT PARTIAL','RCNSTJ MANDIBLE/MAXL ENDOSTEAL IMPLANT PARTIAL','21248','1','','1','0','','','',0, 1, 0, 0),
(1006,'RCNSTJ MANDIBLE/MAXL ENDOSTEAL IMPLANT COMPLETE','RCNSTJ MANDIBLE/MAXL ENDOSTEAL IMPLANT COMPLETE','21249','1','','1','0','','','',0, 1, 0, 0),
(1007,'RCNSTJ ZYGMTC ARCH/GLENOID FOSSA W/BONE CARTLG','RCNSTJ ZYGMTC ARCH/GLENOID FOSSA W/BONE CARTLG','21255','1','','1','0','','','',0, 1, 0, 0),
(1008,'RECONSTRUCTION ORBIT W/OSTEOTOMIES & BONE GRAFTS','RECONSTRUCTION ORBIT W/OSTEOTOMIES & BONE GRAFTS','21256','1','','1','0','','','',0, 1, 0, 0),
(1009,'PERIORBITAL OSTEOTOMIES BONE GRAFTS EXTRACRANIAL','PERIORBITAL OSTEOTOMIES BONE GRAFTS EXTRACRANIAL','21260','1','','1','0','','','',0, 1, 0, 0),
(1010,'PERIORBITAL OSTEOTOMIES W/BONE GRAFTS ICRA & XTR','PERIORBITAL OSTEOTOMIES W/BONE GRAFTS ICRA & XTR','21261','1','','1','0','','','',0, 1, 0, 0),
(1011,'PERIORBITAL OSTEOTOMIES W/BONE GRAFTS W/FOREHEAD','PERIORBITAL OSTEOTOMIES W/BONE GRAFTS W/FOREHEAD','21263','1','','1','0','','','',0, 1, 0, 0),
(1012,'ORBITAL REPOSITIONING W/BONE GRAFTS EXTRACRANIAL','ORBITAL REPOSITIONING W/BONE GRAFTS EXTRACRANIAL','21267','1','','1','0','','','',0, 1, 0, 0),
(1013,'ORBITAL REPOSITIONING W/BONE GRAFTS ICRA & XTRC','ORBITAL REPOSITIONING W/BONE GRAFTS ICRA & XTRC','21268','1','','1','0','','','',0, 1, 0, 0),
(1014,'MALAR AUGMENTATION PROSTHETIC MATERIAL','MALAR AUGMENTATION PROSTHETIC MATERIAL','21270','1','','1','0','','','',0, 1, 0, 0),
(1015,'SECONDARY REVISION ORBITOCRANIOFACIAL RCNSTJ','SECONDARY REVISION ORBITOCRANIOFACIAL RCNSTJ','21275','1','','1','0','','','',0, 1, 0, 0),
(1016,'MEDIAL CANTHOPEXY SEPARATE PROCEDURE','MEDIAL CANTHOPEXY SEPARATE PROCEDURE','21280','1','','1','0','','','',0, 1, 0, 0),
(1017,'LATERAL CANTHOPEXY','LATERAL CANTHOPEXY','21282','1','','1','0','','','',0, 1, 0, 0),
(1018,'REDUCTION MASSETER MUSCLE & BONE EXTRAORAL','REDUCTION MASSETER MUSCLE & BONE EXTRAORAL','21295','1','','1','0','','','',0, 1, 0, 0),
(1019,'REDUCTION MASSETER MUSCLE & BONE INTRAORAL','REDUCTION MASSETER MUSCLE & BONE INTRAORAL','21296','1','','1','0','','','',0, 1, 0, 0),
(1020,'UNLISTED CRANIOFACIAL & MAXILLOFACIAL PROCEDURE','UNLISTED CRANIOFACIAL & MAXILLOFACIAL PROCEDURE','21299','1','','1','0','','','',0, 1, 0, 0),
(1021,'CLOSED TREATMENT NASAL FRACTURE W/O MANIPULATION','CLOSED TREATMENT NASAL FRACTURE W/O MANIPULATION','21310','1','','1','0','','','',0, 1, 0, 0),
(1022,'CLOSED TX NASAL FRACTURE W/O STABILIZATION','CLOSED TX NASAL FRACTURE W/O STABILIZATION','21315','1','','1','0','','','',0, 1, 0, 0),
(1023,'CLOSED TREATMENT NASAL FRACTURE W/STABILIZATION','CLOSED TREATMENT NASAL FRACTURE W/STABILIZATION','21320','1','','1','0','','','',0, 1, 0, 0),
(1024,'OPEN TREATMENT NASAL FRACTURE UNCOMPLICATED','OPEN TREATMENT NASAL FRACTURE UNCOMPLICATED','21325','1','','1','0','','','',0, 1, 0, 0),
(1025,'OPEN TX NASAL FX COMP W/INT&/XTRNL SKELETAL FI','OPEN TX NASAL FX COMP W/INT&/XTRNL SKELETAL FI','21330','1','','1','0','','','',0, 1, 0, 0),
(1026,'OPEN TX NASAL FX W/CONCOMITANT OPTX FXD SEPTUM','OPEN TX NASAL FX W/CONCOMITANT OPTX FXD SEPTUM','21335','1','','1','0','','','',0, 1, 0, 0),
(1027,'OPEN TX NASAL SEPTAL FRACTURE W/WO STABILIZATION','OPEN TX NASAL SEPTAL FRACTURE W/WO STABILIZATION','21336','1','','1','0','','','',0, 1, 0, 0),
(1028,'CLOSED TX NASAL SEPTAL FRACT W/WO STABILIZATION','CLOSED TX NASAL SEPTAL FRACT W/WO STABILIZATION','21337','1','','1','0','','','',0, 1, 0, 0),
(1029,'OPEN TX NASOETHMOID FX W/O EXTERNAL FIXATION','OPEN TX NASOETHMOID FX W/O EXTERNAL FIXATION','21338','1','','1','0','','','',0, 1, 0, 0),
(1030,'OPEN TX NASOETHMOID FX W/EXTERNAL FIXATION','OPEN TX NASOETHMOID FX W/EXTERNAL FIXATION','21339','1','','1','0','','','',0, 1, 0, 0),
(1031,'PERCUTANEOUS TX NASOETHMOID COMPLEX FRACTURE','PERCUTANEOUS TX NASOETHMOID COMPLEX FRACTURE','21340','1','','1','0','','','',0, 1, 0, 0),
(1032,'OPEN TX DEPRESSED FRONTAL SINUS FRACTURE','OPEN TX DEPRESSED FRONTAL SINUS FRACTURE','21343','1','','1','0','','','',0, 1, 0, 0),
(1033,'OPEN TX COMPLICATED FRONTAL SINUS FRACTURE','OPEN TX COMPLICATED FRONTAL SINUS FRACTURE','21344','1','','1','0','','','',0, 1, 0, 0),
(1034,'CLOSED TX NASOMAXILLARY COMPLEX FRACTURE','CLOSED TX NASOMAXILLARY COMPLEX FRACTURE','21345','1','','1','0','','','',0, 1, 0, 0),
(1035,'OPTX NASOMAX CPLX FX LEFT II TYPE W/WIRG & FXJ','OPTX NASOMAX CPLX FX LEFT II TYPE W/WIRG & FXJ','21346','1','','1','0','','','',0, 1, 0, 0),
(1036,'OPTX NASOMAX CPLX FX LEFT II TYPE REQ MLT OPN','OPTX NASOMAX CPLX FX LEFT II TYPE REQ MLT OPN','21347','1','','1','0','','','',0, 1, 0, 0),
(1037,'OPTX NASOMAX CPLX FX LEFT II TYPE W/BONE GRAFT','OPTX NASOMAX CPLX FX LEFT II TYPE W/BONE GRAFT','21348','1','','1','0','','','',0, 1, 0, 0),
(1038,'PERCUTANEOUS TX MALAR AREA FRACTURE','PERCUTANEOUS TX MALAR AREA FRACTURE','21355','1','','1','0','','','',0, 1, 0, 0),
(1039,'OPEN TX DEPRESSED ZYGOMATIC ARCH FRACTURE','OPEN TX DEPRESSED ZYGOMATIC ARCH FRACTURE','21356','1','','1','0','','','',0, 1, 0, 0),
(1040,'OPEN TX DEPRESSED MALAR FRACTURE','OPEN TX DEPRESSED MALAR FRACTURE','21360','1','','1','0','','','',0, 1, 0, 0),
(1041,'OPEN TX COMP FX MALAR W/INTERNAL FX&MULT SURG','OPEN TX COMP FX MALAR W/INTERNAL FX&MULT SURG','21365','1','','1','0','','','',0, 1, 0, 0),
(1042,'OPEN TX COMP FRACTURE MALAR AREA W/BONE GRAFT','OPEN TX COMP FRACTURE MALAR AREA W/BONE GRAFT','21366','1','','1','0','','','',0, 1, 0, 0),
(1043,'OPEN TX ORBITAL FLOOR BLOWOUT FX TRANSANTRAL','OPEN TX ORBITAL FLOOR BLOWOUT FX TRANSANTRAL','21385','1','','1','0','','','',0, 1, 0, 0),
(1044,'OPEN TX ORBITAL FLOOR BLOWOUT FX PERIORBITAL','OPEN TX ORBITAL FLOOR BLOWOUT FX PERIORBITAL','21386','1','','1','0','','','',0, 1, 0, 0),
(1045,'OPEN TX ORBITAL FLOOR BLOWOUT FX COMBINED APPR','OPEN TX ORBITAL FLOOR BLOWOUT FX COMBINED APPR','21387','1','','1','0','','','',0, 1, 0, 0),
(1046,'OPTX ORB FLOOR BLWT FX PRI/BITAL APPR W/ALLPLSTC','OPTX ORB FLOOR BLWT FX PRI/BITAL APPR W/ALLPLSTC','21390','1','','1','0','','','',0, 1, 0, 0),
(1047,'OPTX ORB FLOOR BLWT FX PRI/BITAL APPR W/BONE GRF','OPTX ORB FLOOR BLWT FX PRI/BITAL APPR W/BONE GRF','21395','1','','1','0','','','',0, 1, 0, 0),
(1048,'CLSD TX FX ORBIT EXCEPT BLOWOUT W/O MANIPULATION','CLSD TX FX ORBIT EXCEPT BLOWOUT W/O MANIPULATION','21400','1','','1','0','','','',0, 1, 0, 0),
(1049,'CLOSED TX FX ORBIT EXCEPT BLOWOUT W/MANIPULATION','CLOSED TX FX ORBIT EXCEPT BLOWOUT W/MANIPULATION','21401','1','','1','0','','','',0, 1, 0, 0),
(1050,'OPEN TX FX ORBIT EXCEPT BLOWOUT W/O IMPLANT','OPEN TX FX ORBIT EXCEPT BLOWOUT W/O IMPLANT','21406','1','','1','0','','','',0, 1, 0, 0),
(1051,'OPEN TX FX ORBIT EXCEPT BLOWOUT W/IMPLANT','OPEN TX FX ORBIT EXCEPT BLOWOUT W/IMPLANT','21407','1','','1','0','','','',0, 1, 0, 0),
(1052,'OPEN TX FX ORBIT EXCEPT BLOWOUT W/BONE GRAFT','OPEN TX FX ORBIT EXCEPT BLOWOUT W/BONE GRAFT','21408','1','','1','0','','','',0, 1, 0, 0),
(1053,'CLOSED TX PALATAL/MAXILLARY FX W/FIXATION/SPLINT','CLOSED TX PALATAL/MAXILLARY FX W/FIXATION/SPLINT','21421','1','','1','0','','','',0, 1, 0, 0),
(1054,'OPEN TREATMENT PALATAL/MAXILLARY FRACTURE','OPEN TREATMENT PALATAL/MAXILLARY FRACTURE','21422','1','','1','0','','','',0, 1, 0, 0),
(1055,'OPEN TX PALATAL/MAXILLARY FX COMP MULTIPLE APPR','OPEN TX PALATAL/MAXILLARY FX COMP MULTIPLE APPR','21423','1','','1','0','','','',0, 1, 0, 0),
(1056,'CLOSED TX CRANIOFACIAL SEPARATION','CLOSED TX CRANIOFACIAL SEPARATION','21431','1','','1','0','','','',0, 1, 0, 0),
(1057,'OPEN TX CRANIOFACIAL SEP W/WIRING&/INT FIXJ','OPEN TX CRANIOFACIAL SEP W/WIRING&/INT FIXJ','21432','1','','1','0','','','',0, 1, 0, 0),
(1058,'OPEN TX CRANIOFACIAL SEP COMPLICATED MLT APPR','OPEN TX CRANIOFACIAL SEP COMPLICATED MLT APPR','21433','1','','1','0','','','',0, 1, 0, 0),
(1059,'OPEN TX CRANIOFACIAL SEP COMP W/INT&/XTRNL FIX','OPEN TX CRANIOFACIAL SEP COMP W/INT&/XTRNL FIX','21435','1','','1','0','','','',0, 1, 0, 0),
(1060,'OPTX CRNFCL SEP LFT III TYP COMP INT FIXJ W/BONE','OPTX CRNFCL SEP LFT III TYP COMP INT FIXJ W/BONE','21436','1','','1','0','','','',0, 1, 0, 0),
(1061,'CLTX MANDIBULAR/MAXILLARY ALVEOLAR RIDGE FX SPX','CLTX MANDIBULAR/MAXILLARY ALVEOLAR RIDGE FX SPX','21440','1','','1','0','','','',0, 1, 0, 0),
(1062,'OPTX MANDIBULAR/MAXILLARY ALVEOLAR RIDGE FX SPX','OPTX MANDIBULAR/MAXILLARY ALVEOLAR RIDGE FX SPX','21445','1','','1','0','','','',0, 1, 0, 0),
(1063,'CLOSED TX MANDIBULAR FRACTURE W/O MANIPULATION','CLOSED TX MANDIBULAR FRACTURE W/O MANIPULATION','21450','1','','1','0','','','',0, 1, 0, 0),
(1064,'CLOSED TX MANDIBULAR FRACTURE W/MANIPULATION','CLOSED TX MANDIBULAR FRACTURE W/MANIPULATION','21451','1','','1','0','','','',0, 1, 0, 0),
(1065,'PERCUTANEOUS TX MANDIBULAR FX W/EXTERNAL FIXJ','PERCUTANEOUS TX MANDIBULAR FX W/EXTERNAL FIXJ','21452','1','','1','0','','','',0, 1, 0, 0),
(1066,'CLOSED TX MANDIBULAR FX W/INTERDENTAL FIXATION','CLOSED TX MANDIBULAR FX W/INTERDENTAL FIXATION','21453','1','','1','0','','','',0, 1, 0, 0),
(1067,'OPEN TX MANDIBULAR FX W/EXTERNAL FIXATION','OPEN TX MANDIBULAR FX W/EXTERNAL FIXATION','21454','1','','1','0','','','',0, 1, 0, 0),
(1068,'OPEN TX MANDIBULAR FX W/O INTERDENTAL FIXATION','OPEN TX MANDIBULAR FX W/O INTERDENTAL FIXATION','21461','1','','1','0','','','',0, 1, 0, 0),
(1069,'OPEN TX MANDIBULAR FX W/INTERDENTAL FIXATION','OPEN TX MANDIBULAR FX W/INTERDENTAL FIXATION','21462','1','','1','0','','','',0, 1, 0, 0),
(1070,'OPEN TREATMENT MANDIBULAR CONDYLAR FRACTURE','OPEN TREATMENT MANDIBULAR CONDYLAR FRACTURE','21465','1','','1','0','','','',0, 1, 0, 0),
(1071,'OPTX COMP MANDIBULAR FX MLT APPR W/INT FIXATION','OPTX COMP MANDIBULAR FX MLT APPR W/INT FIXATION','21470','1','','1','0','','','',0, 1, 0, 0),
(1072,'CLOSED TX TEMPOROMANDIBULAR DISLOCATION 1ST/SBSQ','CLOSED TX TEMPOROMANDIBULAR DISLOCATION 1ST/SBSQ','21480','1','','1','0','','','',0, 1, 0, 0),
(1073,'CLOSED TX TEMPOROMANDIBULAR DISLC COMP 1ST/SBSQ','CLOSED TX TEMPOROMANDIBULAR DISLC COMP 1ST/SBSQ','21485','1','','1','0','','','',0, 1, 0, 0),
(1074,'OPEN TREATMENT TEMPOROMANDIBULAR DISLOCATION','OPEN TREATMENT TEMPOROMANDIBULAR DISLOCATION','21490','1','','1','0','','','',0, 1, 0, 0),
(1075,'OPEN TREATMENT HYOID FRACTURE','OPEN TREATMENT HYOID FRACTURE','21495','1','','1','0','','','',0, 1, 0, 0),
(1076,'INTERDENTAL WIRING OTHER THAN FRACTURE','INTERDENTAL WIRING OTHER THAN FRACTURE','21497','1','','1','0','','','',0, 1, 0, 0),
(1077,'UNLISTED MUSCULOSKELETAL PROCEDURE HEAD','UNLISTED MUSCULOSKELETAL PROCEDURE HEAD','21499','1','','1','0','','','',0, 1, 0, 0),
(1078,'I&D DEEP ABSC/HMTMA SOFT TISSUE NECK/THORAX','I&D DEEP ABSC/HMTMA SOFT TISSUE NECK/THORAX','21501','1','','1','0','','','',0, 1, 0, 0),
(1079,'I&D DP ABSC/HMTMA SOFT TISS NCK/THORAX PRTL RI','I&D DP ABSC/HMTMA SOFT TISS NCK/THORAX PRTL RI','21502','1','','1','0','','','',0, 1, 0, 0),
(1080,'INCISION DEEP OPENING BONE CORTEX THORAX','INCISION DEEP OPENING BONE CORTEX THORAX','21510','1','','1','0','','','',0, 1, 0, 0),
(1081,'BIOPSY SOFT TISSUE NECK/THORAX','BIOPSY SOFT TISSUE NECK/THORAX','21550','1','','1','0','','','',0, 1, 0, 0),
(1082,'EXC TUMOR SOFT TIS NECK/ANT THORAX SUBQ 3 CM/>','EXC TUMOR SOFT TIS NECK/ANT THORAX SUBQ 3 CM/>','21552','1','','1','0','','','',0, 1, 0, 0),
(1083,'EXC TUMOR SOFT TISSUE NECK/THORAX SUBFASC 5 CM/>','EXC TUMOR SOFT TISSUE NECK/THORAX SUBFASC 5 CM/>','21554','1','','1','0','','','',0, 1, 0, 0),
(1084,'EXC TUMOR SOFT TISSUE NECK/ANT THORAX SUBQ <3CM','EXC TUMOR SOFT TISSUE NECK/ANT THORAX SUBQ <3CM','21555','1','','1','0','','','',0, 1, 0, 0),
(1085,'EXC TUMOR SOFT TISS NECK/THORAX SUBFASCIAL <5CM','EXC TUMOR SOFT TISS NECK/THORAX SUBFASCIAL <5CM','21556','1','','1','0','','','',0, 1, 0, 0),
(1086,'RAD RESECT TUMOR SOFT TISS NECK/ANT THORAX <5CM','RAD RESECT TUMOR SOFT TISS NECK/ANT THORAX <5CM','21557','1','','1','0','','','',0, 1, 0, 0),
(1087,'RAD RESECT TUMOR SOFT TISS NECK/ANT THORAX 5CM/>','RAD RESECT TUMOR SOFT TISS NECK/ANT THORAX 5CM/>','21558','1','','1','0','','','',0, 1, 0, 0),
(1088,'EXCISION RIB PARTIAL','EXCISION RIB PARTIAL','21600','1','','1','0','','','',0, 1, 0, 0),
(1089,'COSTOTRANSVERSECTOMY SEPARATE PROCEDURE','COSTOTRANSVERSECTOMY SEPARATE PROCEDURE','21610','1','','1','0','','','',0, 1, 0, 0),
(1090,'EXCISION 1ST &/CERVICAL RIB','EXCISION 1ST &/CERVICAL RIB','21615','1','','1','0','','','',0, 1, 0, 0),
(1091,'EXCISION 1ST &/CERVICAL RIB W/SYMPATHECTOMY','EXCISION 1ST &/CERVICAL RIB W/SYMPATHECTOMY','21616','1','','1','0','','','',0, 1, 0, 0),
(1092,'OSTECTOMY STERNUM PARTIAL','OSTECTOMY STERNUM PARTIAL','21620','1','','1','0','','','',0, 1, 0, 0),
(1093,'STERNAL DEBRIDEMENT','STERNAL DEBRIDEMENT','21627','1','','1','0','','','',0, 1, 0, 0),
(1094,'RADICAL RESECTION STERNUM','RADICAL RESECTION STERNUM','21630','1','','1','0','','','',0, 1, 0, 0),
(1095,'RADICAL RESECTION STERNUM W/MEDSTNL LMPHADEC','RADICAL RESECTION STERNUM W/MEDSTNL LMPHADEC','21632','1','','1','0','','','',0, 1, 0, 0),
(1096,'HYOID MYOTOMY & SUSPENSION','HYOID MYOTOMY & SUSPENSION','21685','1','','1','0','','','',0, 1, 0, 0),
(1097,'DIVISION SCALENUS ANTICUS W/O RESCJ CERVICAL RIB','DIVISION SCALENUS ANTICUS W/O RESCJ CERVICAL RIB','21700','1','','1','0','','','',0, 1, 0, 0),
(1098,'DIVISION SCALENUS ANTICUS RESECTION CERVICAL RIB','DIVISION SCALENUS ANTICUS RESECTION CERVICAL RIB','21705','1','','1','0','','','',0, 1, 0, 0),
(1099,'DIVISION STERNOCLEIDOMASTOID OPEN W/O CAST','DIVISION STERNOCLEIDOMASTOID OPEN W/O CAST','21720','1','','1','0','','','',0, 1, 0, 0),
(1100,'DIVISION STERNOCLEIDOMASTOID OPEN W/CAST','DIVISION STERNOCLEIDOMASTOID OPEN W/CAST','21725','1','','1','0','','','',0, 1, 0, 0),
(1101,'REPAIR PECTUS EXCAVATUM/CARINATUM OPEN','REPAIR PECTUS EXCAVATUM/CARINATUM OPEN','21740','1','','1','0','','','',0, 1, 0, 0),
(1102,'REPAIR PECTUS EXCAVATM/CARINATM MINLY W/O THRSC','REPAIR PECTUS EXCAVATM/CARINATM MINLY W/O THRSC','21742','1','','1','0','','','',0, 1, 0, 0),
(1103,'REPAIR PECTUS EXCAVATM/CARINATM MINLY W/THRSC','REPAIR PECTUS EXCAVATM/CARINATM MINLY W/THRSC','21743','1','','1','0','','','',0, 1, 0, 0),
(1104,'CLOSE MEDIAN STERNOTOMY SEP W/WO DEBRIDEMENT SPX','CLOSE MEDIAN STERNOTOMY SEP W/WO DEBRIDEMENT SPX','21750','1','','1','0','','','',0, 1, 0, 0),
(1105,'OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 1-3 RIBS','OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 1-3 RIBS','21811','1','','1','0','','','',0, 1, 0, 0),
(1106,'OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 4-6 RIBS','OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 4-6 RIBS','21812','1','','1','0','','','',0, 1, 0, 0),
(1107,'OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 7+ RIBS','OPEN TX RIB FX W/FIXJ THORACOSCOPIC VIS 7+ RIBS','21813','1','','1','0','','','',0, 1, 0, 0),
(1108,'CLOSED TREATMENT STERNUM FRACTURE','CLOSED TREATMENT STERNUM FRACTURE','21820','1','','1','0','','','',0, 1, 0, 0),
(1109,'OPEN TX STERNUM FRACTURE W/WO SKELETAL FIXATION','OPEN TX STERNUM FRACTURE W/WO SKELETAL FIXATION','21825','1','','1','0','','','',0, 1, 0, 0),
(1110,'UNLISTED PROCEDURE NECK/THORAX','UNLISTED PROCEDURE NECK/THORAX','21899','1','','1','0','','','',0, 1, 0, 0),
(1111,'BIOPSY SOFT TISSUE BACK/FLANK SUPERFICIAL','BIOPSY SOFT TISSUE BACK/FLANK SUPERFICIAL','21920','1','','1','0','','','',0, 1, 0, 0),
(1112,'BIOPSY SOFT TISSUE BACK/FLANK DEEP','BIOPSY SOFT TISSUE BACK/FLANK DEEP','21925','1','','1','0','','','',0, 1, 0, 0),
(1113,'EXCISION TUMOR SOFT TISSUE BACK/FLANK SUBQ <3CM','EXCISION TUMOR SOFT TISSUE BACK/FLANK SUBQ <3CM','21930','1','','1','0','','','',0, 1, 0, 0),
(1114,'EXCISION TUMOR SOFT TIS BACK/FLANK SUBQ 3 CM/>','EXCISION TUMOR SOFT TIS BACK/FLANK SUBQ 3 CM/>','21931','1','','1','0','','','',0, 1, 0, 0),
(1115,'EXC TUMOR SOFT TISS BACK/FLANK SUBFASCIAL <5CM','EXC TUMOR SOFT TISS BACK/FLANK SUBFASCIAL <5CM','21932','1','','1','0','','','',0, 1, 0, 0),
(1116,'EXC TUMOR SOFT TISS BACK/FLANK SUBFASCIAL 5 CM/>','EXC TUMOR SOFT TISS BACK/FLANK SUBFASCIAL 5 CM/>','21933','1','','1','0','','','',0, 1, 0, 0),
(1117,'RAD RESECTION TUMOR SOFT TISSUE BACK/FLANK <5CM','RAD RESECTION TUMOR SOFT TISSUE BACK/FLANK <5CM','21935','1','','1','0','','','',0, 1, 0, 0),
(1118,'RAD RESECTION TUMOR SOFT TISSUE BACK/FLANK 5CM/>','RAD RESECTION TUMOR SOFT TISSUE BACK/FLANK 5CM/>','21936','1','','1','0','','','',0, 1, 0, 0),
(1119,'I&D DEEP ABSCESS PST SPINE CRV THRC/CERVICOTHR','I&D DEEP ABSCESS PST SPINE CRV THRC/CERVICOTHR','22010','1','','1','0','','','',0, 1, 0, 0),
(1120,'I&D DEEP ABSCESS PST SPINE LUMBAR SAC/LUMBOSAC','I&D DEEP ABSCESS PST SPINE LUMBAR SAC/LUMBOSAC','22015','1','','1','0','','','',0, 1, 0, 0),
(1121,'PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM CRV','PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM CRV','22100','1','','1','0','','','',0, 1, 0, 0),
(1122,'PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM THRC','PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM THRC','22101','1','','1','0','','','',0, 1, 0, 0),
(1123,'PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM LMBR','PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM LMBR','22102','1','','1','0','','','',0, 1, 0, 0),
(1124,'PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM EA','PRTL EXC PST VRT INTRNSC B1Y LES 1 VRT SGM EA','22103','1','','1','0','','','',0, 1, 0, 0),
(1125,'PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM CRV','PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM CRV','22110','1','','1','0','','','',0, 1, 0, 0),
(1126,'PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM THRC','PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM THRC','22112','1','','1','0','','','',0, 1, 0, 0),
(1127,'PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM LMBR','PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM LMBR','22114','1','','1','0','','','',0, 1, 0, 0),
(1128,'PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM EA','PRTL EXC VRT BDY B1Y LES W/O SPI CORD 1 SGM EA','22116','1','','1','0','','','',0, 1, 0, 0),
(1129,'OSTEOTOMY SPINE POSTERIOR 3 COLUMN THORACIC','OSTEOTOMY SPINE POSTERIOR 3 COLUMN THORACIC','22206','1','','1','0','','','',0, 1, 0, 0),
(1130,'OSTEOTOMY SPINE POSTERIOR 3 COLUMN LUMBAR','OSTEOTOMY SPINE POSTERIOR 3 COLUMN LUMBAR','22207','1','','1','0','','','',0, 1, 0, 0),
(1131,'OSTEOTOMY SPINE POSTERIOR 3 COLUMN EA ADDL SGM','OSTEOTOMY SPINE POSTERIOR 3 COLUMN EA ADDL SGM','22208','1','','1','0','','','',0, 1, 0, 0),
(1132,'OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM CRV','OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM CRV','22210','1','','1','0','','','',0, 1, 0, 0),
(1133,'OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM THRC','OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM THRC','22212','1','','1','0','','','',0, 1, 0, 0),
(1134,'OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM LMBR','OSTEOTOMY SPINE PST/PSTLAT APPR 1 VRT SGM LMBR','22214','1','','1','0','','','',0, 1, 0, 0),
(1135,'OSTEOT SPI PST/PSTLAT APPR 1 VRT SGM EA VRT SGM','OSTEOT SPI PST/PSTLAT APPR 1 VRT SGM EA VRT SGM','22216','1','','1','0','','','',0, 1, 0, 0),
(1136,'OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM CRV','OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM CRV','22220','1','','1','0','','','',0, 1, 0, 0),
(1137,'OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM THRC','OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM THRC','22222','1','','1','0','','','',0, 1, 0, 0),
(1138,'OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM LMBR','OSTEOTOMY SPINE W/DSKC ANT APPR 1 VRT SGM LMBR','22224','1','','1','0','','','',0, 1, 0, 0),
(1139,'OSTEOT SPI W/DSKC ANT APPR 1 VRT SGM EA VRT SGM','OSTEOT SPI W/DSKC ANT APPR 1 VRT SGM EA VRT SGM','22226','1','','1','0','','','',0, 1, 0, 0),
(1140,'CLOSED TX VERTEBRAL PROCESS FRACTURE','CLOSED TX VERTEBRAL PROCESS FRACTURE','22305','1','','1','0','','','',0, 1, 0, 0),
(1141,'CLTX VRT BDY FX W/O MANJ REQ&W/CSTING/BRACING','CLTX VRT BDY FX W/O MANJ REQ&W/CSTING/BRACING','22310','1','','1','0','','','',0, 1, 0, 0),
(1142,'CLTX VRT FX&/DISLC CSTING/BRACING MANJ/TRCJ','CLTX VRT FX&/DISLC CSTING/BRACING MANJ/TRCJ','22315','1','','1','0','','','',0, 1, 0, 0),
(1143,'OPTX&/RDCTJ ODNTD FX&/DISLC ANT FIXJ W/O GRAFT','OPTX&/RDCTJ ODNTD FX&/DISLC ANT FIXJ W/O GRAFT','22318','1','','1','0','','','',0, 1, 0, 0),
(1144,'OPTX&/RDCTJ ODNTD FX&/DISLC ANT W/INT FIXJ','OPTX&/RDCTJ ODNTD FX&/DISLC ANT W/INT FIXJ','22319','1','','1','0','','','',0, 1, 0, 0),
(1145,'OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM LM','OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM LM','22325','1','','1','0','','','',0, 1, 0, 0),
(1146,'OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM CR','OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM CR','22326','1','','1','0','','','',0, 1, 0, 0),
(1147,'OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM TH','OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM TH','22327','1','','1','0','','','',0, 1, 0, 0),
(1148,'OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM EA','OPTX&/RDCTJ VRT FX&/DISLC PST 1 VRT SGM EA','22328','1','','1','0','','','',0, 1, 0, 0),
(1149,'MANIPULATION SPINE REQUIRING ANESTHESIA','MANIPULATION SPINE REQUIRING ANESTHESIA','22505','1','','1','0','','','',0, 1, 0, 0),
(1150,'PERQ VERTEBROPLASTY UNI/BI INJX CERVICOTHORACIC','PERQ VERTEBROPLASTY UNI/BI INJX CERVICOTHORACIC','22510','1','','1','0','','','',0, 1, 0, 0),
(1151,'PERQ VERTEBROPLASTY UNI/BI INJECTION LUMBOSACRAL','PERQ VERTEBROPLASTY UNI/BI INJECTION LUMBOSACRAL','22511','1','','1','0','','','',0, 1, 0, 0),
(1152,'VERTEBROPLASTY EACH ADDL CERVICOTHOR/LUMBOSACRAL','VERTEBROPLASTY EACH ADDL CERVICOTHOR/LUMBOSACRAL','22512','1','','1','0','','','',0, 1, 0, 0),
(1153,'PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULATION','PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULATION','22513','1','','1','0','','','',0, 1, 0, 0),
(1154,'PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULJ LMBR','PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULJ LMBR','22514','1','','1','0','','','',0, 1, 0, 0),
(1155,'PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULJ EACH','PERQ VERT AGMNTJ CAVITY CRTJ UNI/BI CANNULJ EACH','22515','1','','1','0','','','',0, 1, 0, 0),
(1156,'PERQ INTRDSCL ELECTROTHRM ANNULOPLASTY 1 LEVEL','PERQ INTRDSCL ELECTROTHRM ANNULOPLASTY 1 LEVEL','22526','1','','1','0','','','',0, 1, 0, 0),
(1157,'PERQ INTRDSCL ELECTROTHRM ANNULOPLASTY ADDL LVL','PERQ INTRDSCL ELECTROTHRM ANNULOPLASTY ADDL LVL','22527','1','','1','0','','','',0, 1, 0, 0),
(1158,'ARTHRODESIS LATERAL EXTRACAVITARY THORACIC','ARTHRODESIS LATERAL EXTRACAVITARY THORACIC','22532','1','','1','0','','','',0, 1, 0, 0),
(1159,'ARTHRODESIS LATERAL EXTRACAVITARY LUMBAR','ARTHRODESIS LATERAL EXTRACAVITARY LUMBAR','22533','1','','1','0','','','',0, 1, 0, 0),
(1160,'ARTHRODESIS LAT EXTRACAVITARY EA ADDL THRC/LMBR','ARTHRODESIS LAT EXTRACAVITARY EA ADDL THRC/LMBR','22534','1','','1','0','','','',0, 1, 0, 0),
(1161,'ARTHRD ANT TRANSORL/XTRORAL C1-C2 W/WO EXC ODNTD','ARTHRD ANT TRANSORL/XTRORAL C1-C2 W/WO EXC ODNTD','22548','1','','1','0','','','',0, 1, 0, 0),
(1162,'ARTHRD ANT INTERBODY DECOMPRESS CERVICAL BELW C2','ARTHRD ANT INTERBODY DECOMPRESS CERVICAL BELW C2','22551','1','','1','0','','','',0, 1, 0, 0),
(1163,'ARTHRD ANT INTERDY CERVCL BELW C2 EA ADDL NTRSPC','ARTHRD ANT INTERDY CERVCL BELW C2 EA ADDL NTRSPC','22552','1','','1','0','','','',0, 1, 0, 0),
(1164,'ARTHRD ANT MIN DISCECT INTERBODY CERV BELOW C2','ARTHRD ANT MIN DISCECT INTERBODY CERV BELOW C2','22554','1','','1','0','','','',0, 1, 0, 0),
(1165,'ARTHRD ANT MIN DISCECTOMY INTERBODY THORACIC','ARTHRD ANT MIN DISCECTOMY INTERBODY THORACIC','22556','1','','1','0','','','',0, 1, 0, 0),
(1166,'ARTHRODESIS ANTERIOR INTERBODY LUMBAR','ARTHRODESIS ANTERIOR INTERBODY LUMBAR','22558','1','','1','0','','','',0, 1, 0, 0),
(1167,'ARTHRODESIS ANTERIOR INTERBODY EA ADDL NTRSPC','ARTHRODESIS ANTERIOR INTERBODY EA ADDL NTRSPC','22585','1','','1','0','','','',0, 1, 0, 0),
(1168,'ARTHRODESIS PRESACRAL INTRBDY W/INSTRUMENT L5-S1','ARTHRODESIS PRESACRAL INTRBDY W/INSTRUMENT L5-S1','22586','1','','1','0','','','',0, 1, 0, 0),
(1169,'ARTHRODESIS POSTERIOR CRANIOCERVICAL','ARTHRODESIS POSTERIOR CRANIOCERVICAL','22590','1','','1','0','','','',0, 1, 0, 0),
(1170,'ARTHRODESIS POSTERIOR ATLAS-AXIS C1-C2','ARTHRODESIS POSTERIOR ATLAS-AXIS C1-C2','22595','1','','1','0','','','',0, 1, 0, 0),
(1171,'ARTHRODESIS PST/PSTLAT CERVICAL BELW C2 SGM','ARTHRODESIS PST/PSTLAT CERVICAL BELW C2 SGM','22600','1','','1','0','','','',0, 1, 0, 0),
(1172,'ARTHRODESIS POSTERIOR/POSTEROLATERAL THORACIC','ARTHRODESIS POSTERIOR/POSTEROLATERAL THORACIC','22610','1','','1','0','','','',0, 1, 0, 0),
(1173,'ARTHRODESIS POSTERIOR/POSTEROLATERAL LUMBAR','ARTHRODESIS POSTERIOR/POSTEROLATERAL LUMBAR','22612','1','','1','0','','','',0, 1, 0, 0),
(1174,'ARTHRODESIS POSTERIOR/POSTEROLATERAL EA ADDL','ARTHRODESIS POSTERIOR/POSTEROLATERAL EA ADDL','22614','1','','1','0','','','',0, 1, 0, 0),
(1175,'ARTHRODESIS POSTERIOR INTERBODY LUMBAR','ARTHRODESIS POSTERIOR INTERBODY LUMBAR','22630','1','','1','0','','','',0, 1, 0, 0),
(1176,'ARTHRODESIS POSTERIOR INTERBODY EA ADDL','ARTHRODESIS POSTERIOR INTERBODY EA ADDL','22632','1','','1','0','','','',0, 1, 0, 0),
(1177,'ARTHDSIS POST/POSTEROLATRL/POSTINTERBODY LUMBAR','ARTHDSIS POST/POSTEROLATRL/POSTINTERBODY LUMBAR','22633','1','','1','0','','','',0, 1, 0, 0),
(1178,'ARTHDSIS POST/POSTERLATRL/POSTINTRBDYADL SPC/SEG','ARTHDSIS POST/POSTERLATRL/POSTINTRBDYADL SPC/SEG','22634','1','','1','0','','','',0, 1, 0, 0),
(1179,'ARTHRODESIS POSTERIOR SPINAL DFRM UP 6 VRT SEG','ARTHRODESIS POSTERIOR SPINAL DFRM UP 6 VRT SEG','22800','1','','1','0','','','',0, 1, 0, 0),
(1180,'ARTHRODESIS POSTERIOR SPINAL DFRM 7-12 VRT SEG','ARTHRODESIS POSTERIOR SPINAL DFRM 7-12 VRT SEG','22802','1','','1','0','','','',0, 1, 0, 0),
(1181,'ARTHRODESIS POSTERIOR SPINAL DFRM 13/> VRT SEG','ARTHRODESIS POSTERIOR SPINAL DFRM 13/> VRT SEG','22804','1','','1','0','','','',0, 1, 0, 0),
(1182,'ARTHRODESIS ANTERIOR SPINAL DFRM 2-3 VRT SEG','ARTHRODESIS ANTERIOR SPINAL DFRM 2-3 VRT SEG','22808','1','','1','0','','','',0, 1, 0, 0),
(1183,'ARTHRODESIS ANTERIOR SPINAL DFRM 4-7 VRT SEG','ARTHRODESIS ANTERIOR SPINAL DFRM 4-7 VRT SEG','22810','1','','1','0','','','',0, 1, 0, 0),
(1184,'ARTHRODESIS POSTERIOR SPINAL DFRM 8/> VRT SEG','ARTHRODESIS POSTERIOR SPINAL DFRM 8/> VRT SEG','22812','1','','1','0','','','',0, 1, 0, 0),
(1185,'KYPHECTOMY SINGLE OR TWO SEGMENTS','KYPHECTOMY SINGLE OR TWO SEGMENTS','22818','1','','1','0','','','',0, 1, 0, 0),
(1186,'KYPHECTOMY 3 OR MORE SEGMENTS','KYPHECTOMY 3 OR MORE SEGMENTS','22819','1','','1','0','','','',0, 1, 0, 0),
(1187,'EXPLORATION SPINAL FUSION','EXPLORATION SPINAL FUSION','22830','1','','1','0','','','',0, 1, 0, 0),
(1188,'POSTERIOR NON-SEGMENTAL INSTRUMENTATION','POSTERIOR NON-SEGMENTAL INSTRUMENTATION','22840','1','','1','0','','','',0, 1, 0, 0),
(1189,'INTERNAL SPINAL FIXATION WIRING SPINOUS PROCESS','INTERNAL SPINAL FIXATION WIRING SPINOUS PROCESS','22841','1','','1','0','','','',0, 1, 0, 0),
(1190,'POSTERIOR SEGMENTAL INSTRUMENTATION 3-6 VRT SEG','POSTERIOR SEGMENTAL INSTRUMENTATION 3-6 VRT SEG','22842','1','','1','0','','','',0, 1, 0, 0),
(1191,'POSTERIOR SEGMENTAL INSTRUMENTATION 7-12 VRT SEG','POSTERIOR SEGMENTAL INSTRUMENTATION 7-12 VRT SEG','22843','1','','1','0','','','',0, 1, 0, 0),
(1192,'POSTERIOR SEGMENTAL INSTRUMENTATION 13/> VRT SE','POSTERIOR SEGMENTAL INSTRUMENTATION 13/> VRT SE','22844','1','','1','0','','','',0, 1, 0, 0),
(1193,'ANTERIOR INSTRUMENTATION 2-3 VERTEBRAL SEGMENTS','ANTERIOR INSTRUMENTATION 2-3 VERTEBRAL SEGMENTS','22845','1','','1','0','','','',0, 1, 0, 0),
(1194,'ANTERIOR INSTRUMENTATION 4-7 VERTEBRAL SEGMENTS','ANTERIOR INSTRUMENTATION 4-7 VERTEBRAL SEGMENTS','22846','1','','1','0','','','',0, 1, 0, 0),
(1195,'ANTERIOR INSTRUMENTATION 8/> VERTEBRAL SEGMENTS','ANTERIOR INSTRUMENTATION 8/> VERTEBRAL SEGMENTS','22847','1','','1','0','','','',0, 1, 0, 0),
(1196,'PELVIC FIXATION OTHER THAN SACRUM','PELVIC FIXATION OTHER THAN SACRUM','22848','1','','1','0','','','',0, 1, 0, 0),
(1197,'REINSERTION SPINAL FIXATION DEVICE','REINSERTION SPINAL FIXATION DEVICE','22849','1','','1','0','','','',0, 1, 0, 0),
(1198,'REMOVAL POSTERIOR NONSEGMENTAL INSTRUMENTATION','REMOVAL POSTERIOR NONSEGMENTAL INSTRUMENTATION','22850','1','','1','0','','','',0, 1, 0, 0),
(1199,'APPLICATION INTERVERTEBRAL BIOMECHANICAL DEVICE','APPLICATION INTERVERTEBRAL BIOMECHANICAL DEVICE','22851','1','','1','0','','','',0, 1, 0, 0),
(1200,'REMOVAL POSTERIOR SEGMENTAL INSTRUMENTATION','REMOVAL POSTERIOR SEGMENTAL INSTRUMENTATION','22852','1','','1','0','','','',0, 1, 0, 0),
(1201,'REMOVAL ANTERIOR INSTRUMENTATION','REMOVAL ANTERIOR INSTRUMENTATION','22855','1','','1','0','','','',0, 1, 0, 0),
(1202,'TOT DISC ARTHRP ART DISC ANT APPRO 1 NTRSPC CRV','TOT DISC ARTHRP ART DISC ANT APPRO 1 NTRSPC CRV','22856','1','','1','0','','','',0, 1, 0, 0),
(1203,'TOT DISC ARTHRP ART DISC ANT APPRO 1 NTRSPC LMBR','TOT DISC ARTHRP ART DISC ANT APPRO 1 NTRSPC LMBR','22857','1','','1','0','','','',0, 1, 0, 0),
(1204,'TOT DISC ARTHRP ANT APPR DISC 2ND LEVEL CERVICAL','TOT DISC ARTHRP ANT APPR DISC 2ND LEVEL CERVICAL','22858','1','','1','0','','','',0, 1, 0, 0),
(1205,'REVJ RPLCMT DISC ARTHROPLASTY ANT 1 NTRSPC CRV','REVJ RPLCMT DISC ARTHROPLASTY ANT 1 NTRSPC CRV','22861','1','','1','0','','','',0, 1, 0, 0),
(1206,'REVJ RPLCMT DISC ARTHROPLASTY ANT 1 NTRSPC LMBR','REVJ RPLCMT DISC ARTHROPLASTY ANT 1 NTRSPC LMBR','22862','1','','1','0','','','',0, 1, 0, 0),
(1207,'RMVL DISC ARTHROPLASTY ANT 1 INTERSPACE CERVICAL','RMVL DISC ARTHROPLASTY ANT 1 INTERSPACE CERVICAL','22864','1','','1','0','','','',0, 1, 0, 0),
(1208,'RMVL DISC ARTHROPLASTY ANT 1 INTERSPACE LUMBAR','RMVL DISC ARTHROPLASTY ANT 1 INTERSPACE LUMBAR','22865','1','','1','0','','','',0, 1, 0, 0),
(1209,'UNLISTED PROCEDURE SPINE','UNLISTED PROCEDURE SPINE','22899','1','','1','0','','','',0, 1, 0, 0),
(1210,'EXC TUMOR SOFT TISSUE ABDL WALL SUBFASCIAL <5CM','EXC TUMOR SOFT TISSUE ABDL WALL SUBFASCIAL <5CM','22900','1','','1','0','','','',0, 1, 0, 0),
(1211,'EXC TUMOR SOFT TISSUE ABDL WALL SUBFASCIAL 5CM/>','EXC TUMOR SOFT TISSUE ABDL WALL SUBFASCIAL 5CM/>','22901','1','','1','0','','','',0, 1, 0, 0),
(1212,'EXC TUMOR SOFT TISSUE ABDOMINAL WALL SUBQ <3CM','EXC TUMOR SOFT TISSUE ABDOMINAL WALL SUBQ <3CM','22902','1','','1','0','','','',0, 1, 0, 0),
(1213,'EXC TUMOR SOFT TISSUE ABDOMINAL WALL SUBQ 3 CM/>','EXC TUMOR SOFT TISSUE ABDOMINAL WALL SUBQ 3 CM/>','22903','1','','1','0','','','',0, 1, 0, 0),
(1214,'RAD RESECTION TUMOR SOFT TISSUE ABDL WALL <5CM','RAD RESECTION TUMOR SOFT TISSUE ABDL WALL <5CM','22904','1','','1','0','','','',0, 1, 0, 0),
(1215,'RAD RESECTION TUMOR SOFT TISSUE ABDL WALL 5 CM/>','RAD RESECTION TUMOR SOFT TISSUE ABDL WALL 5 CM/>','22905','1','','1','0','','','',0, 1, 0, 0),
(1216,'UNLISTED PX ABDOMEN MUSCULOSKELETAL SYSTEM','UNLISTED PX ABDOMEN MUSCULOSKELETAL SYSTEM','22999','1','','1','0','','','',0, 1, 0, 0),
(1217,'REMOVAL SUBDELTOID CALCAREOUS DEPOSITS OPEN','REMOVAL SUBDELTOID CALCAREOUS DEPOSITS OPEN','23000','1','','1','0','','','',0, 1, 0, 0),
(1218,'CAPSULAR CONTRACTURE RELEASE','CAPSULAR CONTRACTURE RELEASE','23020','1','','1','0','','','',0, 1, 0, 0),
(1219,'I&D SHOULDER DEEP ABSCESS/HEMATOMA','I&D SHOULDER DEEP ABSCESS/HEMATOMA','23030','1','','1','0','','','',0, 1, 0, 0),
(1220,'I&D SHOULDER INFECTED BURSA','I&D SHOULDER INFECTED BURSA','23031','1','','1','0','','','',0, 1, 0, 0),
(1221,'INCISION BONE CORTEX SHOULDER AREA','INCISION BONE CORTEX SHOULDER AREA','23035','1','','1','0','','','',0, 1, 0, 0),
(1222,'ARTHROTOMY GLENOHUMERAL JT EXPL/DRG/RMVL FB','ARTHROTOMY GLENOHUMERAL JT EXPL/DRG/RMVL FB','23040','1','','1','0','','','',0, 1, 0, 0),
(1223,'ARTHRT ACROMCLAV STRNCLAV JT EXPL/DRG/RMVL FB','ARTHRT ACROMCLAV STRNCLAV JT EXPL/DRG/RMVL FB','23044','1','','1','0','','','',0, 1, 0, 0),
(1224,'BIOPSY SOFT TISSUE SHOULDER SUPERFICIAL','BIOPSY SOFT TISSUE SHOULDER SUPERFICIAL','23065','1','','1','0','','','',0, 1, 0, 0),
(1225,'BIOPSY SOFT TISSUE SHOULDER DEEP','BIOPSY SOFT TISSUE SHOULDER DEEP','23066','1','','1','0','','','',0, 1, 0, 0),
(1226,'EXCISION TUMOR SOFT TISSUE SHOULDER SUBQ 3 CM/>','EXCISION TUMOR SOFT TISSUE SHOULDER SUBQ 3 CM/>','23071','1','','1','0','','','',0, 1, 0, 0),
(1227,'EXC TUMOR SOFT TISSUE SHOULDER SUBFASCIAL 5 CM/>','EXC TUMOR SOFT TISSUE SHOULDER SUBFASCIAL 5 CM/>','23073','1','','1','0','','','',0, 1, 0, 0),
(1228,'EXCISION TUMOR SOFT TISSUE SHOULDER SUBQ <3CM','EXCISION TUMOR SOFT TISSUE SHOULDER SUBQ <3CM','23075','1','','1','0','','','',0, 1, 0, 0),
(1229,'EXC TUMOR SOFT TISS SHOULDER SUBFASC <5CM','EXC TUMOR SOFT TISS SHOULDER SUBFASC <5CM','23076','1','','1','0','','','',0, 1, 0, 0),
(1230,'RAD RESECTION TUMOR SOFT TISSUE SHOULDER <5CM','RAD RESECTION TUMOR SOFT TISSUE SHOULDER <5CM','23077','1','','1','0','','','',0, 1, 0, 0),
(1231,'RAD RESECTION TUMOR SOFT TISSUE SHOULDER 5 CM/>','RAD RESECTION TUMOR SOFT TISSUE SHOULDER 5 CM/>','23078','1','','1','0','','','',0, 1, 0, 0),
(1232,'ARTHROTOMY GLENOHUMERAL JOINT W/BIOPSY','ARTHROTOMY GLENOHUMERAL JOINT W/BIOPSY','23100','1','','1','0','','','',0, 1, 0, 0),
(1233,'ARTHRT ACROMCLAV/STRNCLAV JT W/BX&/EXC CRTLG','ARTHRT ACROMCLAV/STRNCLAV JT W/BX&/EXC CRTLG','23101','1','','1','0','','','',0, 1, 0, 0),
(1234,'ARTHRT GLENOHUMRL JT W/SYNOVECTOMY W/WO BIOPSY','ARTHRT GLENOHUMRL JT W/SYNOVECTOMY W/WO BIOPSY','23105','1','','1','0','','','',0, 1, 0, 0),
(1235,'ARTHRT GLENOHUMRL JT STRNCLAV JT W/SYNVCT W/WOBX','ARTHRT GLENOHUMRL JT STRNCLAV JT W/SYNVCT W/WOBX','23106','1','','1','0','','','',0, 1, 0, 0),
(1236,'ARTHRT GLENOHMRL JT W/JT EXPL W/WO RMVL LOOSE/FB','ARTHRT GLENOHMRL JT W/JT EXPL W/WO RMVL LOOSE/FB','23107','1','','1','0','','','',0, 1, 0, 0),
(1237,'CLAVICULECTOMY PARTIAL','CLAVICULECTOMY PARTIAL','23120','1','','1','0','','','',0, 1, 0, 0),
(1238,'CLAVICULECTOMY TOTAL','CLAVICULECTOMY TOTAL','23125','1','','1','0','','','',0, 1, 0, 0),
(1239,'PARTIAL REPAIR OR REMOVAL OF SHOULDER BONE','PARTIAL REPAIR OR REMOVAL OF SHOULDER BONE','23130','1','','1','0','','','',0, 1, 0, 0),
(1240,'EXC/CURTG BONE CYST/BENIGN TUMOR CLAV/SCAPULA','EXC/CURTG BONE CYST/BENIGN TUMOR CLAV/SCAPULA','23140','1','','1','0','','','',0, 1, 0, 0),
(1241,'EXC/CURTG BONE CST/B9 TUM CLAV/SCAPULA W/AGRFT','EXC/CURTG BONE CST/B9 TUM CLAV/SCAPULA W/AGRFT','23145','1','','1','0','','','',0, 1, 0, 0),
(1242,'EXC/CURTG BONE CST/B9 TUM CLAV/SCAPULA W/ALGRFT','EXC/CURTG BONE CST/B9 TUM CLAV/SCAPULA W/ALGRFT','23146','1','','1','0','','','',0, 1, 0, 0),
(1243,'EXC/CURTG BONE CYST/BENIGN TUMOR PROX HUMERUS','EXC/CURTG BONE CYST/BENIGN TUMOR PROX HUMERUS','23150','1','','1','0','','','',0, 1, 0, 0),
(1244,'EXC/CURTG BONE CYST/BENIGN TUM PROX HUM W/AGRFT','EXC/CURTG BONE CYST/BENIGN TUM PROX HUM W/AGRFT','23155','1','','1','0','','','',0, 1, 0, 0),
(1245,'EXC/CURTG BONE CYST/BENIGN TUM PROX HUM W/ALGRFT','EXC/CURTG BONE CYST/BENIGN TUM PROX HUM W/ALGRFT','23156','1','','1','0','','','',0, 1, 0, 0),
(1246,'SEQUESTRECTOMY CLAVICLE','SEQUESTRECTOMY CLAVICLE','23170','1','','1','0','','','',0, 1, 0, 0),
(1247,'SEQUESTRECTOMY SCAPULA','SEQUESTRECTOMY SCAPULA','23172','1','','1','0','','','',0, 1, 0, 0),
(1248,'SEQUESTRECTOMY HUMERAL HEAD SURGERY NECK','SEQUESTRECTOMY HUMERAL HEAD SURGERY NECK','23174','1','','1','0','','','',0, 1, 0, 0),
(1249,'PARTIAL EXCISION BONE CLAVICLE','PARTIAL EXCISION BONE CLAVICLE','23180','1','','1','0','','','',0, 1, 0, 0),
(1250,'PARTIAL EXCISION BONE SCAPULA','PARTIAL EXCISION BONE SCAPULA','23182','1','','1','0','','','',0, 1, 0, 0),
(1251,'PARTIAL EXCISION BONE PROXIMAL HUMERUS','PARTIAL EXCISION BONE PROXIMAL HUMERUS','23184','1','','1','0','','','',0, 1, 0, 0),
(1252,'OSTECTOMY SCAPULA PARTIAL','OSTECTOMY SCAPULA PARTIAL','23190','1','','1','0','','','',0, 1, 0, 0),
(1253,'RESECTION HUMERAL HEAD','RESECTION HUMERAL HEAD','23195','1','','1','0','','','',0, 1, 0, 0),
(1254,'RADICAL RESECTION TUMOR CLAVICLE','RADICAL RESECTION TUMOR CLAVICLE','23200','1','','1','0','','','',0, 1, 0, 0),
(1255,'RADICAL RESECTION TUMOR SCAPULA','RADICAL RESECTION TUMOR SCAPULA','23210','1','','1','0','','','',0, 1, 0, 0),
(1256,'RADICAL RESECTION BONE TUMOR PROXIMAL HUMERUS','RADICAL RESECTION BONE TUMOR PROXIMAL HUMERUS','23220','1','','1','0','','','',0, 1, 0, 0),
(1257,'REMOVAL FOREIGN BODY SHOULDER SUBCUTANEOUS','REMOVAL FOREIGN BODY SHOULDER SUBCUTANEOUS','23330','1','','1','0','','','',0, 1, 0, 0),
(1258,'REMOVAL SHOULDER FOREIGN BODY DEEP SUBFASCIAL/IM','REMOVAL SHOULDER FOREIGN BODY DEEP SUBFASCIAL/IM','23333','1','','1','0','','','',0, 1, 0, 0),
(1259,'PROSTHESIS REMOVAL HUMERAL/GLENOID COMPONENT','PROSTHESIS REMOVAL HUMERAL/GLENOID COMPONENT','23334','1','','1','0','','','',0, 1, 0, 0),
(1260,'PROSTHESIS REMOVAL HUMERAL AND GLENOID COMPONENT','PROSTHESIS REMOVAL HUMERAL AND GLENOID COMPONENT','23335','1','','1','0','','','',0, 1, 0, 0),
(1261,'INJECTION SHOULDER ARTHROGRAPHY/ CT/MRI ARTHG','INJECTION SHOULDER ARTHROGRAPHY/ CT/MRI ARTHG','23350','1','','1','0','','','',0, 1, 0, 0),
(1262,'MUSCLE TRANSFER SHOULDER/UPPER ARM SINGLE','MUSCLE TRANSFER SHOULDER/UPPER ARM SINGLE','23395','1','','1','0','','','',0, 1, 0, 0),
(1263,'MUSCLE TRANSFER SHOULDER/UPPER ARM MULTIPLE','MUSCLE TRANSFER SHOULDER/UPPER ARM MULTIPLE','23397','1','','1','0','','','',0, 1, 0, 0),
(1264,'SCAPULOPEXY','SCAPULOPEXY','23400','1','','1','0','','','',0, 1, 0, 0),
(1265,'TENOTOMY SHOULDER AREA 1 TENDON','TENOTOMY SHOULDER AREA 1 TENDON','23405','1','','1','0','','','',0, 1, 0, 0),
(1266,'TENOTOMY SHOULDER MULTIPLE THRU SAME INCISION','TENOTOMY SHOULDER MULTIPLE THRU SAME INCISION','23406','1','','1','0','','','',0, 1, 0, 0),
(1267,'OPEN REPAIR OF ROTATOR CUFF ACUTE','OPEN REPAIR OF ROTATOR CUFF ACUTE','23410','1','','1','0','','','',0, 1, 0, 0),
(1268,'OPEN REPAIR OF ROTATOR CUFF CHRONIC','OPEN REPAIR OF ROTATOR CUFF CHRONIC','23412','1','','1','0','','','',0, 1, 0, 0),
(1269,'CORACOACROMIAL LIGAMENT RELEAS W/WOACROMIOPLASTY','CORACOACROMIAL LIGAMENT RELEAS W/WOACROMIOPLASTY','23415','1','','1','0','','','',0, 1, 0, 0),
(1270,'RECONSTRUCTION ROTATOR CUFF AVULSION CHRONIC','RECONSTRUCTION ROTATOR CUFF AVULSION CHRONIC','23420','1','','1','0','','','',0, 1, 0, 0),
(1271,'TENODESIS LONG TENDON BICEPS','TENODESIS LONG TENDON BICEPS','23430','1','','1','0','','','',0, 1, 0, 0),
(1272,'RESECTION/TRANSPLANTATION LONG TENDON BICEPS','RESECTION/TRANSPLANTATION LONG TENDON BICEPS','23440','1','','1','0','','','',0, 1, 0, 0),
(1273,'CAPSULORRHAPHY ANTERIOR PUTTI-PLATT/MAGNUSON','CAPSULORRHAPHY ANTERIOR PUTTI-PLATT/MAGNUSON','23450','1','','1','0','','','',0, 1, 0, 0),
(1274,'CAPSULORRHAPHY ANTERIOR W/LABRAL REPAIR','CAPSULORRHAPHY ANTERIOR W/LABRAL REPAIR','23455','1','','1','0','','','',0, 1, 0, 0),
(1275,'CAPSULORRHAPHY ANTERIOR WITH BONE BLOCK','CAPSULORRHAPHY ANTERIOR WITH BONE BLOCK','23460','1','','1','0','','','',0, 1, 0, 0),
(1276,'CAPSULORRHAPHY ANTERIOR W/CORACOID PROCESS TR','CAPSULORRHAPHY ANTERIOR W/CORACOID PROCESS TR','23462','1','','1','0','','','',0, 1, 0, 0),
(1277,'CAPSULORRHAPHY GLENOHUMERAL JT PST W/WO BONE BLK','CAPSULORRHAPHY GLENOHUMERAL JT PST W/WO BONE BLK','23465','1','','1','0','','','',0, 1, 0, 0),
(1278,'CAPSULORRHAPHY GLENOHUMRL JT MULTI-DIRIONAL INS','CAPSULORRHAPHY GLENOHUMRL JT MULTI-DIRIONAL INS','23466','1','','1','0','','','',0, 1, 0, 0),
(1279,'ARTHROPLASTY GLENOHUMRL JT HEMIARTHROPLASTY','ARTHROPLASTY GLENOHUMRL JT HEMIARTHROPLASTY','23470','1','','1','0','','','',0, 1, 0, 0),
(1280,'ARTHROPLASTY GLENOHUMERAL JOINT TOTAL SHOULDER','ARTHROPLASTY GLENOHUMERAL JOINT TOTAL SHOULDER','23472','1','','1','0','','','',0, 1, 0, 0),
(1281,'REVIS SHOULDER ARTHRPLSTY HUMERAL/GLENOID COMPNT','REVIS SHOULDER ARTHRPLSTY HUMERAL/GLENOID COMPNT','23473','1','','1','0','','','',0, 1, 0, 0),
(1282,'REVIS SHOULDER ARTHRPLSTY HUMERAL&GLENOID COMPNT','REVIS SHOULDER ARTHRPLSTY HUMERAL&GLENOID COMPNT','23474','1','','1','0','','','',0, 1, 0, 0),
(1283,'OSTEOTOMY CLAVICLE W/WO INTERNAL FIXATION','OSTEOTOMY CLAVICLE W/WO INTERNAL FIXATION','23480','1','','1','0','','','',0, 1, 0, 0),
(1284,'OSTEOTOMY CLAV W/WO INT FIXJ W/BONE GRF NON/MAL','OSTEOTOMY CLAV W/WO INT FIXJ W/BONE GRF NON/MAL','23485','1','','1','0','','','',0, 1, 0, 0),
(1285,'PROPH TX W/WO METHYLMETHACRYLATE CLAVICLE','PROPH TX W/WO METHYLMETHACRYLATE CLAVICLE','23490','1','','1','0','','','',0, 1, 0, 0),
(1286,'PROPH TX W/WO METHYLMETHACRYLATE PROX HUMERUS','PROPH TX W/WO METHYLMETHACRYLATE PROX HUMERUS','23491','1','','1','0','','','',0, 1, 0, 0),
(1287,'CLSD TX CLAVICULAR FRACTURE W/O MANIPULATION','CLSD TX CLAVICULAR FRACTURE W/O MANIPULATION','23500','1','','1','0','','','',0, 1, 0, 0),
(1288,'CLSD TX CLAVICULAR FRACTURE W/MANIPULATION','CLSD TX CLAVICULAR FRACTURE W/MANIPULATION','23505','1','','1','0','','','',0, 1, 0, 0),
(1289,'OPEN TX CLAVICULAR FRACTURE INTERNAL FIXATION','OPEN TX CLAVICULAR FRACTURE INTERNAL FIXATION','23515','1','','1','0','','','',0, 1, 0, 0),
(1290,'CLSD TX STERNOCLAVICULAR DISLC W/O MANIPULATION','CLSD TX STERNOCLAVICULAR DISLC W/O MANIPULATION','23520','1','','1','0','','','',0, 1, 0, 0),
(1291,'CLOSED TX STERNOCLAVICULAR DISLC W/MANIPULATION','CLOSED TX STERNOCLAVICULAR DISLC W/MANIPULATION','23525','1','','1','0','','','',0, 1, 0, 0),
(1292,'OPEN TX STERNOCLAVICULAR DISLC ACUTE/CHRONIC','OPEN TX STERNOCLAVICULAR DISLC ACUTE/CHRONIC','23530','1','','1','0','','','',0, 1, 0, 0),
(1293,'OPTX STRNCLAV DISLC ACUTE/CHRONIC W/FASCIAL GRF','OPTX STRNCLAV DISLC ACUTE/CHRONIC W/FASCIAL GRF','23532','1','','1','0','','','',0, 1, 0, 0),
(1294,'CLSD TX ACROMIOCLAVICULAR DISLC W/O MANIPULATION','CLSD TX ACROMIOCLAVICULAR DISLC W/O MANIPULATION','23540','1','','1','0','','','',0, 1, 0, 0),
(1295,'CLSD TX ACROMIOCLAVICULAR DISLC W/MANIPULATION','CLSD TX ACROMIOCLAVICULAR DISLC W/MANIPULATION','23545','1','','1','0','','','',0, 1, 0, 0),
(1296,'OPEN TX ACROMIOCLAVICULAR DISLC ACUTE/CHRONIC','OPEN TX ACROMIOCLAVICULAR DISLC ACUTE/CHRONIC','23550','1','','1','0','','','',0, 1, 0, 0),
(1297,'OPTX ACROMCLAV DISLC ACUTE/CHRONIC W/FASCIAL GRF','OPTX ACROMCLAV DISLC ACUTE/CHRONIC W/FASCIAL GRF','23552','1','','1','0','','','',0, 1, 0, 0),
(1298,'CLOSED TX SCAPULAR FRACTURE W/O MANIPULATION','CLOSED TX SCAPULAR FRACTURE W/O MANIPULATION','23570','1','','1','0','','','',0, 1, 0, 0),
(1299,'CLTX SCAPULAR FX W/MANJ W/WO SKELETAL TRACTION','CLTX SCAPULAR FX W/MANJ W/WO SKELETAL TRACTION','23575','1','','1','0','','','',0, 1, 0, 0),
(1300,'OPEN TX SCAPULAR FX W/INTERNAL FIXATION IF PFRMD','OPEN TX SCAPULAR FX W/INTERNAL FIXATION IF PFRMD','23585','1','','1','0','','','',0, 1, 0, 0),
(1301,'CLTX PROXIMAL HUMERAL FRACTURE W/O MANIPULATION','CLTX PROXIMAL HUMERAL FRACTURE W/O MANIPULATION','23600','1','','1','0','','','',0, 1, 0, 0),
(1302,'CLTX PROX HUMRL FX W/MANJ W/WO SKELETAL TRACJ','CLTX PROX HUMRL FX W/MANJ W/WO SKELETAL TRACJ','23605','1','','1','0','','','',0, 1, 0, 0),
(1303,'OPEN TREATMENT PROXIMAL HUMERAL FRACTURE','OPEN TREATMENT PROXIMAL HUMERAL FRACTURE','23615','1','','1','0','','','',0, 1, 0, 0),
(1304,'OPEN PROX HUMERAL FRACTURE PROSTHETIC RPLCMT','OPEN PROX HUMERAL FRACTURE PROSTHETIC RPLCMT','23616','1','','1','0','','','',0, 1, 0, 0),
(1305,'CLTX GREATER HUMERAL TUBEROSITY FX W/O MANJ','CLTX GREATER HUMERAL TUBEROSITY FX W/O MANJ','23620','1','','1','0','','','',0, 1, 0, 0),
(1306,'CLTX GRTER HUMERAL TUBEROSITY FX W/MANIPULATION','CLTX GRTER HUMERAL TUBEROSITY FX W/MANIPULATION','23625','1','','1','0','','','',0, 1, 0, 0),
(1307,'OPEN TREATMENT GRTER HUMERAL TUBEROSITY FRACTURE','OPEN TREATMENT GRTER HUMERAL TUBEROSITY FRACTURE','23630','1','','1','0','','','',0, 1, 0, 0),
(1308,'CLSD TX SHOULDER DISLC W/MANIPULATION W/O ANES','CLSD TX SHOULDER DISLC W/MANIPULATION W/O ANES','23650','1','','1','0','','','',0, 1, 0, 0),
(1309,'CLSD TX SHOULDER DISLC W/MANIPULATION REQ ANES','CLSD TX SHOULDER DISLC W/MANIPULATION REQ ANES','23655','1','','1','0','','','',0, 1, 0, 0),
(1310,'OPEN TX ACUTE SHOULDER DISLOCATION','OPEN TX ACUTE SHOULDER DISLOCATION','23660','1','','1','0','','','',0, 1, 0, 0),
(1311,'CLTX SHOULDER DISLC W/FX HUMERAL TUBRST W/MANJ','CLTX SHOULDER DISLC W/FX HUMERAL TUBRST W/MANJ','23665','1','','1','0','','','',0, 1, 0, 0),
(1312,'OPEN TX SHOULDER DISLC W/HUMERAL TUBEROSITY FX','OPEN TX SHOULDER DISLC W/HUMERAL TUBEROSITY FX','23670','1','','1','0','','','',0, 1, 0, 0),
(1313,'CLTX SHOULDER DISLC W/SURG/ANTMCL NECK FX W/MANJ','CLTX SHOULDER DISLC W/SURG/ANTMCL NECK FX W/MANJ','23675','1','','1','0','','','',0, 1, 0, 0),
(1314,'OPEN TX SHOULDER DISLOCATION W/NECK FRACTURE','OPEN TX SHOULDER DISLOCATION W/NECK FRACTURE','23680','1','','1','0','','','',0, 1, 0, 0),
(1315,'MANJ W/ANES SHOULDER JOINT W/FIXATION APPARATUS','MANJ W/ANES SHOULDER JOINT W/FIXATION APPARATUS','23700','1','','1','0','','','',0, 1, 0, 0),
(1316,'ARTHRODESIS GLENOHUMERAL JOINT','ARTHRODESIS GLENOHUMERAL JOINT','23800','1','','1','0','','','',0, 1, 0, 0),
(1317,'ARTHRODESIS GLENOHUMERAL JT W/AUTOGENOUS GRAFT','ARTHRODESIS GLENOHUMERAL JT W/AUTOGENOUS GRAFT','23802','1','','1','0','','','',0, 1, 0, 0),
(1318,'INTERTHORACOSCAPULAR AMPUTATION','INTERTHORACOSCAPULAR AMPUTATION','23900','1','','1','0','','','',0, 1, 0, 0),
(1319,'DISARTICULATION SHOULDER','DISARTICULATION SHOULDER','23920','1','','1','0','','','',0, 1, 0, 0),
(1320,'DISRTCJ SHOULDER SECONDARY CLSR/SCAR REVISION','DISRTCJ SHOULDER SECONDARY CLSR/SCAR REVISION','23921','1','','1','0','','','',0, 1, 0, 0),
(1321,'UNLISTED PROCEDURE SHOULDER','UNLISTED PROCEDURE SHOULDER','23929','1','','1','0','','','',0, 1, 0, 0),
(1322,'I&D UPPER ARM/ELBOW DEEP ABSCESS/HEMATOMA','I&D UPPER ARM/ELBOW DEEP ABSCESS/HEMATOMA','23930','1','','1','0','','','',0, 1, 0, 0),
(1323,'INCISION&DRAINAGE UPPER ARM/ELBOW BURSA','INCISION&DRAINAGE UPPER ARM/ELBOW BURSA','23931','1','','1','0','','','',0, 1, 0, 0),
(1324,'INC DEEP W/OPENING BONE CORTEX HUMERUS/ELBOW','INC DEEP W/OPENING BONE CORTEX HUMERUS/ELBOW','23935','1','','1','0','','','',0, 1, 0, 0),
(1325,'ARTHRT ELBOW W/EXPLORATION DRAINAGE/REMOVAL FB','ARTHRT ELBOW W/EXPLORATION DRAINAGE/REMOVAL FB','24000','1','','1','0','','','',0, 1, 0, 0),
(1326,'ARTHRT ELBOW CAPSULAR EXCISION CAPSULAR RLS SPX','ARTHRT ELBOW CAPSULAR EXCISION CAPSULAR RLS SPX','24006','1','','1','0','','','',0, 1, 0, 0),
(1327,'BIOPSY SOFT TISSUE UPPER ARM/ELBOW SUPERFICIAL','BIOPSY SOFT TISSUE UPPER ARM/ELBOW SUPERFICIAL','24065','1','','1','0','','','',0, 1, 0, 0),
(1328,'BIOPSY SOFT TISSUE UPPER ARM/ELBOW AREA DEEP','BIOPSY SOFT TISSUE UPPER ARM/ELBOW AREA DEEP','24066','1','','1','0','','','',0, 1, 0, 0),
(1329,'EXC TUMOR SOFT TISSUE UPPER ARM/ELBOW SUBQ 3CM/>','EXC TUMOR SOFT TISSUE UPPER ARM/ELBOW SUBQ 3CM/>','24071','1','','1','0','','','',0, 1, 0, 0),
(1330,'EXC TUMOR SOFT TISS UPPER ARM/ELBW SUBFASC 5CM/>','EXC TUMOR SOFT TISS UPPER ARM/ELBW SUBFASC 5CM/>','24073','1','','1','0','','','',0, 1, 0, 0),
(1331,'EXC TUMOR SOFT TISS UPPER ARM/ELBOW SUBQ <3CM','EXC TUMOR SOFT TISS UPPER ARM/ELBOW SUBQ <3CM','24075','1','','1','0','','','',0, 1, 0, 0),
(1332,'EXC TUMOR SOFT TISS UPR ARM/ELBOW SUBFASC <5CM','EXC TUMOR SOFT TISS UPR ARM/ELBOW SUBFASC <5CM','24076','1','','1','0','','','',0, 1, 0, 0),
(1333,'RAD RESECT TUMOR SOFT TISS UPPER ARM/ELBOW <5CM','RAD RESECT TUMOR SOFT TISS UPPER ARM/ELBOW <5CM','24077','1','','1','0','','','',0, 1, 0, 0),
(1334,'RAD RESECT TUMOR SOFT TISS UPPER ARM/ELBOW 5CM/>','RAD RESECT TUMOR SOFT TISS UPPER ARM/ELBOW 5CM/>','24079','1','','1','0','','','',0, 1, 0, 0),
(1335,'ARTHROTOMY ELBOW W/SYNOVIAL BIOPSY ONLY','ARTHROTOMY ELBOW W/SYNOVIAL BIOPSY ONLY','24100','1','','1','0','','','',0, 1, 0, 0),
(1336,'ARTHRT ELBOW W/JNT EXPL W/WOBX W/WORMVL LOOSE/FB','ARTHRT ELBOW W/JNT EXPL W/WOBX W/WORMVL LOOSE/FB','24101','1','','1','0','','','',0, 1, 0, 0),
(1337,'ARTHROTOMY ELBOW W/SYNOVECTOMY','ARTHROTOMY ELBOW W/SYNOVECTOMY','24102','1','','1','0','','','',0, 1, 0, 0),
(1338,'EXCISION OLECRANON BURSA','EXCISION OLECRANON BURSA','24105','1','','1','0','','','',0, 1, 0, 0),
(1339,'EXCISION/CURTG BONE CYST/BENIGN TUMOR HUMERUS','EXCISION/CURTG BONE CYST/BENIGN TUMOR HUMERUS','24110','1','','1','0','','','',0, 1, 0, 0),
(1340,'EXC/CURTG BONE CYST/BENIGN TUMOR HUMERUS W/AGRFT','EXC/CURTG BONE CYST/BENIGN TUMOR HUMERUS W/AGRFT','24115','1','','1','0','','','',0, 1, 0, 0),
(1341,'EXC/CURTG BONE CYST/BENIGN TUM HUMERUS W/ALGRFT','EXC/CURTG BONE CYST/BENIGN TUM HUMERUS W/ALGRFT','24116','1','','1','0','','','',0, 1, 0, 0),
(1342,'EXC/CURTG BONE CYST/BENIGN TUMOR H/N RDS/OLECRN','EXC/CURTG BONE CYST/BENIGN TUMOR H/N RDS/OLECRN','24120','1','','1','0','','','',0, 1, 0, 0),
(1343,'EXC/CURTG BONE CST/B9 TUM H/N RDS/OLECRN W/AGRFT','EXC/CURTG BONE CST/B9 TUM H/N RDS/OLECRN W/AGRFT','24125','1','','1','0','','','',0, 1, 0, 0),
(1344,'EXC/CURTG BONE CST/B9 TUM H/N RDS/OLECRN W/ALGRT','EXC/CURTG BONE CST/B9 TUM H/N RDS/OLECRN W/ALGRT','24126','1','','1','0','','','',0, 1, 0, 0),
(1345,'EXCISION RADIAL HEAD','EXCISION RADIAL HEAD','24130','1','','1','0','','','',0, 1, 0, 0),
(1346,'SEQUESTRECTOMY SHAFT/DISTAL HUMERUS','SEQUESTRECTOMY SHAFT/DISTAL HUMERUS','24134','1','','1','0','','','',0, 1, 0, 0),
(1347,'SEQUESTRECTOMY RADIAL HEAD OR NECK','SEQUESTRECTOMY RADIAL HEAD OR NECK','24136','1','','1','0','','','',0, 1, 0, 0),
(1348,'SEQUESTRECTOMY OLECRANON PROCESS','SEQUESTRECTOMY OLECRANON PROCESS','24138','1','','1','0','','','',0, 1, 0, 0),
(1349,'PARTIAL EXCISION BONE HUMERUS','PARTIAL EXCISION BONE HUMERUS','24140','1','','1','0','','','',0, 1, 0, 0),
(1350,'PARTIAL EXCISION BONE RADIAL HEAD/NECK','PARTIAL EXCISION BONE RADIAL HEAD/NECK','24145','1','','1','0','','','',0, 1, 0, 0),
(1351,'PARTIAL EXCISION BONE OLECRANON PROCESS','PARTIAL EXCISION BONE OLECRANON PROCESS','24147','1','','1','0','','','',0, 1, 0, 0),
(1352,'RAD RESCJ CAPSL TISS&HTRTPC BONE ELBW CONTRCT','RAD RESCJ CAPSL TISS&HTRTPC BONE ELBW CONTRCT','24149','1','','1','0','','','',0, 1, 0, 0),
(1353,'RADICAL RESECTION TUMOR SHAFT/DISTAL HUMERUS','RADICAL RESECTION TUMOR SHAFT/DISTAL HUMERUS','24150','1','','1','0','','','',0, 1, 0, 0),
(1354,'RADICAL RESECTION TUMOR RADIAL HEAD/NECK','RADICAL RESECTION TUMOR RADIAL HEAD/NECK','24152','1','','1','0','','','',0, 1, 0, 0),
(1355,'RESECTION ELBOW JOINT ARTHRECTOMY','RESECTION ELBOW JOINT ARTHRECTOMY','24155','1','','1','0','','','',0, 1, 0, 0),
(1356,'PROSTHESIS REMOVAL HUMERAL AND ULNAR COMPONENTS','PROSTHESIS REMOVAL HUMERAL AND ULNAR COMPONENTS','24160','1','','1','0','','','',0, 1, 0, 0),
(1357,'PROSTHESIS REMOVAL RADIAL HEAD','PROSTHESIS REMOVAL RADIAL HEAD','24164','1','','1','0','','','',0, 1, 0, 0),
(1358,'RMVL FOREIGN BODY UPPER ARM/ELBOW SUBCUTANEOUS','RMVL FOREIGN BODY UPPER ARM/ELBOW SUBCUTANEOUS','24200','1','','1','0','','','',0, 1, 0, 0),
(1359,'REMOVAL FOREIGN BODY UPPER ARM/ELBOW DEEP','REMOVAL FOREIGN BODY UPPER ARM/ELBOW DEEP','24201','1','','1','0','','','',0, 1, 0, 0),
(1360,'INJECTION ELBOW ARTHROGRAPHY','INJECTION ELBOW ARTHROGRAPHY','24220','1','','1','0','','','',0, 1, 0, 0),
(1361,'MANIPULATION ELBOW UNDER ANESTHESIA','MANIPULATION ELBOW UNDER ANESTHESIA','24300','1','','1','0','','','',0, 1, 0, 0),
(1362,'MUSCLE/TENDON TRANSFER UPPER ARM/ELBOW SINGLE','MUSCLE/TENDON TRANSFER UPPER ARM/ELBOW SINGLE','24301','1','','1','0','','','',0, 1, 0, 0),
(1363,'TENDON LENGTHENING UPPER ARM/ELBOW EA TENDON','TENDON LENGTHENING UPPER ARM/ELBOW EA TENDON','24305','1','','1','0','','','',0, 1, 0, 0),
(1364,'TENOTOMY OPEN ELBOW TO SHOULDER EACH TENDON','TENOTOMY OPEN ELBOW TO SHOULDER EACH TENDON','24310','1','','1','0','','','',0, 1, 0, 0),
(1365,'TENOPLASTY ELBOW TO SHOULDER SINGLE','TENOPLASTY ELBOW TO SHOULDER SINGLE','24320','1','','1','0','','','',0, 1, 0, 0),
(1366,'FLEXOR-PLASTY ELBOW','FLEXOR-PLASTY ELBOW','24330','1','','1','0','','','',0, 1, 0, 0),
(1367,'FLEXOR-PLASTY ELBOW W/EXTENSOR ADVANCEMENT','FLEXOR-PLASTY ELBOW W/EXTENSOR ADVANCEMENT','24331','1','','1','0','','','',0, 1, 0, 0),
(1368,'TENOLYSIS TRICEPS','TENOLYSIS TRICEPS','24332','1','','1','0','','','',0, 1, 0, 0),
(1369,'TENODESIS BICEPS TENDON ELBOW SEPARATE PROCEDURE','TENODESIS BICEPS TENDON ELBOW SEPARATE PROCEDURE','24340','1','','1','0','','','',0, 1, 0, 0),
(1370,'REPAIR TENDON/MUSCLE UPPER ARM/ELBOW EA','REPAIR TENDON/MUSCLE UPPER ARM/ELBOW EA','24341','1','','1','0','','','',0, 1, 0, 0),
(1371,'RINSJ RPTD BICEPS/TRICEPS TDN DSTL W/WO TDN GRF','RINSJ RPTD BICEPS/TRICEPS TDN DSTL W/WO TDN GRF','24342','1','','1','0','','','',0, 1, 0, 0),
(1372,'REPAIR LATERAL COLLATERAL LIGAMENT ELBOW','REPAIR LATERAL COLLATERAL LIGAMENT ELBOW','24343','1','','1','0','','','',0, 1, 0, 0),
(1373,'RCNSTJ LAT COLTRL LIGM ELBOW W/TENDON GRAFT','RCNSTJ LAT COLTRL LIGM ELBOW W/TENDON GRAFT','24344','1','','1','0','','','',0, 1, 0, 0),
(1374,'REPAIR MEDIAL COLLATERAL LIGAMENT ELBOW','REPAIR MEDIAL COLLATERAL LIGAMENT ELBOW','24345','1','','1','0','','','',0, 1, 0, 0),
(1375,'RCNSTJ MEDIAL COLTRL LIGM ELBW W/TDN GRF','RCNSTJ MEDIAL COLTRL LIGM ELBW W/TDN GRF','24346','1','','1','0','','','',0, 1, 0, 0),
(1376,'TENOTOMY ELBOW LATERAL/MEDIAL PERCUTANEOUS','TENOTOMY ELBOW LATERAL/MEDIAL PERCUTANEOUS','24357','1','','1','0','','','',0, 1, 0, 0),
(1377,'TNOT ELBOW LATERAL/MEDIAL DEBRIDE OPEN','TNOT ELBOW LATERAL/MEDIAL DEBRIDE OPEN','24358','1','','1','0','','','',0, 1, 0, 0),
(1378,'TNOT ELBOW LATERAL/MEDIAL DEBRIDE OPEN TDN RPR','TNOT ELBOW LATERAL/MEDIAL DEBRIDE OPEN TDN RPR','24359','1','','1','0','','','',0, 1, 0, 0),
(1379,'ARTHROPLASTY ELBOW W/MEMBRANE','ARTHROPLASTY ELBOW W/MEMBRANE','24360','1','','1','0','','','',0, 1, 0, 0),
(1380,'ARTHROPLASTY ELBOW W/DISTAL HUMRL PROSTC RPLCMT','ARTHROPLASTY ELBOW W/DISTAL HUMRL PROSTC RPLCMT','24361','1','','1','0','','','',0, 1, 0, 0),
(1381,'ARTHRP ELBOW W/IMPLT&FSCA LATA LIGAMENT RCNSTJ','ARTHRP ELBOW W/IMPLT&FSCA LATA LIGAMENT RCNSTJ','24362','1','','1','0','','','',0, 1, 0, 0),
(1382,'ARTHRP ELBOW W/DISTAL HUM&PROX UR PROSTC RPLCM','ARTHRP ELBOW W/DISTAL HUM&PROX UR PROSTC RPLCM','24363','1','','1','0','','','',0, 1, 0, 0),
(1383,'ARTHROPLASTY RADIAL HEAD','ARTHROPLASTY RADIAL HEAD','24365','1','','1','0','','','',0, 1, 0, 0),
(1384,'ARTHROPLASTY RADIAL HEAD W/IMPLANT','ARTHROPLASTY RADIAL HEAD W/IMPLANT','24366','1','','1','0','','','',0, 1, 0, 0),
(1385,'REVIS ELBOW ARTHRPLSTY HUMERAL/ULNA COMPNT','REVIS ELBOW ARTHRPLSTY HUMERAL/ULNA COMPNT','24370','1','','1','0','','','',0, 1, 0, 0),
(1386,'REVIS ELBOW ARTHRPLSTY HUMERAL&ULNA COMPNT','REVIS ELBOW ARTHRPLSTY HUMERAL&ULNA COMPNT','24371','1','','1','0','','','',0, 1, 0, 0),
(1387,'OSTEOTOMY HUMERUS W/WO INTERNAL FIXATION','OSTEOTOMY HUMERUS W/WO INTERNAL FIXATION','24400','1','','1','0','','','',0, 1, 0, 0),
(1388,'MLT OSTEOT W/RELIGNMT IMED ROD HUMERAL SHAFT','MLT OSTEOT W/RELIGNMT IMED ROD HUMERAL SHAFT','24410','1','','1','0','','','',0, 1, 0, 0),
(1389,'OSTEOPLASTY HUMERUS','OSTEOPLASTY HUMERUS','24420','1','','1','0','','','',0, 1, 0, 0),
(1390,'REPAIR NON/MALUNION HUMERUS W/O GRAFT','REPAIR NON/MALUNION HUMERUS W/O GRAFT','24430','1','','1','0','','','',0, 1, 0, 0),
(1391,'REPAIR NON/MALUNION HUMERUS W/ILIAC/OTH AGRFT','REPAIR NON/MALUNION HUMERUS W/ILIAC/OTH AGRFT','24435','1','','1','0','','','',0, 1, 0, 0),
(1392,'HEMIEPIPHYSEAL ARREST','HEMIEPIPHYSEAL ARREST','24470','1','','1','0','','','',0, 1, 0, 0),
(1393,'DECOMPRESSION FASCT F/ARM W/BRACH ART EXPL','DECOMPRESSION FASCT F/ARM W/BRACH ART EXPL','24495','1','','1','0','','','',0, 1, 0, 0),
(1394,'PROPH TX W/WO METHYLMETHACRYLATE HUMERAL SHAFT','PROPH TX W/WO METHYLMETHACRYLATE HUMERAL SHAFT','24498','1','','1','0','','','',0, 1, 0, 0),
(1395,'CLSD TX HUMERAL SHAFT FRACTURE W/O MANIPULATION','CLSD TX HUMERAL SHAFT FRACTURE W/O MANIPULATION','24500','1','','1','0','','','',0, 1, 0, 0),
(1396,'CLTX HUMERAL SHFT FX W/MANJ W/WO SKELETAL TRACJ','CLTX HUMERAL SHFT FX W/MANJ W/WO SKELETAL TRACJ','24505','1','','1','0','','','',0, 1, 0, 0),
(1397,'OPTX HUMERAL SHFT FX W/PLATE/SCREWS W/WOCERCLAGE','OPTX HUMERAL SHFT FX W/PLATE/SCREWS W/WOCERCLAGE','24515','1','','1','0','','','',0, 1, 0, 0),
(1398,'TX HUMRAL SHAFT FX W/INSJ IMED IMPLT W/W CERCLGE','TX HUMRAL SHAFT FX W/INSJ IMED IMPLT W/W CERCLGE','24516','1','','1','0','','','',0, 1, 0, 0),
(1399,'CLTX SPRCNDYLR/TRANSCNDYLR HUMERAL FX W/WO MANJ','CLTX SPRCNDYLR/TRANSCNDYLR HUMERAL FX W/WO MANJ','24530','1','','1','0','','','',0, 1, 0, 0),
(1400,'CLTX SPRCNDYLR/TRANSCNDYLR HUMERAL FX W/MANJ','CLTX SPRCNDYLR/TRANSCNDYLR HUMERAL FX W/MANJ','24535','1','','1','0','','','',0, 1, 0, 0),
(1401,'PRQ SKEL FIXJ SPRCNDYLR/TRANSCNDYLR HUMERAL FX','PRQ SKEL FIXJ SPRCNDYLR/TRANSCNDYLR HUMERAL FX','24538','1','','1','0','','','',0, 1, 0, 0),
(1402,'OPEN TX HUMERAL SUPRACONDYLAR FRACTURE W/O XTN','OPEN TX HUMERAL SUPRACONDYLAR FRACTURE W/O XTN','24545','1','','1','0','','','',0, 1, 0, 0),
(1403,'OPEN TX HUMERAL SUPRACONDYLAR FRACTURE W/XTN','OPEN TX HUMERAL SUPRACONDYLAR FRACTURE W/XTN','24546','1','','1','0','','','',0, 1, 0, 0),
(1404,'CLTX HUMERAL EPICONDYLAR FX MEDIAL/LAT W/O MANJ','CLTX HUMERAL EPICONDYLAR FX MEDIAL/LAT W/O MANJ','24560','1','','1','0','','','',0, 1, 0, 0),
(1405,'CLTX HUMERAL EPICONDYLAR FX MEDIAL/LAT W/MANJ','CLTX HUMERAL EPICONDYLAR FX MEDIAL/LAT W/MANJ','24565','1','','1','0','','','',0, 1, 0, 0),
(1406,'PRQ SKEL FIXJ HUMRL EPCNDYLR FX MEDIAL/LAT MANJ','PRQ SKEL FIXJ HUMRL EPCNDYLR FX MEDIAL/LAT MANJ','24566','1','','1','0','','','',0, 1, 0, 0),
(1407,'OPEN TX HUMERAL EPICONDYLAR FRACTURE','OPEN TX HUMERAL EPICONDYLAR FRACTURE','24575','1','','1','0','','','',0, 1, 0, 0),
(1408,'CLTX HUMERAL CONDYLAR FX MEDIAL/LAT W/O MANJ','CLTX HUMERAL CONDYLAR FX MEDIAL/LAT W/O MANJ','24576','1','','1','0','','','',0, 1, 0, 0),
(1409,'CLTX HUMERAL CONDYLAR FX MEDIAL/LATERAL W/MANJ','CLTX HUMERAL CONDYLAR FX MEDIAL/LATERAL W/MANJ','24577','1','','1','0','','','',0, 1, 0, 0),
(1410,'OPEN TREATMENT HUMERAL CONDYLAR FRACTURE','OPEN TREATMENT HUMERAL CONDYLAR FRACTURE','24579','1','','1','0','','','',0, 1, 0, 0),
(1411,'PRQ SKEL FIXJ HUMRL CNDYLR FX MEDIAL/LAT W/MANJ','PRQ SKEL FIXJ HUMRL CNDYLR FX MEDIAL/LAT W/MANJ','24582','1','','1','0','','','',0, 1, 0, 0),
(1412,'OPTX PERIARTICULAR FRACTURE &/DISLOCATION ELBO','OPTX PERIARTICULAR FRACTURE &/DISLOCATION ELBO','24586','1','','1','0','','','',0, 1, 0, 0),
(1413,'OPTX PRIARTICULAR FX&/DISLC ELBW W/IMPLT ARTHR','OPTX PRIARTICULAR FX&/DISLC ELBW W/IMPLT ARTHR','24587','1','','1','0','','','',0, 1, 0, 0),
(1414,'TREATMENT CLOSED ELBOW DISLOCATION W/O ANES','TREATMENT CLOSED ELBOW DISLOCATION W/O ANES','24600','1','','1','0','','','',0, 1, 0, 0),
(1415,'TREATMENT CLOSED ELBOW DISLOCATION REQ ANES','TREATMENT CLOSED ELBOW DISLOCATION REQ ANES','24605','1','','1','0','','','',0, 1, 0, 0),
(1416,'OPEN TX ACUTE/CHRONIC ELBOW DISLOCATION','OPEN TX ACUTE/CHRONIC ELBOW DISLOCATION','24615','1','','1','0','','','',0, 1, 0, 0),
(1417,'CLOSED TX MONTEGGIA FX DISLOCATION ELBOW W/MANJ','CLOSED TX MONTEGGIA FX DISLOCATION ELBOW W/MANJ','24620','1','','1','0','','','',0, 1, 0, 0),
(1418,'OPEN TX MONTEGGIA FRACTURE DISLOCATION ELBOW','OPEN TX MONTEGGIA FRACTURE DISLOCATION ELBOW','24635','1','','1','0','','','',0, 1, 0, 0),
(1419,'CLTX RDL HEAD SUBLXTJ CHLD NURSEMAID ELBW W/MANJ','CLTX RDL HEAD SUBLXTJ CHLD NURSEMAID ELBW W/MANJ','24640','1','','1','0','','','',0, 1, 0, 0),
(1420,'CLOSED TX RADIAL HEAD/NECK FX W/O MANIPULATION','CLOSED TX RADIAL HEAD/NECK FX W/O MANIPULATION','24650','1','','1','0','','','',0, 1, 0, 0),
(1421,'CLOSED TX RADIAL HEAD/NECK FX W/MANIPULATION','CLOSED TX RADIAL HEAD/NECK FX W/MANIPULATION','24655','1','','1','0','','','',0, 1, 0, 0),
(1422,'OPEN TX RADIAL HEAD/NECK FRACTURE','OPEN TX RADIAL HEAD/NECK FRACTURE','24665','1','','1','0','','','',0, 1, 0, 0),
(1423,'OPEN TX RADIAL HEAD/NECK FRACTURE PROSTHETIC','OPEN TX RADIAL HEAD/NECK FRACTURE PROSTHETIC','24666','1','','1','0','','','',0, 1, 0, 0),
(1424,'CLOSED TX ULNAR FRACTURE PROXIMAL END W/O MANJ','CLOSED TX ULNAR FRACTURE PROXIMAL END W/O MANJ','24670','1','','1','0','','','',0, 1, 0, 0),
(1425,'CLOSED TX ULNAR FRACTURE PROXIMAL END W/MANJ','CLOSED TX ULNAR FRACTURE PROXIMAL END W/MANJ','24675','1','','1','0','','','',0, 1, 0, 0),
(1426,'OPEN TREATMENT ULNAR FRACTURE PROXIMAL END','OPEN TREATMENT ULNAR FRACTURE PROXIMAL END','24685','1','','1','0','','','',0, 1, 0, 0),
(1427,'ARTHRODESIS ELBOW JOINT LOCAL','ARTHRODESIS ELBOW JOINT LOCAL','24800','1','','1','0','','','',0, 1, 0, 0),
(1428,'ARTHRODESIS ELBOW JOINT W/AUTOGENOUS GRAFT','ARTHRODESIS ELBOW JOINT W/AUTOGENOUS GRAFT','24802','1','','1','0','','','',0, 1, 0, 0),
(1429,'AMPUTATION ARM THRU HUMERUS W/PRIMARY CLOSURE','AMPUTATION ARM THRU HUMERUS W/PRIMARY CLOSURE','24900','1','','1','0','','','',0, 1, 0, 0),
(1430,'AMPUTATION ARM THRU HUMERUS OPEN CIRCULAR','AMPUTATION ARM THRU HUMERUS OPEN CIRCULAR','24920','1','','1','0','','','',0, 1, 0, 0),
(1431,'AMP ARM THRU HUMERUS SECONDARY CLSR/SCAR REVJ','AMP ARM THRU HUMERUS SECONDARY CLSR/SCAR REVJ','24925','1','','1','0','','','',0, 1, 0, 0),
(1432,'AMPUTATION ARM THRU HUMERUS RE-AMPUTATION','AMPUTATION ARM THRU HUMERUS RE-AMPUTATION','24930','1','','1','0','','','',0, 1, 0, 0),
(1433,'AMPUTATION ARM THRU HUMERUS W/IMPLANT','AMPUTATION ARM THRU HUMERUS W/IMPLANT','24931','1','','1','0','','','',0, 1, 0, 0),
(1434,'STUMP ELONGATION UPPER EXTREMITY','STUMP ELONGATION UPPER EXTREMITY','24935','1','','1','0','','','',0, 1, 0, 0),
(1435,'CINEPLASTY UPPER EXTREMITY COMPLETE PROCEDURE','CINEPLASTY UPPER EXTREMITY COMPLETE PROCEDURE','24940','1','','1','0','','','',0, 1, 0, 0),
(1436,'UNLISTED PROCEDURE HUMERUS/ELBOW','UNLISTED PROCEDURE HUMERUS/ELBOW','24999','1','','1','0','','','',0, 1, 0, 0),
(1437,'INCISION EXTENSOR TENDON SHEATH WRIST','INCISION EXTENSOR TENDON SHEATH WRIST','25000','1','','1','0','','','',0, 1, 0, 0),
(1438,'INCISION FLEXOR TENDON SHEATH WRIST','INCISION FLEXOR TENDON SHEATH WRIST','25001','1','','1','0','','','',0, 1, 0, 0),
(1439,'DCMPRN FASCT F/ARM&WRST FLXR/XTNSR W/O DBRDMT','DCMPRN FASCT F/ARM&WRST FLXR/XTNSR W/O DBRDMT','25020','1','','1','0','','','',0, 1, 0, 0),
(1440,'DCMPRN FASCT F/ARM&/WRST FLXR/XTNSR W/DBRDMT','DCMPRN FASCT F/ARM&/WRST FLXR/XTNSR W/DBRDMT','25023','1','','1','0','','','',0, 1, 0, 0),
(1441,'DCMPRN FASCT F/ARM&/WRST FLXR&XTNSR W/O DB','DCMPRN FASCT F/ARM&/WRST FLXR&XTNSR W/O DB','25024','1','','1','0','','','',0, 1, 0, 0),
(1442,'DCMPRN FASCT F/ARM&/WRST FLXR&XTNSR DBRDMT','DCMPRN FASCT F/ARM&/WRST FLXR&XTNSR DBRDMT','25025','1','','1','0','','','',0, 1, 0, 0),
(1443,'I&D FOREARM&/WRIST DEEP ABSCESS/HEMATOMA','I&D FOREARM&/WRIST DEEP ABSCESS/HEMATOMA','25028','1','','1','0','','','',0, 1, 0, 0),
(1444,'INCISION & DRAINAGE FOREARM&/WRIST BURSA','INCISION & DRAINAGE FOREARM&/WRIST BURSA','25031','1','','1','0','','','',0, 1, 0, 0),
(1445,'INCISION DEEP BONE CORTEX FOREARM&/WRIST','INCISION DEEP BONE CORTEX FOREARM&/WRIST','25035','1','','1','0','','','',0, 1, 0, 0),
(1446,'ARTHRT RDCRPL/MIDCARPL JT W/EXPL DRG/RMVL FB','ARTHRT RDCRPL/MIDCARPL JT W/EXPL DRG/RMVL FB','25040','1','','1','0','','','',0, 1, 0, 0),
(1447,'BIOPSY SOFT TISSUE FOREARM&/WRIST SUPERFICIAL','BIOPSY SOFT TISSUE FOREARM&/WRIST SUPERFICIAL','25065','1','','1','0','','','',0, 1, 0, 0),
(1448,'BIOPSY SOFT TISSUE FOREARM&/WRIST DEEP','BIOPSY SOFT TISSUE FOREARM&/WRIST DEEP','25066','1','','1','0','','','',0, 1, 0, 0),
(1449,'EXC TUMOR SOFT TISS FOREARM AND/WRIST SUBQ 3CM/>','EXC TUMOR SOFT TISS FOREARM AND/WRIST SUBQ 3CM/>','25071','1','','1','0','','','',0, 1, 0, 0),
(1450,'EXC TUMOR SFT TISS FOREARM&/WRIST SUBFASC 3CM/>','EXC TUMOR SFT TISS FOREARM&/WRIST SUBFASC 3CM/>','25073','1','','1','0','','','',0, 1, 0, 0),
(1451,'EXC TUMOR SOFT TISSUE FOREARM &/WRIST SUBQ <3CM','EXC TUMOR SOFT TISSUE FOREARM &/WRIST SUBQ <3CM','25075','1','','1','0','','','',0, 1, 0, 0),
(1452,'EXC TUMOR SOFT TISS FOREARM&/WRIST SUBFASC <3CM','EXC TUMOR SOFT TISS FOREARM&/WRIST SUBFASC <3CM','25076','1','','1','0','','','',0, 1, 0, 0),
(1453,'RAD RESECT TUMOR SOFT TISS FOREARM&/WRIST <3 CM','RAD RESECT TUMOR SOFT TISS FOREARM&/WRIST <3 CM','25077','1','','1','0','','','',0, 1, 0, 0),
(1454,'RAD RESCJ TUM SOFT TISSUE FOREARM&/WRIST 3 CM/>','RAD RESCJ TUM SOFT TISSUE FOREARM&/WRIST 3 CM/>','25078','1','','1','0','','','',0, 1, 0, 0),
(1455,'CAPSULOTOMY WRIST','CAPSULOTOMY WRIST','25085','1','','1','0','','','',0, 1, 0, 0),
(1456,'ARTHROTOMY WRIST JOINT WITH BIOPSY','ARTHROTOMY WRIST JOINT WITH BIOPSY','25100','1','','1','0','','','',0, 1, 0, 0),
(1457,'ARTHRT WRST W/JT EXPL W/WO BX W/WO RMVL LOOSE/FB','ARTHRT WRST W/JT EXPL W/WO BX W/WO RMVL LOOSE/FB','25101','1','','1','0','','','',0, 1, 0, 0),
(1458,'ARTHROTOMY WRIST JOINT WITH SYNOVECTOMY','ARTHROTOMY WRIST JOINT WITH SYNOVECTOMY','25105','1','','1','0','','','',0, 1, 0, 0),
(1459,'ARTHROTOMY DSTL RADIOULNAR JOINT RPR CARTILAGE','ARTHROTOMY DSTL RADIOULNAR JOINT RPR CARTILAGE','25107','1','','1','0','','','',0, 1, 0, 0),
(1460,'EXC TENDON FOREARM&/WRIST FLEXOR/EXTENSOR EA','EXC TENDON FOREARM&/WRIST FLEXOR/EXTENSOR EA','25109','1','','1','0','','','',0, 1, 0, 0),
(1461,'EXCISION LESION TENDON SHEATH FOREARM&/WRIST','EXCISION LESION TENDON SHEATH FOREARM&/WRIST','25110','1','','1','0','','','',0, 1, 0, 0),
(1462,'EXCISION GANGLION WRIST DORSAL/VOLAR PRIMARY','EXCISION GANGLION WRIST DORSAL/VOLAR PRIMARY','25111','1','','1','0','','','',0, 1, 0, 0),
(1463,'EXCISION GANGLION WRIST DORSAL/VOLAR RECURRENT','EXCISION GANGLION WRIST DORSAL/VOLAR RECURRENT','25112','1','','1','0','','','',0, 1, 0, 0),
(1464,'RAD EXC BURSA SYNVA WRST/F/ARM TDN SHTHS FLXRS','RAD EXC BURSA SYNVA WRST/F/ARM TDN SHTHS FLXRS','25115','1','','1','0','','','',0, 1, 0, 0),
(1465,'RAD EXC BURSA SYNVA WRST/F/ARM TDN SHTHS XTNSRS','RAD EXC BURSA SYNVA WRST/F/ARM TDN SHTHS XTNSRS','25116','1','','1','0','','','',0, 1, 0, 0),
(1466,'SYNOVECTOMY EXTENSOR TENDON SHTH WRIST 1 CMPRT','SYNOVECTOMY EXTENSOR TENDON SHTH WRIST 1 CMPRT','25118','1','','1','0','','','',0, 1, 0, 0),
(1467,'SYNVCT XTNSR TDN SHTH WRST 1 RESCJ DSTL ULNA','SYNVCT XTNSR TDN SHTH WRST 1 RESCJ DSTL ULNA','25119','1','','1','0','','','',0, 1, 0, 0),
(1468,'EXCISION/CURETTAGE CYST/TUMOR RADIUS/ULNA','EXCISION/CURETTAGE CYST/TUMOR RADIUS/ULNA','25120','1','','1','0','','','',0, 1, 0, 0),
(1469,'EXC/CURTG CYST/TUMOR RADIUS/ULNA W/AUTOGRAFT','EXC/CURTG CYST/TUMOR RADIUS/ULNA W/AUTOGRAFT','25125','1','','1','0','','','',0, 1, 0, 0),
(1470,'EXC/CURTG CYST/TUMOR RADIUS/ULNA W/ALLOGRAFT','EXC/CURTG CYST/TUMOR RADIUS/ULNA W/ALLOGRAFT','25126','1','','1','0','','','',0, 1, 0, 0),
(1471,'EXCISION/CURETTAGE CYST/TUMOR CARPAL BONES','EXCISION/CURETTAGE CYST/TUMOR CARPAL BONES','25130','1','','1','0','','','',0, 1, 0, 0),
(1472,'EXC/CURTG CYST/TUMOR CARPAL BONES W/AUTOGRAFT','EXC/CURTG CYST/TUMOR CARPAL BONES W/AUTOGRAFT','25135','1','','1','0','','','',0, 1, 0, 0),
(1473,'EXC/CURTG CYST/TUMOR CARPAL BONES W/ALLOGRAFT','EXC/CURTG CYST/TUMOR CARPAL BONES W/ALLOGRAFT','25136','1','','1','0','','','',0, 1, 0, 0),
(1474,'SEQUESTRECTOMY FOREARM &/WRIST','SEQUESTRECTOMY FOREARM &/WRIST','25145','1','','1','0','','','',0, 1, 0, 0),
(1475,'PARTIAL EXCISION BONE ULNA','PARTIAL EXCISION BONE ULNA','25150','1','','1','0','','','',0, 1, 0, 0),
(1476,'PARTIAL EXCISION BONE RADIUS','PARTIAL EXCISION BONE RADIUS','25151','1','','1','0','','','',0, 1, 0, 0),
(1477,'RADICAL RESECTION TUMOR RADIUS OR ULNA','RADICAL RESECTION TUMOR RADIUS OR ULNA','25170','1','','1','0','','','',0, 1, 0, 0),
(1478,'CARPECTOMY 1 BONE','CARPECTOMY 1 BONE','25210','1','','1','0','','','',0, 1, 0, 0),
(1479,'CARPECTOMY ALL BONES PROXIMAL ROW','CARPECTOMY ALL BONES PROXIMAL ROW','25215','1','','1','0','','','',0, 1, 0, 0),
(1480,'RADICAL STYLOIDECTOMY SEPARATE PROCEDURE','RADICAL STYLOIDECTOMY SEPARATE PROCEDURE','25230','1','','1','0','','','',0, 1, 0, 0),
(1481,'EXCISION DISTAL ULNA PARTIAL/COMPLETE','EXCISION DISTAL ULNA PARTIAL/COMPLETE','25240','1','','1','0','','','',0, 1, 0, 0),
(1482,'INJECTION WRIST ARTHROGRAPHY','INJECTION WRIST ARTHROGRAPHY','25246','1','','1','0','','','',0, 1, 0, 0),
(1483,'EXPL W/REMOVAL DEEP FOREIGN BODY FOREARM/WRIST','EXPL W/REMOVAL DEEP FOREIGN BODY FOREARM/WRIST','25248','1','','1','0','','','',0, 1, 0, 0),
(1484,'REMOVAL WRIST PROSTHESIS SEPARATE PROCEDURE','REMOVAL WRIST PROSTHESIS SEPARATE PROCEDURE','25250','1','','1','0','','','',0, 1, 0, 0),
(1485,'REMOVAL WRIST PROSTH COMPLICATED W/TOTAL WRIST','REMOVAL WRIST PROSTH COMPLICATED W/TOTAL WRIST','25251','1','','1','0','','','',0, 1, 0, 0),
(1486,'MANIPULATION WRIST UNDER ANESTHESIA','MANIPULATION WRIST UNDER ANESTHESIA','25259','1','','1','0','','','',0, 1, 0, 0),
(1487,'RPR TDN/MUSC FLXR F/ARM&/WRST PRIM 1 EA TDN/MU','RPR TDN/MUSC FLXR F/ARM&/WRST PRIM 1 EA TDN/MU','25260','1','','1','0','','','',0, 1, 0, 0),
(1488,'RPR TDN/MUSC FLXR F/ARM&/WRIST SEC 1 EA TDN/MUS','RPR TDN/MUSC FLXR F/ARM&/WRIST SEC 1 EA TDN/MUS','25263','1','','1','0','','','',0, 1, 0, 0),
(1489,'RPR TDN/MUSC FLXR F/ARM&/WRISTSEC FR GRF EA','RPR TDN/MUSC FLXR F/ARM&/WRISTSEC FR GRF EA','25265','1','','1','0','','','',0, 1, 0, 0),
(1490,'RPR TDN/MUSC XTNSR F/ARM&/WRIST PRIM 1 EA TDN','RPR TDN/MUSC XTNSR F/ARM&/WRIST PRIM 1 EA TDN','25270','1','','1','0','','','',0, 1, 0, 0),
(1491,'RPR TDN/MUSC XTNSR F/ARM&/WRIST SEC 1 EA TDN/MU','RPR TDN/MUSC XTNSR F/ARM&/WRIST SEC 1 EA TDN/MU','25272','1','','1','0','','','',0, 1, 0, 0),
(1492,'RPR TDN/MUSC XTNSR F/ARM&/WRST SEC FR GRF EA TDN','RPR TDN/MUSC XTNSR F/ARM&/WRST SEC FR GRF EA TDN','25274','1','','1','0','','','',0, 1, 0, 0),
(1493,'RPR TENDON SHEATH EXTENSOR F/ARM&/WRIST W/GRAFT','RPR TENDON SHEATH EXTENSOR F/ARM&/WRIST W/GRAFT','25275','1','','1','0','','','',0, 1, 0, 0),
(1494,'LNGTH/SHRT FLXR/XTNSR TDN F/ARM&/WRIST 1 EA TDN','LNGTH/SHRT FLXR/XTNSR TDN F/ARM&/WRIST 1 EA TDN','25280','1','','1','0','','','',0, 1, 0, 0),
(1495,'TNOT FLXR/XTNSR TENDON FOREARM&/WRIST 1 EA','TNOT FLXR/XTNSR TENDON FOREARM&/WRIST 1 EA','25290','1','','1','0','','','',0, 1, 0, 0),
(1496,'TNOLS FLXR/XTNSR TENDON FOREARM&/WRIST 1 EA','TNOLS FLXR/XTNSR TENDON FOREARM&/WRIST 1 EA','25295','1','','1','0','','','',0, 1, 0, 0),
(1497,'TENODESIS WRIST FLEXORS FINGERS','TENODESIS WRIST FLEXORS FINGERS','25300','1','','1','0','','','',0, 1, 0, 0),
(1498,'TENODESIS WRIST EXTENSORS FINGERS','TENODESIS WRIST EXTENSORS FINGERS','25301','1','','1','0','','','',0, 1, 0, 0),
(1499,'TDN TRNSPLJ/TR FLXR/XTNSR F/ARM&/WRST 1 EA TDN','TDN TRNSPLJ/TR FLXR/XTNSR F/ARM&/WRST 1 EA TDN','25310','1','','1','0','','','',0, 1, 0, 0),
(1500,'TDN TRNSPLJ/TR FLXR/XTNSR F/ARM&/WRST 1/TDN GR','TDN TRNSPLJ/TR FLXR/XTNSR F/ARM&/WRST 1/TDN GR','25312','1','','1','0','','','',0, 1, 0, 0),
(1501,'FLEXOR ORIGIN SLIDE FOREARM &/WRIST','FLEXOR ORIGIN SLIDE FOREARM &/WRIST','25315','1','','1','0','','','',0, 1, 0, 0),
(1502,'FLEXOR ORIGIN SLIDE F/ARM&/WRST TENDON TRANSFE','FLEXOR ORIGIN SLIDE F/ARM&/WRST TENDON TRANSFE','25316','1','','1','0','','','',0, 1, 0, 0),
(1503,'CAPSL-RHPHY/RCNSTJ WRST OPN CARPL INS','CAPSL-RHPHY/RCNSTJ WRST OPN CARPL INS','25320','1','','1','0','','','',0, 1, 0, 0),
(1504,'ARTHRP WRST W/WO INTERPOS W/WO XTRNL/INT FIXJ','ARTHRP WRST W/WO INTERPOS W/WO XTRNL/INT FIXJ','25332','1','','1','0','','','',0, 1, 0, 0),
(1505,'CENTRALIZATION WRST ULNA','CENTRALIZATION WRST ULNA','25335','1','','1','0','','','',0, 1, 0, 0),
(1506,'RCNSTJ STABLJ DSTL U/DSTL JT 2 SOFT TISS STABLJ','RCNSTJ STABLJ DSTL U/DSTL JT 2 SOFT TISS STABLJ','25337','1','','1','0','','','',0, 1, 0, 0),
(1507,'OSTEOTOMY RADIUS DISTAL THIRD','OSTEOTOMY RADIUS DISTAL THIRD','25350','1','','1','0','','','',0, 1, 0, 0),
(1508,'OSTEOTOMY RADIUS MIDDLE/PROXIMAL THIRD','OSTEOTOMY RADIUS MIDDLE/PROXIMAL THIRD','25355','1','','1','0','','','',0, 1, 0, 0),
(1509,'OSTEOTOMY ULNA','OSTEOTOMY ULNA','25360','1','','1','0','','','',0, 1, 0, 0),
(1510,'OSTEOTOMY RADIUS & ULNA','OSTEOTOMY RADIUS & ULNA','25365','1','','1','0','','','',0, 1, 0, 0),
(1511,'MLT OSTEOTOMIES W/RELIGNMT IMED ROD RADIUS/ULNA','MLT OSTEOTOMIES W/RELIGNMT IMED ROD RADIUS/ULNA','25370','1','','1','0','','','',0, 1, 0, 0),
(1512,'MLT OSTEOTOMIES W/RELIGNMT IMED ROD RADIUS&ULNA','MLT OSTEOTOMIES W/RELIGNMT IMED ROD RADIUS&ULNA','25375','1','','1','0','','','',0, 1, 0, 0),
(1513,'OSTEOPLASTY RADIUS/ULNA SHORTENING','OSTEOPLASTY RADIUS/ULNA SHORTENING','25390','1','','1','0','','','',0, 1, 0, 0),
(1514,'OSTEOPLASTY RADIUS/ULNA LENGTHENING W/AUTOGRAFT','OSTEOPLASTY RADIUS/ULNA LENGTHENING W/AUTOGRAFT','25391','1','','1','0','','','',0, 1, 0, 0),
(1515,'OSTEOPLASTY RADIUS & ULNA SHORTENING','OSTEOPLASTY RADIUS & ULNA SHORTENING','25392','1','','1','0','','','',0, 1, 0, 0),
(1516,'OSTEOPLASTY RADIUS&ULNA LENGTHENING W/AUTOGRAF','OSTEOPLASTY RADIUS&ULNA LENGTHENING W/AUTOGRAF','25393','1','','1','0','','','',0, 1, 0, 0),
(1517,'OSTEOPLASTY CARPAL BONE SHORTENING','OSTEOPLASTY CARPAL BONE SHORTENING','25394','1','','1','0','','','',0, 1, 0, 0),
(1518,'RPR NONUNION/MALUNION RADIUS/ULNA W/O AUTOGRAFT','RPR NONUNION/MALUNION RADIUS/ULNA W/O AUTOGRAFT','25400','1','','1','0','','','',0, 1, 0, 0),
(1519,'RPR NONUNION/MALUNION RADIUS/ULNA W/AUTOGRAFT','RPR NONUNION/MALUNION RADIUS/ULNA W/AUTOGRAFT','25405','1','','1','0','','','',0, 1, 0, 0),
(1520,'RPR NONUNION/MALUNION RADIUS&ULNA W/O AUTOGRAF','RPR NONUNION/MALUNION RADIUS&ULNA W/O AUTOGRAF','25415','1','','1','0','','','',0, 1, 0, 0),
(1521,'RPR NONUNION/MALUNION RADIUS&ULNA W/AUTOGRAFT','RPR NONUNION/MALUNION RADIUS&ULNA W/AUTOGRAFT','25420','1','','1','0','','','',0, 1, 0, 0),
(1522,'REPAIR DEFECT W/AUTOGRAFT RADIUS/ULNA','REPAIR DEFECT W/AUTOGRAFT RADIUS/ULNA','25425','1','','1','0','','','',0, 1, 0, 0),
(1523,'REPAIR DEFECT W/AUTOGRAFT RADIUS&ULNA','REPAIR DEFECT W/AUTOGRAFT RADIUS&ULNA','25426','1','','1','0','','','',0, 1, 0, 0),
(1524,'INSERTION VASCULAR PEDICLE CARPAL BONE','INSERTION VASCULAR PEDICLE CARPAL BONE','25430','1','','1','0','','','',0, 1, 0, 0),
(1525,'REPAIR NONUNION CARPAL BONE EACH BONE','REPAIR NONUNION CARPAL BONE EACH BONE','25431','1','','1','0','','','',0, 1, 0, 0),
(1526,'RPR NONUNION SCAPHOID CARPAL BNE W/WO RDL STYLEC','RPR NONUNION SCAPHOID CARPAL BNE W/WO RDL STYLEC','25440','1','','1','0','','','',0, 1, 0, 0),
(1527,'ARTHROPLASTY W/PROSTHETIC RPLCMT DISTAL RADIUS','ARTHROPLASTY W/PROSTHETIC RPLCMT DISTAL RADIUS','25441','1','','1','0','','','',0, 1, 0, 0),
(1528,'ARTHROPLASTY W/PROSTHETIC RPLCMT DISTAL ULNA','ARTHROPLASTY W/PROSTHETIC RPLCMT DISTAL ULNA','25442','1','','1','0','','','',0, 1, 0, 0),
(1529,'ARTHROPLASTY W/PROSTHETIC RPLCMT SCAPHOID CARPAL','ARTHROPLASTY W/PROSTHETIC RPLCMT SCAPHOID CARPAL','25443','1','','1','0','','','',0, 1, 0, 0),
(1530,'ARTHROPLASTY W/PROSTHETIC REPLACEMENT LUNATE','ARTHROPLASTY W/PROSTHETIC REPLACEMENT LUNATE','25444','1','','1','0','','','',0, 1, 0, 0),
(1531,'ARTHROPLASTY W/PROSTHETIC REPLACEMENT TRAPEZIUM','ARTHROPLASTY W/PROSTHETIC REPLACEMENT TRAPEZIUM','25445','1','','1','0','','','',0, 1, 0, 0),
(1532,'ARTHRP W/PROSTC RPLCMT DSTL RDS&PRTL/CARPUS','ARTHRP W/PROSTC RPLCMT DSTL RDS&PRTL/CARPUS','25446','1','','1','0','','','',0, 1, 0, 0),
(1533,'ARTHRP INTERPOS INTERCARPAL/METACARPAL JOINTS','ARTHRP INTERPOS INTERCARPAL/METACARPAL JOINTS','25447','1','','1','0','','','',0, 1, 0, 0),
(1534,'REVJ ARTHRP W/REMOVAL IMPLANT WRIST JOINT','REVJ ARTHRP W/REMOVAL IMPLANT WRIST JOINT','25449','1','','1','0','','','',0, 1, 0, 0),
(1535,'EPIPHYSL ARRST EPIPHYSIOD/STAPLING DSTL RDS/U','EPIPHYSL ARRST EPIPHYSIOD/STAPLING DSTL RDS/U','25450','1','','1','0','','','',0, 1, 0, 0),
(1536,'EPIPHYSL ARRST EPIPHYSIOD/STAPLING DSTL RDS&ULNA','EPIPHYSL ARRST EPIPHYSIOD/STAPLING DSTL RDS&ULNA','25455','1','','1','0','','','',0, 1, 0, 0),
(1537,'PROPH TX N/P/PLTWR W/WO METHYLACRYLATE RADIUS','PROPH TX N/P/PLTWR W/WO METHYLACRYLATE RADIUS','25490','1','','1','0','','','',0, 1, 0, 0),
(1538,'PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE ULNA','PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE ULNA','25491','1','','1','0','','','',0, 1, 0, 0),
(1539,'PROPH TX N/P/PLTWR W/WO METHYLMECRYLATE RAD&UL','PROPH TX N/P/PLTWR W/WO METHYLMECRYLATE RAD&UL','25492','1','','1','0','','','',0, 1, 0, 0),
(1540,'CLOSED TX RADIAL SHAFT FRACTURE W/O MANIPULATION','CLOSED TX RADIAL SHAFT FRACTURE W/O MANIPULATION','25500','1','','1','0','','','',0, 1, 0, 0),
(1541,'CLOSED TX RADIAL SHAFT FRACTURE W/MANIPULATION','CLOSED TX RADIAL SHAFT FRACTURE W/MANIPULATION','25505','1','','1','0','','','',0, 1, 0, 0),
(1542,'OPEN TREATMENT RADIAL SHAFT FRACTURE','OPEN TREATMENT RADIAL SHAFT FRACTURE','25515','1','','1','0','','','',0, 1, 0, 0),
(1543,'CLTX RDL SHFT FX&CLTX DISLC DSTL RAD/ULN JT','CLTX RDL SHFT FX&CLTX DISLC DSTL RAD/ULN JT','25520','1','','1','0','','','',0, 1, 0, 0),
(1544,'OPEN RDL SHAFT FX CLOSED RAD/ULN JT DISLOCATE','OPEN RDL SHAFT FX CLOSED RAD/ULN JT DISLOCATE','25525','1','','1','0','','','',0, 1, 0, 0),
(1545,'OPEN RDL SHAFT FX OPEN RAD/ULN JT DISLOCATE','OPEN RDL SHAFT FX OPEN RAD/ULN JT DISLOCATE','25526','1','','1','0','','','',0, 1, 0, 0),
(1546,'CLOSED TX ULNAR SHAFT FRACTURE W/O MANIPULATION','CLOSED TX ULNAR SHAFT FRACTURE W/O MANIPULATION','25530','1','','1','0','','','',0, 1, 0, 0),
(1547,'CLOSED TX ULNAR SHAFT FRACTURE W/MANIPULATION','CLOSED TX ULNAR SHAFT FRACTURE W/MANIPULATION','25535','1','','1','0','','','',0, 1, 0, 0),
(1548,'OPEN TREATMENT OF ULNAR SHAFT FRACTURE','OPEN TREATMENT OF ULNAR SHAFT FRACTURE','25545','1','','1','0','','','',0, 1, 0, 0),
(1549,'CLOSED TX RADIAL&ULNAR SHAFT FRACTURES W/O MAN','CLOSED TX RADIAL&ULNAR SHAFT FRACTURES W/O MAN','25560','1','','1','0','','','',0, 1, 0, 0),
(1550,'CLOSED TX RADIAL&ULNAR SHAFT FRACTURES W/MANJ','CLOSED TX RADIAL&ULNAR SHAFT FRACTURES W/MANJ','25565','1','','1','0','','','',0, 1, 0, 0),
(1551,'OPEN TX RADIAL&ULNAR SHAFT FX W/FIXJ RADIUS/ULNA','OPEN TX RADIAL&ULNAR SHAFT FX W/FIXJ RADIUS/ULNA','25574','1','','1','0','','','',0, 1, 0, 0),
(1552,'OPEN TX RADIAL&ULNAR SHAFT FX W/FIXJ RADIUS&ULNA','OPEN TX RADIAL&ULNAR SHAFT FX W/FIXJ RADIUS&ULNA','25575','1','','1','0','','','',0, 1, 0, 0),
(1553,'CLTX DSTL RADIAL FX/EPIPHYSL SEP W/O MANJ','CLTX DSTL RADIAL FX/EPIPHYSL SEP W/O MANJ','25600','1','','1','0','','','',0, 1, 0, 0),
(1554,'CLTX DSTL RDL FX/EPIPHYSL SEP W/MANJ WHEN PERF','CLTX DSTL RDL FX/EPIPHYSL SEP W/MANJ WHEN PERF','25605','1','','1','0','','','',0, 1, 0, 0),
(1555,'PERQ SKEL FIXJ DISTAL RADIAL FX/EPIPHYSL SEP','PERQ SKEL FIXJ DISTAL RADIAL FX/EPIPHYSL SEP','25606','1','','1','0','','','',0, 1, 0, 0),
(1556,'OPTX DSTL RADL X-ARTIC FX/EPIPHYSL SEP','OPTX DSTL RADL X-ARTIC FX/EPIPHYSL SEP','25607','1','','1','0','','','',0, 1, 0, 0),
(1557,'OPTX DSTL RADL I-ARTIC FX/EPIPHYSL SEP 2 FRAG','OPTX DSTL RADL I-ARTIC FX/EPIPHYSL SEP 2 FRAG','25608','1','','1','0','','','',0, 1, 0, 0),
(1558,'OPTX DSTL RADL I-ARTIC FX/EPIPHYSL SEP 3 FRAG','OPTX DSTL RADL I-ARTIC FX/EPIPHYSL SEP 3 FRAG','25609','1','','1','0','','','',0, 1, 0, 0),
(1559,'CLOSED TX CARPAL SCAPHOID FRACTURE W/O MANJ','CLOSED TX CARPAL SCAPHOID FRACTURE W/O MANJ','25622','1','','1','0','','','',0, 1, 0, 0),
(1560,'CLOSED TX CARPAL SCAPHOID FRACTURE W/MANJ','CLOSED TX CARPAL SCAPHOID FRACTURE W/MANJ','25624','1','','1','0','','','',0, 1, 0, 0),
(1561,'OPEN TX CARPAL SCAPHOID NAVICULAR FRACTURE','OPEN TX CARPAL SCAPHOID NAVICULAR FRACTURE','25628','1','','1','0','','','',0, 1, 0, 0),
(1562,'CLTX CARPAL BONE FX W/O MANJ EACH BONE','CLTX CARPAL BONE FX W/O MANJ EACH BONE','25630','1','','1','0','','','',0, 1, 0, 0),
(1563,'CLTX CARPAL BONE FX W/MANJ EACH BONE','CLTX CARPAL BONE FX W/MANJ EACH BONE','25635','1','','1','0','','','',0, 1, 0, 0),
(1564,'OPEN TX CARPAL BONE FRACTURE OTH/THN SCAPHOID EA','OPEN TX CARPAL BONE FRACTURE OTH/THN SCAPHOID EA','25645','1','','1','0','','','',0, 1, 0, 0),
(1565,'CLOSED TREATMENT ULNAR STYLOID FRACTURE','CLOSED TREATMENT ULNAR STYLOID FRACTURE','25650','1','','1','0','','','',0, 1, 0, 0),
(1566,'PRQ SKELETAL FIXATION ULNAR STYLOID FRACTURE','PRQ SKELETAL FIXATION ULNAR STYLOID FRACTURE','25651','1','','1','0','','','',0, 1, 0, 0),
(1567,'OPEN TREATMENT ULNAR STYLOID FRACTURE','OPEN TREATMENT ULNAR STYLOID FRACTURE','25652','1','','1','0','','','',0, 1, 0, 0),
(1568,'CLTX RDCRPL/INTERCARPL DISLC 1/> BONES W/MANJ','CLTX RDCRPL/INTERCARPL DISLC 1/> BONES W/MANJ','25660','1','','1','0','','','',0, 1, 0, 0),
(1569,'OPEN TX RADIOCARPAL/INTERCARPAL DISLC 1/> BONES','OPEN TX RADIOCARPAL/INTERCARPAL DISLC 1/> BONES','25670','1','','1','0','','','',0, 1, 0, 0),
(1570,'PRQ SKELETAL FIXJ DISTAL RADIOULNAR DISLOCATION','PRQ SKELETAL FIXJ DISTAL RADIOULNAR DISLOCATION','25671','1','','1','0','','','',0, 1, 0, 0),
(1571,'CLOSED TX DISTAL RADIOULNAR DISLOCATION W/MANJ','CLOSED TX DISTAL RADIOULNAR DISLOCATION W/MANJ','25675','1','','1','0','','','',0, 1, 0, 0),
(1572,'OPEN TX DISTAL RADIOULNAR DISLC ACUTE/CHRONIC','OPEN TX DISTAL RADIOULNAR DISLC ACUTE/CHRONIC','25676','1','','1','0','','','',0, 1, 0, 0),
(1573,'CLTX TRANS-SCAPHOPRILUNAR TYP FX DISLC W/MANJ','CLTX TRANS-SCAPHOPRILUNAR TYP FX DISLC W/MANJ','25680','1','','1','0','','','',0, 1, 0, 0),
(1574,'OPEN TX TRANS-SCAPHOPERILUNAR FRACTURE DISLC','OPEN TX TRANS-SCAPHOPERILUNAR FRACTURE DISLC','25685','1','','1','0','','','',0, 1, 0, 0),
(1575,'CLOSED TX LUNATE DISLOCATION W/MANIPULATION','CLOSED TX LUNATE DISLOCATION W/MANIPULATION','25690','1','','1','0','','','',0, 1, 0, 0),
(1576,'OPEN TREATMENT LUNATE DISLOCATION','OPEN TREATMENT LUNATE DISLOCATION','25695','1','','1','0','','','',0, 1, 0, 0),
(1577,'ARTHRODESIS WRIST COMPLETE W/O BONE GRAFT','ARTHRODESIS WRIST COMPLETE W/O BONE GRAFT','25800','1','','1','0','','','',0, 1, 0, 0),
(1578,'ARTHRODESIS WRIST W/SLIDING GRAFT','ARTHRODESIS WRIST W/SLIDING GRAFT','25805','1','','1','0','','','',0, 1, 0, 0),
(1579,'ARTHRODESIS WRIST W/ILIAC/OTHER AUTOGRAFT','ARTHRODESIS WRIST W/ILIAC/OTHER AUTOGRAFT','25810','1','','1','0','','','',0, 1, 0, 0),
(1580,'ARTHRODESIS WRIST LIMITED W/O BONE GRAFT','ARTHRODESIS WRIST LIMITED W/O BONE GRAFT','25820','1','','1','0','','','',0, 1, 0, 0),
(1581,'ARTHRODESIS WRIST LIMITED W/AUTOGRAFT','ARTHRODESIS WRIST LIMITED W/AUTOGRAFT','25825','1','','1','0','','','',0, 1, 0, 0),
(1582,'ARTHRD DSTL RAD/ULN JT SGMTL RSCJ ULNA W/WO BONE','ARTHRD DSTL RAD/ULN JT SGMTL RSCJ ULNA W/WO BONE','25830','1','','1','0','','','',0, 1, 0, 0),
(1583,'AMPUTATION FOREARM THROUGH RADIUS & ULNA','AMPUTATION FOREARM THROUGH RADIUS & ULNA','25900','1','','1','0','','','',0, 1, 0, 0),
(1584,'AMP FOREARM THRU RADIUS & ULNA OPEN CIRCULAR','AMP FOREARM THRU RADIUS & ULNA OPEN CIRCULAR','25905','1','','1','0','','','',0, 1, 0, 0),
(1585,'AMP F/ARM THRU RADIUS&ULNA SEC CLOSURE/SCAR RE','AMP F/ARM THRU RADIUS&ULNA SEC CLOSURE/SCAR RE','25907','1','','1','0','','','',0, 1, 0, 0),
(1586,'AMP FOREARM THRU RADIUS&ULNA RE-AMPUTATION','AMP FOREARM THRU RADIUS&ULNA RE-AMPUTATION','25909','1','','1','0','','','',0, 1, 0, 0),
(1587,'KRUKENBERG PROCEDURE','KRUKENBERG PROCEDURE','25915','1','','1','0','','','',0, 1, 0, 0),
(1588,'DISARTICULATION THROUGH WRIST','DISARTICULATION THROUGH WRIST','25920','1','','1','0','','','',0, 1, 0, 0),
(1589,'DISARTICULATION THRU WRIST SEC CLOSURE/SCAR REVJ','DISARTICULATION THRU WRIST SEC CLOSURE/SCAR REVJ','25922','1','','1','0','','','',0, 1, 0, 0),
(1590,'DISARTICULATION THRU WRIST RE-AMPUTATION','DISARTICULATION THRU WRIST RE-AMPUTATION','25924','1','','1','0','','','',0, 1, 0, 0),
(1591,'TRANSMETACARPAL AMPUTATION','TRANSMETACARPAL AMPUTATION','25927','1','','1','0','','','',0, 1, 0, 0),
(1592,'TRANSMETACARPAL AMPUTATION SEC CLOSURE/SCAR REVJ','TRANSMETACARPAL AMPUTATION SEC CLOSURE/SCAR REVJ','25929','1','','1','0','','','',0, 1, 0, 0),
(1593,'TRANSMETACARPAL AMPUTATION RE-AMPUTATION','TRANSMETACARPAL AMPUTATION RE-AMPUTATION','25931','1','','1','0','','','',0, 1, 0, 0),
(1594,'UNLISTED PROCEDURE FOREARM/WRIST','UNLISTED PROCEDURE FOREARM/WRIST','25999','1','','1','0','','','',0, 1, 0, 0),
(1595,'DRAINAGE FINGER ABSCESS SIMPLE','DRAINAGE FINGER ABSCESS SIMPLE','26010','1','','1','0','','','',0, 1, 0, 0),
(1596,'DRAINAGE FINGER ABSCESS COMPLICATED','DRAINAGE FINGER ABSCESS COMPLICATED','26011','1','','1','0','','','',0, 1, 0, 0),
(1597,'DRAINAGE TENDON SHEATH DIGIT&/PALM EACH','DRAINAGE TENDON SHEATH DIGIT&/PALM EACH','26020','1','','1','0','','','',0, 1, 0, 0),
(1598,'DRAINAGE OF PALMAR BURSA SINGLE BURSA','DRAINAGE OF PALMAR BURSA SINGLE BURSA','26025','1','','1','0','','','',0, 1, 0, 0),
(1599,'DRAINAGE OF PALMAR BURSA MULTIPLE BURSA','DRAINAGE OF PALMAR BURSA MULTIPLE BURSA','26030','1','','1','0','','','',0, 1, 0, 0),
(1600,'INCISION BONE CORTEX HAND/FINGER','INCISION BONE CORTEX HAND/FINGER','26034','1','','1','0','','','',0, 1, 0, 0),
(1601,'DECOMPRESSION FINGERS&/HAND INJECTION INJURY','DECOMPRESSION FINGERS&/HAND INJECTION INJURY','26035','1','','1','0','','','',0, 1, 0, 0),
(1602,'DECOMPRESSIVE FASCIOTOMY HAND','DECOMPRESSIVE FASCIOTOMY HAND','26037','1','','1','0','','','',0, 1, 0, 0),
(1603,'FASCIOTOMY PALMAR PERCUTANEOUS','FASCIOTOMY PALMAR PERCUTANEOUS','26040','1','','1','0','','','',0, 1, 0, 0),
(1604,'FASCIOTOMY PALMAR OPEN PARTIAL','FASCIOTOMY PALMAR OPEN PARTIAL','26045','1','','1','0','','','',0, 1, 0, 0),
(1605,'TENDON SHEATH INCISION','TENDON SHEATH INCISION','26055','1','','1','0','','','',0, 1, 0, 0),
(1606,'TENOTOMY PERCUTANEOUS SINGLE EACH DIGIT','TENOTOMY PERCUTANEOUS SINGLE EACH DIGIT','26060','1','','1','0','','','',0, 1, 0, 0),
(1607,'ARTHRT EXPL DRG/RMVL LOOSE/FB CARP/MTCRPL JT','ARTHRT EXPL DRG/RMVL LOOSE/FB CARP/MTCRPL JT','26070','1','','1','0','','','',0, 1, 0, 0),
(1608,'ARTHRT EXPL DRG/RMVL LOOSE/FB MTCARPHLNGL JT EA','ARTHRT EXPL DRG/RMVL LOOSE/FB MTCARPHLNGL JT EA','26075','1','','1','0','','','',0, 1, 0, 0),
(1609,'ARTHRT EXPL DRG/RMVL LOOSE/FB IPHAL JT EA','ARTHRT EXPL DRG/RMVL LOOSE/FB IPHAL JT EA','26080','1','','1','0','','','',0, 1, 0, 0),
(1610,'ARTHROTOMY BIOPSY CARP/MTCRPL JOINT EACH','ARTHROTOMY BIOPSY CARP/MTCRPL JOINT EACH','26100','1','','1','0','','','',0, 1, 0, 0),
(1611,'ARTHROTOMY BIOPSY MTCARPHLNGL JOINT EACH','ARTHROTOMY BIOPSY MTCARPHLNGL JOINT EACH','26105','1','','1','0','','','',0, 1, 0, 0),
(1612,'ARTHROTOMY BIOPSY INTERPHALANGEAL JOINT EACH','ARTHROTOMY BIOPSY INTERPHALANGEAL JOINT EACH','26110','1','','1','0','','','',0, 1, 0, 0),
(1613,'EX TUM/VASC MALF SFT TISS HAND/FNGR SUBQ 1.5CM/>','EX TUM/VASC MALF SFT TISS HAND/FNGR SUBQ 1.5CM/>','26111','1','','1','0','','','',0, 1, 0, 0),
(1614,'EX TUM/VASC MAL SFT TIS HAND/FNGR SUBFSC 1.5CM/>','EX TUM/VASC MAL SFT TIS HAND/FNGR SUBFSC 1.5CM/>','26113','1','','1','0','','','',0, 1, 0, 0),
(1615,'EXC TUM/VASC MAL SFT TISS HAND/FNGR SUBQ <1.5CM','EXC TUM/VASC MAL SFT TISS HAND/FNGR SUBQ <1.5CM','26115','1','','1','0','','','',0, 1, 0, 0),
(1616,'EXC TUM/VAS MAL SFT TIS HAND/FNGR SUBFASC<1.5CM','EXC TUM/VAS MAL SFT TIS HAND/FNGR SUBFASC<1.5CM','26116','1','','1','0','','','',0, 1, 0, 0),
(1617,'RAD RESECT TUMOR SOFT TISSUE HAND/FINGER <3CM','RAD RESECT TUMOR SOFT TISSUE HAND/FINGER <3CM','26117','1','','1','0','','','',0, 1, 0, 0),
(1618,'RAD RESCJ TUM SOFT TISSUE HAND/FINGER 3 CM/>','RAD RESCJ TUM SOFT TISSUE HAND/FINGER 3 CM/>','26118','1','','1','0','','','',0, 1, 0, 0),
(1619,'FASCT PALM W/WO Z-PLASTY TISSUE REARGMT/SKN GRFT','FASCT PALM W/WO Z-PLASTY TISSUE REARGMT/SKN GRFT','26121','1','','1','0','','','',0, 1, 0, 0),
(1620,'FASCT PRTL PALMAR 1 DGT PROX IPHAL JT W/WO RPR','FASCT PRTL PALMAR 1 DGT PROX IPHAL JT W/WO RPR','26123','1','','1','0','','','',0, 1, 0, 0),
(1621,'FASCT PRTL PALMR ADDL DGT PROX IPHAL JT W/WO RPR','FASCT PRTL PALMR ADDL DGT PROX IPHAL JT W/WO RPR','26125','1','','1','0','','','',0, 1, 0, 0),
(1622,'SYNOVECTOMY CARPOMETACARPAL JOINT','SYNOVECTOMY CARPOMETACARPAL JOINT','26130','1','','1','0','','','',0, 1, 0, 0),
(1623,'SYNVCT MTCARPHLNGL JT W/INTRNSC RLS&XTNSR HOOD','SYNVCT MTCARPHLNGL JT W/INTRNSC RLS&XTNSR HOOD','26135','1','','1','0','','','',0, 1, 0, 0),
(1624,'SYNVCT PROX IPHAL JT W/XTNSR RCNSTJ EA IPHAL JT','SYNVCT PROX IPHAL JT W/XTNSR RCNSTJ EA IPHAL JT','26140','1','','1','0','','','',0, 1, 0, 0),
(1625,'SYNVCT TDN SHTH RAD FLXR TDN PALM&/FNGR EA TDN','SYNVCT TDN SHTH RAD FLXR TDN PALM&/FNGR EA TDN','26145','1','','1','0','','','',0, 1, 0, 0),
(1626,'EXC LESION TDN SHTH/JT CAPSL HAND/FNGR','EXC LESION TDN SHTH/JT CAPSL HAND/FNGR','26160','1','','1','0','','','',0, 1, 0, 0),
(1627,'EXCISION TENDON PALM FLEXOR/EXTENSOR SINGLE EACH','EXCISION TENDON PALM FLEXOR/EXTENSOR SINGLE EACH','26170','1','','1','0','','','',0, 1, 0, 0),
(1628,'EXCISION TENDON FINGER FLEXOR/EXTENSOR EACH','EXCISION TENDON FINGER FLEXOR/EXTENSOR EACH','26180','1','','1','0','','','',0, 1, 0, 0),
(1629,'SESAMOIDECTOMY THUMB/FINGER SEPARATE PROCEDURE','SESAMOIDECTOMY THUMB/FINGER SEPARATE PROCEDURE','26185','1','','1','0','','','',0, 1, 0, 0),
(1630,'EXCISION/CURETTAGE CYST/TUMOR METACARPAL','EXCISION/CURETTAGE CYST/TUMOR METACARPAL','26200','1','','1','0','','','',0, 1, 0, 0),
(1631,'EXC/CURETTAGE CYST/TUMOR METACARPAL W/AUTOGRAFT','EXC/CURETTAGE CYST/TUMOR METACARPAL W/AUTOGRAFT','26205','1','','1','0','','','',0, 1, 0, 0),
(1632,'EXCISION/CURETTAGE CYST/TUMOR PHALANX FINGER','EXCISION/CURETTAGE CYST/TUMOR PHALANX FINGER','26210','1','','1','0','','','',0, 1, 0, 0),
(1633,'EXC/CURETTAGE CYST/TUMOR PHALANX FINGER W/AGRAFT','EXC/CURETTAGE CYST/TUMOR PHALANX FINGER W/AGRAFT','26215','1','','1','0','','','',0, 1, 0, 0),
(1634,'PARTIAL EXCISION BONE METACARPAL','PARTIAL EXCISION BONE METACARPAL','26230','1','','1','0','','','',0, 1, 0, 0),
(1635,'PARTIAL EXCISION PROXIMAL/MIDDLE PHALANX FINGER','PARTIAL EXCISION PROXIMAL/MIDDLE PHALANX FINGER','26235','1','','1','0','','','',0, 1, 0, 0),
(1636,'PARTIAL EXCISION DISTAL PHALANX FINGER','PARTIAL EXCISION DISTAL PHALANX FINGER','26236','1','','1','0','','','',0, 1, 0, 0),
(1637,'RADICAL RESECTION TUMOR METACARPAL','RADICAL RESECTION TUMOR METACARPAL','26250','1','','1','0','','','',0, 1, 0, 0),
(1638,'RAD RESECTION TUMOR PROX/MIDDLE PHALANX FINGER','RAD RESECTION TUMOR PROX/MIDDLE PHALANX FINGER','26260','1','','1','0','','','',0, 1, 0, 0),
(1639,'RADICAL RESECTION TUMOR DISTAL PHALANX FINGER','RADICAL RESECTION TUMOR DISTAL PHALANX FINGER','26262','1','','1','0','','','',0, 1, 0, 0),
(1640,'REMOVAL IMPLANT FROM FINGER/HAND','REMOVAL IMPLANT FROM FINGER/HAND','26320','1','','1','0','','','',0, 1, 0, 0),
(1641,'MANIPULATION FINGER JOINT UNDER ANES EACH JOINT','MANIPULATION FINGER JOINT UNDER ANES EACH JOINT','26340','1','','1','0','','','',0, 1, 0, 0),
(1642,'MANIPLATN PALAR FASCIAL CRD POST INJ SINGLE CORD','MANIPLATN PALAR FASCIAL CRD POST INJ SINGLE CORD','26341','1','','1','0','','','',0, 1, 0, 0),
(1643,'RPR/ADVMNT FLXR TDN N/Z/2 W/O FR GRAFT EA TENDON','RPR/ADVMNT FLXR TDN N/Z/2 W/O FR GRAFT EA TENDON','26350','1','','1','0','','','',0, 1, 0, 0),
(1644,'RPR/ADVMNT FLXR TDN N/Z/2 W/FR GRAFT EA TENDON','RPR/ADVMNT FLXR TDN N/Z/2 W/FR GRAFT EA TENDON','26352','1','','1','0','','','',0, 1, 0, 0),
(1645,'RPR/ADVMNT FLXR TDN ZONE 2 W/O FR GRFT EA TENDON','RPR/ADVMNT FLXR TDN ZONE 2 W/O FR GRFT EA TENDON','26356','1','','1','0','','','',0, 1, 0, 0),
(1646,'RPR/ADVMNT FLXR TDN ZONE 2 W/O FR GRFT EA TENDON','RPR/ADVMNT FLXR TDN ZONE 2 W/O FR GRFT EA TENDON','26357','1','','1','0','','','',0, 1, 0, 0),
(1647,'RPR/ADVMNT FLXR TDN ZONE 2 W/FR GRAFT EA TENDON','RPR/ADVMNT FLXR TDN ZONE 2 W/FR GRAFT EA TENDON','26358','1','','1','0','','','',0, 1, 0, 0),
(1648,'RPR/ADVMNT TDN W/NTC SUPFCIS TDN PRIM EA TDN','RPR/ADVMNT TDN W/NTC SUPFCIS TDN PRIM EA TDN','26370','1','','1','0','','','',0, 1, 0, 0),
(1649,'RPR/ADVMNT TDN W/NTC SUPFCIS TDN W/FREE GRAFT EA','RPR/ADVMNT TDN W/NTC SUPFCIS TDN W/FREE GRAFT EA','26372','1','','1','0','','','',0, 1, 0, 0),
(1650,'RPR/ADVMNT TDN W/NTC SUPFCIS TDN W/O FREE GRF EA','RPR/ADVMNT TDN W/NTC SUPFCIS TDN W/O FREE GRF EA','26373','1','','1','0','','','',0, 1, 0, 0),
(1651,'EXC FLXR TDN W/IMPLTJ SYNTH ROD DLYD TDN GRF H/F','EXC FLXR TDN W/IMPLTJ SYNTH ROD DLYD TDN GRF H/F','26390','1','','1','0','','','',0, 1, 0, 0),
(1652,'RMVL SYNTH ROD & INSJ FLXR TDN GRF H/F EA ROD','RMVL SYNTH ROD & INSJ FLXR TDN GRF H/F EA ROD','26392','1','','1','0','','','',0, 1, 0, 0),
(1653,'REPAIR EXTENSOR TENDON HAND W/O GRAFT EACH','REPAIR EXTENSOR TENDON HAND W/O GRAFT EACH','26410','1','','1','0','','','',0, 1, 0, 0),
(1654,'REPAIR EXTENSOR TENDON HAND W/GRAFT EACH','REPAIR EXTENSOR TENDON HAND W/GRAFT EACH','26412','1','','1','0','','','',0, 1, 0, 0),
(1655,'EXC XTNSR TDN W/IMPLTJ SYNTH ROD DLYD GRF H/F EA','EXC XTNSR TDN W/IMPLTJ SYNTH ROD DLYD GRF H/F EA','26415','1','','1','0','','','',0, 1, 0, 0),
(1656,'RMVL SYNTH ROD & INSJ XTNSR TDN GRF H/F EA ROD','RMVL SYNTH ROD & INSJ XTNSR TDN GRF H/F EA ROD','26416','1','','1','0','','','',0, 1, 0, 0),
(1657,'REPAIR EXTENSOR TENDON FINGER W/O GRAFT EACH','REPAIR EXTENSOR TENDON FINGER W/O GRAFT EACH','26418','1','','1','0','','','',0, 1, 0, 0),
(1658,'REPAIR EXTENSOR TENDON FINGER W/GRAFT EACH','REPAIR EXTENSOR TENDON FINGER W/GRAFT EACH','26420','1','','1','0','','','',0, 1, 0, 0),
(1659,'RPR XTNSR TDN CNTRL SLIP TISS W/LAT BAND EA FNGR','RPR XTNSR TDN CNTRL SLIP TISS W/LAT BAND EA FNGR','26426','1','','1','0','','','',0, 1, 0, 0),
(1660,'RPR XTNSR TDN CNTRL SLIP SEC W/FR GRFT EA FINGER','RPR XTNSR TDN CNTRL SLIP SEC W/FR GRFT EA FINGER','26428','1','','1','0','','','',0, 1, 0, 0),
(1661,'CLTX DSTL XTNSR TDN INSJ W/WO PERCUTAN PINNING','CLTX DSTL XTNSR TDN INSJ W/WO PERCUTAN PINNING','26432','1','','1','0','','','',0, 1, 0, 0),
(1662,'REPAIR EXTENSOR TENDON DISTAL INSERTION W/O GRF','REPAIR EXTENSOR TENDON DISTAL INSERTION W/O GRF','26433','1','','1','0','','','',0, 1, 0, 0),
(1663,'REPAIR EXTENSOR TENDON DISTAL INSERTION W/GRAFT','REPAIR EXTENSOR TENDON DISTAL INSERTION W/GRAFT','26434','1','','1','0','','','',0, 1, 0, 0),
(1664,'REALIGNMENT EXTENSOR TENDON HAND EACH TENDON','REALIGNMENT EXTENSOR TENDON HAND EACH TENDON','26437','1','','1','0','','','',0, 1, 0, 0),
(1665,'TENOLYSIS FLEXOR TENDON PALM/FINGER EACH TENDON','TENOLYSIS FLEXOR TENDON PALM/FINGER EACH TENDON','26440','1','','1','0','','','',0, 1, 0, 0),
(1666,'TENOLYSIS FLEXOR TENDON PALM&FINGER EACH TENDO','TENOLYSIS FLEXOR TENDON PALM&FINGER EACH TENDO','26442','1','','1','0','','','',0, 1, 0, 0),
(1667,'TENOLYSIS EXTENSOR TENDON HAND/FINGER EACH','TENOLYSIS EXTENSOR TENDON HAND/FINGER EACH','26445','1','','1','0','','','',0, 1, 0, 0),
(1668,'TENOLYSIS CPLX XTNSR TENDON FINGER W/FOREARM EA','TENOLYSIS CPLX XTNSR TENDON FINGER W/FOREARM EA','26449','1','','1','0','','','',0, 1, 0, 0),
(1669,'TENOTOMY FLEXOR PALM OPEN EACH TENDON','TENOTOMY FLEXOR PALM OPEN EACH TENDON','26450','1','','1','0','','','',0, 1, 0, 0),
(1670,'TENOTOMY FLEXOR FINGER OPEN EACH TENDON','TENOTOMY FLEXOR FINGER OPEN EACH TENDON','26455','1','','1','0','','','',0, 1, 0, 0),
(1671,'TENOTOMY EXTENSOR HAND/FINGER OPEN EACH TENDON','TENOTOMY EXTENSOR HAND/FINGER OPEN EACH TENDON','26460','1','','1','0','','','',0, 1, 0, 0),
(1672,'TENODESIS PROXIMAL INTERPHALANGEAL JOINT EACH','TENODESIS PROXIMAL INTERPHALANGEAL JOINT EACH','26471','1','','1','0','','','',0, 1, 0, 0),
(1673,'TENODESIS DISTAL JOINT EACH','TENODESIS DISTAL JOINT EACH','26474','1','','1','0','','','',0, 1, 0, 0),
(1674,'LENGTHENING TENDON EXTENSOR HAND/FINGER EACH','LENGTHENING TENDON EXTENSOR HAND/FINGER EACH','26476','1','','1','0','','','',0, 1, 0, 0),
(1675,'SHORTENING TENDON EXTENSOR HAND/FINGER EACH','SHORTENING TENDON EXTENSOR HAND/FINGER EACH','26477','1','','1','0','','','',0, 1, 0, 0),
(1676,'LENGTHENING TENDON FLEXOR HAND/FINGER EACH','LENGTHENING TENDON FLEXOR HAND/FINGER EACH','26478','1','','1','0','','','',0, 1, 0, 0),
(1677,'SHORTENING TENDON FLEXOR HAND/FINGER EACH','SHORTENING TENDON FLEXOR HAND/FINGER EACH','26479','1','','1','0','','','',0, 1, 0, 0),
(1678,'TR/TRNSPL TDN CARP/MTCRPL HAND W/O FR GRF EA TDN','TR/TRNSPL TDN CARP/MTCRPL HAND W/O FR GRF EA TDN','26480','1','','1','0','','','',0, 1, 0, 0),
(1679,'TENDON TRANSFER TRANSPLANT CARP/MTCRPL GRAFT','TENDON TRANSFER TRANSPLANT CARP/MTCRPL GRAFT','26483','1','','1','0','','','',0, 1, 0, 0),
(1680,'TRANSFER/TRANSPLANT TENDON PALMAR W/O GRAFT EACH','TRANSFER/TRANSPLANT TENDON PALMAR W/O GRAFT EACH','26485','1','','1','0','','','',0, 1, 0, 0),
(1681,'TRANSFER/TRANSPLANT TENDON PALMAR W/GRAFT EACH','TRANSFER/TRANSPLANT TENDON PALMAR W/GRAFT EACH','26489','1','','1','0','','','',0, 1, 0, 0),
(1682,'OPPONENSPLASTY SUPFCIS TDN TR TYP EA TDN','OPPONENSPLASTY SUPFCIS TDN TR TYP EA TDN','26490','1','','1','0','','','',0, 1, 0, 0),
(1683,'OPPONENSPLASTY TDN TR W/GRF EA TDN','OPPONENSPLASTY TDN TR W/GRF EA TDN','26492','1','','1','0','','','',0, 1, 0, 0),
(1684,'OPPONENSPLASTY HYPOTHENAR MUSC TR','OPPONENSPLASTY HYPOTHENAR MUSC TR','26494','1','','1','0','','','',0, 1, 0, 0),
(1685,'OPPONENSPLASTY OTHER METHODS','OPPONENSPLASTY OTHER METHODS','26496','1','','1','0','','','',0, 1, 0, 0),
(1686,'TR TDN RESTORE INTRNSC FUNCJ RING&SM FNGR','TR TDN RESTORE INTRNSC FUNCJ RING&SM FNGR','26497','1','','1','0','','','',0, 1, 0, 0),
(1687,'TR TDN RESTORE INTRNSC FUNCJ ALL 4 FNGRS','TR TDN RESTORE INTRNSC FUNCJ ALL 4 FNGRS','26498','1','','1','0','','','',0, 1, 0, 0),
(1688,'CORRECTION CLAW FINGER OTHER METHODS','CORRECTION CLAW FINGER OTHER METHODS','26499','1','','1','0','','','',0, 1, 0, 0),
(1689,'RCNSTJ TENDON PULLEY EACH W/LOCAL TISSUES SPX','RCNSTJ TENDON PULLEY EACH W/LOCAL TISSUES SPX','26500','1','','1','0','','','',0, 1, 0, 0),
(1690,'RCNSTJ TDN PULLEY EA TDN W/TDN/FSCAL GRF SPX','RCNSTJ TDN PULLEY EA TDN W/TDN/FSCAL GRF SPX','26502','1','','1','0','','','',0, 1, 0, 0),
(1691,'RELEASE THENAR MUSCLE','RELEASE THENAR MUSCLE','26508','1','','1','0','','','',0, 1, 0, 0),
(1692,'CROSS INTRINSIC TRANSFER EACH TENDON','CROSS INTRINSIC TRANSFER EACH TENDON','26510','1','','1','0','','','',0, 1, 0, 0),
(1693,'CAPSULODESIS MTCARPHLNGL JOINT SINGLE DIGIT','CAPSULODESIS MTCARPHLNGL JOINT SINGLE DIGIT','26516','1','','1','0','','','',0, 1, 0, 0),
(1694,'CAPSULODESIS MTCARPHLNGL JOINT 2 DIGITS','CAPSULODESIS MTCARPHLNGL JOINT 2 DIGITS','26517','1','','1','0','','','',0, 1, 0, 0),
(1695,'CAPSULODESIS MTCARPHLNGL JOINT 3/4 DIGITS','CAPSULODESIS MTCARPHLNGL JOINT 3/4 DIGITS','26518','1','','1','0','','','',0, 1, 0, 0),
(1696,'CAPSULECTOMY/CAPSULOTOMY MTCARPHLNGL JOINT EACH','CAPSULECTOMY/CAPSULOTOMY MTCARPHLNGL JOINT EACH','26520','1','','1','0','','','',0, 1, 0, 0),
(1697,'CAPSULECTOMY/CAPSULOTOMY IPHAL JOINT EACH','CAPSULECTOMY/CAPSULOTOMY IPHAL JOINT EACH','26525','1','','1','0','','','',0, 1, 0, 0),
(1698,'ARTHROPLASTY METACARPOPHALANGEAL JOINT EACH','ARTHROPLASTY METACARPOPHALANGEAL JOINT EACH','26530','1','','1','0','','','',0, 1, 0, 0),
(1699,'ARTHRP MTCARPHLNGL JT W/PROSTC IMPLT EA JT','ARTHRP MTCARPHLNGL JT W/PROSTC IMPLT EA JT','26531','1','','1','0','','','',0, 1, 0, 0),
(1700,'ARTHROPLASTY INTERPHALANGEAL JOINT EACH','ARTHROPLASTY INTERPHALANGEAL JOINT EACH','26535','1','','1','0','','','',0, 1, 0, 0),
(1701,'ARTHROPLASTY INTERPHALANGEAL JT W/PROSTHETIC EA','ARTHROPLASTY INTERPHALANGEAL JT W/PROSTHETIC EA','26536','1','','1','0','','','',0, 1, 0, 0),
(1702,'RPR COLTRL LIGM MTCARPHLNGL/IPHAL JT','RPR COLTRL LIGM MTCARPHLNGL/IPHAL JT','26540','1','','1','0','','','',0, 1, 0, 0),
(1703,'RCNSTJ COLTRL LIGM MTCARPHLNGL 1 W/TDN/FSCAL GRF','RCNSTJ COLTRL LIGM MTCARPHLNGL 1 W/TDN/FSCAL GRF','26541','1','','1','0','','','',0, 1, 0, 0),
(1704,'RCNSTJ COLTRL LIGM MTCARPHLNGL 1 W/LOCAL TISS','RCNSTJ COLTRL LIGM MTCARPHLNGL 1 W/LOCAL TISS','26542','1','','1','0','','','',0, 1, 0, 0),
(1705,'RCNSTJ COLTRL LIGM IPHAL JT 1 W/GRF EA JT','RCNSTJ COLTRL LIGM IPHAL JT 1 W/GRF EA JT','26545','1','','1','0','','','',0, 1, 0, 0),
(1706,'RPR NON-UNION MTCRPL/PHALANX','RPR NON-UNION MTCRPL/PHALANX','26546','1','','1','0','','','',0, 1, 0, 0),
(1707,'RPR & RCNSTJ FINGER VOLAR PLATE INTERPHALANGEAL','RPR & RCNSTJ FINGER VOLAR PLATE INTERPHALANGEAL','26548','1','','1','0','','','',0, 1, 0, 0),
(1708,'POLLICIZATION DIGIT','POLLICIZATION DIGIT','26550','1','','1','0','','','',0, 1, 0, 0),
(1709,'TR TOE-TO-HAND W/MVASC ANAST GRT TOE WRP/ARND','TR TOE-TO-HAND W/MVASC ANAST GRT TOE WRP/ARND','26551','1','','1','0','','','',0, 1, 0, 0),
(1710,'TR TOE-TO-HAND W/MVASC ANAST OTH/THN GRT TOE 1','TR TOE-TO-HAND W/MVASC ANAST OTH/THN GRT TOE 1','26553','1','','1','0','','','',0, 1, 0, 0),
(1711,'TR TOE-TO-HAND W/MVASC ANAST OTH/THN GRT TOE 2','TR TOE-TO-HAND W/MVASC ANAST OTH/THN GRT TOE 2','26554','1','','1','0','','','',0, 1, 0, 0),
(1712,'TR FNGR AXH POS W/O MVASC ANAST','TR FNGR AXH POS W/O MVASC ANAST','26555','1','','1','0','','','',0, 1, 0, 0),
(1713,'TRANSFER FREE TOE JOINT W/MVASC ANASTOMOSIS','TRANSFER FREE TOE JOINT W/MVASC ANASTOMOSIS','26556','1','','1','0','','','',0, 1, 0, 0),
(1714,'REPAIR SYNDACTYLY EACH SPACE W/SKIN FLAPS','REPAIR SYNDACTYLY EACH SPACE W/SKIN FLAPS','26560','1','','1','0','','','',0, 1, 0, 0),
(1715,'REPAIR SYNDACTYLY EACH SPACE W/SKIN FLAPS&GRAFT','REPAIR SYNDACTYLY EACH SPACE W/SKIN FLAPS&GRAFT','26561','1','','1','0','','','',0, 1, 0, 0),
(1716,'REPAIR SYNDACTYLY EACH SPACE COMPLEX','REPAIR SYNDACTYLY EACH SPACE COMPLEX','26562','1','','1','0','','','',0, 1, 0, 0),
(1717,'OSTEOTOMY METACARPAL EACH','OSTEOTOMY METACARPAL EACH','26565','1','','1','0','','','',0, 1, 0, 0),
(1718,'OSTEOTOMY PHALANX FINGER EACH','OSTEOTOMY PHALANX FINGER EACH','26567','1','','1','0','','','',0, 1, 0, 0),
(1719,'OSTEOPLASTY LENGTHENING METACARPAL/PHALANX','OSTEOPLASTY LENGTHENING METACARPAL/PHALANX','26568','1','','1','0','','','',0, 1, 0, 0),
(1720,'REPAIR CLEFT HAND','REPAIR CLEFT HAND','26580','1','','1','0','','','',0, 1, 0, 0),
(1721,'RCNSTJ POLYDACTYLOUS DIGIT SOFT TISSUE & BONE','RCNSTJ POLYDACTYLOUS DIGIT SOFT TISSUE & BONE','26587','1','','1','0','','','',0, 1, 0, 0),
(1722,'REPAIR MACRODACTYLIA EACH DIGIT','REPAIR MACRODACTYLIA EACH DIGIT','26590','1','','1','0','','','',0, 1, 0, 0),
(1723,'REPAIR INTRINSIC MUSCLES HAND EACH MUSCLE','REPAIR INTRINSIC MUSCLES HAND EACH MUSCLE','26591','1','','1','0','','','',0, 1, 0, 0),
(1724,'RELEASE INTRINSIC MUSCLES HAND EACH MUSCLE','RELEASE INTRINSIC MUSCLES HAND EACH MUSCLE','26593','1','','1','0','','','',0, 1, 0, 0),
(1725,'EXC CONSTRICTING RING FNGR W/MLT Z-PLASTIES','EXC CONSTRICTING RING FNGR W/MLT Z-PLASTIES','26596','1','','1','0','','','',0, 1, 0, 0),
(1726,'CLTX METACARPAL FX W/O MANIPULATION EACH BONE','CLTX METACARPAL FX W/O MANIPULATION EACH BONE','26600','1','','1','0','','','',0, 1, 0, 0),
(1727,'CLTX METACARPAL FX W/MANIPULATION EACH BONE','CLTX METACARPAL FX W/MANIPULATION EACH BONE','26605','1','','1','0','','','',0, 1, 0, 0),
(1728,'CLTX METACARPAL FX W/MANJ W/XTRNL FIXJ EA BONE','CLTX METACARPAL FX W/MANJ W/XTRNL FIXJ EA BONE','26607','1','','1','0','','','',0, 1, 0, 0),
(1729,'PRQ SKELETAL FIXJ METACARPAL FX EACH BONE','PRQ SKELETAL FIXJ METACARPAL FX EACH BONE','26608','1','','1','0','','','',0, 1, 0, 0),
(1730,'OPEN TX METACARPAL FRACTURE SINGLE EA BONE','OPEN TX METACARPAL FRACTURE SINGLE EA BONE','26615','1','','1','0','','','',0, 1, 0, 0),
(1731,'CLTX CARPO/METACARPAL DISLOCATION THUMB W/MANJ','CLTX CARPO/METACARPAL DISLOCATION THUMB W/MANJ','26641','1','','1','0','','','',0, 1, 0, 0),
(1732,'CLTX CARPO/METACARPAL FX DISLC THUMB W/MANJ','CLTX CARPO/METACARPAL FX DISLC THUMB W/MANJ','26645','1','','1','0','','','',0, 1, 0, 0),
(1733,'PRQ SKELETAL FIX CARPO/METACARPAL FX DISLC THUMB','PRQ SKELETAL FIX CARPO/METACARPAL FX DISLC THUMB','26650','1','','1','0','','','',0, 1, 0, 0),
(1734,'OPEN TX CARPOMETACARPAL FRACTURE DISLOCATE THUMB','OPEN TX CARPOMETACARPAL FRACTURE DISLOCATE THUMB','26665','1','','1','0','','','',0, 1, 0, 0),
(1735,'CLTX CARPO/METACARPL DISLC THMB MANJ EA W/O ANES','CLTX CARPO/METACARPL DISLC THMB MANJ EA W/O ANES','26670','1','','1','0','','','',0, 1, 0, 0),
(1736,'CLTX CARPO/MTCRPL DISLC THUMB MANJ EA JT W/ANES','CLTX CARPO/MTCRPL DISLC THUMB MANJ EA JT W/ANES','26675','1','','1','0','','','',0, 1, 0, 0),
(1737,'PRQ SKEL FIXJ CARPO/MTCRPL DISLC THMB MANJ EA JT','PRQ SKEL FIXJ CARPO/MTCRPL DISLC THMB MANJ EA JT','26676','1','','1','0','','','',0, 1, 0, 0),
(1738,'OPEN TX CARPOMETACARPAL DISLOCATE NOT THUMB','OPEN TX CARPOMETACARPAL DISLOCATE NOT THUMB','26685','1','','1','0','','','',0, 1, 0, 0),
(1739,'OPTX CARP/MTCRPL DISLC THMB CPLX MLT/DLYD RDCTJ','OPTX CARP/MTCRPL DISLC THMB CPLX MLT/DLYD RDCTJ','26686','1','','1','0','','','',0, 1, 0, 0),
(1740,'CLTX METACARPOPHALANGEAL DISLC W/MANJ W/O ANES','CLTX METACARPOPHALANGEAL DISLC W/MANJ W/O ANES','26700','1','','1','0','','','',0, 1, 0, 0),
(1741,'CLTX METACARPOPHALANGEAL DISLC W/MANJ W/ANES','CLTX METACARPOPHALANGEAL DISLC W/MANJ W/ANES','26705','1','','1','0','','','',0, 1, 0, 0),
(1742,'PRQ SKEL FIXJ METACARPOPHALANGEAL DISLC W/MANJ','PRQ SKEL FIXJ METACARPOPHALANGEAL DISLC W/MANJ','26706','1','','1','0','','','',0, 1, 0, 0),
(1743,'OPEN TREATMENT METACARPOPHALANGEAL DISLOCATION','OPEN TREATMENT METACARPOPHALANGEAL DISLOCATION','26715','1','','1','0','','','',0, 1, 0, 0),
(1744,'CLTX PHLNGL FX PROX/MIDDLE PX/F/T W/O MANJ EA','CLTX PHLNGL FX PROX/MIDDLE PX/F/T W/O MANJ EA','26720','1','','1','0','','','',0, 1, 0, 0),
(1745,'CLTX PHLNGL FX PROX/MIDDLE PX/F/T W/MANJ EA','CLTX PHLNGL FX PROX/MIDDLE PX/F/T W/MANJ EA','26725','1','','1','0','','','',0, 1, 0, 0),
(1746,'PRQ SKEL FIXJ PHLNGL SHFT FX PROX/MIDDLE PX/F/T','PRQ SKEL FIXJ PHLNGL SHFT FX PROX/MIDDLE PX/F/T','26727','1','','1','0','','','',0, 1, 0, 0),
(1747,'OPEN TX PHALANGEAL SHAFT FRACTURE PROX/MIDDLE EA','OPEN TX PHALANGEAL SHAFT FRACTURE PROX/MIDDLE EA','26735','1','','1','0','','','',0, 1, 0, 0),
(1748,'CLTX ARTCLR FX INVG MTCRPHLNGL/IPHAL JT W/O MANJ','CLTX ARTCLR FX INVG MTCRPHLNGL/IPHAL JT W/O MANJ','26740','1','','1','0','','','',0, 1, 0, 0),
(1749,'CLTX ARTCLR FX INVG MTCARPHLNGL/IPHAL JT W/MANJ','CLTX ARTCLR FX INVG MTCARPHLNGL/IPHAL JT W/MANJ','26742','1','','1','0','','','',0, 1, 0, 0),
(1750,'OPEN TX ARTICULAR FRACTURE MCP/IP JOINT EA','OPEN TX ARTICULAR FRACTURE MCP/IP JOINT EA','26746','1','','1','0','','','',0, 1, 0, 0),
(1751,'CLTX DSTL PHLNGL FX FNGR/THMB W/O MANJ EA','CLTX DSTL PHLNGL FX FNGR/THMB W/O MANJ EA','26750','1','','1','0','','','',0, 1, 0, 0),
(1752,'CLTX DSTL PHLNGL FX FNGR/THMB W/MANJ EA','CLTX DSTL PHLNGL FX FNGR/THMB W/MANJ EA','26755','1','','1','0','','','',0, 1, 0, 0),
(1753,'PRQ SKEL FIXJ DSTL PHLNGL FX FNGR/THMB EA','PRQ SKEL FIXJ DSTL PHLNGL FX FNGR/THMB EA','26756','1','','1','0','','','',0, 1, 0, 0),
(1754,'OPEN TX DISTAL PHALANGEAL FRACTURE EACH','OPEN TX DISTAL PHALANGEAL FRACTURE EACH','26765','1','','1','0','','','',0, 1, 0, 0),
(1755,'CLTX IPHAL JT DISLC W/MANJ W/O ANES','CLTX IPHAL JT DISLC W/MANJ W/O ANES','26770','1','','1','0','','','',0, 1, 0, 0),
(1756,'CLTX IPHAL JT DISLC W/MANJ REQ ANES','CLTX IPHAL JT DISLC W/MANJ REQ ANES','26775','1','','1','0','','','',0, 1, 0, 0),
(1757,'PRQ SKEL FIXJ IPHAL JT DISLC W/MANJ','PRQ SKEL FIXJ IPHAL JT DISLC W/MANJ','26776','1','','1','0','','','',0, 1, 0, 0),
(1758,'OPEN TX INTERPHALANGEAL JOINT DISLOCATION','OPEN TX INTERPHALANGEAL JOINT DISLOCATION','26785','1','','1','0','','','',0, 1, 0, 0),
(1759,'FUSION OPPOSITION THUMB W/AUTOGENOUS GRAFT','FUSION OPPOSITION THUMB W/AUTOGENOUS GRAFT','26820','1','','1','0','','','',0, 1, 0, 0),
(1760,'ARTHRD CARPO/METACARPAL JT THUMB W/WO INT FIXJ','ARTHRD CARPO/METACARPAL JT THUMB W/WO INT FIXJ','26841','1','','1','0','','','',0, 1, 0, 0),
(1761,'ARTHRD CRP/MTACRPL JT THMB W/WO INT FIXJ W/AGRFT','ARTHRD CRP/MTACRPL JT THMB W/WO INT FIXJ W/AGRFT','26842','1','','1','0','','','',0, 1, 0, 0),
(1762,'ARTHRD CARP/MTCRPL JT DGT OTHER THAN THUMB EACH','ARTHRD CARP/MTCRPL JT DGT OTHER THAN THUMB EACH','26843','1','','1','0','','','',0, 1, 0, 0),
(1763,'ARTHRD CARP/MTCRPL JT DGT OTH/THN THMB W/AGRFT','ARTHRD CARP/MTCRPL JT DGT OTH/THN THMB W/AGRFT','26844','1','','1','0','','','',0, 1, 0, 0),
(1764,'ARTHRODESIS METACARPOPHALANGEAL JT W/WO INT FIXJ','ARTHRODESIS METACARPOPHALANGEAL JT W/WO INT FIXJ','26850','1','','1','0','','','',0, 1, 0, 0),
(1765,'ARTHRODESIS MTCRPL JT W/WO INT FIXJ W/AUTOGRAFT','ARTHRODESIS MTCRPL JT W/WO INT FIXJ W/AUTOGRAFT','26852','1','','1','0','','','',0, 1, 0, 0),
(1766,'ARTHRODESIS INTERPHALANGEAL JT W/WO INT FIXJ','ARTHRODESIS INTERPHALANGEAL JT W/WO INT FIXJ','26860','1','','1','0','','','',0, 1, 0, 0),
(1767,'ARTHRODESIS IPHAL JT W/WO INT FIXJ EA IPHAL JT','ARTHRODESIS IPHAL JT W/WO INT FIXJ EA IPHAL JT','26861','1','','1','0','','','',0, 1, 0, 0),
(1768,'ARTHRODESIS IPHAL JT W/WO INT FIXJ W/AUTOGRAFT','ARTHRODESIS IPHAL JT W/WO INT FIXJ W/AUTOGRAFT','26862','1','','1','0','','','',0, 1, 0, 0),
(1769,'ARTHRODESIS IPHAL JT W/WO INT FIXJ W/AGRFT EA JT','ARTHRODESIS IPHAL JT W/WO INT FIXJ W/AGRFT EA JT','26863','1','','1','0','','','',0, 1, 0, 0),
(1770,'AMP MTCRPL W/FINGER/THUMB W/WO INTEROSS TRANSFER','AMP MTCRPL W/FINGER/THUMB W/WO INTEROSS TRANSFER','26910','1','','1','0','','','',0, 1, 0, 0),
(1771,'AMP F/TH 1/2 JT/PHALANX W/NEURECT W/DIR CLSR','AMP F/TH 1/2 JT/PHALANX W/NEURECT W/DIR CLSR','26951','1','','1','0','','','',0, 1, 0, 0),
(1772,'AMP F/TH 1/2 JT/PHALANX W/NEURECT LOCAL FLAP','AMP F/TH 1/2 JT/PHALANX W/NEURECT LOCAL FLAP','26952','1','','1','0','','','',0, 1, 0, 0),
(1773,'UNLISTED PROCEDURE HANDS/FINGERS','UNLISTED PROCEDURE HANDS/FINGERS','26989','1','','1','0','','','',0, 1, 0, 0),
(1774,'I&D PELVIS/HIP JT AREA DEEP ABSCESS/HEMATOMA','I&D PELVIS/HIP JT AREA DEEP ABSCESS/HEMATOMA','26990','1','','1','0','','','',0, 1, 0, 0),
(1775,'I&D PELVIS/HIP JOINT AREA INFECTED BURSA','I&D PELVIS/HIP JOINT AREA INFECTED BURSA','26991','1','','1','0','','','',0, 1, 0, 0),
(1776,'INCISION BONE CORTEX PELVIS&/HIP JOINT','INCISION BONE CORTEX PELVIS&/HIP JOINT','26992','1','','1','0','','','',0, 1, 0, 0),
(1777,'TENOTOMY ADDUCTOR HIP PERCUTANEOUS SPX','TENOTOMY ADDUCTOR HIP PERCUTANEOUS SPX','27000','1','','1','0','','','',0, 1, 0, 0),
(1778,'TENOTOMY ADDUCTOR HIP OPEN','TENOTOMY ADDUCTOR HIP OPEN','27001','1','','1','0','','','',0, 1, 0, 0),
(1779,'TX ADDUXOR SUBQ OPN W/OBTURATOR NEURECTOMY','TX ADDUXOR SUBQ OPN W/OBTURATOR NEURECTOMY','27003','1','','1','0','','','',0, 1, 0, 0),
(1780,'TENOTOMY HIP FLEXOR OPEN SEPARATE PROCEDURE','TENOTOMY HIP FLEXOR OPEN SEPARATE PROCEDURE','27005','1','','1','0','','','',0, 1, 0, 0),
(1781,'TENOTOMY ABDUCTORS&/EXTENSOR HIP OPEN SPX','TENOTOMY ABDUCTORS&/EXTENSOR HIP OPEN SPX','27006','1','','1','0','','','',0, 1, 0, 0),
(1782,'FASCIOTOMY HIP/THIGH ANY TYPE','FASCIOTOMY HIP/THIGH ANY TYPE','27025','1','','1','0','','','',0, 1, 0, 0),
(1783,'DECOMPRESSION FASCIOTOMY PELVIC COMPARTMENT UNI','DECOMPRESSION FASCIOTOMY PELVIC COMPARTMENT UNI','27027','1','','1','0','','','',0, 1, 0, 0),
(1784,'ARTHROTOMY HIP W/DRAINAGE','ARTHROTOMY HIP W/DRAINAGE','27030','1','','1','0','','','',0, 1, 0, 0),
(1785,'ARTHROTOMY HIP EXPLORATION/REMOVAL FOREIGN BODY','ARTHROTOMY HIP EXPLORATION/REMOVAL FOREIGN BODY','27033','1','','1','0','','','',0, 1, 0, 0),
(1786,'DNRVTJ HIP JT INTRAPEL/XTRPEL INTRA-ARTCLR BRNCH','DNRVTJ HIP JT INTRAPEL/XTRPEL INTRA-ARTCLR BRNCH','27035','1','','1','0','','','',0, 1, 0, 0),
(1787,'CAPSLCTOMY/CAPSUL HIP W/RLS HIP FLXR MUSC','CAPSLCTOMY/CAPSUL HIP W/RLS HIP FLXR MUSC','27036','1','','1','0','','','',0, 1, 0, 0),
(1788,'BIOPSY SOFT TISSUE PELVIS&HIP AREA SUPERFICIAL','BIOPSY SOFT TISSUE PELVIS&HIP AREA SUPERFICIAL','27040','1','','1','0','','','',0, 1, 0, 0),
(1789,'BIOPSY SOFT TISSUE PELVIS&HIP DEEP/SUBFSCAL/IM','BIOPSY SOFT TISSUE PELVIS&HIP DEEP/SUBFSCAL/IM','27041','1','','1','0','','','',0, 1, 0, 0),
(1790,'EXCISION TUMOR SOFT TISSUE PELVIS&HIP SUBQ 3CM/>','EXCISION TUMOR SOFT TISSUE PELVIS&HIP SUBQ 3CM/>','27043','1','','1','0','','','',0, 1, 0, 0),
(1791,'EXC TUMOR SOFT TISSUE PELVIS & HIP SUBFASC 5CM/>','EXC TUMOR SOFT TISSUE PELVIS & HIP SUBFASC 5CM/>','27045','1','','1','0','','','',0, 1, 0, 0),
(1792,'EXC TUMOR SOFT TISSUE PELVIS & HIP SUBQ <3CM','EXC TUMOR SOFT TISSUE PELVIS & HIP SUBQ <3CM','27047','1','','1','0','','','',0, 1, 0, 0),
(1793,'EXC TUMOR SOFT TISSUE PELVIS & HIP SUBFASC <5CM','EXC TUMOR SOFT TISSUE PELVIS & HIP SUBFASC <5CM','27048','1','','1','0','','','',0, 1, 0, 0),
(1794,'RAD RESECT TUMOR SOFT TISSUE PELVIS & HIP <5 CM','RAD RESECT TUMOR SOFT TISSUE PELVIS & HIP <5 CM','27049','1','','1','0','','','',0, 1, 0, 0),
(1795,'ARTHROTOMY W/BIOPSY SACROILIAC JOINT','ARTHROTOMY W/BIOPSY SACROILIAC JOINT','27050','1','','1','0','','','',0, 1, 0, 0),
(1796,'ARTHROTOMY W/BIOPSY HIP JOINT','ARTHROTOMY W/BIOPSY HIP JOINT','27052','1','','1','0','','','',0, 1, 0, 0),
(1797,'ARTHROTOMY W/SYNOVECTOMY HIP JOINT','ARTHROTOMY W/SYNOVECTOMY HIP JOINT','27054','1','','1','0','','','',0, 1, 0, 0),
(1798,'DCMPRN FASCIOTOMY PELVIC CMPRT DBRDMT MUSCLE UNI','DCMPRN FASCIOTOMY PELVIC CMPRT DBRDMT MUSCLE UNI','27057','1','','1','0','','','',0, 1, 0, 0),
(1799,'RAD RESECTION TUMOR SOFT TISS PELVIS&HIP 5 CM/>','RAD RESECTION TUMOR SOFT TISS PELVIS&HIP 5 CM/>','27059','1','','1','0','','','',0, 1, 0, 0),
(1800,'EXCISION ISCHIAL BURSA','EXCISION ISCHIAL BURSA','27060','1','','1','0','','','',0, 1, 0, 0),
(1801,'EXCISION TROCHANTERIC BURSA/CALCIFICATION','EXCISION TROCHANTERIC BURSA/CALCIFICATION','27062','1','','1','0','','','',0, 1, 0, 0),
(1802,'EXCISION BONE CYST/BNIGN TUMOR SUPERFICIAL','EXCISION BONE CYST/BNIGN TUMOR SUPERFICIAL','27065','1','','1','0','','','',0, 1, 0, 0),
(1803,'EXCISION BONE CYST/BENIGN TUMOR DEEP','EXCISION BONE CYST/BENIGN TUMOR DEEP','27066','1','','1','0','','','',0, 1, 0, 0),
(1804,'EXC B1 CST/B9 TUM W/AGRFT REQ SEP INC','EXC B1 CST/B9 TUM W/AGRFT REQ SEP INC','27067','1','','1','0','','','',0, 1, 0, 0),
(1805,'PARTIAL EXCISION SUPERFICIAL PELVIS','PARTIAL EXCISION SUPERFICIAL PELVIS','27070','1','','1','0','','','',0, 1, 0, 0),
(1806,'PARTIAL EXCISION DEEP PELVIS','PARTIAL EXCISION DEEP PELVIS','27071','1','','1','0','','','',0, 1, 0, 0),
(1807,'RAD RESCT TUMOR WING OF ILIUM 1 PUBIC/ISCHIAL','RAD RESCT TUMOR WING OF ILIUM 1 PUBIC/ISCHIAL','27075','1','','1','0','','','',0, 1, 0, 0),
(1808,'RAD RESCT TUMOR ILIUM ACETABULUM BOTH PUBIC','RAD RESCT TUMOR ILIUM ACETABULUM BOTH PUBIC','27076','1','','1','0','','','',0, 1, 0, 0),
(1809,'RADICAL RESCTION TUMOR INNOMINATE BONE TOTAL','RADICAL RESCTION TUMOR INNOMINATE BONE TOTAL','27077','1','','1','0','','','',0, 1, 0, 0),
(1810,'RAD RESCT TUMOR ISCHIAL TUBEROSITY&GRT TRCHNTR','RAD RESCT TUMOR ISCHIAL TUBEROSITY&GRT TRCHNTR','27078','1','','1','0','','','',0, 1, 0, 0),
(1811,'COCCYGECTOMY PRIMARY','COCCYGECTOMY PRIMARY','27080','1','','1','0','','','',0, 1, 0, 0),
(1812,'RMVL FOREIGN BODY PELVIS/HIP SUBCUTANEOUS TISS','RMVL FOREIGN BODY PELVIS/HIP SUBCUTANEOUS TISS','27086','1','','1','0','','','',0, 1, 0, 0),
(1813,'REMOVAL FOREIGN BODY PELVIS/HIP DEEP','REMOVAL FOREIGN BODY PELVIS/HIP DEEP','27087','1','','1','0','','','',0, 1, 0, 0),
(1814,'REMOVAL HIP PROSTHESIS SEPARATE PROCEDURE','REMOVAL HIP PROSTHESIS SEPARATE PROCEDURE','27090','1','','1','0','','','',0, 1, 0, 0),
(1815,'RMVL HIP PROSTH COMP W/TOT HIP PROSTH MMA','RMVL HIP PROSTH COMP W/TOT HIP PROSTH MMA','27091','1','','1','0','','','',0, 1, 0, 0),
(1816,'INJECTION HIP ARTHROGRAPHY W/O ANESTHESIA','INJECTION HIP ARTHROGRAPHY W/O ANESTHESIA','27093','1','','1','0','','','',0, 1, 0, 0),
(1817,'INJECTION HIP ARTHROGRAPHY W/ANESTHESIA','INJECTION HIP ARTHROGRAPHY W/ANESTHESIA','27095','1','','1','0','','','',0, 1, 0, 0),
(1818,'INJECT SI JOINT ARTHRGRPHY&/ANES/STEROID W/IMA','INJECT SI JOINT ARTHRGRPHY&/ANES/STEROID W/IMA','27096','1','','1','0','','','',0, 1, 0, 0),
(1819,'RELEASE/RECESSION HAMSTRING PROXIMAL','RELEASE/RECESSION HAMSTRING PROXIMAL','27097','1','','1','0','','','',0, 1, 0, 0),
(1820,'TRANSFER ADDUCTOR ISCHIUM','TRANSFER ADDUCTOR ISCHIUM','27098','1','','1','0','','','',0, 1, 0, 0),
(1821,'TR XTRNL OBLQ MUSC TRCHNTR W/FSCAL/TDN XTN GRF','TR XTRNL OBLQ MUSC TRCHNTR W/FSCAL/TDN XTN GRF','27100','1','','1','0','','','',0, 1, 0, 0),
(1822,'TR PARASPI MUSC HIP FASC/TDN XTN GRF','TR PARASPI MUSC HIP FASC/TDN XTN GRF','27105','1','','1','0','','','',0, 1, 0, 0),
(1823,'TRANSFER ILIOPSOAS GREATER TROCHANTER FEMUR','TRANSFER ILIOPSOAS GREATER TROCHANTER FEMUR','27110','1','','1','0','','','',0, 1, 0, 0),
(1824,'TRANSFER ILIOPSOAS FEMORAL NECK','TRANSFER ILIOPSOAS FEMORAL NECK','27111','1','','1','0','','','',0, 1, 0, 0),
(1825,'ACETABULOPLASTY','ACETABULOPLASTY','27120','1','','1','0','','','',0, 1, 0, 0),
(1826,'ACETABULOPLASTY RESECTION FEMORAL HEAD','ACETABULOPLASTY RESECTION FEMORAL HEAD','27122','1','','1','0','','','',0, 1, 0, 0),
(1827,'HEMIARTHROPLASTY HIP PARTIAL','HEMIARTHROPLASTY HIP PARTIAL','27125','1','','1','0','','','',0, 1, 0, 0),
(1828,'ARTHRP ACETBLR/PROX FEM PROSTC AGRFT/ALGRFT','ARTHRP ACETBLR/PROX FEM PROSTC AGRFT/ALGRFT','27130','1','','1','0','','','',0, 1, 0, 0),
(1829,'CONV PREV HIP TOT HIP ARTHRP W/WO AGRFT/ALGRFT','CONV PREV HIP TOT HIP ARTHRP W/WO AGRFT/ALGRFT','27132','1','','1','0','','','',0, 1, 0, 0),
(1830,'REVJ TOT HIP ARTHRP BTH W/WO AGRFT/ALGRFT','REVJ TOT HIP ARTHRP BTH W/WO AGRFT/ALGRFT','27134','1','','1','0','','','',0, 1, 0, 0),
(1831,'REVJ TOT HIP ARTHRP ACTBLR W/WO AGRFT/ALGRFT','REVJ TOT HIP ARTHRP ACTBLR W/WO AGRFT/ALGRFT','27137','1','','1','0','','','',0, 1, 0, 0),
(1832,'REVJ TOT HIP ARTHRP FEM ONLY W/WO ALGRFT','REVJ TOT HIP ARTHRP FEM ONLY W/WO ALGRFT','27138','1','','1','0','','','',0, 1, 0, 0),
(1833,'OSTEOTOMY&TRANSFER GREATER TROCHANTER SPX','OSTEOTOMY&TRANSFER GREATER TROCHANTER SPX','27140','1','','1','0','','','',0, 1, 0, 0),
(1834,'OSTEOTOMY ILIAC ACETABULAR/INNOMINATE BONE','OSTEOTOMY ILIAC ACETABULAR/INNOMINATE BONE','27146','1','','1','0','','','',0, 1, 0, 0),
(1835,'OSTEOTOMY ILIAC ACETABULAR/INNOMINATE HIP RDCTJ','OSTEOTOMY ILIAC ACETABULAR/INNOMINATE HIP RDCTJ','27147','1','','1','0','','','',0, 1, 0, 0),
(1836,'OSTEOTOMY ILIAC ACETABULAR/INNOMINATE FEM OSTEOT','OSTEOTOMY ILIAC ACETABULAR/INNOMINATE FEM OSTEOT','27151','1','','1','0','','','',0, 1, 0, 0),
(1837,'OSTEOT ILIAC ACTBLR/INNOMINATE BONE OSTEOT RDCTJ','OSTEOT ILIAC ACTBLR/INNOMINATE BONE OSTEOT RDCTJ','27156','1','','1','0','','','',0, 1, 0, 0),
(1838,'OSTEOTOMY PELVIS BILATERAL','OSTEOTOMY PELVIS BILATERAL','27158','1','','1','0','','','',0, 1, 0, 0),
(1839,'OSTEOTOMY FEMORAL NECK SEPARATE PROCEDURE','OSTEOTOMY FEMORAL NECK SEPARATE PROCEDURE','27161','1','','1','0','','','',0, 1, 0, 0),
(1840,'OSTEOT INTERTRCHNTRIC/SUBTRCHNTRIC W/INT/XTRNL','OSTEOT INTERTRCHNTRIC/SUBTRCHNTRIC W/INT/XTRNL','27165','1','','1','0','','','',0, 1, 0, 0),
(1841,'B1 GRF FEM H/N INTERTRCHNTRIC/SUBTRCHNTRIC AREA','B1 GRF FEM H/N INTERTRCHNTRIC/SUBTRCHNTRIC AREA','27170','1','','1','0','','','',0, 1, 0, 0),
(1842,'TX SLP FEMORAL EPIPHYSIS TRCJ W/O REDUCTION','TX SLP FEMORAL EPIPHYSIS TRCJ W/O REDUCTION','27175','1','','1','0','','','',0, 1, 0, 0),
(1843,'TX SLP FEM EPIPHYSIS SINGLE/MULTIPL PINNING SITU','TX SLP FEM EPIPHYSIS SINGLE/MULTIPL PINNING SITU','27176','1','','1','0','','','',0, 1, 0, 0),
(1844,'OPTX SLP FEM EPIPHYSIS SINGLE/MULT PIN/BONE GRFT','OPTX SLP FEM EPIPHYSIS SINGLE/MULT PIN/BONE GRFT','27177','1','','1','0','','','',0, 1, 0, 0),
(1845,'OPTX SLP FEM EPIPHYSIS CLSD MANJ SINGL/MLTPL PIN','OPTX SLP FEM EPIPHYSIS CLSD MANJ SINGL/MLTPL PIN','27178','1','','1','0','','','',0, 1, 0, 0),
(1846,'OPTX SLP FEM EPIPHYSIS OSTPL FEM NCK HEYMAN PX','OPTX SLP FEM EPIPHYSIS OSTPL FEM NCK HEYMAN PX','27179','1','','1','0','','','',0, 1, 0, 0),
(1847,'OPTX SLP FEM EPIPHYSIS OSTEOT&INT FIXJ','OPTX SLP FEM EPIPHYSIS OSTEOT&INT FIXJ','27181','1','','1','0','','','',0, 1, 0, 0),
(1848,'EPIPHYSL ARRST EPIPHYSIOD/STAPLING TRCHNTR FEMUR','EPIPHYSL ARRST EPIPHYSIOD/STAPLING TRCHNTR FEMUR','27185','1','','1','0','','','',0, 1, 0, 0),
(1849,'PROPH TX N/P/PLTWR W/WO MMA FEM NCK & PROX FEMUR','PROPH TX N/P/PLTWR W/WO MMA FEM NCK & PROX FEMUR','27187','1','','1','0','','','',0, 1, 0, 0),
(1850,'CLTX PEL RING FX DISLC DIAST/SUBLXTJ W/O MANJ','CLTX PEL RING FX DISLC DIAST/SUBLXTJ W/O MANJ','27193','1','','1','0','','','',0, 1, 0, 0),
(1851,'CLTX PEL RING FX DISLC DIAST/SUBLXTJ W/MANJ ANES','CLTX PEL RING FX DISLC DIAST/SUBLXTJ W/MANJ ANES','27194','1','','1','0','','','',0, 1, 0, 0),
(1852,'CLOSED TREATMENT COCCYGEAL FRACTURE','CLOSED TREATMENT COCCYGEAL FRACTURE','27200','1','','1','0','','','',0, 1, 0, 0),
(1853,'OPEN TREATMENT COCCYGEAL FRACTURE','OPEN TREATMENT COCCYGEAL FRACTURE','27202','1','','1','0','','','',0, 1, 0, 0),
(1854,'OPTX ILIAC TUBRST AVLS/WING FX FIXJ IF PRFRMD','OPTX ILIAC TUBRST AVLS/WING FX FIXJ IF PRFRMD','27215','1','','1','0','','','',0, 1, 0, 0),
(1855,'PERQ SKELETAL FIXATION PST PELVIC BONE FX&/DIS','PERQ SKELETAL FIXATION PST PELVIC BONE FX&/DIS','27216','1','','1','0','','','',0, 1, 0, 0),
(1856,'OPTX ANT PELVIC BONE FX&/DISLC INT FIXJ IF PFR','OPTX ANT PELVIC BONE FX&/DISLC INT FIXJ IF PFR','27217','1','','1','0','','','',0, 1, 0, 0),
(1857,'OPTX POST PEL BONE FX&/DISLC INT FIXJ IF PFRMD','OPTX POST PEL BONE FX&/DISLC INT FIXJ IF PFRMD','27218','1','','1','0','','','',0, 1, 0, 0),
(1858,'CLTX ACETABULUM HIP/SOCKT FX W/O MANJ','CLTX ACETABULUM HIP/SOCKT FX W/O MANJ','27220','1','','1','0','','','',0, 1, 0, 0),
(1859,'CLTX ACETABULM HIP/SOCKT FX MANJ W/WO SKEL TRACJ','CLTX ACETABULM HIP/SOCKT FX MANJ W/WO SKEL TRACJ','27222','1','','1','0','','','',0, 1, 0, 0),
(1860,'OPTX PST/ANT ACTBLR WALL FX W/INT FIXJ','OPTX PST/ANT ACTBLR WALL FX W/INT FIXJ','27226','1','','1','0','','','',0, 1, 0, 0),
(1861,'OPTX ACTBLR FX INVG ANT/PST 1 COLUMN/FX W/INT','OPTX ACTBLR FX INVG ANT/PST 1 COLUMN/FX W/INT','27227','1','','1','0','','','',0, 1, 0, 0),
(1862,'OPTX ACTBLR FX INVG ANT&POST 2 COLUMNS FX W/INT','OPTX ACTBLR FX INVG ANT&POST 2 COLUMNS FX W/INT','27228','1','','1','0','','','',0, 1, 0, 0),
(1863,'CLTX FEM FX PROX END NCK W/O MANJ','CLTX FEM FX PROX END NCK W/O MANJ','27230','1','','1','0','','','',0, 1, 0, 0),
(1864,'CLTX FEM FX PROX END NCK W/MANJ W/WO SKEL TRACJ','CLTX FEM FX PROX END NCK W/MANJ W/WO SKEL TRACJ','27232','1','','1','0','','','',0, 1, 0, 0),
(1865,'PRQ SKEL FIXJ FEMORAL FX PROX END NECK','PRQ SKEL FIXJ FEMORAL FX PROX END NECK','27235','1','','1','0','','','',0, 1, 0, 0),
(1866,'OPTX FEM FX PROX END NCK INT FIXJ/PROSTC RPLCMT','OPTX FEM FX PROX END NCK INT FIXJ/PROSTC RPLCMT','27236','1','','1','0','','','',0, 1, 0, 0),
(1867,'CLTX INTER/PERI/SUBTROCHANTERIC FEM FX W/O MANJ','CLTX INTER/PERI/SUBTROCHANTERIC FEM FX W/O MANJ','27238','1','','1','0','','','',0, 1, 0, 0),
(1868,'CLTX INTR/PERI/SBTRCHNTC FEMORAL FX W/MANJ','CLTX INTR/PERI/SBTRCHNTC FEMORAL FX W/MANJ','27240','1','','1','0','','','',0, 1, 0, 0),
(1869,'TX INTER/PR/SUBTRCHNTRIC FEMORAL FX SCREW IMPLT','TX INTER/PR/SUBTRCHNTRIC FEMORAL FX SCREW IMPLT','27244','1','','1','0','','','',0, 1, 0, 0),
(1870,'TX INTER/PR/SUBTRCHNTRIC FEM FX IMED IMPLTSCREW','TX INTER/PR/SUBTRCHNTRIC FEM FX IMED IMPLTSCREW','27245','1','','1','0','','','',0, 1, 0, 0),
(1871,'CLTX GREATER TROCHANTERIC FX W/O MANJ','CLTX GREATER TROCHANTERIC FX W/O MANJ','27246','1','','1','0','','','',0, 1, 0, 0),
(1872,'OPEN TREATMENT GREATER TROCHANTERIC FRACTURE','OPEN TREATMENT GREATER TROCHANTERIC FRACTURE','27248','1','','1','0','','','',0, 1, 0, 0),
(1873,'CLTX HIP DISLOCATION TRAUMATIC W/O ANESTHESIA','CLTX HIP DISLOCATION TRAUMATIC W/O ANESTHESIA','27250','1','','1','0','','','',0, 1, 0, 0),
(1874,'CLTX HIP DISLOCATION TRAUMATIC REQ ANESTHESIA','CLTX HIP DISLOCATION TRAUMATIC REQ ANESTHESIA','27252','1','','1','0','','','',0, 1, 0, 0),
(1875,'OPTX HIP DISLOCATION TRAUMATIC W/O INTERNAL FIXJ','OPTX HIP DISLOCATION TRAUMATIC W/O INTERNAL FIXJ','27253','1','','1','0','','','',0, 1, 0, 0),
(1876,'OPTX HIP DISLC TRAUMTC W/ACTBLR WALL&FEM HEAD','OPTX HIP DISLC TRAUMTC W/ACTBLR WALL&FEM HEAD','27254','1','','1','0','','','',0, 1, 0, 0),
(1877,'TX SPONTAN HIP DISLC ABDCT SPLNT/TRCJ W/O ANES','TX SPONTAN HIP DISLC ABDCT SPLNT/TRCJ W/O ANES','27256','1','','1','0','','','',0, 1, 0, 0),
(1878,'TX SPON HIP DISLC ABDCT SPLNT/TRCJ W/MANJ ANES','TX SPON HIP DISLC ABDCT SPLNT/TRCJ W/MANJ ANES','27257','1','','1','0','','','',0, 1, 0, 0),
(1879,'OPTX SPON HIP DISLC RPLCMT FEM HEAD ACTBLM','OPTX SPON HIP DISLC RPLCMT FEM HEAD ACTBLM','27258','1','','1','0','','','',0, 1, 0, 0),
(1880,'OPTX SPON HIP DISLC RPLCMT FEM HEAD ACTBLM SHRT','OPTX SPON HIP DISLC RPLCMT FEM HEAD ACTBLM SHRT','27259','1','','1','0','','','',0, 1, 0, 0),
(1881,'CLTX POST HIP ARTHRP DISLC W/O ANES','CLTX POST HIP ARTHRP DISLC W/O ANES','27265','1','','1','0','','','',0, 1, 0, 0),
(1882,'CLTX POST HIP ARTHRP DISLC REQ ANES','CLTX POST HIP ARTHRP DISLC REQ ANES','27266','1','','1','0','','','',0, 1, 0, 0),
(1883,'CLOSED TX FEMORAL FRACTURE PROX HEAD W/O MANJ','CLOSED TX FEMORAL FRACTURE PROX HEAD W/O MANJ','27267','1','','1','0','','','',0, 1, 0, 0),
(1884,'CLOSED TX FEMORAL FRACTURE PROX HEAD W/MANJ','CLOSED TX FEMORAL FRACTURE PROX HEAD W/MANJ','27268','1','','1','0','','','',0, 1, 0, 0),
(1885,'OPEN TX FEMORAL FRACTURE PROXIMAL END HEAD','OPEN TX FEMORAL FRACTURE PROXIMAL END HEAD','27269','1','','1','0','','','',0, 1, 0, 0),
(1886,'MANIPULATION HIP JOINT GENERAL ANESTHESIA','MANIPULATION HIP JOINT GENERAL ANESTHESIA','27275','1','','1','0','','','',0, 1, 0, 0),
(1887,'ARTHRODESIS SACROILIAC JOINT PERCUTANEOUS','ARTHRODESIS SACROILIAC JOINT PERCUTANEOUS','27279','1','','1','0','','','',0, 1, 0, 0),
(1888,'ARTHRODESIS SACROILIAC JOINT W/OBTAINING GRAFT','ARTHRODESIS SACROILIAC JOINT W/OBTAINING GRAFT','27280','1','','1','0','','','',0, 1, 0, 0),
(1889,'ARTHRODESIS SYMPHYSIS PUBIS W/OBTAINING GRAFT','ARTHRODESIS SYMPHYSIS PUBIS W/OBTAINING GRAFT','27282','1','','1','0','','','',0, 1, 0, 0),
(1890,'ARTHRODESIS HIP JOINT W/OBTAINING GRAFT','ARTHRODESIS HIP JOINT W/OBTAINING GRAFT','27284','1','','1','0','','','',0, 1, 0, 0),
(1891,'ARTHRD HIP JT W/OBTG GRF W/SUBTRCHNTRIC OSTEOT','ARTHRD HIP JT W/OBTG GRF W/SUBTRCHNTRIC OSTEOT','27286','1','','1','0','','','',0, 1, 0, 0),
(1892,'INTERPELVIABDOMINAL AMPUTATION','INTERPELVIABDOMINAL AMPUTATION','27290','1','','1','0','','','',0, 1, 0, 0),
(1893,'DISARTICULATION HIP','DISARTICULATION HIP','27295','1','','1','0','','','',0, 1, 0, 0),
(1894,'UNLISTED PROCEDURE PELVIS/HIP JOINT','UNLISTED PROCEDURE PELVIS/HIP JOINT','27299','1','','1','0','','','',0, 1, 0, 0),
(1895,'I&D DEEP ABSC BURSA/HEMATOMA THIGH/KNEE REGION','I&D DEEP ABSC BURSA/HEMATOMA THIGH/KNEE REGION','27301','1','','1','0','','','',0, 1, 0, 0),
(1896,'INC DEEP W/OPNG BONE CORTEX FEMUR/KNEE','INC DEEP W/OPNG BONE CORTEX FEMUR/KNEE','27303','1','','1','0','','','',0, 1, 0, 0),
(1897,'FASCIOTOMY ILIOTIBIAL OPEN','FASCIOTOMY ILIOTIBIAL OPEN','27305','1','','1','0','','','',0, 1, 0, 0),
(1898,'TENOTOMY PRQ ADDUCTOR/HAMSTRING 1 TENDON SPX','TENOTOMY PRQ ADDUCTOR/HAMSTRING 1 TENDON SPX','27306','1','','1','0','','','',0, 1, 0, 0),
(1899,'TENOTOMY PRQ ADDUCTOR/HAMSTRING MULTIPLE TENDON','TENOTOMY PRQ ADDUCTOR/HAMSTRING MULTIPLE TENDON','27307','1','','1','0','','','',0, 1, 0, 0),
(1900,'ARTHRT KNE W/EXPL DRG/RMVL FB','ARTHRT KNE W/EXPL DRG/RMVL FB','27310','1','','1','0','','','',0, 1, 0, 0),
(1901,'BIOPSY SOFT TISSUE THIGH/KNEE AREA SUPERFICIAL','BIOPSY SOFT TISSUE THIGH/KNEE AREA SUPERFICIAL','27323','1','','1','0','','','',0, 1, 0, 0),
(1902,'BIOPSY SOFT TISSUE THIGH/KNEE AREA DEEP','BIOPSY SOFT TISSUE THIGH/KNEE AREA DEEP','27324','1','','1','0','','','',0, 1, 0, 0),
(1903,'NEURECTOMY HAMSTRING MUSCLE','NEURECTOMY HAMSTRING MUSCLE','27325','1','','1','0','','','',0, 1, 0, 0),
(1904,'NEURECTOMY POPLITEAL','NEURECTOMY POPLITEAL','27326','1','','1','0','','','',0, 1, 0, 0),
(1905,'EXCISION TUMOR SOFT TISSUE THIGH/KNEE SUBQ <3CM','EXCISION TUMOR SOFT TISSUE THIGH/KNEE SUBQ <3CM','27327','1','','1','0','','','',0, 1, 0, 0),
(1906,'EXC TUMOR SOFT TISSUE THIGH/KNEE SUBFASC <5CM','EXC TUMOR SOFT TISSUE THIGH/KNEE SUBFASC <5CM','27328','1','','1','0','','','',0, 1, 0, 0),
(1907,'RAD RESECT TUMOR SOFT TISSUE THIGH/KNEE <5CM','RAD RESECT TUMOR SOFT TISSUE THIGH/KNEE <5CM','27329','1','','1','0','','','',0, 1, 0, 0),
(1908,'ARTHROTOMY KNEE W/SYNOVIAL BIOPSY ONLY','ARTHROTOMY KNEE W/SYNOVIAL BIOPSY ONLY','27330','1','','1','0','','','',0, 1, 0, 0),
(1909,'ARTHRT KNE W/JT EXPL BX/RMVL LOOSE/FB','ARTHRT KNE W/JT EXPL BX/RMVL LOOSE/FB','27331','1','','1','0','','','',0, 1, 0, 0),
(1910,'ARTHRT W/EXC SEMILUNAR CRTLG KNEE MEDIAL/LAT','ARTHRT W/EXC SEMILUNAR CRTLG KNEE MEDIAL/LAT','27332','1','','1','0','','','',0, 1, 0, 0),
(1911,'ARTHRT W/EXC SEMILUNAR CRTLG KNEE MEDIAL&LAT','ARTHRT W/EXC SEMILUNAR CRTLG KNEE MEDIAL&LAT','27333','1','','1','0','','','',0, 1, 0, 0),
(1912,'ARTHROTOMY W/SYNOVECTOMY KNEE ANTERIOR/POSTERIOR','ARTHROTOMY W/SYNOVECTOMY KNEE ANTERIOR/POSTERIOR','27334','1','','1','0','','','',0, 1, 0, 0),
(1913,'ARTHRT W/SYNVCT KNE ANT&POST W/POP AREA','ARTHRT W/SYNVCT KNE ANT&POST W/POP AREA','27335','1','','1','0','','','',0, 1, 0, 0),
(1914,'EXCISON TUMOR SOFT TISSUE THIGH/KNEE SUBQ 3 CM/>','EXCISON TUMOR SOFT TISSUE THIGH/KNEE SUBQ 3 CM/>','27337','1','','1','0','','','',0, 1, 0, 0),
(1915,'EXC TUMOR SOFT TISSUE THIGH/KNEE SUBFASC 5 CM/>','EXC TUMOR SOFT TISSUE THIGH/KNEE SUBFASC 5 CM/>','27339','1','','1','0','','','',0, 1, 0, 0),
(1916,'EXCISION PREPATELLAR BURSA','EXCISION PREPATELLAR BURSA','27340','1','','1','0','','','',0, 1, 0, 0),
(1917,'EXCISION SYNOVIAL CYST POPLITEAL SPACE','EXCISION SYNOVIAL CYST POPLITEAL SPACE','27345','1','','1','0','','','',0, 1, 0, 0),
(1918,'EXCISION LESION MENISCUS/CAPSULE KNEE','EXCISION LESION MENISCUS/CAPSULE KNEE','27347','1','','1','0','','','',0, 1, 0, 0),
(1919,'PATELLECTOMY/HEMIPATELLECTOMY','PATELLECTOMY/HEMIPATELLECTOMY','27350','1','','1','0','','','',0, 1, 0, 0),
(1920,'EXCISION/CURETTAGE CYST/TUMOR FEMUR','EXCISION/CURETTAGE CYST/TUMOR FEMUR','27355','1','','1','0','','','',0, 1, 0, 0),
(1921,'EXCISION/CURETTAGE CYST/TUMOR FEMUR W/ALLOGRAFT','EXCISION/CURETTAGE CYST/TUMOR FEMUR W/ALLOGRAFT','27356','1','','1','0','','','',0, 1, 0, 0),
(1922,'EXCISION/CURETTAGE CYST/TUMOR FEMUR W/AUTOGRAFT','EXCISION/CURETTAGE CYST/TUMOR FEMUR W/AUTOGRAFT','27357','1','','1','0','','','',0, 1, 0, 0),
(1923,'EXCISION/CURETTAGE CYST/TUMOR FEMUR INT FIXATION','EXCISION/CURETTAGE CYST/TUMOR FEMUR INT FIXATION','27358','1','','1','0','','','',0, 1, 0, 0),
(1924,'PRTL EXC BONE FEMUR PROX TIBIA&/FIBULA','PRTL EXC BONE FEMUR PROX TIBIA&/FIBULA','27360','1','','1','0','','','',0, 1, 0, 0),
(1925,'RAD RESECTION TUMOR SOFT TIS THIGH/KNEE 5 CM/>','RAD RESECTION TUMOR SOFT TIS THIGH/KNEE 5 CM/>','27364','1','','1','0','','','',0, 1, 0, 0),
(1926,'RADICAL RESECTION TUMOR FEMOR OR KNEE','RADICAL RESECTION TUMOR FEMOR OR KNEE','27365','1','','1','0','','','',0, 1, 0, 0),
(1927,'INJECTION KNEE ARTHROGRAPHY','INJECTION KNEE ARTHROGRAPHY','27370','1','','1','0','','','',0, 1, 0, 0),
(1928,'REMOVAL FOREIGN BODY DEEP THIGH/KNEE','REMOVAL FOREIGN BODY DEEP THIGH/KNEE','27372','1','','1','0','','','',0, 1, 0, 0),
(1929,'SUTURE INFRAPATELLAR TENDON PRIMARY','SUTURE INFRAPATELLAR TENDON PRIMARY','27380','1','','1','0','','','',0, 1, 0, 0),
(1930,'SUTR INFRAPATELLAR TDN 2 RCNSTJ W/FSCAL/TDN GRF','SUTR INFRAPATELLAR TDN 2 RCNSTJ W/FSCAL/TDN GRF','27381','1','','1','0','','','',0, 1, 0, 0),
(1931,'SUTURE QUADRICEPS/HAMSTRING RUPTURE PRIMARY','SUTURE QUADRICEPS/HAMSTRING RUPTURE PRIMARY','27385','1','','1','0','','','',0, 1, 0, 0),
(1932,'SUTR QUADRICEPS/HAMSTRING MUSC RPT RCNSTJ','SUTR QUADRICEPS/HAMSTRING MUSC RPT RCNSTJ','27386','1','','1','0','','','',0, 1, 0, 0),
(1933,'TENOTOMY OPEN HAMSTRING KNEE HIP SINGLE TENDON','TENOTOMY OPEN HAMSTRING KNEE HIP SINGLE TENDON','27390','1','','1','0','','','',0, 1, 0, 0),
(1934,'TENOTOMY OPN HAMSTRING KNEE HIP MULTIPLE 1 LEG','TENOTOMY OPN HAMSTRING KNEE HIP MULTIPLE 1 LEG','27391','1','','1','0','','','',0, 1, 0, 0),
(1935,'TENOTOMY OPEN HAMSTRING KNEE HIP MULTIPLE BI','TENOTOMY OPEN HAMSTRING KNEE HIP MULTIPLE BI','27392','1','','1','0','','','',0, 1, 0, 0),
(1936,'LENGTHENING HAMSTRING TENDON SINGLE','LENGTHENING HAMSTRING TENDON SINGLE','27393','1','','1','0','','','',0, 1, 0, 0),
(1937,'LENGTHENING HAMSTRING TENDON MULTIPLE 1 LEG','LENGTHENING HAMSTRING TENDON MULTIPLE 1 LEG','27394','1','','1','0','','','',0, 1, 0, 0),
(1938,'LENGTHENING HAMSTRING TENDON MULTIPLE BILATERAL','LENGTHENING HAMSTRING TENDON MULTIPLE BILATERAL','27395','1','','1','0','','','',0, 1, 0, 0),
(1939,'TRANSPLANT/TRANSFER THIGH XTNSR TO FLXR 1 TENDON','TRANSPLANT/TRANSFER THIGH XTNSR TO FLXR 1 TENDON','27396','1','','1','0','','','',0, 1, 0, 0),
(1940,'TRANSPLANT/TRANSFER THIGH XTNSR TO FLXR MULT TDN','TRANSPLANT/TRANSFER THIGH XTNSR TO FLXR MULT TDN','27397','1','','1','0','','','',0, 1, 0, 0),
(1941,'TRANSFER TENDON/MUSCLE HAMSTRINGS FEMUR','TRANSFER TENDON/MUSCLE HAMSTRINGS FEMUR','27400','1','','1','0','','','',0, 1, 0, 0),
(1942,'ARTHROTOMY W/MENISCUS REPAIR KNEE','ARTHROTOMY W/MENISCUS REPAIR KNEE','27403','1','','1','0','','','',0, 1, 0, 0),
(1943,'RPR PRIMARY TORN LIGM&/CAPSULE KNEE COLLATERAL','RPR PRIMARY TORN LIGM&/CAPSULE KNEE COLLATERAL','27405','1','','1','0','','','',0, 1, 0, 0),
(1944,'REPAIR PRIMARY TORN LIGM&/CAPSULE KNEE CRUCIAT','REPAIR PRIMARY TORN LIGM&/CAPSULE KNEE CRUCIAT','27407','1','','1','0','','','',0, 1, 0, 0),
(1945,'RPR 1 TORN LIGM&/CAPSL KNE COLTRL&CRUCIATE','RPR 1 TORN LIGM&/CAPSL KNE COLTRL&CRUCIATE','27409','1','','1','0','','','',0, 1, 0, 0),
(1946,'AUTOLOGOUS CHONDROCYTE IMPLANTATION KNEE','AUTOLOGOUS CHONDROCYTE IMPLANTATION KNEE','27412','1','','1','0','','','',0, 1, 0, 0),
(1947,'OSTEOCHONDRAL ALLOGRAFT KNEE OPEN','OSTEOCHONDRAL ALLOGRAFT KNEE OPEN','27415','1','','1','0','','','',0, 1, 0, 0),
(1948,'OSTEOCHONDRAL AUTOGRAFT KNEE OPEN MOSAICPLASTY','OSTEOCHONDRAL AUTOGRAFT KNEE OPEN MOSAICPLASTY','27416','1','','1','0','','','',0, 1, 0, 0),
(1949,'ANTERIOR TIBIAL TUBERCLEPLASTY','ANTERIOR TIBIAL TUBERCLEPLASTY','27418','1','','1','0','','','',0, 1, 0, 0),
(1950,'RCNSTJ DISLOCATING PATELLA','RCNSTJ DISLOCATING PATELLA','27420','1','','1','0','','','',0, 1, 0, 0),
(1951,'RCNSTJ DISLC PATELLA W/XTNSR RELIGNMT&/MUSC RL','RCNSTJ DISLC PATELLA W/XTNSR RELIGNMT&/MUSC RL','27422','1','','1','0','','','',0, 1, 0, 0),
(1952,'RCNSTJ DISLC PATELLA W/PATELLECTOMY','RCNSTJ DISLC PATELLA W/PATELLECTOMY','27424','1','','1','0','','','',0, 1, 0, 0),
(1953,'LATERAL RETINACULAR RELEASE OPEN','LATERAL RETINACULAR RELEASE OPEN','27425','1','','1','0','','','',0, 1, 0, 0),
(1954,'LIGAMENTOUS RECONSTRUCTION KNEE EXTRA-ARTICULAR','LIGAMENTOUS RECONSTRUCTION KNEE EXTRA-ARTICULAR','27427','1','','1','0','','','',0, 1, 0, 0),
(1955,'LIGAMENTOUS RECONSTRUCTION KNEE INTRA-ARTICULAR','LIGAMENTOUS RECONSTRUCTION KNEE INTRA-ARTICULAR','27428','1','','1','0','','','',0, 1, 0, 0),
(1956,'LIGMOUS RCNSTJ AGMNTJ KNE INTRA-ARTICULAR XTR','LIGMOUS RCNSTJ AGMNTJ KNE INTRA-ARTICULAR XTR','27429','1','','1','0','','','',0, 1, 0, 0),
(1957,'QUADRICEPSPLASTY','QUADRICEPSPLASTY','27430','1','','1','0','','','',0, 1, 0, 0),
(1958,'CAPSULOTOMY POSTERIOR CAPSULAR RELEASE KNEE','CAPSULOTOMY POSTERIOR CAPSULAR RELEASE KNEE','27435','1','','1','0','','','',0, 1, 0, 0),
(1959,'ARTHROPLASTY PATELLA W/O PROSTHESIS','ARTHROPLASTY PATELLA W/O PROSTHESIS','27437','1','','1','0','','','',0, 1, 0, 0),
(1960,'ARTHROPLASTY PATELLA W/PROSTHESIS','ARTHROPLASTY PATELLA W/PROSTHESIS','27438','1','','1','0','','','',0, 1, 0, 0),
(1961,'ARTHROPLASTY KNEE TIBIAL PLATEAU','ARTHROPLASTY KNEE TIBIAL PLATEAU','27440','1','','1','0','','','',0, 1, 0, 0),
(1962,'ARTHRP KNEE TIBIAL PLATEAU DBRDMT&PRTL SYNVCT','ARTHRP KNEE TIBIAL PLATEAU DBRDMT&PRTL SYNVCT','27441','1','','1','0','','','',0, 1, 0, 0),
(1963,'ARTHROPLASTY FEM CONDYLES/TIBIAL PLATEAU KNEE','ARTHROPLASTY FEM CONDYLES/TIBIAL PLATEAU KNEE','27442','1','','1','0','','','',0, 1, 0, 0),
(1964,'ARTHRP FEM CONDYLES/TIBL PLATU KNE DBRDMT&PRTL','ARTHRP FEM CONDYLES/TIBL PLATU KNE DBRDMT&PRTL','27443','1','','1','0','','','',0, 1, 0, 0),
(1965,'ARTHROPLASTY KNEE HINGE PROSTHESIS','ARTHROPLASTY KNEE HINGE PROSTHESIS','27445','1','','1','0','','','',0, 1, 0, 0),
(1966,'ARTHRP KNEE CONDYLE&PLATEAU MEDIAL/LAT CMPRT','ARTHRP KNEE CONDYLE&PLATEAU MEDIAL/LAT CMPRT','27446','1','','1','0','','','',0, 1, 0, 0),
(1967,'ARTHRP KNE CONDYLE&PLATU MEDIAL&LAT COMPARTMENTS','ARTHRP KNE CONDYLE&PLATU MEDIAL&LAT COMPARTMENTS','27447','1','','1','0','','','',0, 1, 0, 0),
(1968,'OSTEOTOMY FEMUR SHAFT/SUPRACONDYLAR W/O FIXATION','OSTEOTOMY FEMUR SHAFT/SUPRACONDYLAR W/O FIXATION','27448','1','','1','0','','','',0, 1, 0, 0),
(1969,'OSTEOTOMY FEMUR SHAFT/SUPRACONDYLAR W/FIXATION','OSTEOTOMY FEMUR SHAFT/SUPRACONDYLAR W/FIXATION','27450','1','','1','0','','','',0, 1, 0, 0),
(1970,'OSTEOT MLT W/RELIGNMT IMED ROD FEM SHFT','OSTEOT MLT W/RELIGNMT IMED ROD FEM SHFT','27454','1','','1','0','','','',0, 1, 0, 0),
(1971,'OSTEOT PROX TIBIA FIB EXC/OSTEOT BEFORE EPIPHYSL','OSTEOT PROX TIBIA FIB EXC/OSTEOT BEFORE EPIPHYSL','27455','1','','1','0','','','',0, 1, 0, 0),
(1972,'OSTEOT PROX TIBIA FIB EXC/OSTEOT AFTER EPIPHYSL','OSTEOT PROX TIBIA FIB EXC/OSTEOT AFTER EPIPHYSL','27457','1','','1','0','','','',0, 1, 0, 0),
(1973,'OSTEOPLASTY FEMUR SHORTENING EXCLUDING 64876','OSTEOPLASTY FEMUR SHORTENING EXCLUDING 64876','27465','1','','1','0','','','',0, 1, 0, 0),
(1974,'OSTEOPLASTY FEMUR LENGTHENING','OSTEOPLASTY FEMUR LENGTHENING','27466','1','','1','0','','','',0, 1, 0, 0),
(1975,'OSTPL FEMUR CMBN LNGTH&SHRT W/FEMORAL SGM TRNSFR','OSTPL FEMUR CMBN LNGTH&SHRT W/FEMORAL SGM TRNSFR','27468','1','','1','0','','','',0, 1, 0, 0),
(1976,'RPR NON/MAL FEMUR DSTL H/N W/O GRF','RPR NON/MAL FEMUR DSTL H/N W/O GRF','27470','1','','1','0','','','',0, 1, 0, 0),
(1977,'RPR NON/MAL FEMUR DSTL H/N W/ILIAC/AUTOG BONE','RPR NON/MAL FEMUR DSTL H/N W/ILIAC/AUTOG BONE','27472','1','','1','0','','','',0, 1, 0, 0),
(1978,'ARREST EPIPHYSEAL DISTAL FEMUR','ARREST EPIPHYSEAL DISTAL FEMUR','27475','1','','1','0','','','',0, 1, 0, 0),
(1979,'ARREST EPIPHYSEAL TIBIA & FIBULA PROXIMAL','ARREST EPIPHYSEAL TIBIA & FIBULA PROXIMAL','27477','1','','1','0','','','',0, 1, 0, 0),
(1980,'ARRST EPIPHYSL CMBN DSTL FEMUR PROX TIBFIB','ARRST EPIPHYSL CMBN DSTL FEMUR PROX TIBFIB','27479','1','','1','0','','','',0, 1, 0, 0),
(1981,'ARRST HEMIEPIPHYSL DSTL FEMUR/PROX TIBIA/FIBULA','ARRST HEMIEPIPHYSL DSTL FEMUR/PROX TIBIA/FIBULA','27485','1','','1','0','','','',0, 1, 0, 0),
(1982,'REVJ TOTAL KNEE ARTHRP W/WO ALGRFT 1 COMPONENT','REVJ TOTAL KNEE ARTHRP W/WO ALGRFT 1 COMPONENT','27486','1','','1','0','','','',0, 1, 0, 0),
(1983,'REVJ TOT KNEE ARTHRP FEM&ENTIRE TIBIAL COMPONE','REVJ TOT KNEE ARTHRP FEM&ENTIRE TIBIAL COMPONE','27487','1','','1','0','','','',0, 1, 0, 0),
(1984,'RMVL PROSTH TOT KNEE PROSTH MMA W/WO INSJ SPACER','RMVL PROSTH TOT KNEE PROSTH MMA W/WO INSJ SPACER','27488','1','','1','0','','','',0, 1, 0, 0),
(1985,'PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE FEMUR','PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE FEMUR','27495','1','','1','0','','','',0, 1, 0, 0),
(1986,'DECOMPRESSION FASCIOTOMY THIGH&/KNEE 1 COMPONENT','DECOMPRESSION FASCIOTOMY THIGH&/KNEE 1 COMPONENT','27496','1','','1','0','','','',0, 1, 0, 0),
(1987,'DCMPRN FASCT THIGH&/KNEE DBRDMT MUSCLE&/NERVE','DCMPRN FASCT THIGH&/KNEE DBRDMT MUSCLE&/NERVE','27497','1','','1','0','','','',0, 1, 0, 0),
(1988,'DCMPRN FASCIOTOMY THIGH&/KNEE MLT COMPARTMENTS','DCMPRN FASCIOTOMY THIGH&/KNEE MLT COMPARTMENTS','27498','1','','1','0','','','',0, 1, 0, 0),
(1989,'DCMPRN FASCT THIGH&/KNEE MLT DBRDMT NV MUSC&NRVE','DCMPRN FASCT THIGH&/KNEE MLT DBRDMT NV MUSC&NRVE','27499','1','','1','0','','','',0, 1, 0, 0),
(1990,'CLOSED TX FEMORAL SHAFT FX W/O MANIPULATION','CLOSED TX FEMORAL SHAFT FX W/O MANIPULATION','27500','1','','1','0','','','',0, 1, 0, 0),
(1991,'CLTX SPRCNDYLR/TRNSCNDYLR FEM FX W/O MANJ','CLTX SPRCNDYLR/TRNSCNDYLR FEM FX W/O MANJ','27501','1','','1','0','','','',0, 1, 0, 0),
(1992,'CLTX FEM SHFT FX W/MANJ W/WO SKIN/SKELETAL TRACJ','CLTX FEM SHFT FX W/MANJ W/WO SKIN/SKELETAL TRACJ','27502','1','','1','0','','','',0, 1, 0, 0),
(1993,'CLTX SPRCNDYLR/TRNSCNDYLR FEM FX W/MANJ','CLTX SPRCNDYLR/TRNSCNDYLR FEM FX W/MANJ','27503','1','','1','0','','','',0, 1, 0, 0),
(1994,'OPTX FEM SHFT FX W/INSJ IMED IMPLT W/WO SCREW','OPTX FEM SHFT FX W/INSJ IMED IMPLT W/WO SCREW','27506','1','','1','0','','','',0, 1, 0, 0),
(1995,'OPTX FEM SHFT FX W/PLATE/SCREWS W/WO CERCLAGE','OPTX FEM SHFT FX W/PLATE/SCREWS W/WO CERCLAGE','27507','1','','1','0','','','',0, 1, 0, 0),
(1996,'CLTX FEM FX DSTL END MEDIAL/LAT CONDYLE W/O MANJ','CLTX FEM FX DSTL END MEDIAL/LAT CONDYLE W/O MANJ','27508','1','','1','0','','','',0, 1, 0, 0),
(1997,'PRQ SKELETAL FIXJ FEMORAL FX DISTAL END','PRQ SKELETAL FIXJ FEMORAL FX DISTAL END','27509','1','','1','0','','','',0, 1, 0, 0),
(1998,'CLTX FEM FX DSTL END MEDIAL/LAT CONDYLE W/MANJ','CLTX FEM FX DSTL END MEDIAL/LAT CONDYLE W/MANJ','27510','1','','1','0','','','',0, 1, 0, 0),
(1999,'OPEN TX FEMORAL SUPRACONDYLAR FRACTURE W/O XTN','OPEN TX FEMORAL SUPRACONDYLAR FRACTURE W/O XTN','27511','1','','1','0','','','',0, 1, 0, 0),
(2000,'OPEN TX FEMORAL SUPRACONDYLAR FRACTURE W/XTN','OPEN TX FEMORAL SUPRACONDYLAR FRACTURE W/XTN','27513','1','','1','0','','','',0, 1, 0, 0),
(2001,'OPEN TX FEMORAL FRACTURE DISTAL MED/LAT CONDYLE','OPEN TX FEMORAL FRACTURE DISTAL MED/LAT CONDYLE','27514','1','','1','0','','','',0, 1, 0, 0),
(2002,'CLTX DISTAL FEMORAL EPIPHYSL SEPARATION W/O MANJ','CLTX DISTAL FEMORAL EPIPHYSL SEPARATION W/O MANJ','27516','1','','1','0','','','',0, 1, 0, 0),
(2003,'CLTX DSTL FEM EPIPHYSL SEP W/MANJ W/WO SKIN/SKEL','CLTX DSTL FEM EPIPHYSL SEP W/MANJ W/WO SKIN/SKEL','27517','1','','1','0','','','',0, 1, 0, 0),
(2004,'OPEN TX DISTAL FEMORAL EPIPHYSEAL SEPARATION','OPEN TX DISTAL FEMORAL EPIPHYSEAL SEPARATION','27519','1','','1','0','','','',0, 1, 0, 0),
(2005,'CLOSED TX PATELLAR FRACTURE W/O MANIPULATION','CLOSED TX PATELLAR FRACTURE W/O MANIPULATION','27520','1','','1','0','','','',0, 1, 0, 0),
(2006,'OPTX PATLLR FX W/INT FIXJ/PATLLC&SOFT TISS RPR','OPTX PATLLR FX W/INT FIXJ/PATLLC&SOFT TISS RPR','27524','1','','1','0','','','',0, 1, 0, 0),
(2007,'CLTX TIBIAL FX PROXIMAL W/O MANIPULATION','CLTX TIBIAL FX PROXIMAL W/O MANIPULATION','27530','1','','1','0','','','',0, 1, 0, 0),
(2008,'CLTX TIBIAL FX PROXIMAL W/WO MANJ W/SKEL TRACJ','CLTX TIBIAL FX PROXIMAL W/WO MANJ W/SKEL TRACJ','27532','1','','1','0','','','',0, 1, 0, 0),
(2009,'OPEN TX TIBIAL FRACTURE PROXIMAL UNICONDYLAR','OPEN TX TIBIAL FRACTURE PROXIMAL UNICONDYLAR','27535','1','','1','0','','','',0, 1, 0, 0),
(2010,'OPTX TIBIAL FX PROX BICONDYLAR W/WO INT FIXJ','OPTX TIBIAL FX PROX BICONDYLAR W/WO INT FIXJ','27536','1','','1','0','','','',0, 1, 0, 0),
(2011,'CLTX INTERCONDYLAR SPI&/TUBRST FX KNE W/WO MAN','CLTX INTERCONDYLAR SPI&/TUBRST FX KNE W/WO MAN','27538','1','','1','0','','','',0, 1, 0, 0),
(2012,'OPEN TX INTERCONDYLAR SPINE/TUBRST FRACTURE KNEE','OPEN TX INTERCONDYLAR SPINE/TUBRST FRACTURE KNEE','27540','1','','1','0','','','',0, 1, 0, 0),
(2013,'CLOSED TX KNEE DISLOCATION W/O ANESTHESIA','CLOSED TX KNEE DISLOCATION W/O ANESTHESIA','27550','1','','1','0','','','',0, 1, 0, 0),
(2014,'CLOSED TX KNEE DISLOCATION W/ANESTHESIA','CLOSED TX KNEE DISLOCATION W/ANESTHESIA','27552','1','','1','0','','','',0, 1, 0, 0),
(2015,'OPEN TX KNEE DISLOCATION W/O LIGAMENTOUS REPAIR','OPEN TX KNEE DISLOCATION W/O LIGAMENTOUS REPAIR','27556','1','','1','0','','','',0, 1, 0, 0),
(2016,'OPEN TX KNEE DISLOCATION W/LIGAMENTOUS REPAIR','OPEN TX KNEE DISLOCATION W/LIGAMENTOUS REPAIR','27557','1','','1','0','','','',0, 1, 0, 0),
(2017,'OPEN TX KNEE DISLOCATION W/REPAIR/RECONSTRUCTION','OPEN TX KNEE DISLOCATION W/REPAIR/RECONSTRUCTION','27558','1','','1','0','','','',0, 1, 0, 0),
(2018,'CLOSED TX PATELLAR DISLOCATION W/O ANESTHESIA','CLOSED TX PATELLAR DISLOCATION W/O ANESTHESIA','27560','1','','1','0','','','',0, 1, 0, 0),
(2019,'CLOSED TX PATELLAR DISLOCATION W/ANESTHESIA','CLOSED TX PATELLAR DISLOCATION W/ANESTHESIA','27562','1','','1','0','','','',0, 1, 0, 0),
(2020,'OPTX PATELLAR DISLC W/WO PRTL/TOT PATELLECTOMY','OPTX PATELLAR DISLC W/WO PRTL/TOT PATELLECTOMY','27566','1','','1','0','','','',0, 1, 0, 0),
(2021,'MANIPULATION KNEE JOINT UNDER GENERAL ANESTHESIA','MANIPULATION KNEE JOINT UNDER GENERAL ANESTHESIA','27570','1','','1','0','','','',0, 1, 0, 0),
(2022,'ARTHRODESIS KNEE ANY TECHNIQUE','ARTHRODESIS KNEE ANY TECHNIQUE','27580','1','','1','0','','','',0, 1, 0, 0),
(2023,'AMPUTATION THIGH THROUGH FEMUR ANY LEVEL','AMPUTATION THIGH THROUGH FEMUR ANY LEVEL','27590','1','','1','0','','','',0, 1, 0, 0),
(2024,'AMP THI THRU FEMUR LVL IMMT FITG TQ W/1ST CST','AMP THI THRU FEMUR LVL IMMT FITG TQ W/1ST CST','27591','1','','1','0','','','',0, 1, 0, 0),
(2025,'AMPUTATION THIGH THRU FEMUR OPEN CIRCULAR','AMPUTATION THIGH THRU FEMUR OPEN CIRCULAR','27592','1','','1','0','','','',0, 1, 0, 0),
(2026,'AMP THIGH THRU FEMUR SEC CLOSURE/SCAR REVISION','AMP THIGH THRU FEMUR SEC CLOSURE/SCAR REVISION','27594','1','','1','0','','','',0, 1, 0, 0),
(2027,'AMPUTATION THIGH THROUGH FEMUR RE-AMPUTATION','AMPUTATION THIGH THROUGH FEMUR RE-AMPUTATION','27596','1','','1','0','','','',0, 1, 0, 0),
(2028,'DISARTICULATION KNEE','DISARTICULATION KNEE','27598','1','','1','0','','','',0, 1, 0, 0),
(2029,'UNLISTED PROCEDURE FEMUR/KNEE','UNLISTED PROCEDURE FEMUR/KNEE','27599','1','','1','0','','','',0, 1, 0, 0),
(2030,'DCMPRN FASCT LEG ANT&/LAT COMPARTMENTS ONLY','DCMPRN FASCT LEG ANT&/LAT COMPARTMENTS ONLY','27600','1','','1','0','','','',0, 1, 0, 0),
(2031,'DCMPRN FASCT LEG POST COMPARTMENT ONLY','DCMPRN FASCT LEG POST COMPARTMENT ONLY','27601','1','','1','0','','','',0, 1, 0, 0),
(2032,'DCMPRN FASCT LEG ANT&/LAT&PST CMPRT','DCMPRN FASCT LEG ANT&/LAT&PST CMPRT','27602','1','','1','0','','','',0, 1, 0, 0),
(2033,'INCISION & DRAINAGE LEG/ANKLE ABSCESS/HEMATOMA','INCISION & DRAINAGE LEG/ANKLE ABSCESS/HEMATOMA','27603','1','','1','0','','','',0, 1, 0, 0),
(2034,'INCISION & DRAINAGE LEG/ANKLE INFECTED BURSA','INCISION & DRAINAGE LEG/ANKLE INFECTED BURSA','27604','1','','1','0','','','',0, 1, 0, 0),
(2035,'TENOTOMY PRQ ACHILLES TENDON SPX LOCAL ANES','TENOTOMY PRQ ACHILLES TENDON SPX LOCAL ANES','27605','1','','1','0','','','',0, 1, 0, 0),
(2036,'TENOTOMY PRQ ACHILLES TENDON SPX GENERAL ANES','TENOTOMY PRQ ACHILLES TENDON SPX GENERAL ANES','27606','1','','1','0','','','',0, 1, 0, 0),
(2037,'INCISION LEG/ANKLE','INCISION LEG/ANKLE','27607','1','','1','0','','','',0, 1, 0, 0),
(2038,'ARTHROTOMY ANKLE W/EXPL DRAINAGE/REMOVAL FB','ARTHROTOMY ANKLE W/EXPL DRAINAGE/REMOVAL FB','27610','1','','1','0','','','',0, 1, 0, 0),
(2039,'ARTHRT PST CAPSUL RLS ANKLE W/WO ACHLL TDN LNGTH','ARTHRT PST CAPSUL RLS ANKLE W/WO ACHLL TDN LNGTH','27612','1','','1','0','','','',0, 1, 0, 0),
(2040,'BIOPSY SOFT TISSUE LEG/ANKLE AREA SUPERFICIAL','BIOPSY SOFT TISSUE LEG/ANKLE AREA SUPERFICIAL','27613','1','','1','0','','','',0, 1, 0, 0),
(2041,'BIOPSY SOFT TISSUE LEG/ANKLE AREA DEEP','BIOPSY SOFT TISSUE LEG/ANKLE AREA DEEP','27614','1','','1','0','','','',0, 1, 0, 0),
(2042,'RAD RESECTION TUMOR SOFT TISSUE LEG/ANKLE <5CM','RAD RESECTION TUMOR SOFT TISSUE LEG/ANKLE <5CM','27615','1','','1','0','','','',0, 1, 0, 0),
(2043,'RAD RESECTION TUMOR SOFT TISSUE LEG/ANKLE 5 CM/>','RAD RESECTION TUMOR SOFT TISSUE LEG/ANKLE 5 CM/>','27616','1','','1','0','','','',0, 1, 0, 0),
(2044,'EXC TUMOR SOFT TISSUE LEG/ANKLE SUBQ <3CM','EXC TUMOR SOFT TISSUE LEG/ANKLE SUBQ <3CM','27618','1','','1','0','','','',0, 1, 0, 0),
(2045,'EXC TUMOR SOFT TISSUE LEG/ANKLE SUBFASCIAL <5CM','EXC TUMOR SOFT TISSUE LEG/ANKLE SUBFASCIAL <5CM','27619','1','','1','0','','','',0, 1, 0, 0),
(2046,'ARTHRT ANKLE W/EXPL W/WO BX W/WO RMVL LOOSE/FB','ARTHRT ANKLE W/EXPL W/WO BX W/WO RMVL LOOSE/FB','27620','1','','1','0','','','',0, 1, 0, 0),
(2047,'ARTHROTOMY W/SYNOVECTOMY ANKLE','ARTHROTOMY W/SYNOVECTOMY ANKLE','27625','1','','1','0','','','',0, 1, 0, 0),
(2048,'ARTHROTOMY W/SYNOVECTOMY ANKLE TENOSYNOVECTOMY','ARTHROTOMY W/SYNOVECTOMY ANKLE TENOSYNOVECTOMY','27626','1','','1','0','','','',0, 1, 0, 0),
(2049,'EXCISION LESION TENDON SHEATH/CAPSULE LEG&/ANK','EXCISION LESION TENDON SHEATH/CAPSULE LEG&/ANK','27630','1','','1','0','','','',0, 1, 0, 0),
(2050,'EXCISION TUMOR SOFT TISSUE LEG/ANKLE SUBQ 3 CM/>','EXCISION TUMOR SOFT TISSUE LEG/ANKLE SUBQ 3 CM/>','27632','1','','1','0','','','',0, 1, 0, 0),
(2051,'EXC TUMOR SOFT TISSUE LEG/ANKLE SUBFASC 5 CM/>','EXC TUMOR SOFT TISSUE LEG/ANKLE SUBFASC 5 CM/>','27634','1','','1','0','','','',0, 1, 0, 0),
(2052,'EXCISION/CURETTAGE BONE CYST/TUMOR TIBIA/FIBULA','EXCISION/CURETTAGE BONE CYST/TUMOR TIBIA/FIBULA','27635','1','','1','0','','','',0, 1, 0, 0),
(2053,'EXC/CURETTAGE CYST/TUMOR TIBIA/FIBULA W/AGRAFT','EXC/CURETTAGE CYST/TUMOR TIBIA/FIBULA W/AGRAFT','27637','1','','1','0','','','',0, 1, 0, 0),
(2054,'EXC/CURETTAGE CYST/TUMOR TIBIA/FIBULA W/ALGRAFT','EXC/CURETTAGE CYST/TUMOR TIBIA/FIBULA W/ALGRAFT','27638','1','','1','0','','','',0, 1, 0, 0),
(2055,'PARTIAL EXCISION BONE TIBIA','PARTIAL EXCISION BONE TIBIA','27640','1','','1','0','','','',0, 1, 0, 0),
(2056,'PARTIAL EXCISION BONE FIBULA','PARTIAL EXCISION BONE FIBULA','27641','1','','1','0','','','',0, 1, 0, 0),
(2057,'RADICAL RESECTION OF TUMOR TIBIA','RADICAL RESECTION OF TUMOR TIBIA','27645','1','','1','0','','','',0, 1, 0, 0),
(2058,'RADICAL RESECTION TUMOR BONE FIBULA','RADICAL RESECTION TUMOR BONE FIBULA','27646','1','','1','0','','','',0, 1, 0, 0),
(2059,'RADICAL RESECTION OF TUMOR TALUS OR CALCANEUS','RADICAL RESECTION OF TUMOR TALUS OR CALCANEUS','27647','1','','1','0','','','',0, 1, 0, 0),
(2060,'INJECTION ANKLE ARTHROGRAPHY','INJECTION ANKLE ARTHROGRAPHY','27648','1','','1','0','','','',0, 1, 0, 0),
(2061,'REPAIR PRIMARY OPEN/PRQ RUPTURED ACHILLES TENDON','REPAIR PRIMARY OPEN/PRQ RUPTURED ACHILLES TENDON','27650','1','','1','0','','','',0, 1, 0, 0),
(2062,'RPR PRIMARY OPEN/PRQ RUPTURED ACHILLES W/GRAFT','RPR PRIMARY OPEN/PRQ RUPTURED ACHILLES W/GRAFT','27652','1','','1','0','','','',0, 1, 0, 0),
(2063,'REPAIR SECONDARY ACHILLES TENDON W/WO GRAFT','REPAIR SECONDARY ACHILLES TENDON W/WO GRAFT','27654','1','','1','0','','','',0, 1, 0, 0),
(2064,'REPAIR FASCIAL DEFECT LEG','REPAIR FASCIAL DEFECT LEG','27656','1','','1','0','','','',0, 1, 0, 0),
(2065,'REPAIR FLEXOR TENDON LEG PRIMARY W/O GRAFT EACH','REPAIR FLEXOR TENDON LEG PRIMARY W/O GRAFT EACH','27658','1','','1','0','','','',0, 1, 0, 0),
(2066,'RPR FLEXOR TENDON LEG SECONDARY W/O GRAFT EACH','RPR FLEXOR TENDON LEG SECONDARY W/O GRAFT EACH','27659','1','','1','0','','','',0, 1, 0, 0),
(2067,'RPR EXTENSOR TENDON LEG PRIMARY W/O GRAFT EACH','RPR EXTENSOR TENDON LEG PRIMARY W/O GRAFT EACH','27664','1','','1','0','','','',0, 1, 0, 0),
(2068,'RPR EXTENSOR TENDON LEG SECONDRY W/WO GRAFT EACH','RPR EXTENSOR TENDON LEG SECONDRY W/WO GRAFT EACH','27665','1','','1','0','','','',0, 1, 0, 0),
(2069,'RPR DISLOC PERONEAL TENDON W/O FIBULAR OSTEOTOMY','RPR DISLOC PERONEAL TENDON W/O FIBULAR OSTEOTOMY','27675','1','','1','0','','','',0, 1, 0, 0),
(2070,'REPAIR DISLOCATING PERONEAL TENDON W/FIB OSTEOT','REPAIR DISLOCATING PERONEAL TENDON W/FIB OSTEOT','27676','1','','1','0','','','',0, 1, 0, 0),
(2071,'TENOLYSIS FLXR/XTNSR TENDON LEG&/ANKLE 1 EACH','TENOLYSIS FLXR/XTNSR TENDON LEG&/ANKLE 1 EACH','27680','1','','1','0','','','',0, 1, 0, 0),
(2072,'TNOLS FLXR/XTNSR TDN LEG&/ANKLE MLT TDN','TNOLS FLXR/XTNSR TDN LEG&/ANKLE MLT TDN','27681','1','','1','0','','','',0, 1, 0, 0),
(2073,'LNGTH/SHRT TENDON LEG/ANKLE 1 TENDON SPX','LNGTH/SHRT TENDON LEG/ANKLE 1 TENDON SPX','27685','1','','1','0','','','',0, 1, 0, 0),
(2074,'LNGTH/SHRT TDN LEG/ANKLE MLT TDN SAME INC EA','LNGTH/SHRT TDN LEG/ANKLE MLT TDN SAME INC EA','27686','1','','1','0','','','',0, 1, 0, 0),
(2075,'GASTROCNEMIUS RECESSION','GASTROCNEMIUS RECESSION','27687','1','','1','0','','','',0, 1, 0, 0),
(2076,'TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING SUPFC','TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING SUPFC','27690','1','','1','0','','','',0, 1, 0, 0),
(2077,'TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING DP','TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING DP','27691','1','','1','0','','','',0, 1, 0, 0),
(2078,'TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING EA TDN','TR/TRNSPL 1 TDN W/MUSC REDIRION/REROUTING EA TDN','27692','1','','1','0','','','',0, 1, 0, 0),
(2079,'RPR PRIMARY DISRUPTED LIGAMENT ANKLE COLLATERAL','RPR PRIMARY DISRUPTED LIGAMENT ANKLE COLLATERAL','27695','1','','1','0','','','',0, 1, 0, 0),
(2080,'RPR PRIM DISRUPTED LIGM ANKLE BTH COLTRL LIGMS','RPR PRIM DISRUPTED LIGM ANKLE BTH COLTRL LIGMS','27696','1','','1','0','','','',0, 1, 0, 0),
(2081,'REPAIR SECONDARY DISRUPTED LIGAMENT ANKLE COLTRL','REPAIR SECONDARY DISRUPTED LIGAMENT ANKLE COLTRL','27698','1','','1','0','','','',0, 1, 0, 0),
(2082,'ARTHROPLASTY ANKLE','ARTHROPLASTY ANKLE','27700','1','','1','0','','','',0, 1, 0, 0),
(2083,'ARTHROPLASTY ANKLE W/IMPLANT','ARTHROPLASTY ANKLE W/IMPLANT','27702','1','','1','0','','','',0, 1, 0, 0),
(2084,'ARTHROPLASTY ANKLE REVISION TOTAL ANKLE','ARTHROPLASTY ANKLE REVISION TOTAL ANKLE','27703','1','','1','0','','','',0, 1, 0, 0),
(2085,'REMOVAL ANKLE IMPLANT','REMOVAL ANKLE IMPLANT','27704','1','','1','0','','','',0, 1, 0, 0),
(2086,'OSTEOTOMY TIBIA','OSTEOTOMY TIBIA','27705','1','','1','0','','','',0, 1, 0, 0),
(2087,'OSTEOTOMY FIBULA','OSTEOTOMY FIBULA','27707','1','','1','0','','','',0, 1, 0, 0),
(2088,'OSTEOTOMY TIBIA & FIBULA','OSTEOTOMY TIBIA & FIBULA','27709','1','','1','0','','','',0, 1, 0, 0),
(2089,'OSTEOT MLT W/RELIGNMT IMED ROD','OSTEOT MLT W/RELIGNMT IMED ROD','27712','1','','1','0','','','',0, 1, 0, 0),
(2090,'OSTEOPLASTY TIBIA & FIBULA LENGTHENING/SHORTENIN','OSTEOPLASTY TIBIA & FIBULA LENGTHENING/SHORTENIN','27715','1','','1','0','','','',0, 1, 0, 0),
(2091,'REPAIR NONUNION/MALUNION TIBIA W/O GRAFT','REPAIR NONUNION/MALUNION TIBIA W/O GRAFT','27720','1','','1','0','','','',0, 1, 0, 0),
(2092,'REPAIR NONUNION/MALUNION TIBIA W/SLIDING GRAFT','REPAIR NONUNION/MALUNION TIBIA W/SLIDING GRAFT','27722','1','','1','0','','','',0, 1, 0, 0),
(2093,'RPR NON/MAL TIBIA W/ILIAC/OTH AGRFT','RPR NON/MAL TIBIA W/ILIAC/OTH AGRFT','27724','1','','1','0','','','',0, 1, 0, 0),
(2094,'RPR NON/MAL TIBIA SYNOSTOSIS W/FIBULA ANY METH','RPR NON/MAL TIBIA SYNOSTOSIS W/FIBULA ANY METH','27725','1','','1','0','','','',0, 1, 0, 0),
(2095,'REPAIR FIBULA NONUNION/MALUNION W/INT FIXATION','REPAIR FIBULA NONUNION/MALUNION W/INT FIXATION','27726','1','','1','0','','','',0, 1, 0, 0),
(2096,'REPAIR CONGENITAL PSEUDARTHROSIS TIBIA','REPAIR CONGENITAL PSEUDARTHROSIS TIBIA','27727','1','','1','0','','','',0, 1, 0, 0),
(2097,'ARREST EPIPHYSEAL OPEN DISTAL TIBIA','ARREST EPIPHYSEAL OPEN DISTAL TIBIA','27730','1','','1','0','','','',0, 1, 0, 0),
(2098,'ARREST EPIPHYSEAL OPEN DISTAL FIBULA','ARREST EPIPHYSEAL OPEN DISTAL FIBULA','27732','1','','1','0','','','',0, 1, 0, 0),
(2099,'ARREST EPIPHYSEAL OPEN DISTAL TIBIA&FIBULA','ARREST EPIPHYSEAL OPEN DISTAL TIBIA&FIBULA','27734','1','','1','0','','','',0, 1, 0, 0),
(2100,'ARREST EPIPHYSEAL ANY METHOD TIBIA & FIBULA','ARREST EPIPHYSEAL ANY METHOD TIBIA & FIBULA','27740','1','','1','0','','','',0, 1, 0, 0),
(2101,'ARRST EPIPHYSL ANY METH TIBFIB&DSTL FEMUR','ARRST EPIPHYSL ANY METH TIBFIB&DSTL FEMUR','27742','1','','1','0','','','',0, 1, 0, 0),
(2102,'PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE TIBIA','PROPH TX N/P/PLTWR W/WO METHYLMETHACRYLATE TIBIA','27745','1','','1','0','','','',0, 1, 0, 0),
(2103,'CLTX TIBIAL SHAFT FX W/O MANIPULATION','CLTX TIBIAL SHAFT FX W/O MANIPULATION','27750','1','','1','0','','','',0, 1, 0, 0),
(2104,'CLTX TIBIAL SHAFT FX W/MANJ W/WO SKEL TRACJ','CLTX TIBIAL SHAFT FX W/MANJ W/WO SKEL TRACJ','27752','1','','1','0','','','',0, 1, 0, 0),
(2105,'PRQ SKELETAL FIXATION TIBIAL SHAFT FRACTURE','PRQ SKELETAL FIXATION TIBIAL SHAFT FRACTURE','27756','1','','1','0','','','',0, 1, 0, 0),
(2106,'OPTX TIBIAL SHFT FX W/PLATE/SCREWS W/WO CERCLAGE','OPTX TIBIAL SHFT FX W/PLATE/SCREWS W/WO CERCLAGE','27758','1','','1','0','','','',0, 1, 0, 0),
(2107,'TX TIBL SHFT FX IMED IMPLT W/WO SCREWS&/CERCLA','TX TIBL SHFT FX IMED IMPLT W/WO SCREWS&/CERCLA','27759','1','','1','0','','','',0, 1, 0, 0),
(2108,'CLTX MEDIAL MALLEOLUS FX W/O MANIPULATION','CLTX MEDIAL MALLEOLUS FX W/O MANIPULATION','27760','1','','1','0','','','',0, 1, 0, 0),
(2109,'CLTX MEDIAL MALLS FX W/MANJ W/WO SKN/SKEL TRACJ','CLTX MEDIAL MALLS FX W/MANJ W/WO SKN/SKEL TRACJ','27762','1','','1','0','','','',0, 1, 0, 0),
(2110,'OPEN TREATMENT MEDIAL MALLEOLUS FRACTURE','OPEN TREATMENT MEDIAL MALLEOLUS FRACTURE','27766','1','','1','0','','','',0, 1, 0, 0),
(2111,'CLOSED TREATMENT PST MALLEOLUS FRACTURE W/O MANJ','CLOSED TREATMENT PST MALLEOLUS FRACTURE W/O MANJ','27767','1','','1','0','','','',0, 1, 0, 0),
(2112,'CLOSED TREATMENT PST MALLEOLUS FRACTURE W/MANJ','CLOSED TREATMENT PST MALLEOLUS FRACTURE W/MANJ','27768','1','','1','0','','','',0, 1, 0, 0),
(2113,'OPEN TREATMENT POSTERIOR MALLEOLUS FRACTURE','OPEN TREATMENT POSTERIOR MALLEOLUS FRACTURE','27769','1','','1','0','','','',0, 1, 0, 0),
(2114,'CLTX PROX FIBULA/SHFT FX W/O MANJ','CLTX PROX FIBULA/SHFT FX W/O MANJ','27780','1','','1','0','','','',0, 1, 0, 0),
(2115,'CLTX PROX FIBULA/SHFT FX W/MANJ','CLTX PROX FIBULA/SHFT FX W/MANJ','27781','1','','1','0','','','',0, 1, 0, 0),
(2116,'OPEN TREATMENT PROXIMAL FIBULA/SHAFT FRACTURE','OPEN TREATMENT PROXIMAL FIBULA/SHAFT FRACTURE','27784','1','','1','0','','','',0, 1, 0, 0),
(2117,'CLTX DSTL FIBULAR FX LAT MALLS W/O MANJ','CLTX DSTL FIBULAR FX LAT MALLS W/O MANJ','27786','1','','1','0','','','',0, 1, 0, 0),
(2118,'CLTX DSTL FIBULAR FX LAT MALLS W/MANJ','CLTX DSTL FIBULAR FX LAT MALLS W/MANJ','27788','1','','1','0','','','',0, 1, 0, 0),
(2119,'OPEN TX DISTAL FIBULAR FRACTURE LAT MALLEOLUS','OPEN TX DISTAL FIBULAR FRACTURE LAT MALLEOLUS','27792','1','','1','0','','','',0, 1, 0, 0),
(2120,'CLOSED TX BIMALLEOLAR ANKLE FRACTURE W/O MANJ','CLOSED TX BIMALLEOLAR ANKLE FRACTURE W/O MANJ','27808','1','','1','0','','','',0, 1, 0, 0),
(2121,'CLOSED TX BIMALLEOLAR ANKLE FRACTURE W/MANJ','CLOSED TX BIMALLEOLAR ANKLE FRACTURE W/MANJ','27810','1','','1','0','','','',0, 1, 0, 0),
(2122,'OPEN TREATMENT BIMALLEOLAR ANKLE FRACTURE','OPEN TREATMENT BIMALLEOLAR ANKLE FRACTURE','27814','1','','1','0','','','',0, 1, 0, 0),
(2123,'CLTX TRIMALLEOLAR ANKLE FX W/O MANIPULATION','CLTX TRIMALLEOLAR ANKLE FX W/O MANIPULATION','27816','1','','1','0','','','',0, 1, 0, 0),
(2124,'CLTX TRIMALLEOLAR ANKLE FX W/MANIPULATION','CLTX TRIMALLEOLAR ANKLE FX W/MANIPULATION','27818','1','','1','0','','','',0, 1, 0, 0),
(2125,'OPEN TX TRIMALLEOLAR ANKLE FX W/O FIXJ PST LIP','OPEN TX TRIMALLEOLAR ANKLE FX W/O FIXJ PST LIP','27822','1','','1','0','','','',0, 1, 0, 0),
(2126,'OPEN TX TRIMALLEOLAR ANKLE FX W/FIXJ PST LIP','OPEN TX TRIMALLEOLAR ANKLE FX W/FIXJ PST LIP','27823','1','','1','0','','','',0, 1, 0, 0),
(2127,'CLTX FX W8 BRG ARTCLR PRTN DSTL TIBIA W/O MANJ','CLTX FX W8 BRG ARTCLR PRTN DSTL TIBIA W/O MANJ','27824','1','','1','0','','','',0, 1, 0, 0),
(2128,'CLTX FX W8 BRG ARTCLR PRTN DSTL TIB W/SKEL TRACJ','CLTX FX W8 BRG ARTCLR PRTN DSTL TIB W/SKEL TRACJ','27825','1','','1','0','','','',0, 1, 0, 0),
(2129,'OPEN TREATMENT FRACTURE DISTAL TIBIA FIBULA','OPEN TREATMENT FRACTURE DISTAL TIBIA FIBULA','27826','1','','1','0','','','',0, 1, 0, 0),
(2130,'OPEN TREATMENT FRACTURE DISTAL TIBIA ONLY','OPEN TREATMENT FRACTURE DISTAL TIBIA ONLY','27827','1','','1','0','','','',0, 1, 0, 0),
(2131,'OPEN TREATMENT FRACTURE DISTAL TIBIA & FIBULA','OPEN TREATMENT FRACTURE DISTAL TIBIA & FIBULA','27828','1','','1','0','','','',0, 1, 0, 0),
(2132,'OPEN TX DISTAL TIBIOFIBULAR JOINT DISRUPTION','OPEN TX DISTAL TIBIOFIBULAR JOINT DISRUPTION','27829','1','','1','0','','','',0, 1, 0, 0),
(2133,'CLTX PROX TIBFIB JT DISLC W/O ANES','CLTX PROX TIBFIB JT DISLC W/O ANES','27830','1','','1','0','','','',0, 1, 0, 0),
(2134,'CLTX PROX TIBFIB JT DISLC REQ ANES','CLTX PROX TIBFIB JT DISLC REQ ANES','27831','1','','1','0','','','',0, 1, 0, 0),
(2135,'OPEN TX PROX TIBFIB JOINT DISLOCATE EXC PROX FIB','OPEN TX PROX TIBFIB JOINT DISLOCATE EXC PROX FIB','27832','1','','1','0','','','',0, 1, 0, 0),
(2136,'CLOSED TX ANKLE DISLOCATION W/O ANESTHESIA','CLOSED TX ANKLE DISLOCATION W/O ANESTHESIA','27840','1','','1','0','','','',0, 1, 0, 0),
(2137,'CLTX ANKLE DISLC REQ ANES W/WO PRQ SKEL FIXJ','CLTX ANKLE DISLC REQ ANES W/WO PRQ SKEL FIXJ','27842','1','','1','0','','','',0, 1, 0, 0),
(2138,'OPTX ANKLE DISLOCATION W/O REPAIR/INTERNAL FIXJ','OPTX ANKLE DISLOCATION W/O REPAIR/INTERNAL FIXJ','27846','1','','1','0','','','',0, 1, 0, 0),
(2139,'OPTX ANKLE DISLOCATION W/REPAIR/INT/XTRNL FIXJ','OPTX ANKLE DISLOCATION W/REPAIR/INT/XTRNL FIXJ','27848','1','','1','0','','','',0, 1, 0, 0),
(2140,'MANIPULATION ANKLE UNDER GENERAL ANESTHESIA','MANIPULATION ANKLE UNDER GENERAL ANESTHESIA','27860','1','','1','0','','','',0, 1, 0, 0),
(2141,'ARTHRODESIS ANKLE OPEN','ARTHRODESIS ANKLE OPEN','27870','1','','1','0','','','',0, 1, 0, 0),
(2142,'ARTHRODESIS TIBIOFIBULAR JOINT PROXIMAL/DISTAL','ARTHRODESIS TIBIOFIBULAR JOINT PROXIMAL/DISTAL','27871','1','','1','0','','','',0, 1, 0, 0),
(2143,'AMPUTATION LEG THROUGH TIBIA&FIBULA','AMPUTATION LEG THROUGH TIBIA&FIBULA','27880','1','','1','0','','','',0, 1, 0, 0),
(2144,'AMP LEG THRU TIBFIB W/IMMT FITG TQ W/1ST CST','AMP LEG THRU TIBFIB W/IMMT FITG TQ W/1ST CST','27881','1','','1','0','','','',0, 1, 0, 0),
(2145,'AMPUTATION LEG THRU TIBIA&FIBULA OPEN CIRCULAR','AMPUTATION LEG THRU TIBIA&FIBULA OPEN CIRCULAR','27882','1','','1','0','','','',0, 1, 0, 0),
(2146,'AMP LEG THRU TIBIA&FIBULA SEC CLOSURE/SCAR REV','AMP LEG THRU TIBIA&FIBULA SEC CLOSURE/SCAR REV','27884','1','','1','0','','','',0, 1, 0, 0),
(2147,'AMP LEG THRU TIBIA&FIBULA RE-AMPUTATION','AMP LEG THRU TIBIA&FIBULA RE-AMPUTATION','27886','1','','1','0','','','',0, 1, 0, 0),
(2148,'AMP ANKLE-MALLI TIBFIB W/PLSTC CLSR&RESCJ NRV','AMP ANKLE-MALLI TIBFIB W/PLSTC CLSR&RESCJ NRV','27888','1','','1','0','','','',0, 1, 0, 0),
(2149,'ANKLE DISARTICULATION','ANKLE DISARTICULATION','27889','1','','1','0','','','',0, 1, 0, 0),
(2150,'DCMPRN FASCT LEG ANT&/LAT W/DBRDMT MUSC&/NERVE','DCMPRN FASCT LEG ANT&/LAT W/DBRDMT MUSC&/NERVE','27892','1','','1','0','','','',0, 1, 0, 0),
(2151,'DCMPRN FASCT LEG PST W/DBRDMT MUSC&/NRV','DCMPRN FASCT LEG PST W/DBRDMT MUSC&/NRV','27893','1','','1','0','','','',0, 1, 0, 0),
(2152,'DCMPRN FASCT LEG ANT&/LAT&PST W/DBRDMT MUS','DCMPRN FASCT LEG ANT&/LAT&PST W/DBRDMT MUS','27894','1','','1','0','','','',0, 1, 0, 0),
(2153,'UNLISTED PROCEDURE LEG/ANKLE','UNLISTED PROCEDURE LEG/ANKLE','27899','1','','1','0','','','',0, 1, 0, 0),
(2154,'INCISION&DRAINAGE BURSA FOOT','INCISION&DRAINAGE BURSA FOOT','28001','1','','1','0','','','',0, 1, 0, 0),
(2155,'I&D BELOW FASCIA FOOT 1 BURSAL SPACE','I&D BELOW FASCIA FOOT 1 BURSAL SPACE','28002','1','','1','0','','','',0, 1, 0, 0),
(2156,'I&D BELOW FASCIA FOOT MULTIPLE AREAS','I&D BELOW FASCIA FOOT MULTIPLE AREAS','28003','1','','1','0','','','',0, 1, 0, 0),
(2157,'INCISION BONE CORTEX FOOT','INCISION BONE CORTEX FOOT','28005','1','','1','0','','','',0, 1, 0, 0),
(2158,'FASCIOTOMY FOOT&/TOE','FASCIOTOMY FOOT&/TOE','28008','1','','1','0','','','',0, 1, 0, 0),
(2159,'TENOTOMY PERCUTANEOUS TOE SINGLE TENDON','TENOTOMY PERCUTANEOUS TOE SINGLE TENDON','28010','1','','1','0','','','',0, 1, 0, 0),
(2160,'TENOTOMY PERCUTANEOUS TOE MULTIPLE TENDON','TENOTOMY PERCUTANEOUS TOE MULTIPLE TENDON','28011','1','','1','0','','','',0, 1, 0, 0),
(2161,'ARTHRT W/EXPL DRG/RMVL LOOSE/FB NTRTRSL/TARS JT','ARTHRT W/EXPL DRG/RMVL LOOSE/FB NTRTRSL/TARS JT','28020','1','','1','0','','','',0, 1, 0, 0),
(2162,'ARTHRT W/EXPL DRG/RMVL LOOSE/FB MTTARPHLNGL JT','ARTHRT W/EXPL DRG/RMVL LOOSE/FB MTTARPHLNGL JT','28022','1','','1','0','','','',0, 1, 0, 0),
(2163,'ARTHRT W/EXPL DRG/RMVL LOOSE/FB IPHAL JT','ARTHRT W/EXPL DRG/RMVL LOOSE/FB IPHAL JT','28024','1','','1','0','','','',0, 1, 0, 0),
(2164,'RELEASE TARSAL TUNNEL','RELEASE TARSAL TUNNEL','28035','1','','1','0','','','',0, 1, 0, 0),
(2165,'EXCISION TUMOR SOFT TIS FOOT/TOE SUBQ 1.5 CM/>','EXCISION TUMOR SOFT TIS FOOT/TOE SUBQ 1.5 CM/>','28039','1','','1','0','','','',0, 1, 0, 0),
(2166,'EXC TUMOR SOFT TISSUE FOOT/TOE SUBFASC 1.5 CM/>','EXC TUMOR SOFT TISSUE FOOT/TOE SUBFASC 1.5 CM/>','28041','1','','1','0','','','',0, 1, 0, 0),
(2167,'EXCISION TUMOR SOFT TISSUE FOOT/TOE SUBQ <1.5CM','EXCISION TUMOR SOFT TISSUE FOOT/TOE SUBQ <1.5CM','28043','1','','1','0','','','',0, 1, 0, 0),
(2168,'EXC TUMOR SOFT TISSUE FOOT/TOE SUBFASC <1.5CM','EXC TUMOR SOFT TISSUE FOOT/TOE SUBFASC <1.5CM','28045','1','','1','0','','','',0, 1, 0, 0),
(2169,'RAD RESECTION TUMOR SOFT TISSUE FOOT/TOE <3CM','RAD RESECTION TUMOR SOFT TISSUE FOOT/TOE <3CM','28046','1','','1','0','','','',0, 1, 0, 0),
(2170,'RAD RESECTION TUMOR SOFT TISSUE FOOT/TOE 3 CM/>','RAD RESECTION TUMOR SOFT TISSUE FOOT/TOE 3 CM/>','28047','1','','1','0','','','',0, 1, 0, 0),
(2171,'ARTHRT W/BX INTERTARSAL/TARSOMETATARSAL JOINT','ARTHRT W/BX INTERTARSAL/TARSOMETATARSAL JOINT','28050','1','','1','0','','','',0, 1, 0, 0),
(2172,'ARTHRTOMY W/BX METATARSOPHALANGEAL JOINT','ARTHRTOMY W/BX METATARSOPHALANGEAL JOINT','28052','1','','1','0','','','',0, 1, 0, 0),
(2173,'ARTHRTOMY W/BX INTERPHALANGEAL JOINT','ARTHRTOMY W/BX INTERPHALANGEAL JOINT','28054','1','','1','0','','','',0, 1, 0, 0),
(2174,'NEURECTOMY INTRINSIC MUSCULATURE OF FOOT','NEURECTOMY INTRINSIC MUSCULATURE OF FOOT','28055','1','','1','0','','','',0, 1, 0, 0),
(2175,'FASCIECTOMY PLANTAR FASCIA PARTIAL SPX','FASCIECTOMY PLANTAR FASCIA PARTIAL SPX','28060','1','','1','0','','','',0, 1, 0, 0),
(2176,'FASCIOTOMY PLANTAR FASCIA RADICAL SPX','FASCIOTOMY PLANTAR FASCIA RADICAL SPX','28062','1','','1','0','','','',0, 1, 0, 0),
(2177,'SYNVCT INTERTARSAL/TARSOMETATARSAL JT EA SPX','SYNVCT INTERTARSAL/TARSOMETATARSAL JT EA SPX','28070','1','','1','0','','','',0, 1, 0, 0),
(2178,'SYNOVECTOMY METATARSOPHALANGEAL JOINT EACH','SYNOVECTOMY METATARSOPHALANGEAL JOINT EACH','28072','1','','1','0','','','',0, 1, 0, 0),
(2179,'EXCISION INTERDIGITAL MORTON NEUROMA SINGLE EACH','EXCISION INTERDIGITAL MORTON NEUROMA SINGLE EACH','28080','1','','1','0','','','',0, 1, 0, 0),
(2180,'SYNOVECTOMY TENDON SHEATH FOOT FLEXOR','SYNOVECTOMY TENDON SHEATH FOOT FLEXOR','28086','1','','1','0','','','',0, 1, 0, 0),
(2181,'SYNOVECTOMY TENDON SHEATH FOOT EXTENSOR','SYNOVECTOMY TENDON SHEATH FOOT EXTENSOR','28088','1','','1','0','','','',0, 1, 0, 0),
(2182,'EXC LESION TENDON SHEATH/CAPSULE W/SYNVCT FOOT','EXC LESION TENDON SHEATH/CAPSULE W/SYNVCT FOOT','28090','1','','1','0','','','',0, 1, 0, 0),
(2183,'EXC LESION TENDON SHEATH/CAPSULE W/SYNVCT TOE EA','EXC LESION TENDON SHEATH/CAPSULE W/SYNVCT TOE EA','28092','1','','1','0','','','',0, 1, 0, 0),
(2184,'EXCISION/CURETTAGE CYST/TUMOR TALUS/CALCANEUS','EXCISION/CURETTAGE CYST/TUMOR TALUS/CALCANEUS','28100','1','','1','0','','','',0, 1, 0, 0),
(2185,'EXC/CURTG CST/B9 TUM TALUS/CLCNS W/ILIAC/AGRFT','EXC/CURTG CST/B9 TUM TALUS/CLCNS W/ILIAC/AGRFT','28102','1','','1','0','','','',0, 1, 0, 0),
(2186,'EXC/CURETTAGE CYST/TUMOR TALUS/CALCANEUS ALGRFT','EXC/CURETTAGE CYST/TUMOR TALUS/CALCANEUS ALGRFT','28103','1','','1','0','','','',0, 1, 0, 0),
(2187,'EXC/CURTG BONE CYST/B9 TUMORTARSAL/METATARSAL','EXC/CURTG BONE CYST/B9 TUMORTARSAL/METATARSAL','28104','1','','1','0','','','',0, 1, 0, 0),
(2188,'EXC/CURTG CST/B9 TUM TARSAL/METAR W/ILIAC/AGRFT','EXC/CURTG CST/B9 TUM TARSAL/METAR W/ILIAC/AGRFT','28106','1','','1','0','','','',0, 1, 0, 0),
(2189,'EXC/CURTG CST/B9 TUM TARSAL/METAR W/ALGRFT','EXC/CURTG CST/B9 TUM TARSAL/METAR W/ALGRFT','28107','1','','1','0','','','',0, 1, 0, 0),
(2190,'EXC/CURTG CST/B9 TUM PHALANGES FOOT','EXC/CURTG CST/B9 TUM PHALANGES FOOT','28108','1','','1','0','','','',0, 1, 0, 0),
(2191,'OSTECTOMY PRTL 5TH METAR HEAD SPX','OSTECTOMY PRTL 5TH METAR HEAD SPX','28110','1','','1','0','','','',0, 1, 0, 0),
(2192,'OSTECTOMY COMPLETE 1ST METATARSAL HEAD','OSTECTOMY COMPLETE 1ST METATARSAL HEAD','28111','1','','1','0','','','',0, 1, 0, 0),
(2193,'OSTECTOMY COMPLETE OTHER METATARSAL HEAD 2/3/4','OSTECTOMY COMPLETE OTHER METATARSAL HEAD 2/3/4','28112','1','','1','0','','','',0, 1, 0, 0),
(2194,'OSTECTOMY COMPLETE 5TH METATARSAL HEAD','OSTECTOMY COMPLETE 5TH METATARSAL HEAD','28113','1','','1','0','','','',0, 1, 0, 0),
(2195,'OSTC COMPL ALL METAR HEADS W/PRTL PROX PHALANGC','OSTC COMPL ALL METAR HEADS W/PRTL PROX PHALANGC','28114','1','','1','0','','','',0, 1, 0, 0),
(2196,'OSTECTOMY TARSAL COALITION','OSTECTOMY TARSAL COALITION','28116','1','','1','0','','','',0, 1, 0, 0),
(2197,'OSTECTOMY CALCANEUS','OSTECTOMY CALCANEUS','28118','1','','1','0','','','',0, 1, 0, 0),
(2198,'OSTECTOMY CALCANEUS SPUR W/WO PLNTAR FASCIAL RLS','OSTECTOMY CALCANEUS SPUR W/WO PLNTAR FASCIAL RLS','28119','1','','1','0','','','',0, 1, 0, 0),
(2199,'PARTIAL EXCISION BONE TALUS/CALCANEUS','PARTIAL EXCISION BONE TALUS/CALCANEUS','28120','1','','1','0','','','',0, 1, 0, 0),
(2200,'PRTL EXC B1 TARSAL/METAR B1 XCP TALUS/CALCANEUS','PRTL EXC B1 TARSAL/METAR B1 XCP TALUS/CALCANEUS','28122','1','','1','0','','','',0, 1, 0, 0),
(2201,'PARTICAL EXCISION BONE PHALANX TOE','PARTICAL EXCISION BONE PHALANX TOE','28124','1','','1','0','','','',0, 1, 0, 0),
(2202,'RESECTION PARTIAL/COMPLETE PHALANGEAL BASE EACH','RESECTION PARTIAL/COMPLETE PHALANGEAL BASE EACH','28126','1','','1','0','','','',0, 1, 0, 0),
(2203,'TALECTOMY ASTRAGALECTOMY','TALECTOMY ASTRAGALECTOMY','28130','1','','1','0','','','',0, 1, 0, 0),
(2204,'METATARSECTOMY','METATARSECTOMY','28140','1','','1','0','','','',0, 1, 0, 0),
(2205,'PHALANGECTOMY TOE EACH TOE','PHALANGECTOMY TOE EACH TOE','28150','1','','1','0','','','',0, 1, 0, 0),
(2206,'RESECTION CONDYLE DISTAL END PHALANX EACH TOE','RESECTION CONDYLE DISTAL END PHALANX EACH TOE','28153','1','','1','0','','','',0, 1, 0, 0),
(2207,'HEMIPHALANGECTOMY/INTERPHALANGEAL JOINT EXC TOE','HEMIPHALANGECTOMY/INTERPHALANGEAL JOINT EXC TOE','28160','1','','1','0','','','',0, 1, 0, 0),
(2208,'RAD RESCJ TUMOR TARSAL EXCEPT TALUS/CALCANEUS','RAD RESCJ TUMOR TARSAL EXCEPT TALUS/CALCANEUS','28171','1','','1','0','','','',0, 1, 0, 0),
(2209,'RADICAL RESECTION TUMOR METATARSAL','RADICAL RESECTION TUMOR METATARSAL','28173','1','','1','0','','','',0, 1, 0, 0),
(2210,'RADICAL RESECTION TUMOR PHALANX OR TOE','RADICAL RESECTION TUMOR PHALANX OR TOE','28175','1','','1','0','','','',0, 1, 0, 0),
(2211,'REMOVAL FOREIGN BODY FOOT SUBCUTANEOUS','REMOVAL FOREIGN BODY FOOT SUBCUTANEOUS','28190','1','','1','0','','','',0, 1, 0, 0),
(2212,'REMOVAL FOREIGN BODY FOOT DEEP','REMOVAL FOREIGN BODY FOOT DEEP','28192','1','','1','0','','','',0, 1, 0, 0),
(2213,'REMOVAL FOREIGN BODY FOOT COMPLICATED','REMOVAL FOREIGN BODY FOOT COMPLICATED','28193','1','','1','0','','','',0, 1, 0, 0),
(2214,'RPR TDN FLXR FOOT 1/2 W/O FREE GRAFG EACH TENDON','RPR TDN FLXR FOOT 1/2 W/O FREE GRAFG EACH TENDON','28200','1','','1','0','','','',0, 1, 0, 0),
(2215,'RPR TENDON FLXR FOOT SEC W/FREE GRAFT EA TENDON','RPR TENDON FLXR FOOT SEC W/FREE GRAFT EA TENDON','28202','1','','1','0','','','',0, 1, 0, 0),
(2216,'REPAIR TENDON EXTENSOR FOOT 1/2 EACH TENDON','REPAIR TENDON EXTENSOR FOOT 1/2 EACH TENDON','28208','1','','1','0','','','',0, 1, 0, 0),
(2217,'RPR TENDON XTNSR FOOT SEC W/FREE GRAFT EA TENDON','RPR TENDON XTNSR FOOT SEC W/FREE GRAFT EA TENDON','28210','1','','1','0','','','',0, 1, 0, 0),
(2218,'TENOLYSIS FLEXOR FOOT SINGLE TENDON','TENOLYSIS FLEXOR FOOT SINGLE TENDON','28220','1','','1','0','','','',0, 1, 0, 0),
(2219,'TENOLYSIS FLEXOR FOOT MULTIPLE TENDONS','TENOLYSIS FLEXOR FOOT MULTIPLE TENDONS','28222','1','','1','0','','','',0, 1, 0, 0),
(2220,'TENOLYSIS EXTENSOR FOOT SINGLE TENDON','TENOLYSIS EXTENSOR FOOT SINGLE TENDON','28225','1','','1','0','','','',0, 1, 0, 0),
(2221,'TENOLYSIS EXTENSOR FOOT MULTIPLE TENDON','TENOLYSIS EXTENSOR FOOT MULTIPLE TENDON','28226','1','','1','0','','','',0, 1, 0, 0),
(2222,'TX OPN TENDON FLEXOR FOOT SINGLE/MULT TENDON SPX','TX OPN TENDON FLEXOR FOOT SINGLE/MULT TENDON SPX','28230','1','','1','0','','','',0, 1, 0, 0),
(2223,'TX OPEN TENDON FLEXOR TOE 1 TENDON SPX','TX OPEN TENDON FLEXOR TOE 1 TENDON SPX','28232','1','','1','0','','','',0, 1, 0, 0),
(2224,'TENOTOMY OPEN EXTENSOR FOOT/TOE EACH TENDON','TENOTOMY OPEN EXTENSOR FOOT/TOE EACH TENDON','28234','1','','1','0','','','',0, 1, 0, 0),
(2225,'RCNSTJ PST TIBL TDN W/EXC ACCESSORY TARSL NAVCLR','RCNSTJ PST TIBL TDN W/EXC ACCESSORY TARSL NAVCLR','28238','1','','1','0','','','',0, 1, 0, 0),
(2226,'TENOTOMY LENGTHENING/RLS ABDUCTOR HALLUCIS MUSC','TENOTOMY LENGTHENING/RLS ABDUCTOR HALLUCIS MUSC','28240','1','','1','0','','','',0, 1, 0, 0),
(2227,'DIVISION PLANTAR FASCIA & MUSCLE SPX','DIVISION PLANTAR FASCIA & MUSCLE SPX','28250','1','','1','0','','','',0, 1, 0, 0),
(2228,'CAPSULOTOMY MIDFOOT MEDIAL RELEASE ONLY SPX','CAPSULOTOMY MIDFOOT MEDIAL RELEASE ONLY SPX','28260','1','','1','0','','','',0, 1, 0, 0),
(2229,'CAPSULOTOMY MIDFOOT W/TENDON LENGTHENING','CAPSULOTOMY MIDFOOT W/TENDON LENGTHENING','28261','1','','1','0','','','',0, 1, 0, 0),
(2230,'CAPSUL MIDFOOT W/PST TALOTIBL CAPSUL&TDN LNGTH','CAPSUL MIDFOOT W/PST TALOTIBL CAPSUL&TDN LNGTH','28262','1','','1','0','','','',0, 1, 0, 0),
(2231,'CAPSULOTOMY MIDTARSAL','CAPSULOTOMY MIDTARSAL','28264','1','','1','0','','','',0, 1, 0, 0),
(2232,'CAPSUL MTTARPHLNGL JT W/WO TENORRHAPHY EA JT SPX','CAPSUL MTTARPHLNGL JT W/WO TENORRHAPHY EA JT SPX','28270','1','','1','0','','','',0, 1, 0, 0),
(2233,'CAPSULOTOMY IPHAL JOINT EACH JOINT SPX','CAPSULOTOMY IPHAL JOINT EACH JOINT SPX','28272','1','','1','0','','','',0, 1, 0, 0),
(2234,'SYNDACTYLIZATION TOES','SYNDACTYLIZATION TOES','28280','1','','1','0','','','',0, 1, 0, 0),
(2235,'CORRECTION HAMMERTOE','CORRECTION HAMMERTOE','28285','1','','1','0','','','',0, 1, 0, 0),
(2236,'CORRECTION COCK-UP 5TH TOE W/PLASTIC CLOSURE','CORRECTION COCK-UP 5TH TOE W/PLASTIC CLOSURE','28286','1','','1','0','','','',0, 1, 0, 0),
(2237,'OSTC PRTL EXOSTC/CONDYLC METAR HEAD','OSTC PRTL EXOSTC/CONDYLC METAR HEAD','28288','1','','1','0','','','',0, 1, 0, 0),
(2238,'HALLUX RIGIDUS CORRECT W/CHEILECTOMY 1ST MP JT','HALLUX RIGIDUS CORRECT W/CHEILECTOMY 1ST MP JT','28289','1','','1','0','','','',0, 1, 0, 0),
(2239,'CORRJ HALLUX VALGUS W/WO SESMDC SMPL EXOSTECTOMY','CORRJ HALLUX VALGUS W/WO SESMDC SMPL EXOSTECTOMY','28290','1','','1','0','','','',0, 1, 0, 0),
(2240,'KELLER/MCBRIDE/MAYO PROCEDURE','KELLER/MCBRIDE/MAYO PROCEDURE','28292','1','','1','0','','','',0, 1, 0, 0),
(2241,'CORRJ HALLUX VALGUS W/WO SESMDC RESCJ JT W/IMPLT','CORRJ HALLUX VALGUS W/WO SESMDC RESCJ JT W/IMPLT','28293','1','','1','0','','','',0, 1, 0, 0),
(2242,'CORRJ HALLUX VALGUS W/WO SESMDC W/TDN TRNSPLS','CORRJ HALLUX VALGUS W/WO SESMDC W/TDN TRNSPLS','28294','1','','1','0','','','',0, 1, 0, 0),
(2243,'CORRJ HALLUX VALGUS W/WO SESMDC W/METAR OSTEOT','CORRJ HALLUX VALGUS W/WO SESMDC W/METAR OSTEOT','28296','1','','1','0','','','',0, 1, 0, 0),
(2244,'CORRJ HALLUX VALGUS W/WO SESMDC LAPIDUS-TYP PX','CORRJ HALLUX VALGUS W/WO SESMDC LAPIDUS-TYP PX','28297','1','','1','0','','','',0, 1, 0, 0),
(2245,'CORRJ HALLUX VALGUS W/WO SESMDC PHALANX OSTEOT','CORRJ HALLUX VALGUS W/WO SESMDC PHALANX OSTEOT','28298','1','','1','0','','','',0, 1, 0, 0),
(2246,'CORRJ HALLUX VALGUS W/WO SESMDC 2 OSTEOT','CORRJ HALLUX VALGUS W/WO SESMDC 2 OSTEOT','28299','1','','1','0','','','',0, 1, 0, 0),
(2247,'OSTEOTOMY CALCANEUS W/WO INTERNAL FIXATION','OSTEOTOMY CALCANEUS W/WO INTERNAL FIXATION','28300','1','','1','0','','','',0, 1, 0, 0),
(2248,'OSTEOTOMY TALUS','OSTEOTOMY TALUS','28302','1','','1','0','','','',0, 1, 0, 0),
(2249,'OSTEOTOMY TARSAL BONES OTH/THN CALCANEUS/TALUS','OSTEOTOMY TARSAL BONES OTH/THN CALCANEUS/TALUS','28304','1','','1','0','','','',0, 1, 0, 0),
(2250,'OSTEOT TARSAL OTH/THN CALCANEUS/TALUS W/AGRFT','OSTEOT TARSAL OTH/THN CALCANEUS/TALUS W/AGRFT','28305','1','','1','0','','','',0, 1, 0, 0),
(2251,'OSTEOT W/WO LNGTH SHRT/CORRJ 1ST METAR','OSTEOT W/WO LNGTH SHRT/CORRJ 1ST METAR','28306','1','','1','0','','','',0, 1, 0, 0),
(2252,'OSTEOT W/WO LNGTH SHRT/CORRJ METAR XCP 1ST TOE','OSTEOT W/WO LNGTH SHRT/CORRJ METAR XCP 1ST TOE','28307','1','','1','0','','','',0, 1, 0, 0),
(2253,'OSTEOT W/WO LNGTH SHRT/CORRJ METAR XCP 1ST EA','OSTEOT W/WO LNGTH SHRT/CORRJ METAR XCP 1ST EA','28308','1','','1','0','','','',0, 1, 0, 0),
(2254,'OSTEOT W/WO LNGTH SHRT/ANGULAR CORRJ METAR MLT','OSTEOT W/WO LNGTH SHRT/ANGULAR CORRJ METAR MLT','28309','1','','1','0','','','',0, 1, 0, 0),
(2255,'OSTEOT SHRT CORRJ PROX PHALANX 1ST TOE','OSTEOT SHRT CORRJ PROX PHALANX 1ST TOE','28310','1','','1','0','','','',0, 1, 0, 0),
(2256,'OSTEOT SHRT CORRJ OTH PHALANGES ANY TOE','OSTEOT SHRT CORRJ OTH PHALANGES ANY TOE','28312','1','','1','0','','','',0, 1, 0, 0),
(2257,'RCNSTJ ANGULAR DFRM TOE SOFT TISS PX ONLY','RCNSTJ ANGULAR DFRM TOE SOFT TISS PX ONLY','28313','1','','1','0','','','',0, 1, 0, 0),
(2258,'SESAMOIDECTOMY FIRST TOE SPX','SESAMOIDECTOMY FIRST TOE SPX','28315','1','','1','0','','','',0, 1, 0, 0),
(2259,'REPAIR NONUNION/MALUNION TARSAL BONES','REPAIR NONUNION/MALUNION TARSAL BONES','28320','1','','1','0','','','',0, 1, 0, 0),
(2260,'RPR NON/MALUNION METARSAL W/WO BONE GRAFT','RPR NON/MALUNION METARSAL W/WO BONE GRAFT','28322','1','','1','0','','','',0, 1, 0, 0),
(2261,'RCNSTJ TOE MACRODACTYLY SOFT TISSUE RESECTION','RCNSTJ TOE MACRODACTYLY SOFT TISSUE RESECTION','28340','1','','1','0','','','',0, 1, 0, 0),
(2262,'RCNSTJ TOE MACRODACTYLY REQUIRING BONE RESECTION','RCNSTJ TOE MACRODACTYLY REQUIRING BONE RESECTION','28341','1','','1','0','','','',0, 1, 0, 0),
(2263,'RECONSTRUCTION TOE POLYDACTYLY','RECONSTRUCTION TOE POLYDACTYLY','28344','1','','1','0','','','',0, 1, 0, 0),
(2264,'RCNSTJ TOE SYNDACTYLY W/WO SKIN GRAFT EACH WEB','RCNSTJ TOE SYNDACTYLY W/WO SKIN GRAFT EACH WEB','28345','1','','1','0','','','',0, 1, 0, 0),
(2265,'RECONSTRUCTION CLEFT FOOT','RECONSTRUCTION CLEFT FOOT','28360','1','','1','0','','','',0, 1, 0, 0),
(2266,'CLOSED TX CALCANEAL FRACTURE W/O MANIPULATION','CLOSED TX CALCANEAL FRACTURE W/O MANIPULATION','28400','1','','1','0','','','',0, 1, 0, 0),
(2267,'CLOSED TX CALCANEAL FRACTURE W/MANIPULATION','CLOSED TX CALCANEAL FRACTURE W/MANIPULATION','28405','1','','1','0','','','',0, 1, 0, 0),
(2268,'PRQ SKELETAL FIXJ CALCANEAL FRACTURE W/MANJ','PRQ SKELETAL FIXJ CALCANEAL FRACTURE W/MANJ','28406','1','','1','0','','','',0, 1, 0, 0),
(2269,'OPEN TREATMENT CALCANEAL FRACTURE','OPEN TREATMENT CALCANEAL FRACTURE','28415','1','','1','0','','','',0, 1, 0, 0),
(2270,'OPEN TREATMENT CALCANEAL FRACTURE W BONE GRAFT','OPEN TREATMENT CALCANEAL FRACTURE W BONE GRAFT','28420','1','','1','0','','','',0, 1, 0, 0),
(2271,'CLOSED TX TALUS FRACTURE W/O MANIPULATION','CLOSED TX TALUS FRACTURE W/O MANIPULATION','28430','1','','1','0','','','',0, 1, 0, 0),
(2272,'CLOSED TX TALUS FRACTURE W/MANIPULATION','CLOSED TX TALUS FRACTURE W/MANIPULATION','28435','1','','1','0','','','',0, 1, 0, 0),
(2273,'PRQ SKELETAL FIXATION TALUS FRACTURE W/MANJ','PRQ SKELETAL FIXATION TALUS FRACTURE W/MANJ','28436','1','','1','0','','','',0, 1, 0, 0),
(2274,'OPEN TREATMENT TALUS FRACTURE','OPEN TREATMENT TALUS FRACTURE','28445','1','','1','0','','','',0, 1, 0, 0),
(2275,'OPEN OSTEOCHONDRAL AUTOGRAFT TALUS','OPEN OSTEOCHONDRAL AUTOGRAFT TALUS','28446','1','','1','0','','','',0, 1, 0, 0),
(2276,'TX TARSAL BONE FX XCP TALUS&CALCN W/O MANJ','TX TARSAL BONE FX XCP TALUS&CALCN W/O MANJ','28450','1','','1','0','','','',0, 1, 0, 0),
(2277,'TX TARSAL BONE FX XCP TALUS&CALCN W/MANJ','TX TARSAL BONE FX XCP TALUS&CALCN W/MANJ','28455','1','','1','0','','','',0, 1, 0, 0),
(2278,'PRQ SKEL FIXJ TARSL FX XCP TALUS&CALCNS W/MANJ','PRQ SKEL FIXJ TARSL FX XCP TALUS&CALCNS W/MANJ','28456','1','','1','0','','','',0, 1, 0, 0),
(2279,'OPEN TX TARSAL FRACTURE XCP TALUS & CALCANEUS EA','OPEN TX TARSAL FRACTURE XCP TALUS & CALCANEUS EA','28465','1','','1','0','','','',0, 1, 0, 0),
(2280,'CLOSED TX METATARSAL FRACTURE W/O MANIPULATION','CLOSED TX METATARSAL FRACTURE W/O MANIPULATION','28470','1','','1','0','','','',0, 1, 0, 0),
(2281,'CLTX METAR FX W/MANJ','CLTX METAR FX W/MANJ','28475','1','','1','0','','','',0, 1, 0, 0),
(2282,'PRQ SKEL FIXJ METAR FX W/MANJ','PRQ SKEL FIXJ METAR FX W/MANJ','28476','1','','1','0','','','',0, 1, 0, 0),
(2283,'OPEN TREATMENT METATARSAL FRACTURE EACH','OPEN TREATMENT METATARSAL FRACTURE EACH','28485','1','','1','0','','','',0, 1, 0, 0),
(2284,'CLTX FX GRT TOE PHLX/PHLG W/O MANJ','CLTX FX GRT TOE PHLX/PHLG W/O MANJ','28490','1','','1','0','','','',0, 1, 0, 0),
(2285,'CLTX FX GRT TOE PHLX/PHLG W/MANJ','CLTX FX GRT TOE PHLX/PHLG W/MANJ','28495','1','','1','0','','','',0, 1, 0, 0),
(2286,'PRQ SKEL FIXJ FX GRT TOE PHLX/PHLG W/MANJ','PRQ SKEL FIXJ FX GRT TOE PHLX/PHLG W/MANJ','28496','1','','1','0','','','',0, 1, 0, 0),
(2287,'OPEN TX FRACTURE GREAT TOE/PHALANX/PHALANGES','OPEN TX FRACTURE GREAT TOE/PHALANX/PHALANGES','28505','1','','1','0','','','',0, 1, 0, 0),
(2288,'CLTX FX PHLX/PHLG OTH/THN GRT TOE W/O MANJ','CLTX FX PHLX/PHLG OTH/THN GRT TOE W/O MANJ','28510','1','','1','0','','','',0, 1, 0, 0),
(2289,'CLTX FX PHLX/PHLG OTH/THN GRT TOE W/MANJ','CLTX FX PHLX/PHLG OTH/THN GRT TOE W/MANJ','28515','1','','1','0','','','',0, 1, 0, 0),
(2290,'OPEN TX FRACTURE PHALANX/PHALANGES NOT GREAT TOE','OPEN TX FRACTURE PHALANX/PHALANGES NOT GREAT TOE','28525','1','','1','0','','','',0, 1, 0, 0),
(2291,'CLOSED TREATMENT SESAMOID FRACTURE','CLOSED TREATMENT SESAMOID FRACTURE','28530','1','','1','0','','','',0, 1, 0, 0),
(2292,'OPEN TX SESAMOID FRACTURE W/WO INTERNAL FIXATION','OPEN TX SESAMOID FRACTURE W/WO INTERNAL FIXATION','28531','1','','1','0','','','',0, 1, 0, 0),
(2293,'CLTX TARSAL DISLC OTH/THN TALOTARSAL W/O ANES','CLTX TARSAL DISLC OTH/THN TALOTARSAL W/O ANES','28540','1','','1','0','','','',0, 1, 0, 0),
(2294,'CLTX TARSAL DISLC OTH/THN TALOTARSAL W/ANES','CLTX TARSAL DISLC OTH/THN TALOTARSAL W/ANES','28545','1','','1','0','','','',0, 1, 0, 0),
(2295,'PRQ SKEL FIXJ TARSL DISLC XCP TALOTARSAL W/MANJ','PRQ SKEL FIXJ TARSL DISLC XCP TALOTARSAL W/MANJ','28546','1','','1','0','','','',0, 1, 0, 0),
(2296,'OPEN TREATMENT TARSAL BONE DISLOCATION','OPEN TREATMENT TARSAL BONE DISLOCATION','28555','1','','1','0','','','',0, 1, 0, 0),
(2297,'CLOSED TX TALOTARSAL JOINT DISLC W/O ANES','CLOSED TX TALOTARSAL JOINT DISLC W/O ANES','28570','1','','1','0','','','',0, 1, 0, 0),
(2298,'CLOSED TX TALOTARSAL JOINT DISLOCATION W/ANES','CLOSED TX TALOTARSAL JOINT DISLOCATION W/ANES','28575','1','','1','0','','','',0, 1, 0, 0),
(2299,'PRQ SKEL FIXJ TALOTARSAL JT DISLC W/MANJ','PRQ SKEL FIXJ TALOTARSAL JT DISLC W/MANJ','28576','1','','1','0','','','',0, 1, 0, 0),
(2300,'OPEN TREATMENT TALOTARSAL JOINT DISLOCATION','OPEN TREATMENT TALOTARSAL JOINT DISLOCATION','28585','1','','1','0','','','',0, 1, 0, 0),
(2301,'CLOSED TX TARSOMETATARSAL DISLOCATION W/O ANES','CLOSED TX TARSOMETATARSAL DISLOCATION W/O ANES','28600','1','','1','0','','','',0, 1, 0, 0),
(2302,'CLOSED TX TARSOMETATARSAL DISLOCATION W/ANES','CLOSED TX TARSOMETATARSAL DISLOCATION W/ANES','28605','1','','1','0','','','',0, 1, 0, 0),
(2303,'PRQ SKEL FIXJ TARS JT DISLC W/MANJ','PRQ SKEL FIXJ TARS JT DISLC W/MANJ','28606','1','','1','0','','','',0, 1, 0, 0),
(2304,'OPEN TREATMENT TARSOMETATARSAL JOINT DISLOCATION','OPEN TREATMENT TARSOMETATARSAL JOINT DISLOCATION','28615','1','','1','0','','','',0, 1, 0, 0),
(2305,'CLTX METATARSOPHLNGL JT DISLC W/O ANES','CLTX METATARSOPHLNGL JT DISLC W/O ANES','28630','1','','1','0','','','',0, 1, 0, 0),
(2306,'CLTX METATARSOPHLNGL JT DISLC REQ ANES','CLTX METATARSOPHLNGL JT DISLC REQ ANES','28635','1','','1','0','','','',0, 1, 0, 0),
(2307,'PRQ SKEL FIXJ METATARSOPHLNGL JT DISLC W/MANJ','PRQ SKEL FIXJ METATARSOPHLNGL JT DISLC W/MANJ','28636','1','','1','0','','','',0, 1, 0, 0),
(2308,'OPEN TX METATARSOPHALANGEAL JOINT DISLOCATION','OPEN TX METATARSOPHALANGEAL JOINT DISLOCATION','28645','1','','1','0','','','',0, 1, 0, 0),
(2309,'CLTX INTERPHALANGEAL JOINT DISLOCATION W/O ANES','CLTX INTERPHALANGEAL JOINT DISLOCATION W/O ANES','28660','1','','1','0','','','',0, 1, 0, 0),
(2310,'CLTX INTERPHALANGEAL JOINT DISLOCATION REQ ANES','CLTX INTERPHALANGEAL JOINT DISLOCATION REQ ANES','28665','1','','1','0','','','',0, 1, 0, 0),
(2311,'PRQ SKEL FIXJ INTERPHALANGEAL JOINT DISLC W/MANJ','PRQ SKEL FIXJ INTERPHALANGEAL JOINT DISLC W/MANJ','28666','1','','1','0','','','',0, 1, 0, 0),
(2312,'OPEN TREATMENT INTERPHALANGEAL JOINT DISLOCATION','OPEN TREATMENT INTERPHALANGEAL JOINT DISLOCATION','28675','1','','1','0','','','',0, 1, 0, 0),
(2313,'ARTHRODESIS PANTALAR','ARTHRODESIS PANTALAR','28705','1','','1','0','','','',0, 1, 0, 0),
(2314,'ARTHRODESIS TRIPLE','ARTHRODESIS TRIPLE','28715','1','','1','0','','','',0, 1, 0, 0),
(2315,'ARTHRODESIS SUBTALAR','ARTHRODESIS SUBTALAR','28725','1','','1','0','','','',0, 1, 0, 0),
(2316,'ARTHRD MIDTARSL/TARSOMETATARSAL MULT/TRANSVRS','ARTHRD MIDTARSL/TARSOMETATARSAL MULT/TRANSVRS','28730','1','','1','0','','','',0, 1, 0, 0),
(2317,'ARTHRD MIDTARSL/TARS MLT/TRANSVRS W/OSTEOT','ARTHRD MIDTARSL/TARS MLT/TRANSVRS W/OSTEOT','28735','1','','1','0','','','',0, 1, 0, 0),
(2318,'ARTHRD W/TDN LNGTH&ADVMNT TARSL NVCLR-CUNEIFOR','ARTHRD W/TDN LNGTH&ADVMNT TARSL NVCLR-CUNEIFOR','28737','1','','1','0','','','',0, 1, 0, 0),
(2319,'ARTHRODESIS MIDTARSOMETATARSAL SINGLE JOINT','ARTHRODESIS MIDTARSOMETATARSAL SINGLE JOINT','28740','1','','1','0','','','',0, 1, 0, 0),
(2320,'ARTHRODESIS GREAT TOE METATARSOPHALANGEAL JOINT','ARTHRODESIS GREAT TOE METATARSOPHALANGEAL JOINT','28750','1','','1','0','','','',0, 1, 0, 0),
(2321,'ARTHRODESIS GREAT TOE INTERPHALANGEAL JOINT','ARTHRODESIS GREAT TOE INTERPHALANGEAL JOINT','28755','1','','1','0','','','',0, 1, 0, 0),
(2322,'ARTHRD W/XTNSR HALLUCIS LONGUS TR 1ST METAR NCK','ARTHRD W/XTNSR HALLUCIS LONGUS TR 1ST METAR NCK','28760','1','','1','0','','','',0, 1, 0, 0),
(2323,'AMPUTATION FOOT MIDTARSAL','AMPUTATION FOOT MIDTARSAL','28800','1','','1','0','','','',0, 1, 0, 0),
(2324,'AMPUTATION FOOT TRANSMETARSAL','AMPUTATION FOOT TRANSMETARSAL','28805','1','','1','0','','','',0, 1, 0, 0),
(2325,'AMPUTATION METATARSAL W/TOE SINGLE','AMPUTATION METATARSAL W/TOE SINGLE','28810','1','','1','0','','','',0, 1, 0, 0),
(2326,'AMPUTATION TOE METATARSOPHALANGEAL JOINT','AMPUTATION TOE METATARSOPHALANGEAL JOINT','28820','1','','1','0','','','',0, 1, 0, 0),
(2327,'AMPUTATION TOE INTERPHALANGEAL JOINT','AMPUTATION TOE INTERPHALANGEAL JOINT','28825','1','','1','0','','','',0, 1, 0, 0),
(2328,'ESWT HI NRG PHYS/QHP W/US GDN INVG PLNTAR FASCIA','ESWT HI NRG PHYS/QHP W/US GDN INVG PLNTAR FASCIA','28890','1','','1','0','','','',0, 1, 0, 0),
(2329,'UNLISTED PROCEDURE FOOT/TOES','UNLISTED PROCEDURE FOOT/TOES','28899','1','','1','0','','','',0, 1, 0, 0),
(2330,'APPLICATION HALO TYPE BODY CAST','APPLICATION HALO TYPE BODY CAST','29000','1','','1','0','','','',0, 1, 0, 0),
(2331,'APPLICATION RISSER JACKET LOCALIZER BODY ONLY','APPLICATION RISSER JACKET LOCALIZER BODY ONLY','29010','1','','1','0','','','',0, 1, 0, 0),
(2332,'APPLICATION RISSER JACKET LOCALIZER BODY W/HEAD','APPLICATION RISSER JACKET LOCALIZER BODY W/HEAD','29015','1','','1','0','','','',0, 1, 0, 0),
(2333,'APPLICATION BODY CAST SHOULDER HIPS','APPLICATION BODY CAST SHOULDER HIPS','29035','1','','1','0','','','',0, 1, 0, 0),
(2334,'APPLICATION BODY CAST SHOULDER HIPS HEAD MINERVA','APPLICATION BODY CAST SHOULDER HIPS HEAD MINERVA','29040','1','','1','0','','','',0, 1, 0, 0),
(2335,'APPLICATION BODY CAST SHOULDER HIPS W/ONE THIGH','APPLICATION BODY CAST SHOULDER HIPS W/ONE THIGH','29044','1','','1','0','','','',0, 1, 0, 0),
(2336,'APPLICATION BODY CAST SHOULDER HIPS BOTH THIGHS','APPLICATION BODY CAST SHOULDER HIPS BOTH THIGHS','29046','1','','1','0','','','',0, 1, 0, 0),
(2337,'APPLICATION CAST FIGURE-OF-8','APPLICATION CAST FIGURE-OF-8','29049','1','','1','0','','','',0, 1, 0, 0),
(2338,'APPLICATION CAST SHOULDER SPICA','APPLICATION CAST SHOULDER SPICA','29055','1','','1','0','','','',0, 1, 0, 0),
(2339,'APPLICATION CAST PLASTER VELPEAU','APPLICATION CAST PLASTER VELPEAU','29058','1','','1','0','','','',0, 1, 0, 0),
(2340,'APPLICATION CAST SHOULDER HAND LONG ARM','APPLICATION CAST SHOULDER HAND LONG ARM','29065','1','','1','0','','','',0, 1, 0, 0),
(2341,'APPLICATION CAST ELBOW FINGER SHORT ARM','APPLICATION CAST ELBOW FINGER SHORT ARM','29075','1','','1','0','','','',0, 1, 0, 0),
(2342,'APPLICATION CAST HAND & LOWER FOREARM GAUNTLET','APPLICATION CAST HAND & LOWER FOREARM GAUNTLET','29085','1','','1','0','','','',0, 1, 0, 0),
(2343,'APPLICATION CAST FINGER','APPLICATION CAST FINGER','29086','1','','1','0','','','',0, 1, 0, 0),
(2344,'APPLICATION LONG ARM SPLINT SHOULDER HAND','APPLICATION LONG ARM SPLINT SHOULDER HAND','29105','1','','1','0','','','',0, 1, 0, 0),
(2345,'APPLICATION SHORT ARM SPLINT FOREARM-HAND STATIC','APPLICATION SHORT ARM SPLINT FOREARM-HAND STATIC','29125','1','','1','0','','','',0, 1, 0, 0),
(2346,'APPLICATION SHORT ARM SPLINT DYNAMIC','APPLICATION SHORT ARM SPLINT DYNAMIC','29126','1','','1','0','','','',0, 1, 0, 0),
(2347,'APPLICATION FINGER SPLINT STATIC','APPLICATION FINGER SPLINT STATIC','29130','1','','1','0','','','',0, 1, 0, 0),
(2348,'APPLICATION FINGER SPLINT DYNAMIC','APPLICATION FINGER SPLINT DYNAMIC','29131','1','','1','0','','','',0, 1, 0, 0),
(2349,'STRAPPING THORAX','STRAPPING THORAX','29200','1','','1','0','','','',0, 1, 0, 0),
(2350,'STRAPPING SHOULDER','STRAPPING SHOULDER','29240','1','','1','0','','','',0, 1, 0, 0),
(2351,'STRAPPING ELBOW/WRIST','STRAPPING ELBOW/WRIST','29260','1','','1','0','','','',0, 1, 0, 0),
(2352,'STRAPPING HAND/FINGER','STRAPPING HAND/FINGER','29280','1','','1','0','','','',0, 1, 0, 0),
(2353,'APPLICATION HIP SPICA CAST 1 LEG','APPLICATION HIP SPICA CAST 1 LEG','29305','1','','1','0','','','',0, 1, 0, 0),
(2354,'APPL HIP SPICA CAST ONE&ONE-HALF SPICA/BOTH LEGS','APPL HIP SPICA CAST ONE&ONE-HALF SPICA/BOTH LEGS','29325','1','','1','0','','','',0, 1, 0, 0),
(2355,'APPLICATION LONG LEG CAST THIGH-TOE','APPLICATION LONG LEG CAST THIGH-TOE','29345','1','','1','0','','','',0, 1, 0, 0),
(2356,'APPLICATION LONG LEG CAST WALKER/AMBULATORY TYPE','APPLICATION LONG LEG CAST WALKER/AMBULATORY TYPE','29355','1','','1','0','','','',0, 1, 0, 0),
(2357,'APPLICATION LONG LEG CAST BRACE','APPLICATION LONG LEG CAST BRACE','29358','1','','1','0','','','',0, 1, 0, 0),
(2358,'APPLICATION CYLINDER CAST THIGH ANKLE','APPLICATION CYLINDER CAST THIGH ANKLE','29365','1','','1','0','','','',0, 1, 0, 0),
(2359,'APPLICATION SHORT LEG CAST BELOW KNEE-TOE','APPLICATION SHORT LEG CAST BELOW KNEE-TOE','29405','1','','1','0','','','',0, 1, 0, 0),
(2360,'APPLICATION SHORT LEG CAST WALKING/AMBULATORY','APPLICATION SHORT LEG CAST WALKING/AMBULATORY','29425','1','','1','0','','','',0, 1, 0, 0),
(2361,'APPLICATION PATELLAR TENDON BEARING CAST','APPLICATION PATELLAR TENDON BEARING CAST','29435','1','','1','0','','','',0, 1, 0, 0),
(2362,'ADDING WALKER PREVIOUSLY APPLIED CAST','ADDING WALKER PREVIOUSLY APPLIED CAST','29440','1','','1','0','','','',0, 1, 0, 0),
(2363,'APPLICATION RIGID TOTAL CONTACT LEG CAST','APPLICATION RIGID TOTAL CONTACT LEG CAST','29445','1','','1','0','','','',0, 1, 0, 0),
(2364,'APPL CLUBFOOT CAST MOLDING/MANJ LONG/SHORT LEG','APPL CLUBFOOT CAST MOLDING/MANJ LONG/SHORT LEG','29450','1','','1','0','','','',0, 1, 0, 0),
(2365,'APPLICATION LONG LEG SPLINT THIGH ANKLE/TOES','APPLICATION LONG LEG SPLINT THIGH ANKLE/TOES','29505','1','','1','0','','','',0, 1, 0, 0),
(2366,'APPLICATION SHORT LEG SPLINT CALF FOOT','APPLICATION SHORT LEG SPLINT CALF FOOT','29515','1','','1','0','','','',0, 1, 0, 0),
(2367,'STRAPPING HIP','STRAPPING HIP','29520','1','','1','0','','','',0, 1, 0, 0),
(2368,'STRAPPING KNEE','STRAPPING KNEE','29530','1','','1','0','','','',0, 1, 0, 0),
(2369,'STRAPPING ANKLE &/FOOT','STRAPPING ANKLE &/FOOT','29540','1','','1','0','','','',0, 1, 0, 0),
(2370,'STRAPPING TOES','STRAPPING TOES','29550','1','','1','0','','','',0, 1, 0, 0),
(2371,'STRAPPING UNNA BOOT','STRAPPING UNNA BOOT','29580','1','','1','0','','','',0, 1, 0, 0),
(2372,'APPL MLTLAYR COMPRES LEG BELOW KNEE W/ANKLE FOOT','APPL MLTLAYR COMPRES LEG BELOW KNEE W/ANKLE FOOT','29581','1','','1','0','','','',0, 1, 0, 0),
(2373,'APPL MLTLAYR COMPRES THGH LEG ANKLE FT WHEN DONE','APPL MLTLAYR COMPRES THGH LEG ANKLE FT WHEN DONE','29582','1','','1','0','','','',0, 1, 0, 0),
(2374,'APPL MLTLAYR COMPRES SYSTEM UPPER & LOWER ARM','APPL MLTLAYR COMPRES SYSTEM UPPER & LOWER ARM','29583','1','','1','0','','','',0, 1, 0, 0),
(2375,'APPL MLTLAYR COMPRES SYS UPARM LWARM HAND&FING','APPL MLTLAYR COMPRES SYS UPARM LWARM HAND&FING','29584','1','','1','0','','','',0, 1, 0, 0),
(2376,'REMOVAL/BIVALVING GAUNTLET BOOT/BODY CAST','REMOVAL/BIVALVING GAUNTLET BOOT/BODY CAST','29700','1','','1','0','','','',0, 1, 0, 0),
(2377,'REMOVAL/BIVALVING FULL ARM/FULL LEG CAST','REMOVAL/BIVALVING FULL ARM/FULL LEG CAST','29705','1','','1','0','','','',0, 1, 0, 0),
(2378,'RMVL/BIVALV SHO/HIP SPICA MINERVA/RISSER JACKET','RMVL/BIVALV SHO/HIP SPICA MINERVA/RISSER JACKET','29710','1','','1','0','','','',0, 1, 0, 0),
(2379,'REPAIR SPICA BODY CAST/JACKET','REPAIR SPICA BODY CAST/JACKET','29720','1','','1','0','','','',0, 1, 0, 0),
(2380,'WINDOWING CAST','WINDOWING CAST','29730','1','','1','0','','','',0, 1, 0, 0),
(2381,'WEDGING CAST EXCEPT CLUBFOOT CASTS','WEDGING CAST EXCEPT CLUBFOOT CASTS','29740','1','','1','0','','','',0, 1, 0, 0),
(2382,'WEDGING CLUBFOOT CAST','WEDGING CLUBFOOT CAST','29750','1','','1','0','','','',0, 1, 0, 0),
(2383,'UNLISTED PROCEDURE CASTING/STRAPPING','UNLISTED PROCEDURE CASTING/STRAPPING','29799','1','','1','0','','','',0, 1, 0, 0),
(2384,'ARTHRS TEMPOROMANDIBULR JT DX W/WO SYNVAL BX SPX','ARTHRS TEMPOROMANDIBULR JT DX W/WO SYNVAL BX SPX','29800','1','','1','0','','','',0, 1, 0, 0),
(2385,'ARTHROSCOPY TEMPOROMANDIBULAR JOINT SURGICAL','ARTHROSCOPY TEMPOROMANDIBULAR JOINT SURGICAL','29804','1','','1','0','','','',0, 1, 0, 0),
(2386,'ARTHROSCOPY SHOULDER DX W/WO SYNOVIAL BIOPSY SPX','ARTHROSCOPY SHOULDER DX W/WO SYNOVIAL BIOPSY SPX','29805','1','','1','0','','','',0, 1, 0, 0),
(2387,'ARTHROSCOPY SHOULDER SURGICAL CAPSULORRHAPHY','ARTHROSCOPY SHOULDER SURGICAL CAPSULORRHAPHY','29806','1','','1','0','','','',0, 1, 0, 0),
(2388,'ARTHROSCOPY SHOULDER SURGICAL REPAIR SLAP LESION','ARTHROSCOPY SHOULDER SURGICAL REPAIR SLAP LESION','29807','1','','1','0','','','',0, 1, 0, 0),
(2389,'ARTHROSCOPY SHOULDER SURGICAL REMOVAL LOOSE/FB','ARTHROSCOPY SHOULDER SURGICAL REMOVAL LOOSE/FB','29819','1','','1','0','','','',0, 1, 0, 0),
(2390,'ARTHROSCOPY SHOULDER SURG SYNOVECTOMY PARTIAL','ARTHROSCOPY SHOULDER SURG SYNOVECTOMY PARTIAL','29820','1','','1','0','','','',0, 1, 0, 0),
(2391,'ARTHROSCOPY SHOULDER SURG SYNOVECTOMY COMPLETE','ARTHROSCOPY SHOULDER SURG SYNOVECTOMY COMPLETE','29821','1','','1','0','','','',0, 1, 0, 0),
(2392,'ARTHROSCOPY SHOULDER SURG DEBRIDEMENT LIMITED','ARTHROSCOPY SHOULDER SURG DEBRIDEMENT LIMITED','29822','1','','1','0','','','',0, 1, 0, 0),
(2393,'ARTHROSCOPY SHOULDER SURG DEBRIDEMENT EXTENSIVE','ARTHROSCOPY SHOULDER SURG DEBRIDEMENT EXTENSIVE','29823','1','','1','0','','','',0, 1, 0, 0),
(2394,'ARTHROSCOPY SHOULDER DISTAL CLAVICULECTOMY','ARTHROSCOPY SHOULDER DISTAL CLAVICULECTOMY','29824','1','','1','0','','','',0, 1, 0, 0),
(2395,'ARTHROSCOPY SHOULDER AHESIOLYSIS W/WO MANIPJ','ARTHROSCOPY SHOULDER AHESIOLYSIS W/WO MANIPJ','29825','1','','1','0','','','',0, 1, 0, 0),
(2396,'ARTHROSCOPY SHOULDER W/CORACOACRM LIGMNT RELEASE','ARTHROSCOPY SHOULDER W/CORACOACRM LIGMNT RELEASE','29826','1','','1','0','','','',0, 1, 0, 0),
(2397,'ARTHROSCOPY SHOULDER ROTATOR CUFF REPAIR','ARTHROSCOPY SHOULDER ROTATOR CUFF REPAIR','29827','1','','1','0','','','',0, 1, 0, 0),
(2398,'ARTHROSCOPY SHOULDER BICEPS TENODESIS','ARTHROSCOPY SHOULDER BICEPS TENODESIS','29828','1','','1','0','','','',0, 1, 0, 0),
(2399,'ARTHROSCOPY ELBOW DIAG W/WO SYNOVIAL BIOPSY SPX','ARTHROSCOPY ELBOW DIAG W/WO SYNOVIAL BIOPSY SPX','29830','1','','1','0','','','',0, 1, 0, 0),
(2400,'ARTHROSCOPY ELBOW SURGICAL W/REMOVAL LOOSE/FB','ARTHROSCOPY ELBOW SURGICAL W/REMOVAL LOOSE/FB','29834','1','','1','0','','','',0, 1, 0, 0),
(2401,'ARTHROSCOPY ELBOW SURGICAL SYNOVECTOMY PARTIAL','ARTHROSCOPY ELBOW SURGICAL SYNOVECTOMY PARTIAL','29835','1','','1','0','','','',0, 1, 0, 0),
(2402,'ARTHROSCOPY ELBOW SURGICAL SYNOVECTOMY COMPLETE','ARTHROSCOPY ELBOW SURGICAL SYNOVECTOMY COMPLETE','29836','1','','1','0','','','',0, 1, 0, 0),
(2403,'ARTHROSCOPY ELBOW SURGICAL DEBRIDEMENT LIMITED','ARTHROSCOPY ELBOW SURGICAL DEBRIDEMENT LIMITED','29837','1','','1','0','','','',0, 1, 0, 0),
(2404,'ARTHROSCOPY ELBOW SURGICAL DEBRIDEMENT EXTENSIVE','ARTHROSCOPY ELBOW SURGICAL DEBRIDEMENT EXTENSIVE','29838','1','','1','0','','','',0, 1, 0, 0),
(2405,'ARTHROSCOPY WRIST DIAG W/WO SYNOVIAL BIOPSY SPX','ARTHROSCOPY WRIST DIAG W/WO SYNOVIAL BIOPSY SPX','29840','1','','1','0','','','',0, 1, 0, 0),
(2406,'ARTHROSCOPY WRIST INFECTION LAVAGE&DRAINAGE','ARTHROSCOPY WRIST INFECTION LAVAGE&DRAINAGE','29843','1','','1','0','','','',0, 1, 0, 0),
(2407,'ARTHROSCOPY WRIST SURGICAL SYNOVECTOMY PARTIAL','ARTHROSCOPY WRIST SURGICAL SYNOVECTOMY PARTIAL','29844','1','','1','0','','','',0, 1, 0, 0),
(2408,'ARTHROSCOPY WRIST SURGICAL SYNOVECTOMY COMPLETE','ARTHROSCOPY WRIST SURGICAL SYNOVECTOMY COMPLETE','29845','1','','1','0','','','',0, 1, 0, 0),
(2409,'ARTHRS WRST EXC&/RPR TRIANG FIBROCART&/JOINT','ARTHRS WRST EXC&/RPR TRIANG FIBROCART&/JOINT','29846','1','','1','0','','','',0, 1, 0, 0),
(2410,'ARTHROSCOPY WRIST SURG INT FIXJ FX/INSTABILITY','ARTHROSCOPY WRIST SURG INT FIXJ FX/INSTABILITY','29847','1','','1','0','','','',0, 1, 0, 0),
(2411,'NDSC WRST SURG W/RLS TRANSVRS CARPL LIGM','NDSC WRST SURG W/RLS TRANSVRS CARPL LIGM','29848','1','','1','0','','','',0, 1, 0, 0),
(2412,'ARTHROSCOPY AID TX SPINE&/FX KNEE W/O FIXJ','ARTHROSCOPY AID TX SPINE&/FX KNEE W/O FIXJ','29850','1','','1','0','','','',0, 1, 0, 0),
(2413,'ARTHROSCOPY AID TX SPINE&/FX KNEE W/FIXJ','ARTHROSCOPY AID TX SPINE&/FX KNEE W/FIXJ','29851','1','','1','0','','','',0, 1, 0, 0),
(2414,'ARTHRS AID TIBIAL FRACTURE PROXIMAL UNICONDYLAR','ARTHRS AID TIBIAL FRACTURE PROXIMAL UNICONDYLAR','29855','1','','1','0','','','',0, 1, 0, 0),
(2415,'ARTHRS AID TIBIAL FX PROX UNICONDYLAR BICONDYLAR','ARTHRS AID TIBIAL FX PROX UNICONDYLAR BICONDYLAR','29856','1','','1','0','','','',0, 1, 0, 0),
(2416,'ARTHROSCOPY HIP DIAGNOSTIC W/WO SYNOVIAL BYP SPX','ARTHROSCOPY HIP DIAGNOSTIC W/WO SYNOVIAL BYP SPX','29860','1','','1','0','','','',0, 1, 0, 0),
(2417,'ARTHROSCOPY HIP SURGICAL W/REMOVAL LOOSE/FB','ARTHROSCOPY HIP SURGICAL W/REMOVAL LOOSE/FB','29861','1','','1','0','','','',0, 1, 0, 0),
(2418,'ARTHRS HIP DEBRIDEMENT/SHAVING ARTICULAR CRTLG','ARTHRS HIP DEBRIDEMENT/SHAVING ARTICULAR CRTLG','29862','1','','1','0','','','',0, 1, 0, 0),
(2419,'ARTHROSCOPY HIP SURGICAL W/SYNOVECTOMY','ARTHROSCOPY HIP SURGICAL W/SYNOVECTOMY','29863','1','','1','0','','','',0, 1, 0, 0),
(2420,'ARTHROSCOPY KNEE OSTEOCHONDRAL AGRFT MOSAICPLAST','ARTHROSCOPY KNEE OSTEOCHONDRAL AGRFT MOSAICPLAST','29866','1','','1','0','','','',0, 1, 0, 0),
(2421,'ARTHROSCOPY KNEE OSTEOCHONDRAL ALLOGRAFT','ARTHROSCOPY KNEE OSTEOCHONDRAL ALLOGRAFT','29867','1','','1','0','','','',0, 1, 0, 0),
(2422,'ARTHROSCOPY KNEE MENISCAL TRNSPLJ MED/LAT','ARTHROSCOPY KNEE MENISCAL TRNSPLJ MED/LAT','29868','1','','1','0','','','',0, 1, 0, 0),
(2423,'ARTHROSCOPY KNEE DIAGNOSTIC W/WO SYNOVIAL BX SPX','ARTHROSCOPY KNEE DIAGNOSTIC W/WO SYNOVIAL BX SPX','29870','1','','1','0','','','',0, 1, 0, 0),
(2424,'ARTHROSCOPY KNEE INFECTION LAVAGE & DRAINAGE','ARTHROSCOPY KNEE INFECTION LAVAGE & DRAINAGE','29871','1','','1','0','','','',0, 1, 0, 0),
(2425,'ARTHROSCOPY KNEE LATERAL RELEASE','ARTHROSCOPY KNEE LATERAL RELEASE','29873','1','','1','0','','','',0, 1, 0, 0),
(2426,'ARTHROSCOPY KNEE REMOVAL LOOSE/FOREIGN BODY','ARTHROSCOPY KNEE REMOVAL LOOSE/FOREIGN BODY','29874','1','','1','0','','','',0, 1, 0, 0),
(2427,'ARTHROSCOPY KNEE SYNOVECTOMY LIMITED SPX','ARTHROSCOPY KNEE SYNOVECTOMY LIMITED SPX','29875','1','','1','0','','','',0, 1, 0, 0),
(2428,'ARTHROSCOPY KNEE SYNOVECTOMY 2/>COMPARTMENTS','ARTHROSCOPY KNEE SYNOVECTOMY 2/>COMPARTMENTS','29876','1','','1','0','','','',0, 1, 0, 0),
(2429,'ARTHRS KNEE DEBRIDEMENT/SHAVING ARTCLR CRTLG','ARTHRS KNEE DEBRIDEMENT/SHAVING ARTCLR CRTLG','29877','1','','1','0','','','',0, 1, 0, 0),
(2430,'ARTHRS KNEE ABRASION ARTHRP/MLT DRLG/MICROFX','ARTHRS KNEE ABRASION ARTHRP/MLT DRLG/MICROFX','29879','1','','1','0','','','',0, 1, 0, 0),
(2431,'ARTHRS KNEE W/MENISCECTOMY MED&LAT W/SHAVING','ARTHRS KNEE W/MENISCECTOMY MED&LAT W/SHAVING','29880','1','','1','0','','','',0, 1, 0, 0),
(2432,'ARTHRS KNE SURG W/MENISCECTOMY MED/LAT W/SHVG','ARTHRS KNE SURG W/MENISCECTOMY MED/LAT W/SHVG','29881','1','','1','0','','','',0, 1, 0, 0),
(2433,'ARTHROSCOPY KNEE W/MENISCUS RPR MEDIAL/LATERAL','ARTHROSCOPY KNEE W/MENISCUS RPR MEDIAL/LATERAL','29882','1','','1','0','','','',0, 1, 0, 0),
(2434,'ARTHROSCOPY KNEE W/MENISCUS RPR MEDIAL&LATERAL','ARTHROSCOPY KNEE W/MENISCUS RPR MEDIAL&LATERAL','29883','1','','1','0','','','',0, 1, 0, 0),
(2435,'ARTHROSCOPY KNEE W/LYSIS ADHESIONS W/WO MANJ SPX','ARTHROSCOPY KNEE W/LYSIS ADHESIONS W/WO MANJ SPX','29884','1','','1','0','','','',0, 1, 0, 0),
(2436,'ARTHRS KNEE DRILL OSTEOCHONDRITIS DISSECANS GRFG','ARTHRS KNEE DRILL OSTEOCHONDRITIS DISSECANS GRFG','29885','1','','1','0','','','',0, 1, 0, 0),
(2437,'ARTHRS KNEE DRILLING OSTEOCHOND DISSECANS LESION','ARTHRS KNEE DRILLING OSTEOCHOND DISSECANS LESION','29886','1','','1','0','','','',0, 1, 0, 0),
(2438,'ARTHRS KNEE DRLG OSTEOCHOND DISSECANS INT FIXJ','ARTHRS KNEE DRLG OSTEOCHOND DISSECANS INT FIXJ','29887','1','','1','0','','','',0, 1, 0, 0),
(2439,'ARTHRS AIDED ANT CRUCIATE LIGM RPR/AGMNTJ/RCNSTJ','ARTHRS AIDED ANT CRUCIATE LIGM RPR/AGMNTJ/RCNSTJ','29888','1','','1','0','','','',0, 1, 0, 0),
(2440,'ARTHRS AIDED PST CRUCIATE LIGM RPR/AGMNTJ/RCNSTJ','ARTHRS AIDED PST CRUCIATE LIGM RPR/AGMNTJ/RCNSTJ','29889','1','','1','0','','','',0, 1, 0, 0),
(2441,'ARTHRS ANKLE EXC OSTCHNDRL DFCT W/DRLG DFCT','ARTHRS ANKLE EXC OSTCHNDRL DFCT W/DRLG DFCT','29891','1','','1','0','','','',0, 1, 0, 0),
(2442,'ARTHRS AID RPR LES/TALAR DOME FX/TIBL PLAFOND FX','ARTHRS AID RPR LES/TALAR DOME FX/TIBL PLAFOND FX','29892','1','','1','0','','','',0, 1, 0, 0),
(2443,'ENDOSCOPIC PLANTAR FASCIOTOMY','ENDOSCOPIC PLANTAR FASCIOTOMY','29893','1','','1','0','','','',0, 1, 0, 0),
(2444,'ARTHROSCOPY ANKLE W/REMOVAL LOOSE/FOREIGN BODY','ARTHROSCOPY ANKLE W/REMOVAL LOOSE/FOREIGN BODY','29894','1','','1','0','','','',0, 1, 0, 0),
(2445,'ARTHROSCOPY ANKLE SURGICAL SYNOVECTOMY PARTIAL','ARTHROSCOPY ANKLE SURGICAL SYNOVECTOMY PARTIAL','29895','1','','1','0','','','',0, 1, 0, 0),
(2446,'ARTHROSCOPY ANKLE SURGICAL DEBRIDEMENT LIMITED','ARTHROSCOPY ANKLE SURGICAL DEBRIDEMENT LIMITED','29897','1','','1','0','','','',0, 1, 0, 0),
(2447,'ARTHROSCOPY ANKLE SURGICAL DEBRIDEMENT EXTENSIVE','ARTHROSCOPY ANKLE SURGICAL DEBRIDEMENT EXTENSIVE','29898','1','','1','0','','','',0, 1, 0, 0),
(2448,'ARTHROSCOPY ANKLE SURGICAL W/ANKLE ARTHRODESIS','ARTHROSCOPY ANKLE SURGICAL W/ANKLE ARTHRODESIS','29899','1','','1','0','','','',0, 1, 0, 0),
(2449,'ARTHROSCOPY METACARPOPHALANGEAL SYNOVIAL BIOPSY','ARTHROSCOPY METACARPOPHALANGEAL SYNOVIAL BIOPSY','29900','1','','1','0','','','',0, 1, 0, 0),
(2450,'ARTHRS METACARPOPHALANGEAL JOINT DEBRIDEMENT','ARTHRS METACARPOPHALANGEAL JOINT DEBRIDEMENT','29901','1','','1','0','','','',0, 1, 0, 0),
(2451,'ARTHRS MTCARPHLNGL JT W/RDCTJ UR COLTRL LIGM','ARTHRS MTCARPHLNGL JT W/RDCTJ UR COLTRL LIGM','29902','1','','1','0','','','',0, 1, 0, 0),
(2452,'ARTHRS SUBTALAR JOINT REMOVE LOOSE/FOREIGN BODY','ARTHRS SUBTALAR JOINT REMOVE LOOSE/FOREIGN BODY','29904','1','','1','0','','','',0, 1, 0, 0),
(2453,'ARTHROSCOPY SUBTALAR JOINT WITH SYNOVECTOMY','ARTHROSCOPY SUBTALAR JOINT WITH SYNOVECTOMY','29905','1','','1','0','','','',0, 1, 0, 0),
(2454,'ARTHROSCOPY SUBTALAR JOINT WITH DEBRIDEMENT','ARTHROSCOPY SUBTALAR JOINT WITH DEBRIDEMENT','29906','1','','1','0','','','',0, 1, 0, 0),
(2455,'ARTHROSCOPY SUBTALAR JOINT SUBTALAR ARTHRODESIS','ARTHROSCOPY SUBTALAR JOINT SUBTALAR ARTHRODESIS','29907','1','','1','0','','','',0, 1, 0, 0),
(2456,'ARTHROSCOPY HIP W/FEMOROPLASTY','ARTHROSCOPY HIP W/FEMOROPLASTY','29914','1','','1','0','','','',0, 1, 0, 0),
(2457,'ARTHROSCOPY HIP W/ACETABULOPLASTY','ARTHROSCOPY HIP W/ACETABULOPLASTY','29915','1','','1','0','','','',0, 1, 0, 0),
(2458,'ARTHROSCOPY HIP W/LABRAL REPAIR','ARTHROSCOPY HIP W/LABRAL REPAIR','29916','1','','1','0','','','',0, 1, 0, 0),
(2459,'UNLISTED PROCEDURE ARTHROSCOPY','UNLISTED PROCEDURE ARTHROSCOPY','29999','1','','1','0','','','',0, 1, 0, 0),
(2460,'DRAINAGE ABSCESS/HEMATOMA NASAL INT APPROACH','DRAINAGE ABSCESS/HEMATOMA NASAL INT APPROACH','30000','1','','1','0','','','',0, 1, 0, 0),
(2461,'DRAINAGE ABSCESS/HEMATOMA NASAL SEPTUM','DRAINAGE ABSCESS/HEMATOMA NASAL SEPTUM','30020','1','','1','0','','','',0, 1, 0, 0),
(2462,'BIOPSY INTRANASAL','BIOPSY INTRANASAL','30100','1','','1','0','','','',0, 1, 0, 0),
(2463,'EXCISION NASAL POLYP SIMPLE','EXCISION NASAL POLYP SIMPLE','30110','1','','1','0','','','',0, 1, 0, 0),
(2464,'EXCISION NASAL POLYP EXTENSIVE','EXCISION NASAL POLYP EXTENSIVE','30115','1','','1','0','','','',0, 1, 0, 0),
(2465,'EXCISION/DESTRUCTION INTRANASAL LESION INT APPR','EXCISION/DESTRUCTION INTRANASAL LESION INT APPR','30117','1','','1','0','','','',0, 1, 0, 0),
(2466,'EXCISION/DESTRUCTION INTRANASAL LESION XTRNL','EXCISION/DESTRUCTION INTRANASAL LESION XTRNL','30118','1','','1','0','','','',0, 1, 0, 0),
(2467,'EXCISION/SURGICAL PLANING SKIN NOSE RHINOPHYMA','EXCISION/SURGICAL PLANING SKIN NOSE RHINOPHYMA','30120','1','','1','0','','','',0, 1, 0, 0),
(2468,'EXCISION DERMOID CYST NOSE SIMPLE SUBCUTANEOUS','EXCISION DERMOID CYST NOSE SIMPLE SUBCUTANEOUS','30124','1','','1','0','','','',0, 1, 0, 0),
(2469,'EXC DERMOID CYST NOSE COMPLEX UNDER BONE/CRTLG','EXC DERMOID CYST NOSE COMPLEX UNDER BONE/CRTLG','30125','1','','1','0','','','',0, 1, 0, 0),
(2470,'EXCISION INFERIOR TURBINATE PARTIAL/COMPLETE','EXCISION INFERIOR TURBINATE PARTIAL/COMPLETE','30130','1','','1','0','','','',0, 1, 0, 0),
(2471,'SUBMUCOUS RESCJ INFERIOR TURBINATE PRTL/COMPL','SUBMUCOUS RESCJ INFERIOR TURBINATE PRTL/COMPL','30140','1','','1','0','','','',0, 1, 0, 0),
(2472,'RHINECTOMY PARTIAL','RHINECTOMY PARTIAL','30150','1','','1','0','','','',0, 1, 0, 0),
(2473,'RHINECTOMY TOTAL','RHINECTOMY TOTAL','30160','1','','1','0','','','',0, 1, 0, 0),
(2474,'INJECTION TURBINATE THERAPEUTIC','INJECTION TURBINATE THERAPEUTIC','30200','1','','1','0','','','',0, 1, 0, 0),
(2475,'DISPLACEMENT THERAPY PROETZ TYPE','DISPLACEMENT THERAPY PROETZ TYPE','30210','1','','1','0','','','',0, 1, 0, 0),
(2476,'INSERTION NASAL SEPTAL PROSTHESIS BUTTON','INSERTION NASAL SEPTAL PROSTHESIS BUTTON','30220','1','','1','0','','','',0, 1, 0, 0),
(2477,'REMOVAL FOREIGN BODY INTRANASAL OFFICE PROCEDURE','REMOVAL FOREIGN BODY INTRANASAL OFFICE PROCEDURE','30300','1','','1','0','','','',0, 1, 0, 0),
(2478,'REMOVAL FOREIGN BODY INTRANASAL GENERAL ANES','REMOVAL FOREIGN BODY INTRANASAL GENERAL ANES','30310','1','','1','0','','','',0, 1, 0, 0),
(2479,'RMVL FOREIGN BODY INTRANASAL LATERAL RHINOTOMY','RMVL FOREIGN BODY INTRANASAL LATERAL RHINOTOMY','30320','1','','1','0','','','',0, 1, 0, 0),
(2480,'RHINP PRIM LAT&ALAR CRTLGS&/ELVTN NASAL TI','RHINP PRIM LAT&ALAR CRTLGS&/ELVTN NASAL TI','30400','1','','1','0','','','',0, 1, 0, 0),
(2481,'RHINP PRIM COMPLETE XTRNL PARTS','RHINP PRIM COMPLETE XTRNL PARTS','30410','1','','1','0','','','',0, 1, 0, 0),
(2482,'RHINOPLASTY PRIMARY W/MAJOR SEPTAL REPAIR','RHINOPLASTY PRIMARY W/MAJOR SEPTAL REPAIR','30420','1','','1','0','','','',0, 1, 0, 0),
(2483,'RHINOPLASTY SECONDARY MINOR REVISION','RHINOPLASTY SECONDARY MINOR REVISION','30430','1','','1','0','','','',0, 1, 0, 0),
(2484,'RHINOPLASTY SECONDARY INTERMEDIATE REVISION','RHINOPLASTY SECONDARY INTERMEDIATE REVISION','30435','1','','1','0','','','',0, 1, 0, 0),
(2485,'RHINOPLASTY SECONDARY MAJOR REVISION','RHINOPLASTY SECONDARY MAJOR REVISION','30450','1','','1','0','','','',0, 1, 0, 0),
(2486,'RHINP DFRM W/COLUM LNGTH TIP ONLY','RHINP DFRM W/COLUM LNGTH TIP ONLY','30460','1','','1','0','','','',0, 1, 0, 0),
(2487,'RHINP DFRM COLUM LNGTH TIP SEPTUM OSTEOT','RHINP DFRM COLUM LNGTH TIP SEPTUM OSTEOT','30462','1','','1','0','','','',0, 1, 0, 0),
(2488,'REPAIR NASAL VESTIBULAR STENOSIS','REPAIR NASAL VESTIBULAR STENOSIS','30465','1','','1','0','','','',0, 1, 0, 0),
(2489,'SEPTOPLASTY/SUBMUCOUS RESECJ W/WO CARTILAGE GRF','SEPTOPLASTY/SUBMUCOUS RESECJ W/WO CARTILAGE GRF','30520','1','','1','0','','','',0, 1, 0, 0),
(2490,'REPAIR CHOANAL ATRESIA INTRANASAL','REPAIR CHOANAL ATRESIA INTRANASAL','30540','1','','1','0','','','',0, 1, 0, 0),
(2491,'REPAIR CHOANAL ATRESIA TRANSPALATINE','REPAIR CHOANAL ATRESIA TRANSPALATINE','30545','1','','1','0','','','',0, 1, 0, 0),
(2492,'LYSIS INTRANASAL SYNECHIA','LYSIS INTRANASAL SYNECHIA','30560','1','','1','0','','','',0, 1, 0, 0),
(2493,'REPAIR FISTULA OROMAXILLARY','REPAIR FISTULA OROMAXILLARY','30580','1','','1','0','','','',0, 1, 0, 0),
(2494,'REPAIR FISTULA ORONASAL','REPAIR FISTULA ORONASAL','30600','1','','1','0','','','',0, 1, 0, 0),
(2495,'SEPTAL/OTHER INTRANASAL DERMATOPLASTY','SEPTAL/OTHER INTRANASAL DERMATOPLASTY','30620','1','','1','0','','','',0, 1, 0, 0),
(2496,'REPAIR NASAL SEPTAL PERFORATIONS','REPAIR NASAL SEPTAL PERFORATIONS','30630','1','','1','0','','','',0, 1, 0, 0),
(2497,'ABLTJ SOFT TIS INFERIOR TURBINATES UNI/BI SUPFC','ABLTJ SOFT TIS INFERIOR TURBINATES UNI/BI SUPFC','30801','1','','1','0','','','',0, 1, 0, 0),
(2498,'ABLTJ SOF TISS INF TURBS UNI/BI SUPFC INTRAMURAL','ABLTJ SOF TISS INF TURBS UNI/BI SUPFC INTRAMURAL','30802','1','','1','0','','','',0, 1, 0, 0),
(2499,'CONTROL NASAL HEMORRHAGE ANTERIOR SIMPLE','CONTROL NASAL HEMORRHAGE ANTERIOR SIMPLE','30901','1','','1','0','','','',0, 1, 0, 0),
(2500,'CONTROL NASAL HEMORRHAGE ANTERIOR COMPLEX','CONTROL NASAL HEMORRHAGE ANTERIOR COMPLEX','30903','1','','1','0','','','',0, 1, 0, 0),
(2501,'CTRL NSL HEMRRG PST NASAL PACKS&/CAUTERY 1ST','CTRL NSL HEMRRG PST NASAL PACKS&/CAUTERY 1ST','30905','1','','1','0','','','',0, 1, 0, 0),
(2502,'CTRL NSL HEMRRG PST NASAL PACKS&/CAUTERY SUBSQ','CTRL NSL HEMRRG PST NASAL PACKS&/CAUTERY SUBSQ','30906','1','','1','0','','','',0, 1, 0, 0),
(2503,'LIGATION ARTERIES ETHMOIDAL','LIGATION ARTERIES ETHMOIDAL','30915','1','','1','0','','','',0, 1, 0, 0),
(2504,'LIGATION ARTERIES INT MAXILLARY TRANSANTRAL','LIGATION ARTERIES INT MAXILLARY TRANSANTRAL','30920','1','','1','0','','','',0, 1, 0, 0),
(2505,'FRACTURE NASAL INFERIOR TURBINATE THERAPEUTIC','FRACTURE NASAL INFERIOR TURBINATE THERAPEUTIC','30930','1','','1','0','','','',0, 1, 0, 0),
(2506,'UNLISTED PROCEDURE NOSE','UNLISTED PROCEDURE NOSE','30999','1','','1','0','','','',0, 1, 0, 0),
(2507,'LAVAGE CANNULATION MAXILLARY SINUS','LAVAGE CANNULATION MAXILLARY SINUS','31000','1','','1','0','','','',0, 1, 0, 0),
(2508,'LAVAGE CANNULATION SPHENOID SINUS','LAVAGE CANNULATION SPHENOID SINUS','31002','1','','1','0','','','',0, 1, 0, 0),
(2509,'SINUSOTOMY MAXILLARY ANTROTOMY INTRANASAL','SINUSOTOMY MAXILLARY ANTROTOMY INTRANASAL','31020','1','','1','0','','','',0, 1, 0, 0),
(2510,'SINUSOTOMY MAXILLARY RAD W/O RMVL ANTROCH POLYPS','SINUSOTOMY MAXILLARY RAD W/O RMVL ANTROCH POLYPS','31030','1','','1','0','','','',0, 1, 0, 0),
(2511,'SINUSOT MAX ANTRT RAD W/RMVL ANTROCH POLYPS','SINUSOT MAX ANTRT RAD W/RMVL ANTROCH POLYPS','31032','1','','1','0','','','',0, 1, 0, 0),
(2512,'PTERYGOMAXILLARY FOSSA SURGERY ANY APPROACH','PTERYGOMAXILLARY FOSSA SURGERY ANY APPROACH','31040','1','','1','0','','','',0, 1, 0, 0),
(2513,'SINUSOTOMY SPHENOID W/WO BIOPSY','SINUSOTOMY SPHENOID W/WO BIOPSY','31050','1','','1','0','','','',0, 1, 0, 0),
(2514,'SINUSOT SPHENOID W/MUCOSAL STRIPPING/RMVL POLYP','SINUSOT SPHENOID W/MUCOSAL STRIPPING/RMVL POLYP','31051','1','','1','0','','','',0, 1, 0, 0),
(2515,'SINUSOTOMY FRONTAL EXTERNAL SIMPLE','SINUSOTOMY FRONTAL EXTERNAL SIMPLE','31070','1','','1','0','','','',0, 1, 0, 0),
(2516,'SINUSOTOMY FRONTAL TRANSORBITAL UNILATERAL','SINUSOTOMY FRONTAL TRANSORBITAL UNILATERAL','31075','1','','1','0','','','',0, 1, 0, 0),
(2517,'SINUSOTOMY FRNT OBLITERATIVE W/O FLAP BROW INC','SINUSOTOMY FRNT OBLITERATIVE W/O FLAP BROW INC','31080','1','','1','0','','','',0, 1, 0, 0),
(2518,'SINUSOT FRNT OBLIT W/O OSTPL FLAP CORONAL INC','SINUSOT FRNT OBLIT W/O OSTPL FLAP CORONAL INC','31081','1','','1','0','','','',0, 1, 0, 0),
(2519,'SINUSOT FRNT OBLIT W/OSTPL FLAP BROW INC','SINUSOT FRNT OBLIT W/OSTPL FLAP BROW INC','31084','1','','1','0','','','',0, 1, 0, 0),
(2520,'SINUSOT FRNT OBLIT W/OSTPL FLAP CORONAL INC','SINUSOT FRNT OBLIT W/OSTPL FLAP CORONAL INC','31085','1','','1','0','','','',0, 1, 0, 0),
(2521,'SINUSOT FRNT NONOBLIT W/OSTPL FLAP BROW INC','SINUSOT FRNT NONOBLIT W/OSTPL FLAP BROW INC','31086','1','','1','0','','','',0, 1, 0, 0),
(2522,'SINUSOT FRNT NONOBLIT W/OSTPL FLAP CORONAL INC','SINUSOT FRNT NONOBLIT W/OSTPL FLAP CORONAL INC','31087','1','','1','0','','','',0, 1, 0, 0),
(2523,'SINUSOT UNI 3/> PARANSL SINUSES','SINUSOT UNI 3/> PARANSL SINUSES','31090','1','','1','0','','','',0, 1, 0, 0),
(2524,'ETHMOIDECTOMY INTRANASAL ANTERIOR','ETHMOIDECTOMY INTRANASAL ANTERIOR','31200','1','','1','0','','','',0, 1, 0, 0),
(2525,'ETHMOIDECTOMY INTRANASAL TOTAL','ETHMOIDECTOMY INTRANASAL TOTAL','31201','1','','1','0','','','',0, 1, 0, 0),
(2526,'ETHMOIDECTOMY EXTRANASAL TOTAL','ETHMOIDECTOMY EXTRANASAL TOTAL','31205','1','','1','0','','','',0, 1, 0, 0),
(2527,'MAXILLECTOMY W/O ORBITAL EXENTERATION','MAXILLECTOMY W/O ORBITAL EXENTERATION','31225','1','','1','0','','','',0, 1, 0, 0),
(2528,'MAXILLECTOMY W/ORBITAL EXENTERATION','MAXILLECTOMY W/ORBITAL EXENTERATION','31230','1','','1','0','','','',0, 1, 0, 0),
(2529,'NASAL ENDOSCOPY DIAGNOSTIC UNI/BI SPX','NASAL ENDOSCOPY DIAGNOSTIC UNI/BI SPX','31231','1','','1','0','','','',0, 1, 0, 0),
(2530,'NASAL/SINUS ENDOSCOPY DX MAXILLARY SINUSOSCOPY','NASAL/SINUS ENDOSCOPY DX MAXILLARY SINUSOSCOPY','31233','1','','1','0','','','',0, 1, 0, 0),
(2531,'NASAL/SINUS ENDOSCOPY DX SPHENOID SINUSOSCOPY','NASAL/SINUS ENDOSCOPY DX SPHENOID SINUSOSCOPY','31235','1','','1','0','','','',0, 1, 0, 0),
(2532,'NASAL/SINUS NDSC SURG W/BX POLYPECT/DBRDMT SPX','NASAL/SINUS NDSC SURG W/BX POLYPECT/DBRDMT SPX','31237','1','','1','0','','','',0, 1, 0, 0),
(2533,'NASAL/SINUS NDSC SURG W/CONTROL NASAL HEMRRG','NASAL/SINUS NDSC SURG W/CONTROL NASAL HEMRRG','31238','1','','1','0','','','',0, 1, 0, 0),
(2534,'NASAL/SINUS NDSC SURG W/DACRYOCSTORHINOSTOMY','NASAL/SINUS NDSC SURG W/DACRYOCSTORHINOSTOMY','31239','1','','1','0','','','',0, 1, 0, 0),
(2535,'NASAL/SINUS NDSC SURG W/CONCHA BULLOSA RESECTION','NASAL/SINUS NDSC SURG W/CONCHA BULLOSA RESECTION','31240','1','','1','0','','','',0, 1, 0, 0),
(2536,'NASAL/SINUS ENDOSCOPY W/ETHMOIDECTOMY PARTIAL','NASAL/SINUS ENDOSCOPY W/ETHMOIDECTOMY PARTIAL','31254','1','','1','0','','','',0, 1, 0, 0),
(2537,'NASAL/SINUS ENDOSCOPY W/ETHMOIDECTOMY TOTAL','NASAL/SINUS ENDOSCOPY W/ETHMOIDECTOMY TOTAL','31255','1','','1','0','','','',0, 1, 0, 0),
(2538,'NASAL/SINUS ENDOSCOPY W/MAXILLARY ANTROSTOMY','NASAL/SINUS ENDOSCOPY W/MAXILLARY ANTROSTOMY','31256','1','','1','0','','','',0, 1, 0, 0),
(2539,'NSL/SINUS NDSC MAX ANTROST W/RMVL TISS MAX SINUS','NSL/SINUS NDSC MAX ANTROST W/RMVL TISS MAX SINUS','31267','1','','1','0','','','',0, 1, 0, 0),
(2540,'NASAL/SINUS NDSC W/FRONTAL SINUS EXPLORATION','NASAL/SINUS NDSC W/FRONTAL SINUS EXPLORATION','31276','1','','1','0','','','',0, 1, 0, 0),
(2541,'NASAL/SINUS ENDOSCOPY W/SPHENOIDOTOMY','NASAL/SINUS ENDOSCOPY W/SPHENOIDOTOMY','31287','1','','1','0','','','',0, 1, 0, 0),
(2542,'NSL/SINUS NDSC SPHENDT RMVL TISS SPHENOID SINUS','NSL/SINUS NDSC SPHENDT RMVL TISS SPHENOID SINUS','31288','1','','1','0','','','',0, 1, 0, 0),
(2543,'NASAL/SINUS NDSC RPR CEREBRSP FLUID LEAK ETHMOID','NASAL/SINUS NDSC RPR CEREBRSP FLUID LEAK ETHMOID','31290','1','','1','0','','','',0, 1, 0, 0),
(2544,'NASAL/SINUS NDSC RPR CEREBSP FLUID LEAK SPHENOID','NASAL/SINUS NDSC RPR CEREBSP FLUID LEAK SPHENOID','31291','1','','1','0','','','',0, 1, 0, 0),
(2545,'NSL/SINUS NDSC SURG W/MEDIAL/INF ORB WALL DCMPRN','NSL/SINUS NDSC SURG W/MEDIAL/INF ORB WALL DCMPRN','31292','1','','1','0','','','',0, 1, 0, 0),
(2546,'NASAL/SINUS NDSC MEDIAL ORB&NF ORB WALL DCMPR','NASAL/SINUS NDSC MEDIAL ORB&NF ORB WALL DCMPR','31293','1','','1','0','','','',0, 1, 0, 0),
(2547,'NASAL/SINUS NDSC SURG W/OPTIC NERVE DCMPRN','NASAL/SINUS NDSC SURG W/OPTIC NERVE DCMPRN','31294','1','','1','0','','','',0, 1, 0, 0),
(2548,'NASAL/SINUS NDSC SURG W/DILAT MAXILLARY SINUS','NASAL/SINUS NDSC SURG W/DILAT MAXILLARY SINUS','31295','1','','1','0','','','',0, 1, 0, 0),
(2549,'NASAL/SINUS NDSC SURG W/DILATION FRONTAL SINUS','NASAL/SINUS NDSC SURG W/DILATION FRONTAL SINUS','31296','1','','1','0','','','',0, 1, 0, 0),
(2550,'NASAL/SINUS NDSC SURG W/DILATION SPHENOID SINUS','NASAL/SINUS NDSC SURG W/DILATION SPHENOID SINUS','31297','1','','1','0','','','',0, 1, 0, 0),
(2551,'UNLISTED PROCEDURE ACCESSORY SINUSES','UNLISTED PROCEDURE ACCESSORY SINUSES','31299','1','','1','0','','','',0, 1, 0, 0),
(2552,'LARYNGOTOMY W/RMVL TUMOR/LARYNGOCELE CORDECTOMY','LARYNGOTOMY W/RMVL TUMOR/LARYNGOCELE CORDECTOMY','31300','1','','1','0','','','',0, 1, 0, 0),
(2553,'LARYNGOTOMY THYROTOMY LARYNGOFISSURE DX','LARYNGOTOMY THYROTOMY LARYNGOFISSURE DX','31320','1','','1','0','','','',0, 1, 0, 0),
(2554,'LARYNGECTOMY TOTAL W/O RADICAL NECK DISSECTION','LARYNGECTOMY TOTAL W/O RADICAL NECK DISSECTION','31360','1','','1','0','','','',0, 1, 0, 0),
(2555,'LARYNGECTOMY TOTAL W/RADICAL NECK DISSECTION','LARYNGECTOMY TOTAL W/RADICAL NECK DISSECTION','31365','1','','1','0','','','',0, 1, 0, 0),
(2556,'LARYNGECTOMY STOT SUPRAGLOTTIC W/O RAD NECK DSJ','LARYNGECTOMY STOT SUPRAGLOTTIC W/O RAD NECK DSJ','31367','1','','1','0','','','',0, 1, 0, 0),
(2557,'LARYNGECTOMY STOT SUPRAGLOTTIC W/RAD NCK DSJ','LARYNGECTOMY STOT SUPRAGLOTTIC W/RAD NCK DSJ','31368','1','','1','0','','','',0, 1, 0, 0),
(2558,'PARTIAL LARYNGECTOMY HEMILARYGECTOMY HORIZONTAL','PARTIAL LARYNGECTOMY HEMILARYGECTOMY HORIZONTAL','31370','1','','1','0','','','',0, 1, 0, 0),
(2559,'PARTIAL LARYNGECTOMY HEMILARYNG LATEROVERTICAL','PARTIAL LARYNGECTOMY HEMILARYNG LATEROVERTICAL','31375','1','','1','0','','','',0, 1, 0, 0),
(2560,'PARTIAL LARYNGECTOMY HEMILARYNG ANTEROVERTICAL','PARTIAL LARYNGECTOMY HEMILARYNG ANTEROVERTICAL','31380','1','','1','0','','','',0, 1, 0, 0),
(2561,'PARTIAL LARYNG HEMILARYNG ANTERO-LATERO-VERTICAL','PARTIAL LARYNG HEMILARYNG ANTERO-LATERO-VERTICAL','31382','1','','1','0','','','',0, 1, 0, 0),
(2562,'PHARYNGOLARYNGECTOMY W/RAD NECK DSJ W/O RCNSTJ','PHARYNGOLARYNGECTOMY W/RAD NECK DSJ W/O RCNSTJ','31390','1','','1','0','','','',0, 1, 0, 0),
(2563,'PHARYNGOLARYNGECTOMY W/RAD NECK DSJ W/RCNSTJ','PHARYNGOLARYNGECTOMY W/RAD NECK DSJ W/RCNSTJ','31395','1','','1','0','','','',0, 1, 0, 0),
(2564,'ARYTENOIDECTOMY/ARYTENOIDOPEXY XTRNL APPROACH','ARYTENOIDECTOMY/ARYTENOIDOPEXY XTRNL APPROACH','31400','1','','1','0','','','',0, 1, 0, 0),
(2565,'EPIGLOTTIDECTOMY','EPIGLOTTIDECTOMY','31420','1','','1','0','','','',0, 1, 0, 0),
(2566,'INTUBATION ENDOTRACHEAL EMERGENCY PROCEDURE','INTUBATION ENDOTRACHEAL EMERGENCY PROCEDURE','31500','1','','1','0','','','',0, 1, 0, 0),
(2567,'TRACHEOTOMY TUBE CHANGE PRIOR TO FISTULA TRACT','TRACHEOTOMY TUBE CHANGE PRIOR TO FISTULA TRACT','31502','1','','1','0','','','',0, 1, 0, 0),
(2568,'LARYNGOSCOPY INDIRECT DIAGNOSTIC SPX','LARYNGOSCOPY INDIRECT DIAGNOSTIC SPX','31505','1','','1','0','','','',0, 1, 0, 0),
(2569,'LARYNGOSCOPY INDIRECT W/BIOPSY','LARYNGOSCOPY INDIRECT W/BIOPSY','31510','1','','1','0','','','',0, 1, 0, 0),
(2570,'LARYNGOSCOPY INDIRECT W/REMOVAL FOREIGN BODY','LARYNGOSCOPY INDIRECT W/REMOVAL FOREIGN BODY','31511','1','','1','0','','','',0, 1, 0, 0),
(2571,'LARYNGOSCOPY INDIRECT W/REMOVAL LESION','LARYNGOSCOPY INDIRECT W/REMOVAL LESION','31512','1','','1','0','','','',0, 1, 0, 0),
(2572,'LARYNGOSCOPY INDIRECT W/VOCAL CORD INJECTION','LARYNGOSCOPY INDIRECT W/VOCAL CORD INJECTION','31513','1','','1','0','','','',0, 1, 0, 0),
(2573,'LARYNGOSCOPY W/WO TRACHEOSCOPY ASPIRATION','LARYNGOSCOPY W/WO TRACHEOSCOPY ASPIRATION','31515','1','','1','0','','','',0, 1, 0, 0),
(2574,'LARYNGOSCOPY W/WO TRACHEOSCOPY DX NEWBORN','LARYNGOSCOPY W/WO TRACHEOSCOPY DX NEWBORN','31520','1','','1','0','','','',0, 1, 0, 0),
(2575,'LARYNGOSCOPY W/WO TRACHEOSCOPY DX EXCEPT NEWBORN','LARYNGOSCOPY W/WO TRACHEOSCOPY DX EXCEPT NEWBORN','31525','1','','1','0','','','',0, 1, 0, 0),
(2576,'LARYNGOSCOPY W/WO TRACHEOSCOPY W/MICRO/TELESCOPE','LARYNGOSCOPY W/WO TRACHEOSCOPY W/MICRO/TELESCOPE','31526','1','','1','0','','','',0, 1, 0, 0),
(2577,'LARYNGOSCOPY W/WO TRACHEOSCOPY INSERT OBTURATOR','LARYNGOSCOPY W/WO TRACHEOSCOPY INSERT OBTURATOR','31527','1','','1','0','','','',0, 1, 0, 0),
(2578,'LARYNGOSCOPY W/WO TRACHEOSCOPY W/DILATION IN','LARYNGOSCOPY W/WO TRACHEOSCOPY W/DILATION IN','31528','1','','1','0','','','',0, 1, 0, 0),
(2579,'LARYNGOSCOPY W/WO TRACHEOSCOPY DILATION SUBSQ','LARYNGOSCOPY W/WO TRACHEOSCOPY DILATION SUBSQ','31529','1','','1','0','','','',0, 1, 0, 0),
(2580,'LARYNGOSCOPY W/FOREIGN BODY REMOVAL','LARYNGOSCOPY W/FOREIGN BODY REMOVAL','31530','1','','1','0','','','',0, 1, 0, 0),
(2581,'LARYNGOSCOPY FOREIGN BODY RMVL MICRO/TELESCOPE','LARYNGOSCOPY FOREIGN BODY RMVL MICRO/TELESCOPE','31531','1','','1','0','','','',0, 1, 0, 0),
(2582,'LARYNGOSCOPY DIRECT OPERATIVE W/BIOPSY','LARYNGOSCOPY DIRECT OPERATIVE W/BIOPSY','31535','1','','1','0','','','',0, 1, 0, 0),
(2583,'LARYNGOSCOPY W/BIOPSY MICROSCOPE/TELESCOPE','LARYNGOSCOPY W/BIOPSY MICROSCOPE/TELESCOPE','31536','1','','1','0','','','',0, 1, 0, 0),
(2584,'LARYNGOSCOPY EXC TUM&/STRIPPING CORDS/EPIGLOTT','LARYNGOSCOPY EXC TUM&/STRIPPING CORDS/EPIGLOTT','31540','1','','1','0','','','',0, 1, 0, 0),
(2585,'LARGSC EXC TUM&/STRPG CORDS/EPIGL MCRSCP/TLSCP','LARGSC EXC TUM&/STRPG CORDS/EPIGL MCRSCP/TLSCP','31541','1','','1','0','','','',0, 1, 0, 0),
(2586,'LARGSC MICRO/TELESCOPE RMVL LES VOCAL CORD FLAP','LARGSC MICRO/TELESCOPE RMVL LES VOCAL CORD FLAP','31545','1','','1','0','','','',0, 1, 0, 0),
(2587,'LARGSC MICRO/TELESCOPE RMVL LES VOCAL CORD GRAFT','LARGSC MICRO/TELESCOPE RMVL LES VOCAL CORD GRAFT','31546','1','','1','0','','','',0, 1, 0, 0),
(2588,'LARYNGOSCOPY DIRECT OPERATIVE W/ARYTENOIDECTOMY','LARYNGOSCOPY DIRECT OPERATIVE W/ARYTENOIDECTOMY','31560','1','','1','0','','','',0, 1, 0, 0),
(2589,'LARGSC ARYTENOIDECTOMY MICROSCOPE/TELESCOPE','LARGSC ARYTENOIDECTOMY MICROSCOPE/TELESCOPE','31561','1','','1','0','','','',0, 1, 0, 0),
(2590,'LARYNGOSCOPE INJECTION VOCAL CORD THERAPEUTIC','LARYNGOSCOPE INJECTION VOCAL CORD THERAPEUTIC','31570','1','','1','0','','','',0, 1, 0, 0),
(2591,'LARGSC W/NJX VOCAL CORD THER W/MICRO/TELESCOPE','LARGSC W/NJX VOCAL CORD THER W/MICRO/TELESCOPE','31571','1','','1','0','','','',0, 1, 0, 0),
(2592,'LARYNGOSCOPY FLEXIBLE FIBEROPTIC DIAGNOSTIC','LARYNGOSCOPY FLEXIBLE FIBEROPTIC DIAGNOSTIC','31575','1','','1','0','','','',0, 1, 0, 0),
(2593,'LARYNGOSCOPY FLEXIBLE FIBEROPTIC W/BIOPSY','LARYNGOSCOPY FLEXIBLE FIBEROPTIC W/BIOPSY','31576','1','','1','0','','','',0, 1, 0, 0),
(2594,'LARYNGOSCOPY FLX FIBEROPTIC RMVL FOREIGN BODY','LARYNGOSCOPY FLX FIBEROPTIC RMVL FOREIGN BODY','31577','1','','1','0','','','',0, 1, 0, 0),
(2595,'LARYNGOSCOPY FLEXIBLE FIBEROPTIC REMOVAL LESION','LARYNGOSCOPY FLEXIBLE FIBEROPTIC REMOVAL LESION','31578','1','','1','0','','','',0, 1, 0, 0),
(2596,'LARYNGOSCOPY FLX/RGD FIBOPT W/STROBOSCOPY','LARYNGOSCOPY FLX/RGD FIBOPT W/STROBOSCOPY','31579','1','','1','0','','','',0, 1, 0, 0),
(2597,'LARYNGOPLASTY LARYN WEB 2 STG W/KEEL INSJ&RMVL','LARYNGOPLASTY LARYN WEB 2 STG W/KEEL INSJ&RMVL','31580','1','','1','0','','','',0, 1, 0, 0),
(2598,'LARYNGP LARYN STENOSIS GRF/CORE MOLD W/TRACHT','LARYNGP LARYN STENOSIS GRF/CORE MOLD W/TRACHT','31582','1','','1','0','','','',0, 1, 0, 0),
(2599,'LARYNGOPLASTY W/OPEN REDUCTION FRACTURE','LARYNGOPLASTY W/OPEN REDUCTION FRACTURE','31584','1','','1','0','','','',0, 1, 0, 0),
(2600,'LARYNGOPLASTY CRICOID SPLIT','LARYNGOPLASTY CRICOID SPLIT','31587','1','','1','0','','','',0, 1, 0, 0),
(2601,'LARYNGOPLASTY NOT OTHERWISE SPECIFIED','LARYNGOPLASTY NOT OTHERWISE SPECIFIED','31588','1','','1','0','','','',0, 1, 0, 0),
(2602,'LARYNGEAL REINNERVATION NEUROMUSCULAR PEDICLE','LARYNGEAL REINNERVATION NEUROMUSCULAR PEDICLE','31590','1','','1','0','','','',0, 1, 0, 0),
(2603,'SECTION RECURRENT LARYNGEAL NERVE THER UNI SPX','SECTION RECURRENT LARYNGEAL NERVE THER UNI SPX','31595','1','','1','0','','','',0, 1, 0, 0),
(2604,'UNLISTED PROCEDURE LARYNX','UNLISTED PROCEDURE LARYNX','31599','1','','1','0','','','',0, 1, 0, 0),
(2605,'TRACHEOSTOMY PLANNED SEPARATE PROCEDURE','TRACHEOSTOMY PLANNED SEPARATE PROCEDURE','31600','1','','1','0','','','',0, 1, 0, 0),
(2606,'TRACHEOSTOMY PLANNED UNDER 2 YEARS SPX','TRACHEOSTOMY PLANNED UNDER 2 YEARS SPX','31601','1','','1','0','','','',0, 1, 0, 0),
(2607,'TRACHEOSTOMY EMERGENCY PROCEDURE TRANSTRACHEAL','TRACHEOSTOMY EMERGENCY PROCEDURE TRANSTRACHEAL','31603','1','','1','0','','','',0, 1, 0, 0),
(2608,'TRACHEOSTOMY EMERGENCY CRICOTHYROID MEMBRANE','TRACHEOSTOMY EMERGENCY CRICOTHYROID MEMBRANE','31605','1','','1','0','','','',0, 1, 0, 0),
(2609,'TRACHEOSTOMY FENESTRATION W/SKIN FLAPS','TRACHEOSTOMY FENESTRATION W/SKIN FLAPS','31610','1','','1','0','','','',0, 1, 0, 0),
(2610,'CONSTJ TRACHEOESOPHGL FSTL&INSJ SP PROSTH','CONSTJ TRACHEOESOPHGL FSTL&INSJ SP PROSTH','31611','1','','1','0','','','',0, 1, 0, 0),
(2611,'TRACHEAL PNXR PRQ W/TRANSTRACHEAL ASPIR&/NJX','TRACHEAL PNXR PRQ W/TRANSTRACHEAL ASPIR&/NJX','31612','1','','1','0','','','',0, 1, 0, 0),
(2612,'TRACHEOSTOMA REVJ SMPL W/O FLAP ROTATION','TRACHEOSTOMA REVJ SMPL W/O FLAP ROTATION','31613','1','','1','0','','','',0, 1, 0, 0),
(2613,'TRACHEOSTOMA REVJ CPLX W/FLAP ROTATION','TRACHEOSTOMA REVJ CPLX W/FLAP ROTATION','31614','1','','1','0','','','',0, 1, 0, 0),
(2614,'TRACHEOBRNCHSC THRU EST TRACHS INC','TRACHEOBRNCHSC THRU EST TRACHS INC','31615','1','','1','0','','','',0, 1, 0, 0),
(2615,'BRNCHSC INCL FLUOR GDNCE DX W/CELL WASHG SPX','BRNCHSC INCL FLUOR GDNCE DX W/CELL WASHG SPX','31622','1','','1','0','','','',0, 1, 0, 0),
(2616,'BRNCHSC BRUSHING/PROTECTED BRUSHINGS','BRNCHSC BRUSHING/PROTECTED BRUSHINGS','31623','1','','1','0','','','',0, 1, 0, 0),
(2617,'BRNCHSC W/BRNCL ALVEOLAR LAVAGE','BRNCHSC W/BRNCL ALVEOLAR LAVAGE','31624','1','','1','0','','','',0, 1, 0, 0),
(2618,'BRONCHOSCOPY BRONCHIAL/ENDOBRNCL BX 1+ SITES','BRONCHOSCOPY BRONCHIAL/ENDOBRNCL BX 1+ SITES','31625','1','','1','0','','','',0, 1, 0, 0),
(2619,'BRONCHOSCOPY W/PLMT FIDUCIAL MARKERS SINGLE/MULT','BRONCHOSCOPY W/PLMT FIDUCIAL MARKERS SINGLE/MULT','31626','1','','1','0','','','',0, 1, 0, 0),
(2620,'BRONCHOSCOPY W/CPTR-ASST IMAGE-GUIDED NAVIGATION','BRONCHOSCOPY W/CPTR-ASST IMAGE-GUIDED NAVIGATION','31627','1','','1','0','','','',0, 1, 0, 0),
(2621,'BRONCHOSCOPY W/TRANSBRONCHIAL LUNG BX 1 LOBE','BRONCHOSCOPY W/TRANSBRONCHIAL LUNG BX 1 LOBE','31628','1','','1','0','','','',0, 1, 0, 0),
(2622,'BRONCHOSCOPY NEEDLE BX TRACHEA MAIN STEM&/BRON','BRONCHOSCOPY NEEDLE BX TRACHEA MAIN STEM&/BRON','31629','1','','1','0','','','',0, 1, 0, 0),
(2623,'BRNCHSC W/TRACHEAL/BRONCHIAL DILAT/CLSD RDCTJ FX','BRNCHSC W/TRACHEAL/BRONCHIAL DILAT/CLSD RDCTJ FX','31630','1','','1','0','','','',0, 1, 0, 0),
(2624,'BRONCHOSCOPY W/PLACEMENT TRACHEAL STENT','BRONCHOSCOPY W/PLACEMENT TRACHEAL STENT','31631','1','','1','0','','','',0, 1, 0, 0),
(2625,'BRONCHOSCOPY W/TRANSBRONCHIAL LUNG BX EACH LOBE','BRONCHOSCOPY W/TRANSBRONCHIAL LUNG BX EACH LOBE','31632','1','','1','0','','','',0, 1, 0, 0),
(2626,'BRONCHOSCOPY W/TRANSBRONCL NDL ASPIR BX EA LOBE','BRONCHOSCOPY W/TRANSBRONCL NDL ASPIR BX EA LOBE','31633','1','','1','0','','','',0, 1, 0, 0),
(2627,'BRONCHOSCOPY BALLOON OCCLUSION','BRONCHOSCOPY BALLOON OCCLUSION','31634','1','','1','0','','','',0, 1, 0, 0),
(2628,'BRONCHOSCOPY W/REMOVAL FOREIGN BODY','BRONCHOSCOPY W/REMOVAL FOREIGN BODY','31635','1','','1','0','','','',0, 1, 0, 0),
(2629,'BRNCHSC W/PLACEMENT BRNCL STENT 1ST BRONCHUS','BRNCHSC W/PLACEMENT BRNCL STENT 1ST BRONCHUS','31636','1','','1','0','','','',0, 1, 0, 0),
(2630,'BRONCHOSCOPY EACH MAJOR BRONCHUS STENTED','BRONCHOSCOPY EACH MAJOR BRONCHUS STENTED','31637','1','','1','0','','','',0, 1, 0, 0),
(2631,'BRNCHSC REVJ TRACHEAL/BRNCL STENT INS PREV SESS','BRNCHSC REVJ TRACHEAL/BRNCL STENT INS PREV SESS','31638','1','','1','0','','','',0, 1, 0, 0),
(2632,'BRONCHOSCOPY W/EXCISION TUMOR','BRONCHOSCOPY W/EXCISION TUMOR','31640','1','','1','0','','','',0, 1, 0, 0),
(2633,'BRNCHSC W/DSTRJ TUM RELIEF STENOSIS OTH/THN EXC','BRNCHSC W/DSTRJ TUM RELIEF STENOSIS OTH/THN EXC','31641','1','','1','0','','','',0, 1, 0, 0),
(2634,'BRNCHSC W/PLMT CATH INTRCV RADIOELMNT APPL','BRNCHSC W/PLMT CATH INTRCV RADIOELMNT APPL','31643','1','','1','0','','','',0, 1, 0, 0),
(2635,'BRNCHSC W/THER ASPIR TRACHEOBRNCL TREE 1ST','BRNCHSC W/THER ASPIR TRACHEOBRNCL TREE 1ST','31645','1','','1','0','','','',0, 1, 0, 0),
(2636,'BRNCHSC W/THER ASPIR TRACHEOBRNCL TREE SBSQ','BRNCHSC W/THER ASPIR TRACHEOBRNCL TREE SBSQ','31646','1','','1','0','','','',0, 1, 0, 0),
(2637,'BRNCHSC OCCLUSION&INSERT BRONCH VALVE INIT LOBE','BRNCHSC OCCLUSION&INSERT BRONCH VALVE INIT LOBE','31647','1','','1','0','','','',0, 1, 0, 0),
(2638,'BRNCHSC REMOVAL BRONCHIAL VALVE INITIAL','BRNCHSC REMOVAL BRONCHIAL VALVE INITIAL','31648','1','','1','0','','','',0, 1, 0, 0),
(2639,'BRNCHSC REMOVAL BRONCHIAL VALVE EA ADDL','BRNCHSC REMOVAL BRONCHIAL VALVE EA ADDL','31649','1','','1','0','','','',0, 1, 0, 0),
(2640,'BRNCHSC OCCLUSION&INSERT BRONCH VALVE ADDL LOBE','BRNCHSC OCCLUSION&INSERT BRONCH VALVE ADDL LOBE','31651','1','','1','0','','','',0, 1, 0, 0),
(2641,'BRNCHSC EBUS GUIDED SAMPL 1/2 NODE STATION/STRUX','BRNCHSC EBUS GUIDED SAMPL 1/2 NODE STATION/STRUX','31652','1','','1','0','','','',0, 1, 0, 0),
(2642,'BRNCHSC EBUS GUIDED SAMPL 3/> NODE STATION/STRUX','BRNCHSC EBUS GUIDED SAMPL 3/> NODE STATION/STRUX','31653','1','','1','0','','','',0, 1, 0, 0),
(2643,'BRNSCHSC TNDSC EBUS DX/TX INTERVENTION PERPH LES','BRNSCHSC TNDSC EBUS DX/TX INTERVENTION PERPH LES','31654','1','','1','0','','','',0, 1, 0, 0),
(2644,'BRONCHOSCOPIC THERMOPLASTY ONE LOBE','BRONCHOSCOPIC THERMOPLASTY ONE LOBE','31660','1','','1','0','','','',0, 1, 0, 0),
(2645,'BRONCHOSCOPIC THERMOPLASTY 2/> LOBES','BRONCHOSCOPIC THERMOPLASTY 2/> LOBES','31661','1','','1','0','','','',0, 1, 0, 0),
(2646,'CATHETERIZATION W/BRONCHIAL BRUSH BIOPSY','CATHETERIZATION W/BRONCHIAL BRUSH BIOPSY','31717','1','','1','0','','','',0, 1, 0, 0),
(2647,'CATHETER ASPIRATION NASOTRACHEAL SPX','CATHETER ASPIRATION NASOTRACHEAL SPX','31720','1','','1','0','','','',0, 1, 0, 0),
(2648,'CATH ASPIR TRACHEOBRNCL FIBERSCOPE BEDSIDE SPX','CATH ASPIR TRACHEOBRNCL FIBERSCOPE BEDSIDE SPX','31725','1','','1','0','','','',0, 1, 0, 0),
(2649,'TTRACH INTRO NDL WIRE DIL/STENT/TUBE O2 THER','TTRACH INTRO NDL WIRE DIL/STENT/TUBE O2 THER','31730','1','','1','0','','','',0, 1, 0, 0),
(2650,'TRACHEOPLASTY CERVICAL','TRACHEOPLASTY CERVICAL','31750','1','','1','0','','','',0, 1, 0, 0),
(2651,'TRACHEOPLASTY TRACHEOPHARYNGEAL FSTLJ EA STG','TRACHEOPLASTY TRACHEOPHARYNGEAL FSTLJ EA STG','31755','1','','1','0','','','',0, 1, 0, 0),
(2652,'TRACHEOPLASTY INTRATHORACIC','TRACHEOPLASTY INTRATHORACIC','31760','1','','1','0','','','',0, 1, 0, 0),
(2653,'CARINAL RECONSTRUCTION','CARINAL RECONSTRUCTION','31766','1','','1','0','','','',0, 1, 0, 0),
(2654,'BRONCHOPLASTY GRAFT REPAIR','BRONCHOPLASTY GRAFT REPAIR','31770','1','','1','0','','','',0, 1, 0, 0),
(2655,'BRONCHOPLASTY EXCISION STENOSIS & ANASTOMOSIS','BRONCHOPLASTY EXCISION STENOSIS & ANASTOMOSIS','31775','1','','1','0','','','',0, 1, 0, 0),
(2656,'EXCISION TRACHEAL STENOSIS&ANASTOMOSIS CERVICA','EXCISION TRACHEAL STENOSIS&ANASTOMOSIS CERVICA','31780','1','','1','0','','','',0, 1, 0, 0),
(2657,'EXC TRACHEAL STENOSIS&ANAST CERVICOTHORACIC','EXC TRACHEAL STENOSIS&ANAST CERVICOTHORACIC','31781','1','','1','0','','','',0, 1, 0, 0),
(2658,'EXCISION TRACHEAL TUMOR/CARCINOMA CERVICAL','EXCISION TRACHEAL TUMOR/CARCINOMA CERVICAL','31785','1','','1','0','','','',0, 1, 0, 0),
(2659,'EXCISION TRACHEAL TUMOR/CARCINOMA THORACIC','EXCISION TRACHEAL TUMOR/CARCINOMA THORACIC','31786','1','','1','0','','','',0, 1, 0, 0),
(2660,'SUTURE TRACHEAL WOUND/INJURY CERVICAL','SUTURE TRACHEAL WOUND/INJURY CERVICAL','31800','1','','1','0','','','',0, 1, 0, 0),
(2661,'SUTURE TRACHEAL WOUND/INJURY INTRATHORACIC','SUTURE TRACHEAL WOUND/INJURY INTRATHORACIC','31805','1','','1','0','','','',0, 1, 0, 0),
(2662,'SURG CLSR TRACHEOSTOMY/FISTULA W/O PLASTIC RPR','SURG CLSR TRACHEOSTOMY/FISTULA W/O PLASTIC RPR','31820','1','','1','0','','','',0, 1, 0, 0),
(2663,'SURG CLSR TRACHEOSTOMY/FISTULA W/PLASTIC RPR','SURG CLSR TRACHEOSTOMY/FISTULA W/PLASTIC RPR','31825','1','','1','0','','','',0, 1, 0, 0),
(2664,'REVISION TRACHEOSTOMY SCAR','REVISION TRACHEOSTOMY SCAR','31830','1','','1','0','','','',0, 1, 0, 0),
(2665,'UNLISTED PROCEDURE TRACHEA BRONCHI','UNLISTED PROCEDURE TRACHEA BRONCHI','31899','1','','1','0','','','',0, 1, 0, 0),
(2666,'THORACOSTOMY W/RIB RESECTION EMPYEMA','THORACOSTOMY W/RIB RESECTION EMPYEMA','32035','1','','1','0','','','',0, 1, 0, 0),
(2667,'THORACOSTOMY OPEN FLAP DRAINAGE EMPYEMA','THORACOSTOMY OPEN FLAP DRAINAGE EMPYEMA','32036','1','','1','0','','','',0, 1, 0, 0),
(2668,'THORACTOMY W/DX BX LUNG INFILTRATE UNILATERAL','THORACTOMY W/DX BX LUNG INFILTRATE UNILATERAL','32096','1','','1','0','','','',0, 1, 0, 0),
(2669,'THORACTOMY W/DX BX LUNG NODULE/MASS UNILATERAL','THORACTOMY W/DX BX LUNG NODULE/MASS UNILATERAL','32097','1','','1','0','','','',0, 1, 0, 0),
(2670,'THORACOTOMY W/BIOPSY OF PLEURA','THORACOTOMY W/BIOPSY OF PLEURA','32098','1','','1','0','','','',0, 1, 0, 0),
(2671,'THORACOTOMY WITH EXPLORATION','THORACOTOMY WITH EXPLORATION','32100','1','','1','0','','','',0, 1, 0, 0),
(2672,'THORCOM CTRL TRAUMTC HEMRRG&/RPR LNG TEAR','THORCOM CTRL TRAUMTC HEMRRG&/RPR LNG TEAR','32110','1','','1','0','','','',0, 1, 0, 0),
(2673,'THORACOTOMY POSTOPERATIVE COMPLICATIONS','THORACOTOMY POSTOPERATIVE COMPLICATIONS','32120','1','','1','0','','','',0, 1, 0, 0),
(2674,'THORACOTOMY OPN INTRAPLEURAL PNEUMONOLYSIS','THORACOTOMY OPN INTRAPLEURAL PNEUMONOLYSIS','32124','1','','1','0','','','',0, 1, 0, 0),
(2675,'THORCOM W/REMOVAL OF CYST','THORCOM W/REMOVAL OF CYST','32140','1','','1','0','','','',0, 1, 0, 0),
(2676,'THORACOTOMY W/RESECTION BULLAE','THORACOTOMY W/RESECTION BULLAE','32141','1','','1','0','','','',0, 1, 0, 0),
(2677,'THORCOM W/RMVL INTRAPLEURAL FB/FIBRIN DEP','THORCOM W/RMVL INTRAPLEURAL FB/FIBRIN DEP','32150','1','','1','0','','','',0, 1, 0, 0),
(2678,'THORCOM W/RMVL IPUL FB','THORCOM W/RMVL IPUL FB','32151','1','','1','0','','','',0, 1, 0, 0),
(2679,'THORACOTOMY W/CARDIAC MASSAGE','THORACOTOMY W/CARDIAC MASSAGE','32160','1','','1','0','','','',0, 1, 0, 0),
(2680,'PNEUMONOSTOMY W/OPEN DRAINAGE ABSCESS/CYST','PNEUMONOSTOMY W/OPEN DRAINAGE ABSCESS/CYST','32200','1','','1','0','','','',0, 1, 0, 0),
(2681,'PLEURAL SCARIFICATION REPEAT PNEUMOTHORAX','PLEURAL SCARIFICATION REPEAT PNEUMOTHORAX','32215','1','','1','0','','','',0, 1, 0, 0),
(2682,'DECORTICATION PULMONARY TOTAL SEPARATE PROCEDURE','DECORTICATION PULMONARY TOTAL SEPARATE PROCEDURE','32220','1','','1','0','','','',0, 1, 0, 0),
(2683,'DECORTICATION PULMONARY PARTIAL SEPARATE PROC','DECORTICATION PULMONARY PARTIAL SEPARATE PROC','32225','1','','1','0','','','',0, 1, 0, 0),
(2684,'PLEURECTOMY PARIETAL SEPARATE PROCEDURE','PLEURECTOMY PARIETAL SEPARATE PROCEDURE','32310','1','','1','0','','','',0, 1, 0, 0),
(2685,'DECORTICATION & PARIETAL PLEURECTOMY','DECORTICATION & PARIETAL PLEURECTOMY','32320','1','','1','0','','','',0, 1, 0, 0),
(2686,'BIOPSY PLEURA PERCUTANEOUS NEEDLE','BIOPSY PLEURA PERCUTANEOUS NEEDLE','32400','1','','1','0','','','',0, 1, 0, 0),
(2687,'BIOPSY LUNG/MEDIASTINUM PERCUTANEOUS NEEDLE','BIOPSY LUNG/MEDIASTINUM PERCUTANEOUS NEEDLE','32405','1','','1','0','','','',0, 1, 0, 0),
(2688,'REMOVAL OF LUNG PNEUMONECTOMY','REMOVAL OF LUNG PNEUMONECTOMY','32440','1','','1','0','','','',0, 1, 0, 0),
(2689,'REMOVAL LUNG PNEUMONECTOMY RESXN SGMNT TRACHEA','REMOVAL LUNG PNEUMONECTOMY RESXN SGMNT TRACHEA','32442','1','','1','0','','','',0, 1, 0, 0),
(2690,'REMOVAL LUNG PNEUMONECTOMY EXTRAPLEURAL','REMOVAL LUNG PNEUMONECTOMY EXTRAPLEURAL','32445','1','','1','0','','','',0, 1, 0, 0),
(2691,'RMVL LUNG OTHER THAN PNEUMONECTOMY 1 LOBE LOBECT','RMVL LUNG OTHER THAN PNEUMONECTOMY 1 LOBE LOBECT','32480','1','','1','0','','','',0, 1, 0, 0),
(2692,'RMVL LUNG OTHER THAN PNEUMONECT 2 LOBES BILOBEC','RMVL LUNG OTHER THAN PNEUMONECT 2 LOBES BILOBEC','32482','1','','1','0','','','',0, 1, 0, 0),
(2693,'RMVL LUNG OTHER THAN PNEUMONECT 1 SEGMENTECTOMY','RMVL LUNG OTHER THAN PNEUMONECT 1 SEGMENTECTOMY','32484','1','','1','0','','','',0, 1, 0, 0),
(2694,'RMVL LUNG XCP TOT PNEUMONECTOMY SLEEVE LOBECTOMY','RMVL LUNG XCP TOT PNEUMONECTOMY SLEEVE LOBECTOMY','32486','1','','1','0','','','',0, 1, 0, 0),
(2695,'RMVL LUNG OTHER/THAN PNUMEC COMPLETION PNUMEC','RMVL LUNG OTHER/THAN PNUMEC COMPLETION PNUMEC','32488','1','','1','0','','','',0, 1, 0, 0),
(2696,'RMVL LUNG OTH/THN PNUMEC RESXN-PLCTJ EMPHY LUNG','RMVL LUNG OTH/THN PNUMEC RESXN-PLCTJ EMPHY LUNG','32491','1','','1','0','','','',0, 1, 0, 0),
(2697,'RESCJ&BRONCHOPLASTY PFRMD TM LOBEC/SGMECTOMY','RESCJ&BRONCHOPLASTY PFRMD TM LOBEC/SGMECTOMY','32501','1','','1','0','','','',0, 1, 0, 0),
(2698,'RESCJ APICAL LUNG TUMOR W/O CHEST WALL RCNSTJ','RESCJ APICAL LUNG TUMOR W/O CHEST WALL RCNSTJ','32503','1','','1','0','','','',0, 1, 0, 0),
(2699,'RESCJ APICAL LUNG TUMOR W/CHEST WALL RCNSTJ','RESCJ APICAL LUNG TUMOR W/CHEST WALL RCNSTJ','32504','1','','1','0','','','',0, 1, 0, 0),
(2700,'THORACOTOMY W/THERAPEUTIC WEDGE RESEXN INITIAL','THORACOTOMY W/THERAPEUTIC WEDGE RESEXN INITIAL','32505','1','','1','0','','','',0, 1, 0, 0),
(2701,'THORACOTOMY W/THERAP WEDGE RESEXN ADDL IPSILATRL','THORACOTOMY W/THERAP WEDGE RESEXN ADDL IPSILATRL','32506','1','','1','0','','','',0, 1, 0, 0),
(2702,'THORACOTOMY W/DX WEDGE RESEXN & ANTOM LUNG RESE','THORACOTOMY W/DX WEDGE RESEXN & ANTOM LUNG RESE','32507','1','','1','0','','','',0, 1, 0, 0),
(2703,'EXTRAPLEURAL ENUCLEATION EMPYEMA EMPYEMECTOMY','EXTRAPLEURAL ENUCLEATION EMPYEMA EMPYEMECTOMY','32540','1','','1','0','','','',0, 1, 0, 0),
(2704,'INSERTION INDWELLING TUNNELED PLEURAL CATHETER','INSERTION INDWELLING TUNNELED PLEURAL CATHETER','32550','1','','1','0','','','',0, 1, 0, 0),
(2705,'TUBE THORACOSTOMY INCLUDES WATER SEAL','TUBE THORACOSTOMY INCLUDES WATER SEAL','32551','1','','1','0','','','',0, 1, 0, 0),
(2706,'RMVL NDWELLG TUNNELED PLEURAL CATHETER W/CUFF','RMVL NDWELLG TUNNELED PLEURAL CATHETER W/CUFF','32552','1','','1','0','','','',0, 1, 0, 0),
(2707,'PLMT NTRSTL DEV RADJ THX GID PRQ INTRATHRC 1/MLT','PLMT NTRSTL DEV RADJ THX GID PRQ INTRATHRC 1/MLT','32553','1','','1','0','','','',0, 1, 0, 0),
(2708,'THORACENTESIS NEEDLE/CATH PLEURA W/O IMAGING','THORACENTESIS NEEDLE/CATH PLEURA W/O IMAGING','32554','1','','1','0','','','',0, 1, 0, 0),
(2709,'THORACENTESIS NEEDLE/CATH PLEURA W/IMAGING','THORACENTESIS NEEDLE/CATH PLEURA W/IMAGING','32555','1','','1','0','','','',0, 1, 0, 0),
(2710,'PERQ DRAINAGE PLEURA INSERT CATH W/O IMAGING','PERQ DRAINAGE PLEURA INSERT CATH W/O IMAGING','32556','1','','1','0','','','',0, 1, 0, 0),
(2711,'PERQ DRAINAGE PLEURA INSERT CATH W/IMAGING','PERQ DRAINAGE PLEURA INSERT CATH W/IMAGING','32557','1','','1','0','','','',0, 1, 0, 0),
(2712,'INSTLJ VIA CHEST TUBE/CATH AGENT FOR PLEURODESIS','INSTLJ VIA CHEST TUBE/CATH AGENT FOR PLEURODESIS','32560','1','','1','0','','','',0, 1, 0, 0),
(2713,'INSTLJ VIA CH TUBE/CATH AGENT FBRNLYSIS 1ST DAY','INSTLJ VIA CH TUBE/CATH AGENT FBRNLYSIS 1ST DAY','32561','1','','1','0','','','',0, 1, 0, 0),
(2714,'INSTLJ CH TUBE/CATH AGENT FBRNLYSIS SBSQ DAY','INSTLJ CH TUBE/CATH AGENT FBRNLYSIS SBSQ DAY','32562','1','','1','0','','','',0, 1, 0, 0),
(2715,'THORSC DX LUNGS/PERICAR/MED/PLEURAL SPACE W/O BX','THORSC DX LUNGS/PERICAR/MED/PLEURAL SPACE W/O BX','32601','1','','1','0','','','',0, 1, 0, 0),
(2716,'THORACOSCOPY DX PERICARDIAL SAC W/BIOPSY SPX','THORACOSCOPY DX PERICARDIAL SAC W/BIOPSY SPX','32604','1','','1','0','','','',0, 1, 0, 0),
(2717,'THORACOSCOPY DX MEDIASTINAL SPACE W/BIOPSY SPX','THORACOSCOPY DX MEDIASTINAL SPACE W/BIOPSY SPX','32606','1','','1','0','','','',0, 1, 0, 0),
(2718,'THORACOSCOPY W/DX BX OF LUNG INFILTRATE UNILATRL','THORACOSCOPY W/DX BX OF LUNG INFILTRATE UNILATRL','32607','1','','1','0','','','',0, 1, 0, 0),
(2719,'THORACOSCOPY W/DX BX OF LUNG NODULES UNILATRL','THORACOSCOPY W/DX BX OF LUNG NODULES UNILATRL','32608','1','','1','0','','','',0, 1, 0, 0),
(2720,'THORACOSCOPY WITH BIOPSYIES OF PLEURA','THORACOSCOPY WITH BIOPSYIES OF PLEURA','32609','1','','1','0','','','',0, 1, 0, 0),
(2721,'THORACOSCOPY W/PLEURODESIS','THORACOSCOPY W/PLEURODESIS','32650','1','','1','0','','','',0, 1, 0, 0),
(2722,'THORACOSCOPY W/PARTIAL PULMONARY DECORTICATION','THORACOSCOPY W/PARTIAL PULMONARY DECORTICATION','32651','1','','1','0','','','',0, 1, 0, 0),
(2723,'THRSC TOT PULM DCRTCTJ INTRAPLEURAL PNEUMONOLSS','THRSC TOT PULM DCRTCTJ INTRAPLEURAL PNEUMONOLSS','32652','1','','1','0','','','',0, 1, 0, 0),
(2724,'THORACOSCOPY RMVL INTRAPLEURAL FB/FIBRIN DEPOSIT','THORACOSCOPY RMVL INTRAPLEURAL FB/FIBRIN DEPOSIT','32653','1','','1','0','','','',0, 1, 0, 0),
(2725,'THORACOSCOPY CONTROL TRAUMATIC HEMORRHAGE','THORACOSCOPY CONTROL TRAUMATIC HEMORRHAGE','32654','1','','1','0','','','',0, 1, 0, 0),
(2726,'THORACOSCOPY W/RESECTION BULLAE W/WO PLEURAL PX','THORACOSCOPY W/RESECTION BULLAE W/WO PLEURAL PX','32655','1','','1','0','','','',0, 1, 0, 0),
(2727,'THORACOSCOPY W/PARIETAL PLEURECTOMY','THORACOSCOPY W/PARIETAL PLEURECTOMY','32656','1','','1','0','','','',0, 1, 0, 0),
(2728,'THORACOSCOPY W/RMVL CLOT/FB FROM PERICARDIAL SAC','THORACOSCOPY W/RMVL CLOT/FB FROM PERICARDIAL SAC','32658','1','','1','0','','','',0, 1, 0, 0),
(2729,'THRSC CRTJ PRCRD WINDOW/PRTL RESCJ PRCRD SAC','THRSC CRTJ PRCRD WINDOW/PRTL RESCJ PRCRD SAC','32659','1','','1','0','','','',0, 1, 0, 0),
(2730,'THORACOSCOPY W/EXC PERICARDIAL CYST TUMOR/MASS','THORACOSCOPY W/EXC PERICARDIAL CYST TUMOR/MASS','32661','1','','1','0','','','',0, 1, 0, 0),
(2731,'THORACOSCOPY W/EXC MEDIASTINAL CYST TUMOR/MASS','THORACOSCOPY W/EXC MEDIASTINAL CYST TUMOR/MASS','32662','1','','1','0','','','',0, 1, 0, 0),
(2732,'THORACOSCOPY W/LOBECTOMY SINGLE LOBE','THORACOSCOPY W/LOBECTOMY SINGLE LOBE','32663','1','','1','0','','','',0, 1, 0, 0),
(2733,'THORACOSCOPY W/THORACIC SYMPATHECTOMY','THORACOSCOPY W/THORACIC SYMPATHECTOMY','32664','1','','1','0','','','',0, 1, 0, 0),
(2734,'THORACOSCOPY W/ESOPHAGOMYOTOMY HELLER TYPE','THORACOSCOPY W/ESOPHAGOMYOTOMY HELLER TYPE','32665','1','','1','0','','','',0, 1, 0, 0),
(2735,'THORACOSCOPY W/THERA WEDGE RESEXN INITIAL UNILAT','THORACOSCOPY W/THERA WEDGE RESEXN INITIAL UNILAT','32666','1','','1','0','','','',0, 1, 0, 0),
(2736,'THORACOSCOPY W/THERA WEDGE RESEXN ADDL IPSILATRL','THORACOSCOPY W/THERA WEDGE RESEXN ADDL IPSILATRL','32667','1','','1','0','','','',0, 1, 0, 0),
(2737,'THORACOSCOPY W/DX WEDGE RESEXN ANATO LUNG RESEXN','THORACOSCOPY W/DX WEDGE RESEXN ANATO LUNG RESEXN','32668','1','','1','0','','','',0, 1, 0, 0),
(2738,'THORACOSCOPY W/SEGMENTECTOMY','THORACOSCOPY W/SEGMENTECTOMY','32669','1','','1','0','','','',0, 1, 0, 0),
(2739,'THORACOSCOPY W/BILOBECTOMY','THORACOSCOPY W/BILOBECTOMY','32670','1','','1','0','','','',0, 1, 0, 0),
(2740,'THORACOSCOPY W/PNEUMONECTOMY','THORACOSCOPY W/PNEUMONECTOMY','32671','1','','1','0','','','',0, 1, 0, 0),
(2741,'THORACOSCOPY W/RESEXN-PLICAJ EMPHYSEMA LUNG UNIL','THORACOSCOPY W/RESEXN-PLICAJ EMPHYSEMA LUNG UNIL','32672','1','','1','0','','','',0, 1, 0, 0),
(2742,'THORACOSCOPY RESEXN THYMUS UNI/BILATERAL','THORACOSCOPY RESEXN THYMUS UNI/BILATERAL','32673','1','','1','0','','','',0, 1, 0, 0),
(2743,'THORCOSCPY W/MEDIASTINL & REGIONL LYMPHDENECTOMY','THORCOSCPY W/MEDIASTINL & REGIONL LYMPHDENECTOMY','32674','1','','1','0','','','',0, 1, 0, 0),
(2744,'THORAX STEREOTACTIC RADIATION TARGET W/TX COURSE','THORAX STEREOTACTIC RADIATION TARGET W/TX COURSE','32701','1','','1','0','','','',0, 1, 0, 0),
(2745,'REPAIR LUNG HERNIA THROUGH CHEST WALL','REPAIR LUNG HERNIA THROUGH CHEST WALL','32800','1','','1','0','','','',0, 1, 0, 0),
(2746,'CLSR CH WALL FLWG OPN FLAP DRG EMPYEMA','CLSR CH WALL FLWG OPN FLAP DRG EMPYEMA','32810','1','','1','0','','','',0, 1, 0, 0),
(2747,'OPEN CLOSURE MAJOR BRONCHIAL FISTULA','OPEN CLOSURE MAJOR BRONCHIAL FISTULA','32815','1','','1','0','','','',0, 1, 0, 0),
(2748,'MAJOR RECONSTRUCTION CHEST WALL POSTTRAUMATIC','MAJOR RECONSTRUCTION CHEST WALL POSTTRAUMATIC','32820','1','','1','0','','','',0, 1, 0, 0),
(2749,'DONOR PNEUMONECTOMY FROM CADAVER DONOR','DONOR PNEUMONECTOMY FROM CADAVER DONOR','32850','1','','1','0','','','',0, 1, 0, 0),
(2750,'LUNG TRANSPLANT 1 W/O CARDIOPULMONARY BYPASS','LUNG TRANSPLANT 1 W/O CARDIOPULMONARY BYPASS','32851','1','','1','0','','','',0, 1, 0, 0),
(2751,'LUNG TRANSPLANT 1 W/CARDIOPULMONARY BYPASS','LUNG TRANSPLANT 1 W/CARDIOPULMONARY BYPASS','32852','1','','1','0','','','',0, 1, 0, 0),
(2752,'LUNG TRANSPLANT 2 W/O CARDIOPULMONARY BYPASS','LUNG TRANSPLANT 2 W/O CARDIOPULMONARY BYPASS','32853','1','','1','0','','','',0, 1, 0, 0),
(2753,'LUNG TRANSPLANT 2 W/CARDIOPULMONARY BYPASS','LUNG TRANSPLANT 2 W/CARDIOPULMONARY BYPASS','32854','1','','1','0','','','',0, 1, 0, 0),
(2754,'BKBENCH PREPJ CADAVER DONOR LUNG ALLOGRAFT UNI','BKBENCH PREPJ CADAVER DONOR LUNG ALLOGRAFT UNI','32855','1','','1','0','','','',0, 1, 0, 0),
(2755,'BKBENCH PREPJ CADAVER DONOR LUNG ALLOGRAFT BI','BKBENCH PREPJ CADAVER DONOR LUNG ALLOGRAFT BI','32856','1','','1','0','','','',0, 1, 0, 0),
(2756,'RESECTION RIBS EXTRAPLEURAL ALL STAGES','RESECTION RIBS EXTRAPLEURAL ALL STAGES','32900','1','','1','0','','','',0, 1, 0, 0),
(2757,'THORACOPLASTY SCHEDE TYPE/EXTRAPLEURAL','THORACOPLASTY SCHEDE TYPE/EXTRAPLEURAL','32905','1','','1','0','','','',0, 1, 0, 0),
(2758,'THORACOP SCHEDE TYP/XTRPLEURAL CLSR BRNCPLR FSTL','THORACOP SCHEDE TYP/XTRPLEURAL CLSR BRNCPLR FSTL','32906','1','','1','0','','','',0, 1, 0, 0),
(2759,'PNEUMONOLYSIS XTRPRIOSTEAL W/FILLING/PACKING PX','PNEUMONOLYSIS XTRPRIOSTEAL W/FILLING/PACKING PX','32940','1','','1','0','','','',0, 1, 0, 0),
(2760,'PNEUMOTHORAX THER INTRAPLEURAL INJECTION AIR','PNEUMOTHORAX THER INTRAPLEURAL INJECTION AIR','32960','1','','1','0','','','',0, 1, 0, 0),
(2761,'TOTAL LUNG LAVAGE UNILATERAL','TOTAL LUNG LAVAGE UNILATERAL','32997','1','','1','0','','','',0, 1, 0, 0),
(2762,'ABLATION PULMONARY TUMOR PERQ RADIOFREQUENCY UNI','ABLATION PULMONARY TUMOR PERQ RADIOFREQUENCY UNI','32998','1','','1','0','','','',0, 1, 0, 0),
(2763,'UNLISTED PROCEDURE LUNGS & PLEURA','UNLISTED PROCEDURE LUNGS & PLEURA','32999','1','','1','0','','','',0, 1, 0, 0),
(2764,'PERICARDIOCENTESIS INITIAL','PERICARDIOCENTESIS INITIAL','33010','1','','1','0','','','',0, 1, 0, 0),
(2765,'PERICARDIOCENTESIS SUBSEQUENT','PERICARDIOCENTESIS SUBSEQUENT','33011','1','','1','0','','','',0, 1, 0, 0),
(2766,'TUBE PERICARDIOSTOMY','TUBE PERICARDIOSTOMY','33015','1','','1','0','','','',0, 1, 0, 0),
(2767,'PERICARDIOTOMY REMOVAL CLOT/FOREIGN BODY PRIMARY','PERICARDIOTOMY REMOVAL CLOT/FOREIGN BODY PRIMARY','33020','1','','1','0','','','',0, 1, 0, 0),
(2768,'CRTJ PERICARDIAL WINDOW/PRTL RESECJ W/DRG/BX','CRTJ PERICARDIAL WINDOW/PRTL RESECJ W/DRG/BX','33025','1','','1','0','','','',0, 1, 0, 0),
(2769,'PRICARDIECTOMY STOT/COMPL W/O CARDPULM BYPASS','PRICARDIECTOMY STOT/COMPL W/O CARDPULM BYPASS','33030','1','','1','0','','','',0, 1, 0, 0),
(2770,'PRICARDIECTOMY STOT/COMPL W/CARDPULM BYPASS','PRICARDIECTOMY STOT/COMPL W/CARDPULM BYPASS','33031','1','','1','0','','','',0, 1, 0, 0),
(2771,'RESECTION PERICARDIAL CYST/TUMOR','RESECTION PERICARDIAL CYST/TUMOR','33050','1','','1','0','','','',0, 1, 0, 0),
(2772,'EXC INTRACARDIAC TUMOR RESCJ CARDIOPULMONARY BYP','EXC INTRACARDIAC TUMOR RESCJ CARDIOPULMONARY BYP','33120','1','','1','0','','','',0, 1, 0, 0),
(2773,'RESECTION EXTERNAL CARDIAC TUMOR','RESECTION EXTERNAL CARDIAC TUMOR','33130','1','','1','0','','','',0, 1, 0, 0),
(2774,'TRANSMYOCARDIAL LASER REVASCULAR THORACOTOMY SPX','TRANSMYOCARDIAL LASER REVASCULAR THORACOTOMY SPX','33140','1','','1','0','','','',0, 1, 0, 0),
(2775,'TRANSMYOCRD LASER REVSC PFRMD TM OTH OPN CAR PX','TRANSMYOCRD LASER REVSC PFRMD TM OTH OPN CAR PX','33141','1','','1','0','','','',0, 1, 0, 0),
(2776,'INSERTION EPICARDIAL ELECTRODE OPEN','INSERTION EPICARDIAL ELECTRODE OPEN','33202','1','','1','0','','','',0, 1, 0, 0),
(2777,'INSERTION EPICARDIAL ELECTRODE ENDOSCOPIC','INSERTION EPICARDIAL ELECTRODE ENDOSCOPIC','33203','1','','1','0','','','',0, 1, 0, 0),
(2778,'INS NEW/RPLCMT PRM PACEMAKR W/TRANS ELTRD ATRIAL','INS NEW/RPLCMT PRM PACEMAKR W/TRANS ELTRD ATRIAL','33206','1','','1','0','','','',0, 1, 0, 0),
(2779,'INS NEW/RPLC PRM PACEMAKER W/TRANSV ELTRD VENTR','INS NEW/RPLC PRM PACEMAKER W/TRANSV ELTRD VENTR','33207','1','','1','0','','','',0, 1, 0, 0),
(2780,'INS NEW/RPLCMT PRM PM W/TRANSV ELTRD ATRIAL&VENT','INS NEW/RPLCMT PRM PM W/TRANSV ELTRD ATRIAL&VENT','33208','1','','1','0','','','',0, 1, 0, 0),
(2781,'INSJ/RPLCMT TEMP TRANSVNS 1CHMBR ELTRD/PM CATH','INSJ/RPLCMT TEMP TRANSVNS 1CHMBR ELTRD/PM CATH','33210','1','','1','0','','','',0, 1, 0, 0),
(2782,'INSJ/RPLCMT TEMP TRANSVNS 2CHMBR PACG ELTRDS SPX','INSJ/RPLCMT TEMP TRANSVNS 2CHMBR PACG ELTRDS SPX','33211','1','','1','0','','','',0, 1, 0, 0),
(2783,'INS PM PLS GEN W/EXIST SINGLE LEAD','INS PM PLS GEN W/EXIST SINGLE LEAD','33212','1','','1','0','','','',0, 1, 0, 0),
(2784,'INS PACEMAKER PULSE GEN ONLY W/EXIST DUAL LEADS','INS PACEMAKER PULSE GEN ONLY W/EXIST DUAL LEADS','33213','1','','1','0','','','',0, 1, 0, 0),
(2785,'UPG PACEMAKER SYS CONVERT 1CHMBR SYS 2CHMBR SYS','UPG PACEMAKER SYS CONVERT 1CHMBR SYS 2CHMBR SYS','33214','1','','1','0','','','',0, 1, 0, 0),
(2786,'RPSG PREV IMPLTED PM/DFB R ATR/R VENTR ELECTRODE','RPSG PREV IMPLTED PM/DFB R ATR/R VENTR ELECTRODE','33215','1','','1','0','','','',0, 1, 0, 0),
(2787,'INSJ 1 TRANSVNS ELTRD PERM PACEMAKER/IMPLTBL DFB','INSJ 1 TRANSVNS ELTRD PERM PACEMAKER/IMPLTBL DFB','33216','1','','1','0','','','',0, 1, 0, 0),
(2788,'INSJ 2 TRANSVNS ELTRD PERM PACEMAKER/IMPLTBL DFB','INSJ 2 TRANSVNS ELTRD PERM PACEMAKER/IMPLTBL DFB','33217','1','','1','0','','','',0, 1, 0, 0),
(2789,'RPR 1 TRANSVNS ELTRD PRM PM/PACING IMPLNTBL DFB','RPR 1 TRANSVNS ELTRD PRM PM/PACING IMPLNTBL DFB','33218','1','','1','0','','','',0, 1, 0, 0),
(2790,'RPR 2 TRANSVNS ELECTRODES PRM PM/IMPLANTABLE DFB','RPR 2 TRANSVNS ELECTRODES PRM PM/IMPLANTABLE DFB','33220','1','','1','0','','','',0, 1, 0, 0),
(2791,'INS PACEMAKER PULSE GEN ONLY W/EXIST MULT LEADS','INS PACEMAKER PULSE GEN ONLY W/EXIST MULT LEADS','33221','1','','1','0','','','',0, 1, 0, 0),
(2792,'RELOCATION OF SKIN POCKET FOR PACEMAKER','RELOCATION OF SKIN POCKET FOR PACEMAKER','33222','1','','1','0','','','',0, 1, 0, 0),
(2793,'RELOCATE SKIN POCKET IMPLANTABLE DEFIBRILLATOR','RELOCATE SKIN POCKET IMPLANTABLE DEFIBRILLATOR','33223','1','','1','0','','','',0, 1, 0, 0),
(2794,'INSJ ELTRD CAR VEN SYS ATTCH PREV PM/DFB PLS GEN','INSJ ELTRD CAR VEN SYS ATTCH PREV PM/DFB PLS GEN','33224','1','','1','0','','','',0, 1, 0, 0),
(2795,'INSJ ELTRD CAR VEN SYS TM INSJ DFB/PM PLS GEN','INSJ ELTRD CAR VEN SYS TM INSJ DFB/PM PLS GEN','33225','1','','1','0','','','',0, 1, 0, 0),
(2796,'RPSG PREV IMPLTED CAR VEN SYS L VENTR ELTRD','RPSG PREV IMPLTED CAR VEN SYS L VENTR ELTRD','33226','1','','1','0','','','',0, 1, 0, 0),
(2797,'REMVL PERM PM PLSE GEN W/REPL PLSE GEN SNGL LEAD','REMVL PERM PM PLSE GEN W/REPL PLSE GEN SNGL LEAD','33227','1','','1','0','','','',0, 1, 0, 0),
(2798,'REMVL PERM PM PLS GEN W/REPL PLSE GEN 2 LEAD SYS','REMVL PERM PM PLS GEN W/REPL PLSE GEN 2 LEAD SYS','33228','1','','1','0','','','',0, 1, 0, 0),
(2799,'REMVL PERM PM PLS GEN W/REPL PLSE GEN MULT LEAD','REMVL PERM PM PLS GEN W/REPL PLSE GEN MULT LEAD','33229','1','','1','0','','','',0, 1, 0, 0),
(2800,'INSJ IMPLNTBL DEFIB PULSE GEN W/EXIST DUAL LEADS','INSJ IMPLNTBL DEFIB PULSE GEN W/EXIST DUAL LEADS','33230','1','','1','0','','','',0, 1, 0, 0),
(2801,'INSJ IMPLNTBL DEFIB PULSE GEN W/EXIST MULTILEADS','INSJ IMPLNTBL DEFIB PULSE GEN W/EXIST MULTILEADS','33231','1','','1','0','','','',0, 1, 0, 0),
(2802,'REMOVAL PERMANENT PACEMAKER PULSE GENERATOR ONLY','REMOVAL PERMANENT PACEMAKER PULSE GENERATOR ONLY','33233','1','','1','0','','','',0, 1, 0, 0),
(2803,'RMVL TRANSVNS PM ELTRD 1 LEAD SYS ATR/VENTR','RMVL TRANSVNS PM ELTRD 1 LEAD SYS ATR/VENTR','33234','1','','1','0','','','',0, 1, 0, 0),
(2804,'RMVL TRANSVNS PM ELTRD DUAL LEAD SYS','RMVL TRANSVNS PM ELTRD DUAL LEAD SYS','33235','1','','1','0','','','',0, 1, 0, 0),
(2805,'RMVL PRM EPICAR PM&ELTRDS THORCOM 1 LEAD SYS','RMVL PRM EPICAR PM&ELTRDS THORCOM 1 LEAD SYS','33236','1','','1','0','','','',0, 1, 0, 0),
(2806,'RMVL PRM EPICAR PM&ELTRDS THORCOM DUAL LEAD SY','RMVL PRM EPICAR PM&ELTRDS THORCOM DUAL LEAD SY','33237','1','','1','0','','','',0, 1, 0, 0),
(2807,'RMVL PRM TRANSVENOUS ELECTRODE THORACOTOMY','RMVL PRM TRANSVENOUS ELECTRODE THORACOTOMY','33238','1','','1','0','','','',0, 1, 0, 0),
(2808,'INSJ IMPLNTBL DEFIB PULSE GEN W/1 EXISTING LD','INSJ IMPLNTBL DEFIB PULSE GEN W/1 EXISTING LD','33240','1','','1','0','','','',0, 1, 0, 0),
(2809,'REMOVAL IMPLANTABLE DEFIB PULSE GENERATOR ONLY','REMOVAL IMPLANTABLE DEFIB PULSE GENERATOR ONLY','33241','1','','1','0','','','',0, 1, 0, 0),
(2810,'RMVL 1/DUAL CHAMBER DEFIB ELECTRODE BY THORACOM','RMVL 1/DUAL CHAMBER DEFIB ELECTRODE BY THORACOM','33243','1','','1','0','','','',0, 1, 0, 0),
(2811,'RMVL1/DUAL CHMBR IMPLTBL DFB ELTRD TRANSVNS XTRJ','RMVL1/DUAL CHMBR IMPLTBL DFB ELTRD TRANSVNS XTRJ','33244','1','','1','0','','','',0, 1, 0, 0),
(2812,'INSJ/RPLCMT PERM DFB W/TRNSVNS LDS 1/DUAL CHMBR','INSJ/RPLCMT PERM DFB W/TRNSVNS LDS 1/DUAL CHMBR','33249','1','','1','0','','','',0, 1, 0, 0),
(2813,'ABLATION ARRHYTHMOGENIC FOCI/PATHWAY W/O BYPASS','ABLATION ARRHYTHMOGENIC FOCI/PATHWAY W/O BYPASS','33250','1','','1','0','','','',0, 1, 0, 0),
(2814,'ABLATION ARRHYTHMOGENIC FOCI/PATHWAY W/BYPASS','ABLATION ARRHYTHMOGENIC FOCI/PATHWAY W/BYPASS','33251','1','','1','0','','','',0, 1, 0, 0),
(2815,'ABLATION & RECONSTRUCTION ATRIA LIMITED','ABLATION & RECONSTRUCTION ATRIA LIMITED','33254','1','','1','0','','','',0, 1, 0, 0),
(2816,'ABLATION & RCNSTJ ATRIA EXTNSV W/O BYPASS','ABLATION & RCNSTJ ATRIA EXTNSV W/O BYPASS','33255','1','','1','0','','','',0, 1, 0, 0),
(2817,'ABLATION & RCNSTJ ATRIA EXTNSV W/BYPASS','ABLATION & RCNSTJ ATRIA EXTNSV W/BYPASS','33256','1','','1','0','','','',0, 1, 0, 0),
(2818,'ATRIA ABLATE & RCNSTJ W/OTHER PROCEDURE LIMITE','ATRIA ABLATE & RCNSTJ W/OTHER PROCEDURE LIMITE','33257','1','','1','0','','','',0, 1, 0, 0),
(2819,'ATRIA ABLTJ & RCNSTJ W/OTHER PX EXTENSIV W/O BYP','ATRIA ABLTJ & RCNSTJ W/OTHER PX EXTENSIV W/O BYP','33258','1','','1','0','','','',0, 1, 0, 0),
(2820,'ATRIA ABLTJ & RCNSTJ W/OTHER PX EXTEN W/BYPASS','ATRIA ABLTJ & RCNSTJ W/OTHER PX EXTEN W/BYPASS','33259','1','','1','0','','','',0, 1, 0, 0),
(2821,'OPRATIVE ABLTJ VENTR ARRHYTHMOGENIC FOC W/BYPASS','OPRATIVE ABLTJ VENTR ARRHYTHMOGENIC FOC W/BYPASS','33261','1','','1','0','','','',0, 1, 0, 0),
(2822,'RMVL IMPLTBL DFB PLSE GEN W/REPL PLSE GEN 1 LEAD','RMVL IMPLTBL DFB PLSE GEN W/REPL PLSE GEN 1 LEAD','33262','1','','1','0','','','',0, 1, 0, 0),
(2823,'RMVL IMPLTBL DFB PLSE GEN W/RPLCMT PLSE GEN 2 LD','RMVL IMPLTBL DFB PLSE GEN W/RPLCMT PLSE GEN 2 LD','33263','1','','1','0','','','',0, 1, 0, 0),
(2824,'RMVL IMPLTBL DFB PLS GEN W/RPLCMT PLS GEN MLT LD','RMVL IMPLTBL DFB PLS GEN W/RPLCMT PLS GEN MLT LD','33264','1','','1','0','','','',0, 1, 0, 0),
(2825,'NDSC ABLATION & RCNSTJ ATRIA LIMITED W/O BYPAS','NDSC ABLATION & RCNSTJ ATRIA LIMITED W/O BYPAS','33265','1','','1','0','','','',0, 1, 0, 0),
(2826,'NDSC ABLATION & RCNSTJ ATRIA EXTEN W/O BYPASS','NDSC ABLATION & RCNSTJ ATRIA EXTEN W/O BYPASS','33266','1','','1','0','','','',0, 1, 0, 0),
(2827,'INS/RPLCMNT PERM SUBQ IMPLTBL DFB W/SUBQ ELTRD','INS/RPLCMNT PERM SUBQ IMPLTBL DFB W/SUBQ ELTRD','33270','1','','1','0','','','',0, 1, 0, 0),
(2828,'INSJ OF SUBQ IMPLANTABLE DEFIBRILLATOR ELECTRODE','INSJ OF SUBQ IMPLANTABLE DEFIBRILLATOR ELECTRODE','33271','1','','1','0','','','',0, 1, 0, 0),
(2829,'RMVL OF SUBQ IMPLANTABLE DEFIBRILLATOR ELECTRODE','RMVL OF SUBQ IMPLANTABLE DEFIBRILLATOR ELECTRODE','33272','1','','1','0','','','',0, 1, 0, 0),
(2830,'REPOS PREVIOUSLY IMPLANTED SUBQ IMPLANTABLE DFB','REPOS PREVIOUSLY IMPLANTED SUBQ IMPLANTABLE DFB','33273','1','','1','0','','','',0, 1, 0, 0),
(2831,'IMPLANTATION PT-ACTIVATED CARDIAC EVENT RECORDER','IMPLANTATION PT-ACTIVATED CARDIAC EVENT RECORDER','33282','1','','1','0','','','',0, 1, 0, 0),
(2832,'RMVL IMPLANTABLE PT-ACTIVATED CAR EVENT RECORDER','RMVL IMPLANTABLE PT-ACTIVATED CAR EVENT RECORDER','33284','1','','1','0','','','',0, 1, 0, 0),
(2833,'REPAIR CARDIAC WOUND W/O BYPASS','REPAIR CARDIAC WOUND W/O BYPASS','33300','1','','1','0','','','',0, 1, 0, 0),
(2834,'REPAIR CARDIAC WOUND W/CARDIOPULMONARY BYPASS','REPAIR CARDIAC WOUND W/CARDIOPULMONARY BYPASS','33305','1','','1','0','','','',0, 1, 0, 0),
(2835,'CARDIOT EXPL W/RMVL FB ATR/VENTR THRMB W/O BYP','CARDIOT EXPL W/RMVL FB ATR/VENTR THRMB W/O BYP','33310','1','','1','0','','','',0, 1, 0, 0),
(2836,'CARDIOT EXPL RMVL FB ATR/VENTR THRMB CARD BYP','CARDIOT EXPL RMVL FB ATR/VENTR THRMB CARD BYP','33315','1','','1','0','','','',0, 1, 0, 0),
(2837,'SUTR RPR AORTA/GRT VSL W/O SHUNT/CARD BYP','SUTR RPR AORTA/GRT VSL W/O SHUNT/CARD BYP','33320','1','','1','0','','','',0, 1, 0, 0),
(2838,'SUTR RPR AORTA/GREAT VESSEL W/SHUNT BYPASS','SUTR RPR AORTA/GREAT VESSEL W/SHUNT BYPASS','33321','1','','1','0','','','',0, 1, 0, 0),
(2839,'SUTURE REPAIR AORTA/GREAT VESSEL W/BYPASS','SUTURE REPAIR AORTA/GREAT VESSEL W/BYPASS','33322','1','','1','0','','','',0, 1, 0, 0),
(2840,'INSJ GRAFT AORTA/GREAT VESSEL W/O SHUNT/BYPASS','INSJ GRAFT AORTA/GREAT VESSEL W/O SHUNT/BYPASS','33330','1','','1','0','','','',0, 1, 0, 0),
(2841,'INSJ GRAFT AORTA/GREAT VESSEL W/BYPASS','INSJ GRAFT AORTA/GREAT VESSEL W/BYPASS','33335','1','','1','0','','','',0, 1, 0, 0),
(2842,'REPLACE AORTIC VALVE PERQ FEMORAL ARTRY APPROACH','REPLACE AORTIC VALVE PERQ FEMORAL ARTRY APPROACH','33361','1','','1','0','','','',0, 1, 0, 0),
(2843,'REPLACE AORTIC VALVE OPENFEMORAL ARTERY APPROACH','REPLACE AORTIC VALVE OPENFEMORAL ARTERY APPROACH','33362','1','','1','0','','','',0, 1, 0, 0),
(2844,'REPLACE AORTIC VALVE OPEN AXILLRY ARTRY APPROACH','REPLACE AORTIC VALVE OPEN AXILLRY ARTRY APPROACH','33363','1','','1','0','','','',0, 1, 0, 0),
(2845,'REPLACE AORTIC VALVE OPEN ILIAC ARTERY APPROACH','REPLACE AORTIC VALVE OPEN ILIAC ARTERY APPROACH','33364','1','','1','0','','','',0, 1, 0, 0),
(2846,'REPLACE AORTIC VALVE OPEN TRANSAORTIC APPROACH','REPLACE AORTIC VALVE OPEN TRANSAORTIC APPROACH','33365','1','','1','0','','','',0, 1, 0, 0),
(2847,'TRANSCATHETER TRANSAPICAL REPLACEMT AORTIC VALVE','TRANSCATHETER TRANSAPICAL REPLACEMT AORTIC VALVE','33366','1','','1','0','','','',0, 1, 0, 0),
(2848,'REPLACE AORTIC VALVE W/BYP PRQ ART/VENOUS APPRCH','REPLACE AORTIC VALVE W/BYP PRQ ART/VENOUS APPRCH','33367','1','','1','0','','','',0, 1, 0, 0),
(2849,'REPLACE AORTIC VALVE W/BYP OPEN ART/VENOUS APRCH','REPLACE AORTIC VALVE W/BYP OPEN ART/VENOUS APRCH','33368','1','','1','0','','','',0, 1, 0, 0),
(2850,'REPLACE AORTA VALVE W/BYP CNTRL ART/VENOUS APRCH','REPLACE AORTA VALVE W/BYP CNTRL ART/VENOUS APRCH','33369','1','','1','0','','','',0, 1, 0, 0),
(2851,'VALVULOPLASTY AORTIC VALVE OPEN W/BYPASS','VALVULOPLASTY AORTIC VALVE OPEN W/BYPASS','33400','1','','1','0','','','',0, 1, 0, 0),
(2852,'VALVULOPLASTY AORTIC VALVE OPEN W/INFLOW OCCLUS','VALVULOPLASTY AORTIC VALVE OPEN W/INFLOW OCCLUS','33401','1','','1','0','','','',0, 1, 0, 0),
(2853,'VLVP AORTIC VALVE W/TRANSVENTR DILAT W/CARD BYP','VLVP AORTIC VALVE W/TRANSVENTR DILAT W/CARD BYP','33403','1','','1','0','','','',0, 1, 0, 0),
(2854,'CONSTRUCTION APICAL-AORTIC CONDUIT','CONSTRUCTION APICAL-AORTIC CONDUIT','33404','1','','1','0','','','',0, 1, 0, 0),
(2855,'RPLCMT PROST AORTIC VALVE XCP HOMOGRF/STENT','RPLCMT PROST AORTIC VALVE XCP HOMOGRF/STENT','33405','1','','1','0','','','',0, 1, 0, 0),
(2856,'RPLCMT AORTIC VALVE ALLOGRAFT VALVE FREEHAND','RPLCMT AORTIC VALVE ALLOGRAFT VALVE FREEHAND','33406','1','','1','0','','','',0, 1, 0, 0),
(2857,'RPLCMT AORTIC VALVE W/STENTLESS TISSUE VALVE','RPLCMT AORTIC VALVE W/STENTLESS TISSUE VALVE','33410','1','','1','0','','','',0, 1, 0, 0),
(2858,'RPLCMT AORTIC VALVE ANNULUS ENLGMENT NONC SINUS','RPLCMT AORTIC VALVE ANNULUS ENLGMENT NONC SINUS','33411','1','','1','0','','','',0, 1, 0, 0),
(2859,'REPLACEMENT AORTIC VALVE KONNO PROCEDURE','REPLACEMENT AORTIC VALVE KONNO PROCEDURE','33412','1','','1','0','','','',0, 1, 0, 0),
(2860,'REPLACEMENT AORTIC&PULMON VALVES ROSS PROCEDUR','REPLACEMENT AORTIC&PULMON VALVES ROSS PROCEDUR','33413','1','','1','0','','','',0, 1, 0, 0),
(2861,'RPR VENTR O/F TRC OBSTRCJ PATCH ENLGMENT O/F TRC','RPR VENTR O/F TRC OBSTRCJ PATCH ENLGMENT O/F TRC','33414','1','','1','0','','','',0, 1, 0, 0),
(2862,'RESECTION/INCISION SUBVALVULAR TISSUE','RESECTION/INCISION SUBVALVULAR TISSUE','33415','1','','1','0','','','',0, 1, 0, 0),
(2863,'VENTRICULOMYOTOMY-MYECTOMY','VENTRICULOMYOTOMY-MYECTOMY','33416','1','','1','0','','','',0, 1, 0, 0),
(2864,'AORTOPLASTY SUPRAVALVULAR STENOSIS','AORTOPLASTY SUPRAVALVULAR STENOSIS','33417','1','','1','0','','','',0, 1, 0, 0),
(2865,'TCAT MITRAL VALVE REPAIR INITIAL PROSTHESIS','TCAT MITRAL VALVE REPAIR INITIAL PROSTHESIS','33418','1','','1','0','','','',0, 1, 0, 0),
(2866,'TCAT MITRAL VALVE REPAIR ADDL PROSTHESIS','TCAT MITRAL VALVE REPAIR ADDL PROSTHESIS','33419','1','','1','0','','','',0, 1, 0, 0),
(2867,'VALVOTOMY MITRAL VALVE CLOSED HEART','VALVOTOMY MITRAL VALVE CLOSED HEART','33420','1','','1','0','','','',0, 1, 0, 0),
(2868,'VALVOTOMY MITRAL VALVE OPEN HEART W/BYPASS','VALVOTOMY MITRAL VALVE OPEN HEART W/BYPASS','33422','1','','1','0','','','',0, 1, 0, 0),
(2869,'VALVULOPLASTY MITRAL VALVE W/CARDIAC BYPASS','VALVULOPLASTY MITRAL VALVE W/CARDIAC BYPASS','33425','1','','1','0','','','',0, 1, 0, 0),
(2870,'VLVP MITRAL VALVE W/CARD BYP W/PROSTC RING','VLVP MITRAL VALVE W/CARD BYP W/PROSTC RING','33426','1','','1','0','','','',0, 1, 0, 0),
(2871,'VLVP MITRAL VALVE W/BYPASS RAD RCNSTJ W/WO RING','VLVP MITRAL VALVE W/BYPASS RAD RCNSTJ W/WO RING','33427','1','','1','0','','','',0, 1, 0, 0),
(2872,'REPLACEMENT MITRAL VALVE W/CARDIOPULMONARY BYP','REPLACEMENT MITRAL VALVE W/CARDIOPULMONARY BYP','33430','1','','1','0','','','',0, 1, 0, 0),
(2873,'VALVECTOMY TRICUSPID VALVE W/CARDIOPULMONARY BYP','VALVECTOMY TRICUSPID VALVE W/CARDIOPULMONARY BYP','33460','1','','1','0','','','',0, 1, 0, 0),
(2874,'VALVULOPLASTY TRICUSPID VALVE W/O RING INSERTION','VALVULOPLASTY TRICUSPID VALVE W/O RING INSERTION','33463','1','','1','0','','','',0, 1, 0, 0),
(2875,'VALVULOPLASTY TRICUSPID VALVE W/RING INSERTION','VALVULOPLASTY TRICUSPID VALVE W/RING INSERTION','33464','1','','1','0','','','',0, 1, 0, 0),
(2876,'REPLACEMENT TRICUSPID VALVE W/CARD BYPASS','REPLACEMENT TRICUSPID VALVE W/CARD BYPASS','33465','1','','1','0','','','',0, 1, 0, 0),
(2877,'TRICUSPID VALVE RPSG&PLCTJ EBSTEIN ANOMALY','TRICUSPID VALVE RPSG&PLCTJ EBSTEIN ANOMALY','33468','1','','1','0','','','',0, 1, 0, 0),
(2878,'VALVOTOMY PULMONARY VALVE CLSD HEART TRANSVENTR','VALVOTOMY PULMONARY VALVE CLSD HEART TRANSVENTR','33470','1','','1','0','','','',0, 1, 0, 0),
(2879,'VALVOTOMY PULM VALVE CLSD HEART VIA PULM ARTERY','VALVOTOMY PULM VALVE CLSD HEART VIA PULM ARTERY','33471','1','','1','0','','','',0, 1, 0, 0),
(2880,'VALVOTOMY PULMONARY VALVE OPEN HEART W/BYPASS','VALVOTOMY PULMONARY VALVE OPEN HEART W/BYPASS','33474','1','','1','0','','','',0, 1, 0, 0),
(2881,'REPLACEMENT PULMONARY VALVE','REPLACEMENT PULMONARY VALVE','33475','1','','1','0','','','',0, 1, 0, 0),
(2882,'R VENTRIC RESCJ INFUND STEN W/WO COMMISSUROTOMY','R VENTRIC RESCJ INFUND STEN W/WO COMMISSUROTOMY','33476','1','','1','0','','','',0, 1, 0, 0),
(2883,'TCAT PULMONARY VALVE IMPLANTATION PRQ APPROACH','TCAT PULMONARY VALVE IMPLANTATION PRQ APPROACH','33477','1','','1','0','','','',0, 1, 0, 0),
(2884,'OUTFLOW TRACT AGMNTJ W/WO COMMISSUR/INFUND RESCJ','OUTFLOW TRACT AGMNTJ W/WO COMMISSUR/INFUND RESCJ','33478','1','','1','0','','','',0, 1, 0, 0),
(2885,'RPR NON-STRUCT PROSTC VALVE DYSFUNCTION W/BYPASS','RPR NON-STRUCT PROSTC VALVE DYSFUNCTION W/BYPASS','33496','1','','1','0','','','',0, 1, 0, 0),
(2886,'RPR CORONARY AV/ARTERIOCAR CHMBR FSTL W/BYPASS','RPR CORONARY AV/ARTERIOCAR CHMBR FSTL W/BYPASS','33500','1','','1','0','','','',0, 1, 0, 0),
(2887,'RPR CORONARY AV/ARTERIOCAR CHMBR FSTL W/O BYPASS','RPR CORONARY AV/ARTERIOCAR CHMBR FSTL W/O BYPASS','33501','1','','1','0','','','',0, 1, 0, 0),
(2888,'RPR ANOM CORONARY ART PULM ART ORIGIN LIGATION','RPR ANOM CORONARY ART PULM ART ORIGIN LIGATION','33502','1','','1','0','','','',0, 1, 0, 0),
(2889,'RPR ANOM CORONARY ARTERY PULM ART ORIGIN GRAFT','RPR ANOM CORONARY ARTERY PULM ART ORIGIN GRAFT','33503','1','','1','0','','','',0, 1, 0, 0),
(2890,'RPR ANOM CORONARY ART PULM ART ORIGIN GRF W/BYP','RPR ANOM CORONARY ART PULM ART ORIGIN GRF W/BYP','33504','1','','1','0','','','',0, 1, 0, 0),
(2891,'RPR ANOM CORON ART W/CONSTJ INTRAPULM ART TUNNEL','RPR ANOM CORON ART W/CONSTJ INTRAPULM ART TUNNEL','33505','1','','1','0','','','',0, 1, 0, 0),
(2892,'RPR ANOM CORONARY ART FROM PULM ART TO AORTA','RPR ANOM CORONARY ART FROM PULM ART TO AORTA','33506','1','','1','0','','','',0, 1, 0, 0),
(2893,'RPR ANOM AORTIC ORIGIN CORONARY ART UNROOF/TLCJ','RPR ANOM AORTIC ORIGIN CORONARY ART UNROOF/TLCJ','33507','1','','1','0','','','',0, 1, 0, 0),
(2894,'NDSC SURG W/VIDEO-ASSISTED HARVEST VEIN CABG','NDSC SURG W/VIDEO-ASSISTED HARVEST VEIN CABG','33508','1','','1','0','','','',0, 1, 0, 0),
(2895,'CORONARY ARTERY BYPASS 1 CORONARY VENOUS GRAFT','CORONARY ARTERY BYPASS 1 CORONARY VENOUS GRAFT','33510','1','','1','0','','','',0, 1, 0, 0),
(2896,'CORONARY ARTERY BYPASS 2 CORONARY VENOUS GRAFTS','CORONARY ARTERY BYPASS 2 CORONARY VENOUS GRAFTS','33511','1','','1','0','','','',0, 1, 0, 0),
(2897,'CORONARY ARTERY BYPASS 3 CORONARY VENOUS GRAFTS','CORONARY ARTERY BYPASS 3 CORONARY VENOUS GRAFTS','33512','1','','1','0','','','',0, 1, 0, 0),
(2898,'CORONARY ARTERY BYPASS 4 CORONARY VENOUS GRAFTS','CORONARY ARTERY BYPASS 4 CORONARY VENOUS GRAFTS','33513','1','','1','0','','','',0, 1, 0, 0),
(2899,'CORONARY ARTERY BYPASS 5 CORONARY VENOUS GRAFTS','CORONARY ARTERY BYPASS 5 CORONARY VENOUS GRAFTS','33514','1','','1','0','','','',0, 1, 0, 0),
(2900,'CORONARY ARTERY BYPASS 6/+ CORONARY VENOUS GRAFT','CORONARY ARTERY BYPASS 6/+ CORONARY VENOUS GRAFT','33516','1','','1','0','','','',0, 1, 0, 0),
(2901,'CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 1 VEIN','CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 1 VEIN','33517','1','','1','0','','','',0, 1, 0, 0),
(2902,'CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 2 VEIN','CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 2 VEIN','33518','1','','1','0','','','',0, 1, 0, 0),
(2903,'CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 3 VEIN','CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 3 VEIN','33519','1','','1','0','','','',0, 1, 0, 0),
(2904,'CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 4 VEIN','CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 4 VEIN','33521','1','','1','0','','','',0, 1, 0, 0),
(2905,'CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 5 VEIN','CORONARY ARTERY BYP W/VEIN & ARTERY GRAFT 5 VEIN','33522','1','','1','0','','','',0, 1, 0, 0),
(2906,'CORONARY ARTERY BYP W/VEIN &ARTERY GRAFT 6 VEIN','CORONARY ARTERY BYP W/VEIN &ARTERY GRAFT 6 VEIN','33523','1','','1','0','','','',0, 1, 0, 0),
(2907,'ROPRTJ CAB/VALVE PX > 1 MO AFTER ORIGINAL OPERJ','ROPRTJ CAB/VALVE PX > 1 MO AFTER ORIGINAL OPERJ','33530','1','','1','0','','','',0, 1, 0, 0),
(2908,'CABG W/ARTERIAL GRAFT SINGLE ARTERIAL GRAFT','CABG W/ARTERIAL GRAFT SINGLE ARTERIAL GRAFT','33533','1','','1','0','','','',0, 1, 0, 0),
(2909,'CABG W/ARTERIAL GRAFT TWO ARTERIAL GRAFTS','CABG W/ARTERIAL GRAFT TWO ARTERIAL GRAFTS','33534','1','','1','0','','','',0, 1, 0, 0),
(2910,'CABG W/ARTERIAL GRAFT THREE ARTERIAL GRAFTS','CABG W/ARTERIAL GRAFT THREE ARTERIAL GRAFTS','33535','1','','1','0','','','',0, 1, 0, 0),
(2911,'CABG W/ARTERIAL GRAFT FOUR/>ARTERIAL GRAFTS','CABG W/ARTERIAL GRAFT FOUR/>ARTERIAL GRAFTS','33536','1','','1','0','','','',0, 1, 0, 0),
(2912,'MYOCARDIAL RESECTION','MYOCARDIAL RESECTION','33542','1','','1','0','','','',0, 1, 0, 0),
(2913,'RPR POSTINFRCJ VENTRICULAR SEPTAL DEFECT','RPR POSTINFRCJ VENTRICULAR SEPTAL DEFECT','33545','1','','1','0','','','',0, 1, 0, 0),
(2914,'SURG VENTRICULAR RSTRJ PX W/PROSTC PATCH PFRMD','SURG VENTRICULAR RSTRJ PX W/PROSTC PATCH PFRMD','33548','1','','1','0','','','',0, 1, 0, 0),
(2915,'CORONARY ENDARTERCOMY OPEN ANY METHOD','CORONARY ENDARTERCOMY OPEN ANY METHOD','33572','1','','1','0','','','',0, 1, 0, 0),
(2916,'CLOSURE ATRIOVENTRICULAR VALVE SUTURE/PATCH','CLOSURE ATRIOVENTRICULAR VALVE SUTURE/PATCH','33600','1','','1','0','','','',0, 1, 0, 0),
(2917,'CLOSURE SEMILUNAR VALVE AORTIC/PULM SUTURE/PATCH','CLOSURE SEMILUNAR VALVE AORTIC/PULM SUTURE/PATCH','33602','1','','1','0','','','',0, 1, 0, 0),
(2918,'ANAST PULMONARY ART AORTA DAMUS-KAYE-STANSEL PX','ANAST PULMONARY ART AORTA DAMUS-KAYE-STANSEL PX','33606','1','','1','0','','','',0, 1, 0, 0),
(2919,'RPR CAR ANOMAL XCP PULM ATRESIA VENTR SEPTL DFCT','RPR CAR ANOMAL XCP PULM ATRESIA VENTR SEPTL DFCT','33608','1','','1','0','','','',0, 1, 0, 0),
(2920,'RPR CAR ANOMAL SURG ENLGMENT VENTR SEPTL DFCT','RPR CAR ANOMAL SURG ENLGMENT VENTR SEPTL DFCT','33610','1','','1','0','','','',0, 1, 0, 0),
(2921,'RPR 2 OUTLET R VNTRC W/INTRAVENTR TUNNEL RPR','RPR 2 OUTLET R VNTRC W/INTRAVENTR TUNNEL RPR','33611','1','','1','0','','','',0, 1, 0, 0),
(2922,'RPR 2 OUTLET R VNTRC RPR R VENTR O/F TRC OBSTRCJ','RPR 2 OUTLET R VNTRC RPR R VENTR O/F TRC OBSTRCJ','33612','1','','1','0','','','',0, 1, 0, 0),
(2923,'RPR CAR ANOMAL CLSR SEPTL DFCT SMPL FONTAN PX','RPR CAR ANOMAL CLSR SEPTL DFCT SMPL FONTAN PX','33615','1','','1','0','','','',0, 1, 0, 0),
(2924,'RPR COMPLEX CARDIAC ANOMALY MODIFIED FONTAN PX','RPR COMPLEX CARDIAC ANOMALY MODIFIED FONTAN PX','33617','1','','1','0','','','',0, 1, 0, 0),
(2925,'RPR 1 VNTRC W/O/F OBSTRCJ&AORTIC ARCH HYPOPLAS','RPR 1 VNTRC W/O/F OBSTRCJ&AORTIC ARCH HYPOPLAS','33619','1','','1','0','','','',0, 1, 0, 0),
(2926,'APPLICATION RIGHT & LEFT PULMONARY ARTERY BAND','APPLICATION RIGHT & LEFT PULMONARY ARTERY BAND','33620','1','','1','0','','','',0, 1, 0, 0),
(2927,'TRANSTHORACIC CATHETER INSERTION FOR STENT PLMT','TRANSTHORACIC CATHETER INSERTION FOR STENT PLMT','33621','1','','1','0','','','',0, 1, 0, 0),
(2928,'RECONSTRUCTION COMPLEX CARDIAC ANOMALY','RECONSTRUCTION COMPLEX CARDIAC ANOMALY','33622','1','','1','0','','','',0, 1, 0, 0),
(2929,'RPR ATRIAL SEPTAL DFCT SECUNDUM W/BYP W/WO PATCH','RPR ATRIAL SEPTAL DFCT SECUNDUM W/BYP W/WO PATCH','33641','1','','1','0','','','',0, 1, 0, 0),
(2930,'DIR/PTCH CLS SINUS VENOSUS W/WO ANOM PUL VEN DRG','DIR/PTCH CLS SINUS VENOSUS W/WO ANOM PUL VEN DRG','33645','1','','1','0','','','',0, 1, 0, 0),
(2931,'RPR ATRIAL & VENTRIC SEPTAL DFCT DIR/PATCH CLS','RPR ATRIAL & VENTRIC SEPTAL DFCT DIR/PATCH CLS','33647','1','','1','0','','','',0, 1, 0, 0),
(2932,'RPR INCPLT/PRTL AV CANAL W/WO AV VALVE RPR','RPR INCPLT/PRTL AV CANAL W/WO AV VALVE RPR','33660','1','','1','0','','','',0, 1, 0, 0),
(2933,'RPR INTRM/TRANSJ AV CANAL W/WO AV VALVE RPR','RPR INTRM/TRANSJ AV CANAL W/WO AV VALVE RPR','33665','1','','1','0','','','',0, 1, 0, 0),
(2934,'RPR COMPL AV CANAL W/WO PROSTC VALVE','RPR COMPL AV CANAL W/WO PROSTC VALVE','33670','1','','1','0','','','',0, 1, 0, 0),
(2935,'CLOSURE MULTIPLE VENTRICULAR SEPTAL DEFECTS','CLOSURE MULTIPLE VENTRICULAR SEPTAL DEFECTS','33675','1','','1','0','','','',0, 1, 0, 0),
(2936,'CLOSURE MULTIPLE VSD W/RESECTION','CLOSURE MULTIPLE VSD W/RESECTION','33676','1','','1','0','','','',0, 1, 0, 0),
(2937,'CLOSURE MULTIPLE VSD W/REMOVAL ARTERY BAND','CLOSURE MULTIPLE VSD W/REMOVAL ARTERY BAND','33677','1','','1','0','','','',0, 1, 0, 0),
(2938,'CLSR 1 VENTRICULAR SEPTAL DEFECT W/WO PATCH','CLSR 1 VENTRICULAR SEPTAL DEFECT W/WO PATCH','33681','1','','1','0','','','',0, 1, 0, 0),
(2939,'CLSR V-SEPTL DFCT W/PULM VLVT/INFUND RESCJ','CLSR V-SEPTL DFCT W/PULM VLVT/INFUND RESCJ','33684','1','','1','0','','','',0, 1, 0, 0),
(2940,'CLSR V-SEPTAL DFCT W/RMVL P-ART BAND W/WO GUSSET','CLSR V-SEPTAL DFCT W/RMVL P-ART BAND W/WO GUSSET','33688','1','','1','0','','','',0, 1, 0, 0),
(2941,'BANDING PULMONARY ARTERY','BANDING PULMONARY ARTERY','33690','1','','1','0','','','',0, 1, 0, 0),
(2942,'COMPL RPR TETRALOGY FALLOT W/O PULM ATRESIA','COMPL RPR TETRALOGY FALLOT W/O PULM ATRESIA','33692','1','','1','0','','','',0, 1, 0, 0),
(2943,'COMPL RPR T-FALLOT W/O PULM ATRESIA TANULR PATCH','COMPL RPR T-FALLOT W/O PULM ATRESIA TANULR PATCH','33694','1','','1','0','','','',0, 1, 0, 0),
(2944,'COMPL RPR T-FALLOT W/PULM ATRESIA','COMPL RPR T-FALLOT W/PULM ATRESIA','33697','1','','1','0','','','',0, 1, 0, 0),
(2945,'RPR SINUS VALSALVA FISTULA','RPR SINUS VALSALVA FISTULA','33702','1','','1','0','','','',0, 1, 0, 0),
(2946,'RPR SINUS VALSALVA FISTULA W/RPR V-SEPTAL DEFECT','RPR SINUS VALSALVA FISTULA W/RPR V-SEPTAL DEFECT','33710','1','','1','0','','','',0, 1, 0, 0),
(2947,'RPR SINUS VALSALVA ANEURYSM','RPR SINUS VALSALVA ANEURYSM','33720','1','','1','0','','','',0, 1, 0, 0),
(2948,'CLOSURE AORTICO-LEFT VENTRICULAR TUNNEL','CLOSURE AORTICO-LEFT VENTRICULAR TUNNEL','33722','1','','1','0','','','',0, 1, 0, 0),
(2949,'REPAIR ISOLATED PARTIAL PULM VENOUS RETURN','REPAIR ISOLATED PARTIAL PULM VENOUS RETURN','33724','1','','1','0','','','',0, 1, 0, 0),
(2950,'REPAIR PULMONARY VENOUS STENOSIS','REPAIR PULMONARY VENOUS STENOSIS','33726','1','','1','0','','','',0, 1, 0, 0),
(2951,'COMPLETE RPR ANOMALOUS PULMONARY VENOUS RETURN','COMPLETE RPR ANOMALOUS PULMONARY VENOUS RETURN','33730','1','','1','0','','','',0, 1, 0, 0),
(2952,'RPR COR TRIATM/SUPVALVR RING RESCJ L ATRIAL MEMB','RPR COR TRIATM/SUPVALVR RING RESCJ L ATRIAL MEMB','33732','1','','1','0','','','',0, 1, 0, 0),
(2953,'ATRIAL SEPTECTOMY/SEPTOSTOMY CLOSED HEART','ATRIAL SEPTECTOMY/SEPTOSTOMY CLOSED HEART','33735','1','','1','0','','','',0, 1, 0, 0),
(2954,'ATRIAL SEPTECTOMY/SEPTOSTOMY OPEN HEART W/BYPASS','ATRIAL SEPTECTOMY/SEPTOSTOMY OPEN HEART W/BYPASS','33736','1','','1','0','','','',0, 1, 0, 0),
(2955,'ATRIAL SEPTECT/SEPTOST OPN HRT W/INFL OCCLUSION','ATRIAL SEPTECT/SEPTOST OPN HRT W/INFL OCCLUSION','33737','1','','1','0','','','',0, 1, 0, 0),
(2956,'SHUNT SUBCLAVIAN PULMONARY ARTERY','SHUNT SUBCLAVIAN PULMONARY ARTERY','33750','1','','1','0','','','',0, 1, 0, 0),
(2957,'SHUNT ASCENDING AORTA PULMONARY ARTERY','SHUNT ASCENDING AORTA PULMONARY ARTERY','33755','1','','1','0','','','',0, 1, 0, 0),
(2958,'SHUNT DESCENDING AORTA PULMONARY ARTERY','SHUNT DESCENDING AORTA PULMONARY ARTERY','33762','1','','1','0','','','',0, 1, 0, 0),
(2959,'SHUNT CENTRAL W/PROSTHETIC GRAFT','SHUNT CENTRAL W/PROSTHETIC GRAFT','33764','1','','1','0','','','',0, 1, 0, 0),
(2960,'SHUNT SUPERIOR VENA CAVA PULMONARY ART 1 LUNG','SHUNT SUPERIOR VENA CAVA PULMONARY ART 1 LUNG','33766','1','','1','0','','','',0, 1, 0, 0),
(2961,'SHUNT SUPERIOR VENA CAVA PULM ARTERY BOTH LUNGS','SHUNT SUPERIOR VENA CAVA PULM ARTERY BOTH LUNGS','33767','1','','1','0','','','',0, 1, 0, 0),
(2962,'ANASTOMOSIS CAVOPULMARY 2ND SUPRIOR VENA CAVA','ANASTOMOSIS CAVOPULMARY 2ND SUPRIOR VENA CAVA','33768','1','','1','0','','','',0, 1, 0, 0),
(2963,'RPR TRPOS GREAT VSLS W/O ENLGMNT V-SEPTL DFCT','RPR TRPOS GREAT VSLS W/O ENLGMNT V-SEPTL DFCT','33770','1','','1','0','','','',0, 1, 0, 0),
(2964,'RPR TRPOS GREAT VSLS W/ENLGMNT V-SEPTL DFCT','RPR TRPOS GREAT VSLS W/ENLGMNT V-SEPTL DFCT','33771','1','','1','0','','','',0, 1, 0, 0),
(2965,'RPR TRPOS GREAT VSLS ATRIAL BAFFLE PX W/BYPASS','RPR TRPOS GREAT VSLS ATRIAL BAFFLE PX W/BYPASS','33774','1','','1','0','','','',0, 1, 0, 0),
(2966,'RPR TRPOS GREAT VSLS ATR BAFFLE W/RMVL PULM BAND','RPR TRPOS GREAT VSLS ATR BAFFLE W/RMVL PULM BAND','33775','1','','1','0','','','',0, 1, 0, 0),
(2967,'RPR TRPOS GRT VSL ATR BAFFLE W/CLSR V-SEPTL DFCT','RPR TRPOS GRT VSL ATR BAFFLE W/CLSR V-SEPTL DFCT','33776','1','','1','0','','','',0, 1, 0, 0),
(2968,'RPR TRPOS GRT VSL ATR BAFFLE W/BYP SBPULM OBSTRC','RPR TRPOS GRT VSL ATR BAFFLE W/BYP SBPULM OBSTRC','33777','1','','1','0','','','',0, 1, 0, 0),
(2969,'RPR TRPOS GRT VESSEL AORTIC PULMONARY ART RCNSTJ','RPR TRPOS GRT VESSEL AORTIC PULMONARY ART RCNSTJ','33778','1','','1','0','','','',0, 1, 0, 0),
(2970,'RPR TGV AORTIC PULM ART RCNSTJ W/RMVL PULM BAND','RPR TGV AORTIC PULM ART RCNSTJ W/RMVL PULM BAND','33779','1','','1','0','','','',0, 1, 0, 0),
(2971,'RPR TGV AORTIC P-ART RCNSTJ W/CLSR V-SEPTL DFCT','RPR TGV AORTIC P-ART RCNSTJ W/CLSR V-SEPTL DFCT','33780','1','','1','0','','','',0, 1, 0, 0),
(2972,'RPR TGV AORTIC P-ART RCNSTJ RPR SBPULMC OBSTRCJ','RPR TGV AORTIC P-ART RCNSTJ RPR SBPULMC OBSTRCJ','33781','1','','1','0','','','',0, 1, 0, 0),
(2973,'A-ROOT TLCJ VSD PULM STNS RPR W/O C OST RIMPLTJ','A-ROOT TLCJ VSD PULM STNS RPR W/O C OST RIMPLTJ','33782','1','','1','0','','','',0, 1, 0, 0),
(2974,'A-ROOT TLCJ VSD PULM STNS RPR W/RIMPLTJ C OSTIA','A-ROOT TLCJ VSD PULM STNS RPR W/RIMPLTJ C OSTIA','33783','1','','1','0','','','',0, 1, 0, 0),
(2975,'TOTAL REPAIR TRUNCUS ARTERIOSUS','TOTAL REPAIR TRUNCUS ARTERIOSUS','33786','1','','1','0','','','',0, 1, 0, 0),
(2976,'REIMPLANTATION ANOMALOUS PULMONARY ARTERY','REIMPLANTATION ANOMALOUS PULMONARY ARTERY','33788','1','','1','0','','','',0, 1, 0, 0),
(2977,'AORTIC SUSPENSION TRACHEAL DECOMPRESSION SPX','AORTIC SUSPENSION TRACHEAL DECOMPRESSION SPX','33800','1','','1','0','','','',0, 1, 0, 0),
(2978,'DIVISION ABERRANT VESSEL VASCULAR RING','DIVISION ABERRANT VESSEL VASCULAR RING','33802','1','','1','0','','','',0, 1, 0, 0),
(2979,'DIVISION ABERRANT VESSEL W/REANASTOMOSIS','DIVISION ABERRANT VESSEL W/REANASTOMOSIS','33803','1','','1','0','','','',0, 1, 0, 0),
(2980,'OBLTRJ AORTOPULMONARY SEPTAL DEFECT W/O BYPASS','OBLTRJ AORTOPULMONARY SEPTAL DEFECT W/O BYPASS','33813','1','','1','0','','','',0, 1, 0, 0),
(2981,'OBLTRJ AORTOPULMONARY SEPTAL DEFECT W/BYPASS','OBLTRJ AORTOPULMONARY SEPTAL DEFECT W/BYPASS','33814','1','','1','0','','','',0, 1, 0, 0),
(2982,'REPAIR PATENT DUCTUS ARTERIOSUS LIGATION','REPAIR PATENT DUCTUS ARTERIOSUS LIGATION','33820','1','','1','0','','','',0, 1, 0, 0),
(2983,'RPR PATENT DUXUS ARTERIOSUS DIV UNDER 18 YR','RPR PATENT DUXUS ARTERIOSUS DIV UNDER 18 YR','33822','1','','1','0','','','',0, 1, 0, 0),
(2984,'RPR PATENT DUXUS ARTERIOSUS DIV 18 YR & OLDER','RPR PATENT DUXUS ARTERIOSUS DIV 18 YR & OLDER','33824','1','','1','0','','','',0, 1, 0, 0),
(2985,'EXC COARCJ AORTA W/WO PDA W/DIRECT ANASTOMOSIS','EXC COARCJ AORTA W/WO PDA W/DIRECT ANASTOMOSIS','33840','1','','1','0','','','',0, 1, 0, 0),
(2986,'EXCISION COARCTATION AORTA W/WO PDA W/GRAFT','EXCISION COARCTATION AORTA W/WO PDA W/GRAFT','33845','1','','1','0','','','',0, 1, 0, 0),
(2987,'EXC COARCJ AORTA W/L SUBCLAV ART/PROSTC GUSSET','EXC COARCJ AORTA W/L SUBCLAV ART/PROSTC GUSSET','33851','1','','1','0','','','',0, 1, 0, 0),
(2988,'RPR HYPOPLSTC A-ARCH W/AGRFT/PROSTC W/O BYPASS','RPR HYPOPLSTC A-ARCH W/AGRFT/PROSTC W/O BYPASS','33852','1','','1','0','','','',0, 1, 0, 0),
(2989,'RPR HYPOPLSTC A-ARCH W/AGRFT/PROSTC W/BYPASS','RPR HYPOPLSTC A-ARCH W/AGRFT/PROSTC W/BYPASS','33853','1','','1','0','','','',0, 1, 0, 0),
(2990,'ASCENDING AORTA GRF W/CARD BYP & VALVE SSP','ASCENDING AORTA GRF W/CARD BYP & VALVE SSP','33860','1','','1','0','','','',0, 1, 0, 0),
(2991,'AS-AORT GRF W/CARD BYP & AORTIC ROOT RPLCMT','AS-AORT GRF W/CARD BYP & AORTIC ROOT RPLCMT','33863','1','','1','0','','','',0, 1, 0, 0),
(2992,'ASCENDING AORTA GRF VALVE SPARE ROOT REMODEL','ASCENDING AORTA GRF VALVE SPARE ROOT REMODEL','33864','1','','1','0','','','',0, 1, 0, 0),
(2993,'TRANSVERSE ARCH GRAFT W/CARDIOPULMONARY BYPASS','TRANSVERSE ARCH GRAFT W/CARDIOPULMONARY BYPASS','33870','1','','1','0','','','',0, 1, 0, 0),
(2994,'DESCENDING THORACIC AORTA GRAFT W/WO BYPASS','DESCENDING THORACIC AORTA GRAFT W/WO BYPASS','33875','1','','1','0','','','',0, 1, 0, 0),
(2995,'RPR THORACOABDOMINAL AORTIC ANEURYS W/WO BYPASS','RPR THORACOABDOMINAL AORTIC ANEURYS W/WO BYPASS','33877','1','','1','0','','','',0, 1, 0, 0),
(2996,'EVASC RPR DTA COVERAGE ART ORIGIN 1ST ENDOPROSTH','EVASC RPR DTA COVERAGE ART ORIGIN 1ST ENDOPROSTH','33880','1','','1','0','','','',0, 1, 0, 0),
(2997,'EVASC RPR DTA EXP COVERAGE W/O ART ORIGIN','EVASC RPR DTA EXP COVERAGE W/O ART ORIGIN','33881','1','','1','0','','','',0, 1, 0, 0),
(2998,'PLMT PROX XTN PROSTH EVASC RPR DTA 1ST XTN','PLMT PROX XTN PROSTH EVASC RPR DTA 1ST XTN','33883','1','','1','0','','','',0, 1, 0, 0),
(2999,'PLMT PROX XTN PROSTH EVASC RPR DTA EA PROX XTN','PLMT PROX XTN PROSTH EVASC RPR DTA EA PROX XTN','33884','1','','1','0','','','',0, 1, 0, 0),
(3000,'PLMT DSTL XTN PROSTH DLYD AFTER EVASC RPR DTA','PLMT DSTL XTN PROSTH DLYD AFTER EVASC RPR DTA','33886','1','','1','0','','','',0, 1, 0, 0),
(3001,'OPN SUBCLA CRTD ART TRPOS NCK INC ULAT','OPN SUBCLA CRTD ART TRPOS NCK INC ULAT','33889','1','','1','0','','','',0, 1, 0, 0),
(3002,'BYP GRF W/DESCENDING THORACIC AORTA RPR NECK INC','BYP GRF W/DESCENDING THORACIC AORTA RPR NECK INC','33891','1','','1','0','','','',0, 1, 0, 0),
(3003,'PULMONARY ARTERY EMBOLECTOMY W/CARD BYPASS','PULMONARY ARTERY EMBOLECTOMY W/CARD BYPASS','33910','1','','1','0','','','',0, 1, 0, 0),
(3004,'PULMONARY ARTERY EMBOLECTOMY W/O CARD BYPASS','PULMONARY ARTERY EMBOLECTOMY W/O CARD BYPASS','33915','1','','1','0','','','',0, 1, 0, 0),
(3005,'PULMONARY ENDARTERCOMY W/WO EMBOLECTOMY W/BYPASS','PULMONARY ENDARTERCOMY W/WO EMBOLECTOMY W/BYPASS','33916','1','','1','0','','','',0, 1, 0, 0),
(3006,'RPR PULMONARY ART STENOSIS RCNSTJ W/PATCH/GRAFT','RPR PULMONARY ART STENOSIS RCNSTJ W/PATCH/GRAFT','33917','1','','1','0','','','',0, 1, 0, 0),
(3007,'RPR PULMONARY ATRESIA W/CONSTJ/RPLCMT CONDUIT','RPR PULMONARY ATRESIA W/CONSTJ/RPLCMT CONDUIT','33920','1','','1','0','','','',0, 1, 0, 0),
(3008,'TRANSECTION PULMONARY ARTERY W/CARD BYPASS','TRANSECTION PULMONARY ARTERY W/CARD BYPASS','33922','1','','1','0','','','',0, 1, 0, 0),
(3009,'LIG&TKDN SYSIC-TO-PULM ART SHUNT W/CGEN HEART','LIG&TKDN SYSIC-TO-PULM ART SHUNT W/CGEN HEART','33924','1','','1','0','','','',0, 1, 0, 0),
(3010,'RPR P-ART ARBORIZJ ANOMAL UNIFCLIZJ W/O BYPASS','RPR P-ART ARBORIZJ ANOMAL UNIFCLIZJ W/O BYPASS','33925','1','','1','0','','','',0, 1, 0, 0),
(3011,'RPR P-ART ARBORIZJ ANOMAL UNIFCLIZJ W/BYPASS','RPR P-ART ARBORIZJ ANOMAL UNIFCLIZJ W/BYPASS','33926','1','','1','0','','','',0, 1, 0, 0),
(3012,'DONOR CARDIECTOMY-PNEUMONECTOMY','DONOR CARDIECTOMY-PNEUMONECTOMY','33930','1','','1','0','','','',0, 1, 0, 0),
(3013,'BKBENCH PREPJ CADAVER DONOR HEART/LUNG ALLOGRAFT','BKBENCH PREPJ CADAVER DONOR HEART/LUNG ALLOGRAFT','33933','1','','1','0','','','',0, 1, 0, 0),
(3014,'HEART-LUNG TRNSPL W/RECIPIENT CARDIECTOMY-PNUMEC','HEART-LUNG TRNSPL W/RECIPIENT CARDIECTOMY-PNUMEC','33935','1','','1','0','','','',0, 1, 0, 0),
(3015,'DONOR CARDIECTOMY','DONOR CARDIECTOMY','33940','1','','1','0','','','',0, 1, 0, 0),
(3016,'BKBENCH PREPJ CADAVER DONOR HEART ALLOGRAFT','BKBENCH PREPJ CADAVER DONOR HEART ALLOGRAFT','33944','1','','1','0','','','',0, 1, 0, 0),
(3017,'HEART TRANSPLANT W/WO RECIPIENT CARDIECTOMY','HEART TRANSPLANT W/WO RECIPIENT CARDIECTOMY','33945','1','','1','0','','','',0, 1, 0, 0),
(3018,'ECMO/ECLS INITIATION VENO-VENOUS','ECMO/ECLS INITIATION VENO-VENOUS','33946','1','','1','0','','','',0, 1, 0, 0),
(3019,'ECMO/ECLS INITIATION VENO-ARTERIAL','ECMO/ECLS INITIATION VENO-ARTERIAL','33947','1','','1','0','','','',0, 1, 0, 0),
(3020,'ECMO/ECLS DAILY MANAGEMENT EACH DAY VENO-VENOUS','ECMO/ECLS DAILY MANAGEMENT EACH DAY VENO-VENOUS','33948','1','','1','0','','','',0, 1, 0, 0),
(3021,'ECMO/ECLS DAILY MANAGEMENT EA DAY VENO-ARTERIAL','ECMO/ECLS DAILY MANAGEMENT EA DAY VENO-ARTERIAL','33949','1','','1','0','','','',0, 1, 0, 0),
(3022,'ECMO/ECLS INSJ OF PRPH CANNULA BIRTH-5 YRS PERQ','ECMO/ECLS INSJ OF PRPH CANNULA BIRTH-5 YRS PERQ','33951','1','','1','0','','','',0, 1, 0, 0),
(3023,'ECMO/ECLS INSJ OF PRPH CANNULA 6 YRS&OLDER PERQ','ECMO/ECLS INSJ OF PRPH CANNULA 6 YRS&OLDER PERQ','33952','1','','1','0','','','',0, 1, 0, 0),
(3024,'ECMO/ECLS INSJ OF PRPH CANNULA BIRTH-5 YRS OPEN','ECMO/ECLS INSJ OF PRPH CANNULA BIRTH-5 YRS OPEN','33953','1','','1','0','','','',0, 1, 0, 0),
(3025,'ECMO/ECLS INSJ OF PRPH CANNULA 6 YRS&OLDER OPEN','ECMO/ECLS INSJ OF PRPH CANNULA 6 YRS&OLDER OPEN','33954','1','','1','0','','','',0, 1, 0, 0),
(3026,'ECMO/ECLS INSJ OF CENTRAL CANNULA BIRTH-5 YRS','ECMO/ECLS INSJ OF CENTRAL CANNULA BIRTH-5 YRS','33955','1','','1','0','','','',0, 1, 0, 0),
(3027,'ECMO/ECLS INSJ OF CENTRAL CANNULA 6 YRS & OLDER','ECMO/ECLS INSJ OF CENTRAL CANNULA 6 YRS & OLDER','33956','1','','1','0','','','',0, 1, 0, 0),
(3028,'ECMO/ECLS REPOS PERIPH CANNULA PERQ BIRTH-5 YRS','ECMO/ECLS REPOS PERIPH CANNULA PERQ BIRTH-5 YRS','33957','1','','1','0','','','',0, 1, 0, 0),
(3029,'ECMO/ECLS REPOS PERPH CANNULA PRQ 6 YRS & OLDER','ECMO/ECLS REPOS PERPH CANNULA PRQ 6 YRS & OLDER','33958','1','','1','0','','','',0, 1, 0, 0),
(3030,'ECMO/ECLS REPOS PERPH CANNULA OPEN BIRTH-5 YRS','ECMO/ECLS REPOS PERPH CANNULA OPEN BIRTH-5 YRS','33959','1','','1','0','','','',0, 1, 0, 0),
(3031,'ECMO/ECLS REPOS PERPH CANNULA OPEN 6 YRS & OLDER','ECMO/ECLS REPOS PERPH CANNULA OPEN 6 YRS & OLDER','33962','1','','1','0','','','',0, 1, 0, 0),
(3032,'ECMO/ECLS REPOS CENTRAL PERPH CANNULA BIRTH-5YRS','ECMO/ECLS REPOS CENTRAL PERPH CANNULA BIRTH-5YRS','33963','1','','1','0','','','',0, 1, 0, 0),
(3033,'ECMO/ECLS ECLS REPOS CENTRAL CNULA 6YRS & OLDER','ECMO/ECLS ECLS REPOS CENTRAL CNULA 6YRS & OLDER','33964','1','','1','0','','','',0, 1, 0, 0),
(3034,'ECMO/ECLS RMVL OF PERPH CANNULA PERQ BIRTH-5 YRS','ECMO/ECLS RMVL OF PERPH CANNULA PERQ BIRTH-5 YRS','33965','1','','1','0','','','',0, 1, 0, 0),
(3035,'ECMO/ECLS RMVL OF PRPH CANNULA PRQ 6 YRS & OLDER','ECMO/ECLS RMVL OF PRPH CANNULA PRQ 6 YRS & OLDER','33966','1','','1','0','','','',0, 1, 0, 0),
(3036,'INSERTION INTRA-AORTIC BALLOON ASSIST DEV PERQ','INSERTION INTRA-AORTIC BALLOON ASSIST DEV PERQ','33967','1','','1','0','','','',0, 1, 0, 0),
(3037,'REMOVAL INTRA-AORTIC BALLOON ASSIST DEVICE PRQ','REMOVAL INTRA-AORTIC BALLOON ASSIST DEVICE PRQ','33968','1','','1','0','','','',0, 1, 0, 0),
(3038,'ECMO/ECLS RMVL OF PERPH CANNULA OPEN BIRTH-5 YRS','ECMO/ECLS RMVL OF PERPH CANNULA OPEN BIRTH-5 YRS','33969','1','','1','0','','','',0, 1, 0, 0),
(3039,'INSJ INTRA-AORT BALO ASSIST DEV VIA FEM ART OPEN','INSJ INTRA-AORT BALO ASSIST DEV VIA FEM ART OPEN','33970','1','','1','0','','','',0, 1, 0, 0),
(3040,'RMVL I-AORT BALO ASST DEV W/RPR FEM ART W/WO GRF','RMVL I-AORT BALO ASST DEV W/RPR FEM ART W/WO GRF','33971','1','','1','0','','','',0, 1, 0, 0),
(3041,'INSJ I-AORT BALO ASSIST DEV VIA ASCENDING AORTA','INSJ I-AORT BALO ASSIST DEV VIA ASCENDING AORTA','33973','1','','1','0','','','',0, 1, 0, 0),
(3042,'RMVL ASCENDING-AORTA BALO DEV W/RPR ASCEND-AORTA','RMVL ASCENDING-AORTA BALO DEV W/RPR ASCEND-AORTA','33974','1','','1','0','','','',0, 1, 0, 0),
(3043,'INSJ VENTRIC ASSIST DEV XTRCORP SINGLE VENTRICLE','INSJ VENTRIC ASSIST DEV XTRCORP SINGLE VENTRICLE','33975','1','','1','0','','','',0, 1, 0, 0),
(3044,'INSJ VENTRIC ASSIST DEV XTRCORP BIVENTRICULAR','INSJ VENTRIC ASSIST DEV XTRCORP BIVENTRICULAR','33976','1','','1','0','','','',0, 1, 0, 0),
(3045,'REMOVAL VENTR ASSIST DEVICE XTRCORP 1 VENTRICLE','REMOVAL VENTR ASSIST DEVICE XTRCORP 1 VENTRICLE','33977','1','','1','0','','','',0, 1, 0, 0),
(3046,'REMOVAL VENTR ASSIST DEVICE XTRCORP BIVENTR','REMOVAL VENTR ASSIST DEVICE XTRCORP BIVENTR','33978','1','','1','0','','','',0, 1, 0, 0),
(3047,'INSJ VENTR ASSIST DEV IMPLTABLE ICORP 1 VNTRC','INSJ VENTR ASSIST DEV IMPLTABLE ICORP 1 VNTRC','33979','1','','1','0','','','',0, 1, 0, 0),
(3048,'RMVL VENTR ASSIST DEV IMPLTABLE ICORP 1 VNTRC','RMVL VENTR ASSIST DEV IMPLTABLE ICORP 1 VNTRC','33980','1','','1','0','','','',0, 1, 0, 0),
(3049,'RPLCMT XTRCORP VAD 1/BIVENTR PUMP 1/EA PUMP','RPLCMT XTRCORP VAD 1/BIVENTR PUMP 1/EA PUMP','33981','1','','1','0','','','',0, 1, 0, 0),
(3050,'PLCMT VAD PMP IMPLTBL ICORP 1 VENTR W/O BYPASS','PLCMT VAD PMP IMPLTBL ICORP 1 VENTR W/O BYPASS','33982','1','','1','0','','','',0, 1, 0, 0),
(3051,'RPLCMT VAD PMP IMPLTBL ICORP 1 VNTR W/BYPASS','RPLCMT VAD PMP IMPLTBL ICORP 1 VNTR W/BYPASS','33983','1','','1','0','','','',0, 1, 0, 0),
(3052,'ECMO/ECLS RMVL PRPH CANNULA OPEN 6 YRS & OLDER','ECMO/ECLS RMVL PRPH CANNULA OPEN 6 YRS & OLDER','33984','1','','1','0','','','',0, 1, 0, 0),
(3053,'ECMO/ECLS REMOVAL OF CENTRAL CANNULA BIRTH-5 YRS','ECMO/ECLS REMOVAL OF CENTRAL CANNULA BIRTH-5 YRS','33985','1','','1','0','','','',0, 1, 0, 0),
(3054,'ECMO/ECLS RMVL OF CENTRAL CANNULA 6 YRS & OLDER','ECMO/ECLS RMVL OF CENTRAL CANNULA 6 YRS & OLDER','33986','1','','1','0','','','',0, 1, 0, 0),
(3055,'ARTERY EXPOS/GRAFT ARTERY PERFUSION ECMO/ECLS','ARTERY EXPOS/GRAFT ARTERY PERFUSION ECMO/ECLS','33987','1','','1','0','','','',0, 1, 0, 0),
(3056,'INSERT LEFT HEART VENT BY THORACIC INC ECMO/ECLS','INSERT LEFT HEART VENT BY THORACIC INC ECMO/ECLS','33988','1','','1','0','','','',0, 1, 0, 0),
(3057,'RMVL LEFT HEART VENT BY THORACIC INCIS ECMO/ECLS','RMVL LEFT HEART VENT BY THORACIC INCIS ECMO/ECLS','33989','1','','1','0','','','',0, 1, 0, 0),
(3058,'INSJ PERQ VAD W/IMAGING ARTERY ACCESS ONLY','INSJ PERQ VAD W/IMAGING ARTERY ACCESS ONLY','33990','1','','1','0','','','',0, 1, 0, 0),
(3059,'INSJ PERQ VAD TRNSPTAL W/IMAGE ART&VENOUS ACCESS','INSJ PERQ VAD TRNSPTAL W/IMAGE ART&VENOUS ACCESS','33991','1','','1','0','','','',0, 1, 0, 0),
(3060,'REMOVAL PERCUTANEOUS VAD DIFFERENT SESSION','REMOVAL PERCUTANEOUS VAD DIFFERENT SESSION','33992','1','','1','0','','','',0, 1, 0, 0),
(3061,'REPOSITION VAD W/IMAGING DIFFERENT SESSION','REPOSITION VAD W/IMAGING DIFFERENT SESSION','33993','1','','1','0','','','',0, 1, 0, 0),
(3062,'UNLISTED CARDIAC SURGERY','UNLISTED CARDIAC SURGERY','33999','1','','1','0','','','',0, 1, 0, 0),
(3063,'EMBLC/THRMBC CATH CRTD SUBCLA/INNOMINATE ART','EMBLC/THRMBC CATH CRTD SUBCLA/INNOMINATE ART','34001','1','','1','0','','','',0, 1, 0, 0),
(3064,'EMBLC/THRMBC INNOMINATE SUBCLAVIAN ARTERY','EMBLC/THRMBC INNOMINATE SUBCLAVIAN ARTERY','34051','1','','1','0','','','',0, 1, 0, 0),
(3065,'EMBLC/THRMBC AX BRACH INNOMINATE SUBCLA ART','EMBLC/THRMBC AX BRACH INNOMINATE SUBCLA ART','34101','1','','1','0','','','',0, 1, 0, 0),
(3066,'EMBLC/THRMBC W/WO CATH RADIAL/ULNAR ART ARM INC','EMBLC/THRMBC W/WO CATH RADIAL/ULNAR ART ARM INC','34111','1','','1','0','','','',0, 1, 0, 0),
(3067,'EMBLC/THRMBC RNL CELIAC MESENTRY AORTO-ILIAC ART','EMBLC/THRMBC RNL CELIAC MESENTRY AORTO-ILIAC ART','34151','1','','1','0','','','',0, 1, 0, 0),
(3068,'EMBLC/THRMBC FEMORAL POPLITEAL AORTO-ILIAC ART','EMBLC/THRMBC FEMORAL POPLITEAL AORTO-ILIAC ART','34201','1','','1','0','','','',0, 1, 0, 0),
(3069,'EMBLC/THRMBC POPLITEAL-TIBIO-PRONEAL ART LEG INC','EMBLC/THRMBC POPLITEAL-TIBIO-PRONEAL ART LEG INC','34203','1','','1','0','','','',0, 1, 0, 0),
(3070,'THRMBC DIR/W/CATH VENA CAVA ILIAC VEIN ABDL INC','THRMBC DIR/W/CATH VENA CAVA ILIAC VEIN ABDL INC','34401','1','','1','0','','','',0, 1, 0, 0),
(3071,'THRMBC DIR/W/CATH V/C ILIAC FEMPOP VEIN LEG INC','THRMBC DIR/W/CATH V/C ILIAC FEMPOP VEIN LEG INC','34421','1','','1','0','','','',0, 1, 0, 0),
(3072,'THRMBC DIR/W/CATH V/C ILIAC FEMPOP VEIN ABDL&LEG','THRMBC DIR/W/CATH V/C ILIAC FEMPOP VEIN ABDL&LEG','34451','1','','1','0','','','',0, 1, 0, 0),
(3073,'THRMBC DIR/W/CATH SUBCLAVIAN VEIN NECK INC','THRMBC DIR/W/CATH SUBCLAVIAN VEIN NECK INC','34471','1','','1','0','','','',0, 1, 0, 0),
(3074,'THRMBC DIR/W/CATH AXILL&SUBCLAVIAN VEIN ARM IN','THRMBC DIR/W/CATH AXILL&SUBCLAVIAN VEIN ARM IN','34490','1','','1','0','','','',0, 1, 0, 0),
(3075,'VALVULOPLASTY FEMORAL VEIN','VALVULOPLASTY FEMORAL VEIN','34501','1','','1','0','','','',0, 1, 0, 0),
(3076,'RECONSTRUCTION VENA CAVA ANY METHOD','RECONSTRUCTION VENA CAVA ANY METHOD','34502','1','','1','0','','','',0, 1, 0, 0),
(3077,'VENOUS VALVE TRANSPOSITION ANY VEIN DONOR','VENOUS VALVE TRANSPOSITION ANY VEIN DONOR','34510','1','','1','0','','','',0, 1, 0, 0),
(3078,'CROSS-OVER VEIN GRAFT VENOUS SYSTEM','CROSS-OVER VEIN GRAFT VENOUS SYSTEM','34520','1','','1','0','','','',0, 1, 0, 0),
(3079,'SAPHENOPOPLITEAL VEIN ANASTOMOSIS','SAPHENOPOPLITEAL VEIN ANASTOMOSIS','34530','1','','1','0','','','',0, 1, 0, 0),
(3080,'EVASC RPR AAA W/AORTO-AORTIC TUBE PROSTH','EVASC RPR AAA W/AORTO-AORTIC TUBE PROSTH','34800','1','','1','0','','','',0, 1, 0, 0),
(3081,'EVASC RPR AAA W/MDLR BFRC PROSTH 1 LIMB','EVASC RPR AAA W/MDLR BFRC PROSTH 1 LIMB','34802','1','','1','0','','','',0, 1, 0, 0),
(3082,'EVASC RPR AAA W/MDLR BFRC PROSTH 2 LIMBS','EVASC RPR AAA W/MDLR BFRC PROSTH 2 LIMBS','34803','1','','1','0','','','',0, 1, 0, 0),
(3083,'EVASC RPR AAA W/UNIBDY BFRC PROSTH','EVASC RPR AAA W/UNIBDY BFRC PROSTH','34804','1','','1','0','','','',0, 1, 0, 0),
(3084,'EVASC RPR AAA AORTO-UNIILIAC/AORTO-UNIFEM PROSTH','EVASC RPR AAA AORTO-UNIILIAC/AORTO-UNIFEM PROSTH','34805','1','','1','0','','','',0, 1, 0, 0),
(3085,'TCAT PLACEMENT PHYSIOLOGIC SENSOR ANEURYSMAL SAC','TCAT PLACEMENT PHYSIOLOGIC SENSOR ANEURYSMAL SAC','34806','1','','1','0','','','',0, 1, 0, 0),
(3086,'EVASC PLACEMENT ILIAC ARTERY OCCLUSION DEVICE','EVASC PLACEMENT ILIAC ARTERY OCCLUSION DEVICE','34808','1','','1','0','','','',0, 1, 0, 0),
(3087,'OPN FEM ART EXPOS DLVR EVASC PROSTH UNI','OPN FEM ART EXPOS DLVR EVASC PROSTH UNI','34812','1','','1','0','','','',0, 1, 0, 0),
(3088,'PLMT FEM-FEM PROSTC GRF EVASC AORTIC ARYSM RPR','PLMT FEM-FEM PROSTC GRF EVASC AORTIC ARYSM RPR','34813','1','','1','0','','','',0, 1, 0, 0),
(3089,'ILIAC ART EXPOS PROSTH/ILIAC OCCLS EVASC UNI','ILIAC ART EXPOS PROSTH/ILIAC OCCLS EVASC UNI','34820','1','','1','0','','','',0, 1, 0, 0),
(3090,'PLMT XTN PROSTH EVASC RPR ARYSM/DSJ 1ST VSL','PLMT XTN PROSTH EVASC RPR ARYSM/DSJ 1ST VSL','34825','1','','1','0','','','',0, 1, 0, 0),
(3091,'PLMT XTN PROSTH EVASC RPR ARYSM/DSJ EA VSL','PLMT XTN PROSTH EVASC RPR ARYSM/DSJ EA VSL','34826','1','','1','0','','','',0, 1, 0, 0),
(3092,'OPN RPR ARYSM RPR ARTL TRAUMA TUBE PROSTH','OPN RPR ARYSM RPR ARTL TRAUMA TUBE PROSTH','34830','1','','1','0','','','',0, 1, 0, 0),
(3093,'OPN RPR ARYSM RPR ARTL TRMA AORTOBIILIAC PROSTH','OPN RPR ARYSM RPR ARTL TRMA AORTOBIILIAC PROSTH','34831','1','','1','0','','','',0, 1, 0, 0),
(3094,'OPN RPR ARYSM RPR ARTL TRMA AORTO-BIFEM PROSTH','OPN RPR ARYSM RPR ARTL TRMA AORTO-BIFEM PROSTH','34832','1','','1','0','','','',0, 1, 0, 0),
(3095,'ILIAC ART EXPOS W/CRTJ CONDUIT UNI','ILIAC ART EXPOS W/CRTJ CONDUIT UNI','34833','1','','1','0','','','',0, 1, 0, 0),
(3096,'BRACH ART EXPOS DPLMNT AORTIC/ILIAC PROSTH UNI','BRACH ART EXPOS DPLMNT AORTIC/ILIAC PROSTH UNI','34834','1','','1','0','','','',0, 1, 0, 0),
(3097,'PLNNING PT SPEC FENEST VISCERAL AORTIC GRAFT','PLNNING PT SPEC FENEST VISCERAL AORTIC GRAFT','34839','1','','1','0','','','',0, 1, 0, 0),
(3098,'ENDOVASC VISCER AORTA REPAIR FENEST 1 ENDOGRAFT','ENDOVASC VISCER AORTA REPAIR FENEST 1 ENDOGRAFT','34841','1','','1','0','','','',0, 1, 0, 0),
(3099,'ENDOVASC VISCER AORTA REPAIR FENEST 2 ENDOGRAFT','ENDOVASC VISCER AORTA REPAIR FENEST 2 ENDOGRAFT','34842','1','','1','0','','','',0, 1, 0, 0),
(3100,'ENDOVASC VISCER AORTA REPAIR FENEST 3 ENDOGRAFT','ENDOVASC VISCER AORTA REPAIR FENEST 3 ENDOGRAFT','34843','1','','1','0','','','',0, 1, 0, 0),
(3101,'ENDOVASC VISCER AORTA REPR FENEST 4+ ENDOGRAFT','ENDOVASC VISCER AORTA REPR FENEST 4+ ENDOGRAFT','34844','1','','1','0','','','',0, 1, 0, 0),
(3102,'VISCER AND INFRARENAL ABDOM AORTA 1 PROSTHESIS','VISCER AND INFRARENAL ABDOM AORTA 1 PROSTHESIS','34845','1','','1','0','','','',0, 1, 0, 0),
(3103,'VISCER AND INFRARENAL ABDOM AORTA 2 PROSTHESIS','VISCER AND INFRARENAL ABDOM AORTA 2 PROSTHESIS','34846','1','','1','0','','','',0, 1, 0, 0),
(3104,'VISCER AND INFRARENAL ABDOM AORTA 3 PROSTHESIS','VISCER AND INFRARENAL ABDOM AORTA 3 PROSTHESIS','34847','1','','1','0','','','',0, 1, 0, 0),
(3105,'VISCER AND INFRARENAL ABDOM AORTA 4+ PROSTHESIS','VISCER AND INFRARENAL ABDOM AORTA 4+ PROSTHESIS','34848','1','','1','0','','','',0, 1, 0, 0),
(3106,'EVASC RPR ILIAC ART ILIO-ILIAC PROSTHESIS','EVASC RPR ILIAC ART ILIO-ILIAC PROSTHESIS','34900','1','','1','0','','','',0, 1, 0, 0),
(3107,'DIR RPR ANEURYSM CAROTID-SUBCLAVIAN ARTERY','DIR RPR ANEURYSM CAROTID-SUBCLAVIAN ARTERY','35001','1','','1','0','','','',0, 1, 0, 0),
(3108,'DIR RPR RUPTD ANEURYSM CAROTID-SUBCLAVIAN ARTERY','DIR RPR RUPTD ANEURYSM CAROTID-SUBCLAVIAN ARTERY','35002','1','','1','0','','','',0, 1, 0, 0),
(3109,'DIR RPR ANEURYSM VERTEBRAL ARTERY','DIR RPR ANEURYSM VERTEBRAL ARTERY','35005','1','','1','0','','','',0, 1, 0, 0),
(3110,'DIR RPR ANEURYSM AXIL-BRACHIAL ARM INCISION','DIR RPR ANEURYSM AXIL-BRACHIAL ARM INCISION','35011','1','','1','0','','','',0, 1, 0, 0),
(3111,'DIR RPR RUPTD ANEURYSM AXIL-BRACHIAL ARM INCIS','DIR RPR RUPTD ANEURYSM AXIL-BRACHIAL ARM INCIS','35013','1','','1','0','','','',0, 1, 0, 0),
(3112,'DIR RPR ANEURYSM INNOMINATE/SUBCLAVIAN ARTERY','DIR RPR ANEURYSM INNOMINATE/SUBCLAVIAN ARTERY','35021','1','','1','0','','','',0, 1, 0, 0),
(3113,'DIR RPR RUPTD ANEURYSM INNOMINATE/SUBCLAVIAN','DIR RPR RUPTD ANEURYSM INNOMINATE/SUBCLAVIAN','35022','1','','1','0','','','',0, 1, 0, 0),
(3114,'DIR RPR RUPTD ANEURYSM RADIAL/ULNAR ARTERY','DIR RPR RUPTD ANEURYSM RADIAL/ULNAR ARTERY','35045','1','','1','0','','','',0, 1, 0, 0),
(3115,'DIR RPR ANEURYSM ABDOMINAL AORTA','DIR RPR ANEURYSM ABDOMINAL AORTA','35081','1','','1','0','','','',0, 1, 0, 0),
(3116,'DIR RPR RUPTD ANEURYSM ABDOMINAL AORTA','DIR RPR RUPTD ANEURYSM ABDOMINAL AORTA','35082','1','','1','0','','','',0, 1, 0, 0),
(3117,'DIR RPR ANEURYSM ABDOM AORTA W/VISCERAL VESSELS','DIR RPR ANEURYSM ABDOM AORTA W/VISCERAL VESSELS','35091','1','','1','0','','','',0, 1, 0, 0),
(3118,'DIR RPR RUPTD ANEURSM ABDOM AORTA W/VISCERA VSLS','DIR RPR RUPTD ANEURSM ABDOM AORTA W/VISCERA VSLS','35092','1','','1','0','','','',0, 1, 0, 0),
(3119,'DIR RPR ANEURYSM ABDOM AORTA W/ILIAC VESSELS','DIR RPR ANEURYSM ABDOM AORTA W/ILIAC VESSELS','35102','1','','1','0','','','',0, 1, 0, 0),
(3120,'DIR RPR RUPTD ANEURYSM ABDOM AORTA W/ILIAC VSLS','DIR RPR RUPTD ANEURYSM ABDOM AORTA W/ILIAC VSLS','35103','1','','1','0','','','',0, 1, 0, 0),
(3121,'DIR RPR ANEURYSM SPLENIC ARTERY','DIR RPR ANEURYSM SPLENIC ARTERY','35111','1','','1','0','','','',0, 1, 0, 0),
(3122,'DIR RPR RUPTD ANEURYSM SPLENIC ARTERY','DIR RPR RUPTD ANEURYSM SPLENIC ARTERY','35112','1','','1','0','','','',0, 1, 0, 0),
(3123,'DIR RPR ANEURYSM HEPATIC/CELIAC/RENAL/MESENTERIC','DIR RPR ANEURYSM HEPATIC/CELIAC/RENAL/MESENTERIC','35121','1','','1','0','','','',0, 1, 0, 0),
(3124,'DIR RPR RUPTD ANEURSM HEPATIC/CELIAC/RENAL/MESEN','DIR RPR RUPTD ANEURSM HEPATIC/CELIAC/RENAL/MESEN','35122','1','','1','0','','','',0, 1, 0, 0),
(3125,'DIR RPR ANEURYSM & GRAFT ILIAC ARTERY','DIR RPR ANEURYSM & GRAFT ILIAC ARTERY','35131','1','','1','0','','','',0, 1, 0, 0),
(3126,'DIR RPR RUPTD ANEURYSM & GRAFT ILIAC ARTERY','DIR RPR RUPTD ANEURYSM & GRAFT ILIAC ARTERY','35132','1','','1','0','','','',0, 1, 0, 0),
(3127,'DIR RPR ANEURYSM & GRAFT COMMON FEMORAL ARTERY','DIR RPR ANEURYSM & GRAFT COMMON FEMORAL ARTERY','35141','1','','1','0','','','',0, 1, 0, 0),
(3128,'DIR RPR RUPTD ANEURYSM & GRF COMMON FEMORAL ART','DIR RPR RUPTD ANEURYSM & GRF COMMON FEMORAL ART','35142','1','','1','0','','','',0, 1, 0, 0),
(3129,'DIR RPR ANEURYSM & GRAFT POPLITEAL ARTERY','DIR RPR ANEURYSM & GRAFT POPLITEAL ARTERY','35151','1','','1','0','','','',0, 1, 0, 0),
(3130,'DIR RPR RUPTD ANEURYSM & GRF POPLITEAL ARTERY','DIR RPR RUPTD ANEURYSM & GRF POPLITEAL ARTERY','35152','1','','1','0','','','',0, 1, 0, 0),
(3131,'REPAIR CONGENITAL AV FISTULA HEAD & NECK','REPAIR CONGENITAL AV FISTULA HEAD & NECK','35180','1','','1','0','','','',0, 1, 0, 0),
(3132,'RPR CONGENITAL AV FISTULA THORAX & ABDOMEN','RPR CONGENITAL AV FISTULA THORAX & ABDOMEN','35182','1','','1','0','','','',0, 1, 0, 0),
(3133,'RPR CONGENITAL AV FISTULA EXTREMITIES','RPR CONGENITAL AV FISTULA EXTREMITIES','35184','1','','1','0','','','',0, 1, 0, 0),
(3134,'RPR/TRAUMATIC AV FISTULA HEAD & NECK','RPR/TRAUMATIC AV FISTULA HEAD & NECK','35188','1','','1','0','','','',0, 1, 0, 0),
(3135,'RPR/TRAUMATIC AV FISTULA THORAX & ABDOMEN','RPR/TRAUMATIC AV FISTULA THORAX & ABDOMEN','35189','1','','1','0','','','',0, 1, 0, 0),
(3136,'RPR/TRAUMATIC AV FISTULA EXTREMITIES','RPR/TRAUMATIC AV FISTULA EXTREMITIES','35190','1','','1','0','','','',0, 1, 0, 0),
(3137,'REPAIR BLOOD VESSEL DIRECT NECK','REPAIR BLOOD VESSEL DIRECT NECK','35201','1','','1','0','','','',0, 1, 0, 0),
(3138,'REPAIR BLOOD VESSEL DIRECT UPPER EXTREMITY','REPAIR BLOOD VESSEL DIRECT UPPER EXTREMITY','35206','1','','1','0','','','',0, 1, 0, 0),
(3139,'REPAIR BLOOD VESSEL DIRECT HAND FINGER','REPAIR BLOOD VESSEL DIRECT HAND FINGER','35207','1','','1','0','','','',0, 1, 0, 0),
(3140,'RPR BLOOD VESSEL DIRECT INTRATHORACIC W/BYPASS','RPR BLOOD VESSEL DIRECT INTRATHORACIC W/BYPASS','35211','1','','1','0','','','',0, 1, 0, 0),
(3141,'RPR BLOOD VESSEL DIRECT INTRATHORACIC W/O BYPASS','RPR BLOOD VESSEL DIRECT INTRATHORACIC W/O BYPASS','35216','1','','1','0','','','',0, 1, 0, 0),
(3142,'RPR BLOOD VESSEL DIRECT INTRA-ABDOMINAL','RPR BLOOD VESSEL DIRECT INTRA-ABDOMINAL','35221','1','','1','0','','','',0, 1, 0, 0),
(3143,'RPR BLOOD VESSEL DIRECT LOWER EXTREMITY','RPR BLOOD VESSEL DIRECT LOWER EXTREMITY','35226','1','','1','0','','','',0, 1, 0, 0),
(3144,'REPAIR BLOOD VESSEL W/VEIN GRAFT NECK','REPAIR BLOOD VESSEL W/VEIN GRAFT NECK','35231','1','','1','0','','','',0, 1, 0, 0),
(3145,'REPAIR BLOOD VESSEL W/VEIN GRAFT UPPER EXTREMITY','REPAIR BLOOD VESSEL W/VEIN GRAFT UPPER EXTREMITY','35236','1','','1','0','','','',0, 1, 0, 0),
(3146,'RPR BLOOD VESSEL VEIN GRAFT INTRATHORACIC W/BYP','RPR BLOOD VESSEL VEIN GRAFT INTRATHORACIC W/BYP','35241','1','','1','0','','','',0, 1, 0, 0),
(3147,'RPR BLOOD VESSEL VEIN GRF INTRATHORACIC W/O BYP','RPR BLOOD VESSEL VEIN GRF INTRATHORACIC W/O BYP','35246','1','','1','0','','','',0, 1, 0, 0),
(3148,'REPAIR BLOOD VESSEL VEIN GRAFT INTRA-ABDOMINAL','REPAIR BLOOD VESSEL VEIN GRAFT INTRA-ABDOMINAL','35251','1','','1','0','','','',0, 1, 0, 0),
(3149,'REPAIR BLOOD VESSEL VEIN GRAFT LOWER EXTREMITY','REPAIR BLOOD VESSEL VEIN GRAFT LOWER EXTREMITY','35256','1','','1','0','','','',0, 1, 0, 0),
(3150,'REPAIR BLOOD VESSEL W/GRAFT OTHER/THAN VEIN NECK','REPAIR BLOOD VESSEL W/GRAFT OTHER/THAN VEIN NECK','35261','1','','1','0','','','',0, 1, 0, 0),
(3151,'RPR BLOOD VSL GRF OTH/THN VEIN UPPER EXTREMITY','RPR BLOOD VSL GRF OTH/THN VEIN UPPER EXTREMITY','35266','1','','1','0','','','',0, 1, 0, 0),
(3152,'RPR BLOOD VSL GRF OTH/THN VEIN INTRATHRC W/BYP','RPR BLOOD VSL GRF OTH/THN VEIN INTRATHRC W/BYP','35271','1','','1','0','','','',0, 1, 0, 0),
(3153,'RPR BLOOD VSL GRF OTH/THN VEIN INTRATHRC W/O BYP','RPR BLOOD VSL GRF OTH/THN VEIN INTRATHRC W/O BYP','35276','1','','1','0','','','',0, 1, 0, 0),
(3154,'RPR BLVSL W/GRFT OTHER/THAN VEIN INTRA-ABDOMINAL','RPR BLVSL W/GRFT OTHER/THAN VEIN INTRA-ABDOMINAL','35281','1','','1','0','','','',0, 1, 0, 0),
(3155,'RPR BLVSL W/GRF OTHER/THAN VEIN LOWER EXTREMITY','RPR BLVSL W/GRF OTHER/THAN VEIN LOWER EXTREMITY','35286','1','','1','0','','','',0, 1, 0, 0),
(3156,'TEAEC W/PATCH GRF CAROTID VERTB SUBCLAV NECK INC','TEAEC W/PATCH GRF CAROTID VERTB SUBCLAV NECK INC','35301','1','','1','0','','','',0, 1, 0, 0),
(3157,'TEAEC W/GRAFT SUPERFICIAL FEMORAL ARTERY','TEAEC W/GRAFT SUPERFICIAL FEMORAL ARTERY','35302','1','','1','0','','','',0, 1, 0, 0),
(3158,'TEAEC W/GRAFT POPLITEAL ARTERY','TEAEC W/GRAFT POPLITEAL ARTERY','35303','1','','1','0','','','',0, 1, 0, 0),
(3159,'TEAEC W/GRAFT TIBIOPERONEAL TRUNK ARTERY','TEAEC W/GRAFT TIBIOPERONEAL TRUNK ARTERY','35304','1','','1','0','','','',0, 1, 0, 0),
(3160,'TEAEC W/GRAFT TIBIAL/PERONEAL ART 1ST VESSEL','TEAEC W/GRAFT TIBIAL/PERONEAL ART 1ST VESSEL','35305','1','','1','0','','','',0, 1, 0, 0),
(3161,'TEAEC W/GRAFT EA ADDL TIBIAL/PERONEAL ART','TEAEC W/GRAFT EA ADDL TIBIAL/PERONEAL ART','35306','1','','1','0','','','',0, 1, 0, 0),
(3162,'TEAEC W/WO PATCH GRF SUBCLAV INNOM THORACIC INC','TEAEC W/WO PATCH GRF SUBCLAV INNOM THORACIC INC','35311','1','','1','0','','','',0, 1, 0, 0),
(3163,'TEAEC W/WO PATCH GRF AXILLARY-BRACHIAL','TEAEC W/WO PATCH GRF AXILLARY-BRACHIAL','35321','1','','1','0','','','',0, 1, 0, 0),
(3164,'TEAEC W/WO PATCH GRAFT ABDOMINAL AORTA','TEAEC W/WO PATCH GRAFT ABDOMINAL AORTA','35331','1','','1','0','','','',0, 1, 0, 0),
(3165,'TEAEC W/WO PATCH GRAFT MESENTERIC CELIAC/RENAL','TEAEC W/WO PATCH GRAFT MESENTERIC CELIAC/RENAL','35341','1','','1','0','','','',0, 1, 0, 0),
(3166,'TEAEC W/WO PATCH GRAFT ILIAC','TEAEC W/WO PATCH GRAFT ILIAC','35351','1','','1','0','','','',0, 1, 0, 0),
(3167,'TEAEC W/WO PATCH GRAFT ILIOFEMORAL','TEAEC W/WO PATCH GRAFT ILIOFEMORAL','35355','1','','1','0','','','',0, 1, 0, 0),
(3168,'TEAEC W/WO PATCH GRAFT COMBINED AORTOILIAC','TEAEC W/WO PATCH GRAFT COMBINED AORTOILIAC','35361','1','','1','0','','','',0, 1, 0, 0),
(3169,'TEAEC W/WO PATCH GRAFT COMBINED AORTOILIOFEMORAL','TEAEC W/WO PATCH GRAFT COMBINED AORTOILIOFEMORAL','35363','1','','1','0','','','',0, 1, 0, 0),
(3170,'TEAEC W/WO PATCH GRAFT COMMON FEMORAL','TEAEC W/WO PATCH GRAFT COMMON FEMORAL','35371','1','','1','0','','','',0, 1, 0, 0),
(3171,'TEAEC W/WO PATCH GRAFT DEEP PROFUNDA FEMORAL','TEAEC W/WO PATCH GRAFT DEEP PROFUNDA FEMORAL','35372','1','','1','0','','','',0, 1, 0, 0),
(3172,'ROPRTJ CRTD TEAEC > 1 MO AFTER ORIGINAL OPRATIO','ROPRTJ CRTD TEAEC > 1 MO AFTER ORIGINAL OPRATIO','35390','1','','1','0','','','',0, 1, 0, 0),
(3173,'ANGIOSCOPY NON-CORONARY VESSEL/GRAFTS THER IVNTJ','ANGIOSCOPY NON-CORONARY VESSEL/GRAFTS THER IVNTJ','35400','1','','1','0','','','',0, 1, 0, 0),
(3174,'TRLUML BALOON ANGIOPL OPN RENAL/OTH VISCERAL ART','TRLUML BALOON ANGIOPL OPN RENAL/OTH VISCERAL ART','35450','1','','1','0','','','',0, 1, 0, 0),
(3175,'TRLUML BALLOON ANGIOPLASTY OPEN AORTIC','TRLUML BALLOON ANGIOPLASTY OPEN AORTIC','35452','1','','1','0','','','',0, 1, 0, 0),
(3176,'TRLUML BALO ANGIOP OPN BRCH/CPHLC TRNK/BRNCH EA','TRLUML BALO ANGIOP OPN BRCH/CPHLC TRNK/BRNCH EA','35458','1','','1','0','','','',0, 1, 0, 0),
(3177,'TRLUML BALLOON ANGIOPLASTY OPEN VENOUS','TRLUML BALLOON ANGIOPLASTY OPEN VENOUS','35460','1','','1','0','','','',0, 1, 0, 0),
(3178,'TRLUML BALLOON ANGIOP PRQ RENAL/VISCERAL ART','TRLUML BALLOON ANGIOP PRQ RENAL/VISCERAL ART','35471','1','','1','0','','','',0, 1, 0, 0),
(3179,'TRLUML BALLOON ANGIOPLASTY PERCUTANEOUS AORTIC','TRLUML BALLOON ANGIOPLASTY PERCUTANEOUS AORTIC','35472','1','','1','0','','','',0, 1, 0, 0),
(3180,'TRLUML BALO ANGIOP PRQ BRCH/CPHLC TRNK/BRNCH EA','TRLUML BALO ANGIOP PRQ BRCH/CPHLC TRNK/BRNCH EA','35475','1','','1','0','','','',0, 1, 0, 0),
(3181,'TRLUML BALLOON ANGIOPLASTY PERCUTANEOUS VENOUS','TRLUML BALLOON ANGIOPLASTY PERCUTANEOUS VENOUS','35476','1','','1','0','','','',0, 1, 0, 0),
(3182,'HARVEST UXTR VEIN 1 SGM LOWER EXTREMITY/CABG PX','HARVEST UXTR VEIN 1 SGM LOWER EXTREMITY/CABG PX','35500','1','','1','0','','','',0, 1, 0, 0),
(3183,'BYPASS W/VEIN COMMON-IPSILATERAL CAROTID','BYPASS W/VEIN COMMON-IPSILATERAL CAROTID','35501','1','','1','0','','','',0, 1, 0, 0),
(3184,'BYPASS W/VEIN CAROTID-SUBCLV/SUBCLAVIAN CAROTID','BYPASS W/VEIN CAROTID-SUBCLV/SUBCLAVIAN CAROTID','35506','1','','1','0','','','',0, 1, 0, 0),
(3185,'BYPASS W/VEIN CAROTID-VERTEBRAL','BYPASS W/VEIN CAROTID-VERTEBRAL','35508','1','','1','0','','','',0, 1, 0, 0),
(3186,'BYPASS W/VEIN CAROTID-CONTRALATERAL CAROTID','BYPASS W/VEIN CAROTID-CONTRALATERAL CAROTID','35509','1','','1','0','','','',0, 1, 0, 0),
(3187,'BYPASS W/VEIN CAROTID-BRACHIAL','BYPASS W/VEIN CAROTID-BRACHIAL','35510','1','','1','0','','','',0, 1, 0, 0),
(3188,'BYPASS W/VEIN SUBCLAVIAN-SUBCLAVIAN','BYPASS W/VEIN SUBCLAVIAN-SUBCLAVIAN','35511','1','','1','0','','','',0, 1, 0, 0),
(3189,'BYPASS W/VEIN SUBCLAVIAN-BRACHIAL','BYPASS W/VEIN SUBCLAVIAN-BRACHIAL','35512','1','','1','0','','','',0, 1, 0, 0),
(3190,'BYPASS W/VEIN SUBCLAVIAN-VERTEBRAL','BYPASS W/VEIN SUBCLAVIAN-VERTEBRAL','35515','1','','1','0','','','',0, 1, 0, 0),
(3191,'BYPASS W/VEIN SUBCLAVIAN-AXILLARY','BYPASS W/VEIN SUBCLAVIAN-AXILLARY','35516','1','','1','0','','','',0, 1, 0, 0),
(3192,'BYPASS W/VEIN AXILLARY-AXILLARY','BYPASS W/VEIN AXILLARY-AXILLARY','35518','1','','1','0','','','',0, 1, 0, 0),
(3193,'BYPASS W/VEIN AXILLARY-FEMORAL','BYPASS W/VEIN AXILLARY-FEMORAL','35521','1','','1','0','','','',0, 1, 0, 0),
(3194,'BYPASS W/VEIN AXILLARY-BRACHIAL','BYPASS W/VEIN AXILLARY-BRACHIAL','35522','1','','1','0','','','',0, 1, 0, 0),
(3195,'BYPASS W/VEIN BRACHIAL-ULNAR/-RADIAL','BYPASS W/VEIN BRACHIAL-ULNAR/-RADIAL','35523','1','','1','0','','','',0, 1, 0, 0),
(3196,'BYPASS W/VEIN BRACHIAL-BRACHIAL','BYPASS W/VEIN BRACHIAL-BRACHIAL','35525','1','','1','0','','','',0, 1, 0, 0),
(3197,'BYPASS W/VEIN AORTOSUBCLAV/CAROTID/INNOMINATE','BYPASS W/VEIN AORTOSUBCLAV/CAROTID/INNOMINATE','35526','1','','1','0','','','',0, 1, 0, 0),
(3198,'BYPASS W/VEIN AORTOCELIAC/AORTOMESENTERIC','BYPASS W/VEIN AORTOCELIAC/AORTOMESENTERIC','35531','1','','1','0','','','',0, 1, 0, 0),
(3199,'BYPASS W/VEIN AXILLARY-FEMORAL-FEMORAL','BYPASS W/VEIN AXILLARY-FEMORAL-FEMORAL','35533','1','','1','0','','','',0, 1, 0, 0),
(3200,'BYPASS W/VEIN HEPATORENAL','BYPASS W/VEIN HEPATORENAL','35535','1','','1','0','','','',0, 1, 0, 0),
(3201,'BYPASS W/VEIN SPLENORENAL','BYPASS W/VEIN SPLENORENAL','35536','1','','1','0','','','',0, 1, 0, 0),
(3202,'BYPASS W/VEIN AORTOILIAC','BYPASS W/VEIN AORTOILIAC','35537','1','','1','0','','','',0, 1, 0, 0),
(3203,'BYPASS W/VEIN AORTOBI-ILIAC','BYPASS W/VEIN AORTOBI-ILIAC','35538','1','','1','0','','','',0, 1, 0, 0),
(3204,'BYPASS W/VEIN AORTOFEMORAL','BYPASS W/VEIN AORTOFEMORAL','35539','1','','1','0','','','',0, 1, 0, 0),
(3205,'BYPASS W/VEIN AORTOBIFEMORAL','BYPASS W/VEIN AORTOBIFEMORAL','35540','1','','1','0','','','',0, 1, 0, 0),
(3206,'BYPASS W/VEIN FEMORAL-POPLITEAL','BYPASS W/VEIN FEMORAL-POPLITEAL','35556','1','','1','0','','','',0, 1, 0, 0),
(3207,'BYPASS W/VEIN FEMORAL-FEMORAL','BYPASS W/VEIN FEMORAL-FEMORAL','35558','1','','1','0','','','',0, 1, 0, 0),
(3208,'BYPASS W/VEIN AORTORENAL','BYPASS W/VEIN AORTORENAL','35560','1','','1','0','','','',0, 1, 0, 0),
(3209,'BYPASS W/VEIN ILIOILIAC','BYPASS W/VEIN ILIOILIAC','35563','1','','1','0','','','',0, 1, 0, 0),
(3210,'BYPASS W/VEIN ILIOFEMORAL','BYPASS W/VEIN ILIOFEMORAL','35565','1','','1','0','','','',0, 1, 0, 0),
(3211,'BYP FEM-ANT TIBL PST TIBL PRONEAL ART/OTH DSTL','BYP FEM-ANT TIBL PST TIBL PRONEAL ART/OTH DSTL','35566','1','','1','0','','','',0, 1, 0, 0),
(3212,'BYP TIBL-TIBL/PRONEAL-TIBL/TIBL/PRONEAL TRK-TIBL','BYP TIBL-TIBL/PRONEAL-TIBL/TIBL/PRONEAL TRK-TIBL','35570','1','','1','0','','','',0, 1, 0, 0),
(3213,'BYP W/VEIN POP-TIBL-PRONEAL ART/OTH DSTL VSL','BYP W/VEIN POP-TIBL-PRONEAL ART/OTH DSTL VSL','35571','1','','1','0','','','',0, 1, 0, 0),
(3214,'HARVEST FEMPOP VEIN 1 SGM VASC RCNSTJ PX','HARVEST FEMPOP VEIN 1 SGM VASC RCNSTJ PX','35572','1','','1','0','','','',0, 1, 0, 0),
(3215,'IN-SITU VEIN BYPASS FEMORAL-POPLITEAL','IN-SITU VEIN BYPASS FEMORAL-POPLITEAL','35583','1','','1','0','','','',0, 1, 0, 0),
(3216,'IN-SITU FEM-ANT TIBL PST TIBL/PRONEAL ART','IN-SITU FEM-ANT TIBL PST TIBL/PRONEAL ART','35585','1','','1','0','','','',0, 1, 0, 0),
(3217,'IN-SITU VEIN BYP POP-TIBL PRONEAL','IN-SITU VEIN BYP POP-TIBL PRONEAL','35587','1','','1','0','','','',0, 1, 0, 0),
(3218,'HARVEST UPPER EXTREMITY ARTERY 1 SEGMENT CABG','HARVEST UPPER EXTREMITY ARTERY 1 SEGMENT CABG','35600','1','','1','0','','','',0, 1, 0, 0),
(3219,'BYP OTH/THN VEIN COMMON-IPSILATERAL CAROTID','BYP OTH/THN VEIN COMMON-IPSILATERAL CAROTID','35601','1','','1','0','','','',0, 1, 0, 0),
(3220,'BYP OTH/THN VEIN CAROTID-SUBCLAVIAN','BYP OTH/THN VEIN CAROTID-SUBCLAVIAN','35606','1','','1','0','','','',0, 1, 0, 0),
(3221,'BYP OTH/THN VEIN SUBCLAVIAN-SUBCLAVIAN','BYP OTH/THN VEIN SUBCLAVIAN-SUBCLAVIAN','35612','1','','1','0','','','',0, 1, 0, 0),
(3222,'BYP OTH/THN VEIN SUBCLAVIAN-AXILLARY','BYP OTH/THN VEIN SUBCLAVIAN-AXILLARY','35616','1','','1','0','','','',0, 1, 0, 0),
(3223,'BYP OTH/THN VEIN AXILLARY-FEMORAL','BYP OTH/THN VEIN AXILLARY-FEMORAL','35621','1','','1','0','','','',0, 1, 0, 0),
(3224,'BYP OTH/THN VEIN AXILLARY-POPLITEAL/-TIBIAL','BYP OTH/THN VEIN AXILLARY-POPLITEAL/-TIBIAL','35623','1','','1','0','','','',0, 1, 0, 0),
(3225,'BYPASS NOT VEIN AORTOSUBCLA/CAROTID/INNOMINATE','BYPASS NOT VEIN AORTOSUBCLA/CAROTID/INNOMINATE','35626','1','','1','0','','','',0, 1, 0, 0),
(3226,'BYP OTH/THN VEIN AORTOCELIAC AORTOMSN AORTORNL','BYP OTH/THN VEIN AORTOCELIAC AORTOMSN AORTORNL','35631','1','','1','0','','','',0, 1, 0, 0),
(3227,'BYPASS GRAFT W/OTHER THAN VEIN ILIO-CELIAC','BYPASS GRAFT W/OTHER THAN VEIN ILIO-CELIAC','35632','1','','1','0','','','',0, 1, 0, 0),
(3228,'BYPASS GRAFT W/OTHER THAN VEIN ILIO-MESENTERIC','BYPASS GRAFT W/OTHER THAN VEIN ILIO-MESENTERIC','35633','1','','1','0','','','',0, 1, 0, 0),
(3229,'BYPASS GRAFT W/OTHER THAN VEIN ILIORENAL','BYPASS GRAFT W/OTHER THAN VEIN ILIORENAL','35634','1','','1','0','','','',0, 1, 0, 0),
(3230,'BYP OTH/THN VEIN SPLENORENAL','BYP OTH/THN VEIN SPLENORENAL','35636','1','','1','0','','','',0, 1, 0, 0),
(3231,'BYP OTH/THN VEIN AORTOILIAC','BYP OTH/THN VEIN AORTOILIAC','35637','1','','1','0','','','',0, 1, 0, 0),
(3232,'BYP OTH/THN VEIN AORTOBI-ILIAC','BYP OTH/THN VEIN AORTOBI-ILIAC','35638','1','','1','0','','','',0, 1, 0, 0),
(3233,'BYP OTH/THN VEIN CAROTID-VERTEBRAL','BYP OTH/THN VEIN CAROTID-VERTEBRAL','35642','1','','1','0','','','',0, 1, 0, 0),
(3234,'BYP OTH/THN VEIN SUBCLAVIAN-VERTEBRAL','BYP OTH/THN VEIN SUBCLAVIAN-VERTEBRAL','35645','1','','1','0','','','',0, 1, 0, 0),
(3235,'BYP OTH/THN VEIN AORTOBIFEMORAL','BYP OTH/THN VEIN AORTOBIFEMORAL','35646','1','','1','0','','','',0, 1, 0, 0),
(3236,'BYP OTH/THN VEIN AORTOFEMORAL','BYP OTH/THN VEIN AORTOFEMORAL','35647','1','','1','0','','','',0, 1, 0, 0),
(3237,'BYP OTH/THN VEIN AXILLARY-AXILLARY','BYP OTH/THN VEIN AXILLARY-AXILLARY','35650','1','','1','0','','','',0, 1, 0, 0),
(3238,'BYP OTH/THN VEIN AXILLARY-FEMORAL-FEMORAL','BYP OTH/THN VEIN AXILLARY-FEMORAL-FEMORAL','35654','1','','1','0','','','',0, 1, 0, 0),
(3239,'BYP OTH/THN VEIN FEMORAL-POPLITEAL','BYP OTH/THN VEIN FEMORAL-POPLITEAL','35656','1','','1','0','','','',0, 1, 0, 0),
(3240,'BYP OTH/THN VEIN FEMORAL-FEMORAL','BYP OTH/THN VEIN FEMORAL-FEMORAL','35661','1','','1','0','','','',0, 1, 0, 0),
(3241,'BYP OTH/THN VEIN ILIOILIAC','BYP OTH/THN VEIN ILIOILIAC','35663','1','','1','0','','','',0, 1, 0, 0),
(3242,'BYP OTH/THN VEIN ILIOFEMORAL','BYP OTH/THN VEIN ILIOFEMORAL','35665','1','','1','0','','','',0, 1, 0, 0),
(3243,'BYP OTH/THN VEIN FEM-ANT TIBL PST TIBL/PRONEAL','BYP OTH/THN VEIN FEM-ANT TIBL PST TIBL/PRONEAL','35666','1','','1','0','','','',0, 1, 0, 0),
(3244,'BYP OTH/THN VEIN POPLITEAL-TIBIAL/-PERONEAL ART','BYP OTH/THN VEIN POPLITEAL-TIBIAL/-PERONEAL ART','35671','1','','1','0','','','',0, 1, 0, 0),
(3245,'BYPASS COMPOSITE GRAFT PROSTHETIC & VEIN','BYPASS COMPOSITE GRAFT PROSTHETIC & VEIN','35681','1','','1','0','','','',0, 1, 0, 0),
(3246,'BYP AUTOG COMPOSIT 2 SEG VEINS FROM 2 LOCATIONS','BYP AUTOG COMPOSIT 2 SEG VEINS FROM 2 LOCATIONS','35682','1','','1','0','','','',0, 1, 0, 0),
(3247,'BYP AUTOG COMPOSIT 3/> SEG FROM 2/> LOCATION','BYP AUTOG COMPOSIT 3/> SEG FROM 2/> LOCATION','35683','1','','1','0','','','',0, 1, 0, 0),
(3248,'PLMT VEIN PATCH/CUFF DSTL ANAST BYP CONDUIT','PLMT VEIN PATCH/CUFF DSTL ANAST BYP CONDUIT','35685','1','','1','0','','','',0, 1, 0, 0),
(3249,'CRTJ DSTL ARVEN FSTL LXTR BYP SURG NON-HEMO','CRTJ DSTL ARVEN FSTL LXTR BYP SURG NON-HEMO','35686','1','','1','0','','','',0, 1, 0, 0),
(3250,'TRPOS&/RIMPLTJ VERTEBRAL CAROTID ART','TRPOS&/RIMPLTJ VERTEBRAL CAROTID ART','35691','1','','1','0','','','',0, 1, 0, 0),
(3251,'TRPOS&/RIMPLTJ VERTEBRAL SUBCLAVIAN ART','TRPOS&/RIMPLTJ VERTEBRAL SUBCLAVIAN ART','35693','1','','1','0','','','',0, 1, 0, 0),
(3252,'TRPOS&/RIMPLTJ SUBCLAVIAN CAROTID ART','TRPOS&/RIMPLTJ SUBCLAVIAN CAROTID ART','35694','1','','1','0','','','',0, 1, 0, 0),
(3253,'TRPOS&/RIMPLTJ CAROTID SUBCLAVIAN ART','TRPOS&/RIMPLTJ CAROTID SUBCLAVIAN ART','35695','1','','1','0','','','',0, 1, 0, 0),
(3254,'RIMPLTJ VISC ART INFRARNL AORTIC PROSTH EA ART','RIMPLTJ VISC ART INFRARNL AORTIC PROSTH EA ART','35697','1','','1','0','','','',0, 1, 0, 0),
(3255,'ROPRTJ > 1 MO AFTER ORIGINAL OPRATION','ROPRTJ > 1 MO AFTER ORIGINAL OPRATION','35700','1','','1','0','','','',0, 1, 0, 0),
(3256,'EXPL N/FLWD SURG RPR W/WO LYSIS CAROTID ARTERY','EXPL N/FLWD SURG RPR W/WO LYSIS CAROTID ARTERY','35701','1','','1','0','','','',0, 1, 0, 0),
(3257,'EXPL N/FLWD SURG RPR W/WO LYSIS FEMORAL ARTERY','EXPL N/FLWD SURG RPR W/WO LYSIS FEMORAL ARTERY','35721','1','','1','0','','','',0, 1, 0, 0),
(3258,'EXPL N/FLWD SURG RPR W/WO LYSIS POPLITEAL ARTERY','EXPL N/FLWD SURG RPR W/WO LYSIS POPLITEAL ARTERY','35741','1','','1','0','','','',0, 1, 0, 0),
(3259,'EXPL N/FLWD SURG RPR W/WO LYSIS OTHER ARTERY','EXPL N/FLWD SURG RPR W/WO LYSIS OTHER ARTERY','35761','1','','1','0','','','',0, 1, 0, 0),
(3260,'EXPL PO HEMRRG THROMBOSIS/INFCTJ NCK','EXPL PO HEMRRG THROMBOSIS/INFCTJ NCK','35800','1','','1','0','','','',0, 1, 0, 0),
(3261,'EXPL PO HEMRRG THROMBOSIS/INFCTJ CH','EXPL PO HEMRRG THROMBOSIS/INFCTJ CH','35820','1','','1','0','','','',0, 1, 0, 0),
(3262,'EXPL PO HEMRRG THROMBOSIS/INFCTJ ABD','EXPL PO HEMRRG THROMBOSIS/INFCTJ ABD','35840','1','','1','0','','','',0, 1, 0, 0),
(3263,'EXPL PO HEMRRG THROMBOSIS/INFCTJ XTR','EXPL PO HEMRRG THROMBOSIS/INFCTJ XTR','35860','1','','1','0','','','',0, 1, 0, 0),
(3264,'RPR GRF-ENTERIC FSTL','RPR GRF-ENTERIC FSTL','35870','1','','1','0','','','',0, 1, 0, 0),
(3265,'THRMBC ARTL/VEN GRF OTH/THN HEMO GRF/FSTL','THRMBC ARTL/VEN GRF OTH/THN HEMO GRF/FSTL','35875','1','','1','0','','','',0, 1, 0, 0),
(3266,'THRMBC ARTL/VEN GRF XCP HEMO GRF/FSTL W/REVJ GRF','THRMBC ARTL/VEN GRF XCP HEMO GRF/FSTL W/REVJ GRF','35876','1','','1','0','','','',0, 1, 0, 0),
(3267,'REVJ LXTR ARTL BYP OPN VEIN PATCH ANGIOP','REVJ LXTR ARTL BYP OPN VEIN PATCH ANGIOP','35879','1','','1','0','','','',0, 1, 0, 0),
(3268,'REVJ LXTR ARTL BYP OPN W/SGMTL VEIN INTERPOS','REVJ LXTR ARTL BYP OPN W/SGMTL VEIN INTERPOS','35881','1','','1','0','','','',0, 1, 0, 0),
(3269,'REVISION FEMORAL ANAST OPEN NONAUTOG GRAFT','REVISION FEMORAL ANAST OPEN NONAUTOG GRAFT','35883','1','','1','0','','','',0, 1, 0, 0),
(3270,'REVISION FEMORAL ANAST OPEN W/AUTOG GRAFT','REVISION FEMORAL ANAST OPEN W/AUTOG GRAFT','35884','1','','1','0','','','',0, 1, 0, 0),
(3271,'EXCISION INFECTED NECK GRAFT','EXCISION INFECTED NECK GRAFT','35901','1','','1','0','','','',0, 1, 0, 0),
(3272,'EXCISION INFECTED GRAFT EXTREMITY','EXCISION INFECTED GRAFT EXTREMITY','35903','1','','1','0','','','',0, 1, 0, 0),
(3273,'EXCISION INFECTED GRAFT THORAX','EXCISION INFECTED GRAFT THORAX','35905','1','','1','0','','','',0, 1, 0, 0),
(3274,'EXCISION INFECTED GRAFT ABDOMEN','EXCISION INFECTED GRAFT ABDOMEN','35907','1','','1','0','','','',0, 1, 0, 0),
(3275,'INTRODUCTION NEEDLE/INTRACATHETER VEIN','INTRODUCTION NEEDLE/INTRACATHETER VEIN','36000','1','','1','0','','','',0, 1, 0, 0),
(3276,'INJECTION PX PRQ TX EXTREMITY PSEUDOANEURYSM','INJECTION PX PRQ TX EXTREMITY PSEUDOANEURYSM','36002','1','','1','0','','','',0, 1, 0, 0),
(3277,'NJX PX XTR VNGRPH W/INTRO NDL/INTRACATH','NJX PX XTR VNGRPH W/INTRO NDL/INTRACATH','36005','1','','1','0','','','',0, 1, 0, 0),
(3278,'INTRO CATHETER SUPERIOR/INFERIOR VENA CAVA','INTRO CATHETER SUPERIOR/INFERIOR VENA CAVA','36010','1','','1','0','','','',0, 1, 0, 0),
(3279,'SLCTV CATH PLMT VEN SYS 1ST ORDER BRANCH','SLCTV CATH PLMT VEN SYS 1ST ORDER BRANCH','36011','1','','1','0','','','',0, 1, 0, 0),
(3280,'SLCTV CATH PLMT VEN SYS 2ND ORDER/> SLCTV BRANC','SLCTV CATH PLMT VEN SYS 2ND ORDER/> SLCTV BRANC','36012','1','','1','0','','','',0, 1, 0, 0),
(3281,'INTRO CATHETER RIGHT HEART/MAIN PULMONARY ARTERY','INTRO CATHETER RIGHT HEART/MAIN PULMONARY ARTERY','36013','1','','1','0','','','',0, 1, 0, 0),
(3282,'SLCTV CATHETER PLMT LEFT/RIGHT PULMONARY ARTERY','SLCTV CATHETER PLMT LEFT/RIGHT PULMONARY ARTERY','36014','1','','1','0','','','',0, 1, 0, 0),
(3283,'SLCTV CATH PLMT SEGMENTAL/SUBSEGMENTAL PULM ART','SLCTV CATH PLMT SEGMENTAL/SUBSEGMENTAL PULM ART','36015','1','','1','0','','','',0, 1, 0, 0),
(3284,'INTRO NEEDLE/INTRACATH CAROTID/VERTEBRAL ARTERY','INTRO NEEDLE/INTRACATH CAROTID/VERTEBRAL ARTERY','36100','1','','1','0','','','',0, 1, 0, 0),
(3285,'INTRO NEEDLE/INTRACATH RETROGRADE BRACHIAL ART','INTRO NEEDLE/INTRACATH RETROGRADE BRACHIAL ART','36120','1','','1','0','','','',0, 1, 0, 0),
(3286,'INTRO NEEDLE/INTRACATH EXTREMITY ARTERY','INTRO NEEDLE/INTRACATH EXTREMITY ARTERY','36140','1','','1','0','','','',0, 1, 0, 0),
(3287,'INTRO NDL/CATH AV SHUNT IST ACCESS W/ RAD EVAL','INTRO NDL/CATH AV SHUNT IST ACCESS W/ RAD EVAL','36147','1','','1','0','','','',0, 1, 0, 0),
(3288,'INTRO NDL/CATH AV SHUNT ADDL ACCESS THER IVNTJ','INTRO NDL/CATH AV SHUNT ADDL ACCESS THER IVNTJ','36148','1','','1','0','','','',0, 1, 0, 0),
(3289,'INTRO NEEDLE/INTRACATH AORTIC TRANSLUMBAR','INTRO NEEDLE/INTRACATH AORTIC TRANSLUMBAR','36160','1','','1','0','','','',0, 1, 0, 0),
(3290,'INTRODUCTION CATHETER AORTA','INTRODUCTION CATHETER AORTA','36200','1','','1','0','','','',0, 1, 0, 0),
(3291,'SLCTV CATHJ EA 1ST ORD THRC/BRCH/CPHLC BRNCH','SLCTV CATHJ EA 1ST ORD THRC/BRCH/CPHLC BRNCH','36215','1','','1','0','','','',0, 1, 0, 0),
(3292,'SLCTV CATHJ 1ST 2ND ORD THRC/BRCH/CPHLC BRNCH','SLCTV CATHJ 1ST 2ND ORD THRC/BRCH/CPHLC BRNCH','36216','1','','1','0','','','',0, 1, 0, 0),
(3293,'SLCTV CATHJ 3RD+ ORD SLCTV THRC/BRCH/CPHLC BRNCH','SLCTV CATHJ 3RD+ ORD SLCTV THRC/BRCH/CPHLC BRNCH','36217','1','','1','0','','','',0, 1, 0, 0),
(3294,'SLCTV CATHJ EA 2ND+ ORD THRC/BRCH/CPHLC BRNCH','SLCTV CATHJ EA 2ND+ ORD THRC/BRCH/CPHLC BRNCH','36218','1','','1','0','','','',0, 1, 0, 0),
(3295,'NONSLCTV CATH THOR AORTA ANGIO INTR/XTRCRANL ART','NONSLCTV CATH THOR AORTA ANGIO INTR/XTRCRANL ART','36221','1','','1','0','','','',0, 1, 0, 0),
(3296,'SLCTV CATH CAROTID/INNOM ART ANGIO XTRCRANL ART','SLCTV CATH CAROTID/INNOM ART ANGIO XTRCRANL ART','36222','1','','1','0','','','',0, 1, 0, 0),
(3297,'SLCTV CATH CAROTID/INNOM ART ANGIO INTRCRANL ART','SLCTV CATH CAROTID/INNOM ART ANGIO INTRCRANL ART','36223','1','','1','0','','','',0, 1, 0, 0),
(3298,'SLCTV CATH INTRNL CAROTID ART ANGIO INTRCRNL ART','SLCTV CATH INTRNL CAROTID ART ANGIO INTRCRNL ART','36224','1','','1','0','','','',0, 1, 0, 0),
(3299,'SLCTV CATH SUBCLAVIAN ART ANGIO VERTEBRAL ARTERY','SLCTV CATH SUBCLAVIAN ART ANGIO VERTEBRAL ARTERY','36225','1','','1','0','','','',0, 1, 0, 0),
(3300,'SLCTV CATH VERTEBRAL ART ANGIO VERTEBRAL ARTERY','SLCTV CATH VERTEBRAL ART ANGIO VERTEBRAL ARTERY','36226','1','','1','0','','','',0, 1, 0, 0),
(3301,'SLCTV CATH XTRNL CAROTID ANGIO XTRNL CAROTD CIRC','SLCTV CATH XTRNL CAROTID ANGIO XTRNL CAROTD CIRC','36227','1','','1','0','','','',0, 1, 0, 0),
(3302,'SLCTV CATH INTRCRNL BRNCH ANGIO INTRL CAROT/VERT','SLCTV CATH INTRCRNL BRNCH ANGIO INTRL CAROT/VERT','36228','1','','1','0','','','',0, 1, 0, 0),
(3303,'SLCTV CATHJ EA 1ST ORD ABDL PEL/LXTR ART BRNCH','SLCTV CATHJ EA 1ST ORD ABDL PEL/LXTR ART BRNCH','36245','1','','1','0','','','',0, 1, 0, 0),
(3304,'SLCTV CATHJ 2ND ORDER ABDL PEL/LXTR ART BRNCH','SLCTV CATHJ 2ND ORDER ABDL PEL/LXTR ART BRNCH','36246','1','','1','0','','','',0, 1, 0, 0),
(3305,'SLCTV CATHJ 3RD+ ORD SLCTV ABDL PEL/LXTR BRNCH','SLCTV CATHJ 3RD+ ORD SLCTV ABDL PEL/LXTR BRNCH','36247','1','','1','0','','','',0, 1, 0, 0),
(3306,'SLCTV CATHJ EA 2ND+ ORD ABDL PEL/LXTR ART BRNCH','SLCTV CATHJ EA 2ND+ ORD ABDL PEL/LXTR ART BRNCH','36248','1','','1','0','','','',0, 1, 0, 0),
(3307,'SLCTV CATH 1STORD W/WO ART PUNCT/FLUORO/S&I UN','SLCTV CATH 1STORD W/WO ART PUNCT/FLUORO/S&I UN','36251','1','','1','0','','','',0, 1, 0, 0),
(3308,'SLCTV CATH 1STORD W/WO ART PUNCT/FLUOR/S&I BIL','SLCTV CATH 1STORD W/WO ART PUNCT/FLUOR/S&I BIL','36252','1','','1','0','','','',0, 1, 0, 0),
(3309,'SUPSLCTV CATH 2ND+ORD RENAL&ACCESSORY ARTERY/S&I','SUPSLCTV CATH 2ND+ORD RENAL&ACCESSORY ARTERY/S&I','36253','1','','1','0','','','',0, 1, 0, 0),
(3310,'SUPSLCTV CATH 2ND+ORD RENAL&ACCESSORY ARTERY/S&I','SUPSLCTV CATH 2ND+ORD RENAL&ACCESSORY ARTERY/S&I','36254','1','','1','0','','','',0, 1, 0, 0),
(3311,'INSJ IMPLANTABLE INTRA-ARTERIAL INFUSION PUM','INSJ IMPLANTABLE INTRA-ARTERIAL INFUSION PUM','36260','1','','1','0','','','',0, 1, 0, 0),
(3312,'REVJ IMPLANTED INTRA-ARTERIAL INFUSION PUMP','REVJ IMPLANTED INTRA-ARTERIAL INFUSION PUMP','36261','1','','1','0','','','',0, 1, 0, 0),
(3313,'REMOVAL IMPLANTED INTRA-ARTERIAL INFUSION PUMP','REMOVAL IMPLANTED INTRA-ARTERIAL INFUSION PUMP','36262','1','','1','0','','','',0, 1, 0, 0),
(3314,'UNLISTED PROCEDURE VASCULAR INJECTION','UNLISTED PROCEDURE VASCULAR INJECTION','36299','1','','1','0','','','',0, 1, 0, 0),
(3315,'VNPNXR <3 YEARS PHY/QHP SKILL FEMRAL/JUGLAR VEIN','VNPNXR <3 YEARS PHY/QHP SKILL FEMRAL/JUGLAR VEIN','36400','1','','1','0','','','',0, 1, 0, 0),
(3316,'VNPNXR <3 YEARS PHYS/QHP SKILL SCALP VEIN','VNPNXR <3 YEARS PHYS/QHP SKILL SCALP VEIN','36405','1','','1','0','','','',0, 1, 0, 0),
(3317,'VNPNXR <3 YEARS PHYS/QHP SKILL OTHER VEIN','VNPNXR <3 YEARS PHYS/QHP SKILL OTHER VEIN','36406','1','','1','0','','','',0, 1, 0, 0),
(3318,'VNPNXR 3 YEARS/> PHYS/QHP SKILL','VNPNXR 3 YEARS/> PHYS/QHP SKILL','36410','1','','1','0','','','',0, 1, 0, 0),
(3319,'COLLECTION VENOUS BLOOD VENIPUNCTURE','COLLECTION VENOUS BLOOD VENIPUNCTURE','36415','1','','1','0','','','',0, 1, 0, 0),
(3320,'COLLECTION CAPILLARY BLOOD SPECIMEN','COLLECTION CAPILLARY BLOOD SPECIMEN','36416','1','','1','0','','','',0, 1, 0, 0),
(3321,'VENIPUNCTURE CUTDOWN UNDER AGE 1 YR','VENIPUNCTURE CUTDOWN UNDER AGE 1 YR','36420','1','','1','0','','','',0, 1, 0, 0),
(3322,'VENIPUNCTURE CUTDOWN AGE 1 YR/>','VENIPUNCTURE CUTDOWN AGE 1 YR/>','36425','1','','1','0','','','',0, 1, 0, 0),
(3323,'TRANSFUSION BLOOD/BLOOD COMPONENTS','TRANSFUSION BLOOD/BLOOD COMPONENTS','36430','1','','1','0','','','',0, 1, 0, 0),
(3324,'PUSH TRANSFUSION BLOOD 2 YR/UNDER','PUSH TRANSFUSION BLOOD 2 YR/UNDER','36440','1','','1','0','','','',0, 1, 0, 0),
(3325,'EXCHNG TRANSFUSION BLOOD NEWBORN','EXCHNG TRANSFUSION BLOOD NEWBORN','36450','1','','1','0','','','',0, 1, 0, 0),
(3326,'EXCHNG TRANSFUSION BLOOD OTHER/THAN NEW BORN','EXCHNG TRANSFUSION BLOOD OTHER/THAN NEW BORN','36455','1','','1','0','','','',0, 1, 0, 0),
(3327,'TRANSFUSION INTRAUTERINE FETAL','TRANSFUSION INTRAUTERINE FETAL','36460','1','','1','0','','','',0, 1, 0, 0),
(3328,'1/MLT NJXS SCLRSG SLNS SPIDER VEINS LIMB/TRUNK','1/MLT NJXS SCLRSG SLNS SPIDER VEINS LIMB/TRUNK','36468','1','','1','0','','','',0, 1, 0, 0),
(3329,'NJX SCLEROSING SOLUTION SINGLE VEIN','NJX SCLEROSING SOLUTION SINGLE VEIN','36470','1','','1','0','','','',0, 1, 0, 0),
(3330,'NJX SCLEROSING SOLUTION MULTIPLE VEINS SAME LEG','NJX SCLEROSING SOLUTION MULTIPLE VEINS SAME LEG','36471','1','','1','0','','','',0, 1, 0, 0),
(3331,'ENDOVEN ABLTJ INCMPTNT VEIN XTR RF 1ST VEIN','ENDOVEN ABLTJ INCMPTNT VEIN XTR RF 1ST VEIN','36475','1','','1','0','','','',0, 1, 0, 0),
(3332,'ENDOVEN ABLTJ INCMPTNT VEIN XTR RF 2ND+ VEINS','ENDOVEN ABLTJ INCMPTNT VEIN XTR RF 2ND+ VEINS','36476','1','','1','0','','','',0, 1, 0, 0),
(3333,'ENDOVEN ABLTJ INCMPTNT VEIN XTR LASER 1ST VEIN','ENDOVEN ABLTJ INCMPTNT VEIN XTR LASER 1ST VEIN','36478','1','','1','0','','','',0, 1, 0, 0),
(3334,'ENDOVEN ABLTJ INCMPTNT VEIN XTR LASER 2ND+ VEINS','ENDOVEN ABLTJ INCMPTNT VEIN XTR LASER 2ND+ VEINS','36479','1','','1','0','','','',0, 1, 0, 0),
(3335,'PRQ PORTAL VEIN CATHETERIZATION ANY METHOD','PRQ PORTAL VEIN CATHETERIZATION ANY METHOD','36481','1','','1','0','','','',0, 1, 0, 0),
(3336,'VEN CATHJ SLCTV ORGAN BLD SAMPLING','VEN CATHJ SLCTV ORGAN BLD SAMPLING','36500','1','','1','0','','','',0, 1, 0, 0),
(3337,'CATHJ UMBILICAL VEIN DX/THER NB','CATHJ UMBILICAL VEIN DX/THER NB','36510','1','','1','0','','','',0, 1, 0, 0),
(3338,'THERAPEUTIC APHERESIS WHITE BLOOD CELLS','THERAPEUTIC APHERESIS WHITE BLOOD CELLS','36511','1','','1','0','','','',0, 1, 0, 0),
(3339,'THERAPEUTIC APHERESIS RED BLOOD CELLS','THERAPEUTIC APHERESIS RED BLOOD CELLS','36512','1','','1','0','','','',0, 1, 0, 0),
(3340,'THERAPEUTIC APHERESIS PLATELETS','THERAPEUTIC APHERESIS PLATELETS','36513','1','','1','0','','','',0, 1, 0, 0),
(3341,'THERAPEUTIC APHERESIS PLASMA PHERESIS','THERAPEUTIC APHERESIS PLASMA PHERESIS','36514','1','','1','0','','','',0, 1, 0, 0),
(3342,'THER APHERESIS W/XTRCORP IMMUNODSPTJ& PLSM RENFJ','THER APHERESIS W/XTRCORP IMMUNODSPTJ& PLSM RENFJ','36515','1','','1','0','','','',0, 1, 0, 0),
(3343,'THER APHRS XTRCORP SLCTV ADSRPJ/FILTRJ & REINFSJ','THER APHRS XTRCORP SLCTV ADSRPJ/FILTRJ & REINFSJ','36516','1','','1','0','','','',0, 1, 0, 0),
(3344,'PHOTOPHERESIS EXTRACORPOREAL','PHOTOPHERESIS EXTRACORPOREAL','36522','1','','1','0','','','',0, 1, 0, 0),
(3345,'INSJ NON-TUNNELED CENTRAL VENOUS CATH AGE < 5 Y','INSJ NON-TUNNELED CENTRAL VENOUS CATH AGE < 5 Y','36555','1','','1','0','','','',0, 1, 0, 0),
(3346,'INSJ NON-TUNNELED CENTRAL VENOUS CATH AGE 5 YR/>','INSJ NON-TUNNELED CENTRAL VENOUS CATH AGE 5 YR/>','36556','1','','1','0','','','',0, 1, 0, 0),
(3347,'INSERT TUNNELED CVC W/O SUBQ PORT/PMP AGE <5 YR','INSERT TUNNELED CVC W/O SUBQ PORT/PMP AGE <5 YR','36557','1','','1','0','','','',0, 1, 0, 0),
(3348,'INSJ TUNNELED CVC W/O SUBQ PORT/PMP AGE 5 YR/>','INSJ TUNNELED CVC W/O SUBQ PORT/PMP AGE 5 YR/>','36558','1','','1','0','','','',0, 1, 0, 0),
(3349,'INSJ TUNNELED CTR VAD W/SUBQ PORT UNDER 5 YR','INSJ TUNNELED CTR VAD W/SUBQ PORT UNDER 5 YR','36560','1','','1','0','','','',0, 1, 0, 0),
(3350,'INSJ TUNNELED CTR VAD W/SUBQ PORT AGE 5 YR/>','INSJ TUNNELED CTR VAD W/SUBQ PORT AGE 5 YR/>','36561','1','','1','0','','','',0, 1, 0, 0),
(3351,'INSJ TUNNELED CTR VAD W/SUBQ PUMP','INSJ TUNNELED CTR VAD W/SUBQ PUMP','36563','1','','1','0','','','',0, 1, 0, 0),
(3352,'INSJ TUN VAD REQ 2 CATH 2 SITS W/O SUBQ PORT/PMP','INSJ TUN VAD REQ 2 CATH 2 SITS W/O SUBQ PORT/PMP','36565','1','','1','0','','','',0, 1, 0, 0),
(3353,'INSJ TUN VAD REQ 2 CATH 2 SITS W/SUBQ PORT','INSJ TUN VAD REQ 2 CATH 2 SITS W/SUBQ PORT','36566','1','','1','0','','','',0, 1, 0, 0),
(3354,'INSJ PRPH CVC W/O SUBQ PORT/PMP UNDER 5 YR','INSJ PRPH CVC W/O SUBQ PORT/PMP UNDER 5 YR','36568','1','','1','0','','','',0, 1, 0, 0),
(3355,'INSJ PRPH CVC W/O SUBQ PORT/PMP AGE 5 YR/>','INSJ PRPH CVC W/O SUBQ PORT/PMP AGE 5 YR/>','36569','1','','1','0','','','',0, 1, 0, 0),
(3356,'INSJ PRPH CTR VAD W/SUBQ PORT UNDER 5 YR','INSJ PRPH CTR VAD W/SUBQ PORT UNDER 5 YR','36570','1','','1','0','','','',0, 1, 0, 0),
(3357,'INSJ PRPH CTR VAD W/SUBQ PORT AGE 5 YR/>','INSJ PRPH CTR VAD W/SUBQ PORT AGE 5 YR/>','36571','1','','1','0','','','',0, 1, 0, 0),
(3358,'RPR TUN/NON-TUN CTR VAD CATH W/O SUBQ PORT/PMP','RPR TUN/NON-TUN CTR VAD CATH W/O SUBQ PORT/PMP','36575','1','','1','0','','','',0, 1, 0, 0),
(3359,'RPR CTR VAD W/SUBQ PORT/PMP CTR/PRPH INSJ SIT','RPR CTR VAD W/SUBQ PORT/PMP CTR/PRPH INSJ SIT','36576','1','','1','0','','','',0, 1, 0, 0),
(3360,'RPLCMT CATH CTR VAD SUBQ PORT/PMP','RPLCMT CATH CTR VAD SUBQ PORT/PMP','36578','1','','1','0','','','',0, 1, 0, 0),
(3361,'RPLCMT COMPL NON-TUN CVC W/O SUBQ PORT/PMP','RPLCMT COMPL NON-TUN CVC W/O SUBQ PORT/PMP','36580','1','','1','0','','','',0, 1, 0, 0),
(3362,'RPLCMT COMPL TUN CVC W/O SUBQ PORT/PMP','RPLCMT COMPL TUN CVC W/O SUBQ PORT/PMP','36581','1','','1','0','','','',0, 1, 0, 0),
(3363,'RPLCMT COMPL TUN CTR VAD W/SUBQ PORT','RPLCMT COMPL TUN CTR VAD W/SUBQ PORT','36582','1','','1','0','','','',0, 1, 0, 0),
(3364,'RPLCMT COMPL TUN CTR VAD W/SUBQ PMP','RPLCMT COMPL TUN CTR VAD W/SUBQ PMP','36583','1','','1','0','','','',0, 1, 0, 0),
(3365,'RPLCMT COMPL PRPH CVC W/O SUBQ PORT/PMP','RPLCMT COMPL PRPH CVC W/O SUBQ PORT/PMP','36584','1','','1','0','','','',0, 1, 0, 0),
(3366,'RPLCMT COMPL PRPH CTR VAD W/SUBQ PORT','RPLCMT COMPL PRPH CTR VAD W/SUBQ PORT','36585','1','','1','0','','','',0, 1, 0, 0),
(3367,'RMVL TUN CVC W/O SUBQ PORT/PMP','RMVL TUN CVC W/O SUBQ PORT/PMP','36589','1','','1','0','','','',0, 1, 0, 0),
(3368,'RMVL TUN CTR VAD W/SUBQ PORT/PMP CTR/PRPH INSJ','RMVL TUN CTR VAD W/SUBQ PORT/PMP CTR/PRPH INSJ','36590','1','','1','0','','','',0, 1, 0, 0),
(3369,'COLLECT BLOOD FROM IMPLANT VENOUS ACCESS DEVICE','COLLECT BLOOD FROM IMPLANT VENOUS ACCESS DEVICE','36591','1','','1','0','','','',0, 1, 0, 0),
(3370,'COLLECT BLOOD FROM CATHETER VENOUS NOS','COLLECT BLOOD FROM CATHETER VENOUS NOS','36592','1','','1','0','','','',0, 1, 0, 0),
(3371,'DECLOT BY THROMBOLYTIC AGENT IMPLANT DEVICE/CATH','DECLOT BY THROMBOLYTIC AGENT IMPLANT DEVICE/CATH','36593','1','','1','0','','','',0, 1, 0, 0),
(3372,'MCHNL RMVL PRICATH OBSTR CV DEV VIA VEN ACCESS','MCHNL RMVL PRICATH OBSTR CV DEV VIA VEN ACCESS','36595','1','','1','0','','','',0, 1, 0, 0),
(3373,'MCHNL RMVL INTRAL OBSTR CV DEV THRU DEV LUMEN','MCHNL RMVL INTRAL OBSTR CV DEV THRU DEV LUMEN','36596','1','','1','0','','','',0, 1, 0, 0),
(3374,'RPSG PREVIOUSLY PLACED CVC UNDER FLUOR GDNCE','RPSG PREVIOUSLY PLACED CVC UNDER FLUOR GDNCE','36597','1','','1','0','','','',0, 1, 0, 0),
(3375,'CNTRST NJX RAD EVAL CTR VAD FLUOR IMG&REPRT','CNTRST NJX RAD EVAL CTR VAD FLUOR IMG&REPRT','36598','1','','1','0','','','',0, 1, 0, 0),
(3376,'ARTERIAL PUNCTURE WITHDRAWAL BLOOD DX','ARTERIAL PUNCTURE WITHDRAWAL BLOOD DX','36600','1','','1','0','','','',0, 1, 0, 0),
(3377,'ARTL CATHJ/CANNULJ MNTR/TRANSFUSION SPX PRQ','ARTL CATHJ/CANNULJ MNTR/TRANSFUSION SPX PRQ','36620','1','','1','0','','','',0, 1, 0, 0),
(3378,'ARTL CATHJ/CANNULJ MNTR/TRANSFUSION SPX CUTDOWN','ARTL CATHJ/CANNULJ MNTR/TRANSFUSION SPX CUTDOWN','36625','1','','1','0','','','',0, 1, 0, 0),
(3379,'ARTL CATHJ PROLNG NFS THER CHEMOTX CUTDOWN','ARTL CATHJ PROLNG NFS THER CHEMOTX CUTDOWN','36640','1','','1','0','','','',0, 1, 0, 0),
(3380,'CATHETERIZATION UMBILICAL NEWBORN ART DX/THERAPY','CATHETERIZATION UMBILICAL NEWBORN ART DX/THERAPY','36660','1','','1','0','','','',0, 1, 0, 0),
(3381,'PLACEMENT NEEDLE INTRAOSSEOUS INFUSION','PLACEMENT NEEDLE INTRAOSSEOUS INFUSION','36680','1','','1','0','','','',0, 1, 0, 0),
(3382,'INSJ CANNULA HEMO OTH PURPOSE SPX VEIN VEIN','INSJ CANNULA HEMO OTH PURPOSE SPX VEIN VEIN','36800','1','','1','0','','','',0, 1, 0, 0),
(3383,'INSJ CANNULA HEMO OTH PURPOSE SPX ARVEN XTRNL','INSJ CANNULA HEMO OTH PURPOSE SPX ARVEN XTRNL','36810','1','','1','0','','','',0, 1, 0, 0),
(3384,'INSJ CANNULA HEMO OTH SPX ARVEN XTRNL REVJ/CLSR','INSJ CANNULA HEMO OTH SPX ARVEN XTRNL REVJ/CLSR','36815','1','','1','0','','','',0, 1, 0, 0),
(3385,'ARVEN ANAST OPN UPR ARM CEPHALIC VEIN TRPOS','ARVEN ANAST OPN UPR ARM CEPHALIC VEIN TRPOS','36818','1','','1','0','','','',0, 1, 0, 0),
(3386,'ARVEN ANAST OPN UPR ARM BASILIC VEIN TRPOS','ARVEN ANAST OPN UPR ARM BASILIC VEIN TRPOS','36819','1','','1','0','','','',0, 1, 0, 0),
(3387,'ARVEN ANAST OPN F/ARM VEIN TRPOS','ARVEN ANAST OPN F/ARM VEIN TRPOS','36820','1','','1','0','','','',0, 1, 0, 0),
(3388,'ARTERIOVENOUS ANASTOMOSIS OPEN DIRECT','ARTERIOVENOUS ANASTOMOSIS OPEN DIRECT','36821','1','','1','0','','','',0, 1, 0, 0),
(3389,'INSJ CNULA ISLTD XC-CIRCJ REG CHEMOTX XTR RMVL','INSJ CNULA ISLTD XC-CIRCJ REG CHEMOTX XTR RMVL','36823','1','','1','0','','','',0, 1, 0, 0),
(3390,'CRTJ ARVEN FSTL XCP DIR ARVEN ANAST AUTOG GRF','CRTJ ARVEN FSTL XCP DIR ARVEN ANAST AUTOG GRF','36825','1','','1','0','','','',0, 1, 0, 0),
(3391,'CRTJ ARVEN FSTL XCP DIR ARVEN ANAST NONAUTOG GRF','CRTJ ARVEN FSTL XCP DIR ARVEN ANAST NONAUTOG GRF','36830','1','','1','0','','','',0, 1, 0, 0),
(3392,'THRMBC OPN ARVEN FSTL W/O REVJ DIAL GRF','THRMBC OPN ARVEN FSTL W/O REVJ DIAL GRF','36831','1','','1','0','','','',0, 1, 0, 0),
(3393,'REVJ OPN ARVEN FSTL W/O THRMBC DIAL GRF','REVJ OPN ARVEN FSTL W/O THRMBC DIAL GRF','36832','1','','1','0','','','',0, 1, 0, 0),
(3394,'REVJ OPN ARVEN FSTL W/THRMBC DIAL GRF','REVJ OPN ARVEN FSTL W/THRMBC DIAL GRF','36833','1','','1','0','','','',0, 1, 0, 0),
(3395,'INSERTION THOMAS SHUNT SEPARATE PROCEDURE','INSERTION THOMAS SHUNT SEPARATE PROCEDURE','36835','1','','1','0','','','',0, 1, 0, 0),
(3396,'DSTL REVSC&INTERVAL LIG UXTR HEMO ACCESS','DSTL REVSC&INTERVAL LIG UXTR HEMO ACCESS','36838','1','','1','0','','','',0, 1, 0, 0),
(3397,'XTRNL CANNULA DECLTNG SPX W/O BALO CATH','XTRNL CANNULA DECLTNG SPX W/O BALO CATH','36860','1','','1','0','','','',0, 1, 0, 0),
(3398,'XTRNL CANNULA DECLTNG SPX W/BALO CATH','XTRNL CANNULA DECLTNG SPX W/BALO CATH','36861','1','','1','0','','','',0, 1, 0, 0),
(3399,'THRMBC PRQ ARVEN FSTL AUTOG/NONAUTOG GRF','THRMBC PRQ ARVEN FSTL AUTOG/NONAUTOG GRF','36870','1','','1','0','','','',0, 1, 0, 0),
(3400,'VENOUS ANASTOMOSIS OPEN PORTOCAVAL','VENOUS ANASTOMOSIS OPEN PORTOCAVAL','37140','1','','1','0','','','',0, 1, 0, 0),
(3401,'VENOUS ANASTOMOSIS OPEN RENOPORTAL','VENOUS ANASTOMOSIS OPEN RENOPORTAL','37145','1','','1','0','','','',0, 1, 0, 0),
(3402,'VENOUS ANASTOMOSIS OPEN CAVAL-MESENTERIC','VENOUS ANASTOMOSIS OPEN CAVAL-MESENTERIC','37160','1','','1','0','','','',0, 1, 0, 0),
(3403,'VENOUS ANASTOMOSIS OPEN SPLENORENAL PROXIMAL','VENOUS ANASTOMOSIS OPEN SPLENORENAL PROXIMAL','37180','1','','1','0','','','',0, 1, 0, 0),
(3404,'VENOUS ANASTOMOSIS OPEN SPLENORENAL DISTAL','VENOUS ANASTOMOSIS OPEN SPLENORENAL DISTAL','37181','1','','1','0','','','',0, 1, 0, 0),
(3405,'INSJ TRANSVNS INTRAHEPATC PORTOSYSIC SHUNT','INSJ TRANSVNS INTRAHEPATC PORTOSYSIC SHUNT','37182','1','','1','0','','','',0, 1, 0, 0),
(3406,'REVJ TRANSVNS INTRAHEPATIC PORTOSYSTEMIC SHUNT','REVJ TRANSVNS INTRAHEPATIC PORTOSYSTEMIC SHUNT','37183','1','','1','0','','','',0, 1, 0, 0),
(3407,'PRIM PRQ TRLUML MCHNL THRMBC N-COR N-ICRA 1ST','PRIM PRQ TRLUML MCHNL THRMBC N-COR N-ICRA 1ST','37184','1','','1','0','','','',0, 1, 0, 0),
(3408,'PRIM PRQ TRLUML MCHNL THRMBC N-COR N-ICRA SBSQ','PRIM PRQ TRLUML MCHNL THRMBC N-COR N-ICRA SBSQ','37185','1','','1','0','','','',0, 1, 0, 0),
(3409,'SEC PRQ TRLUML THRMBC N-CORONARY N-INTRACRANIAL','SEC PRQ TRLUML THRMBC N-CORONARY N-INTRACRANIAL','37186','1','','1','0','','','',0, 1, 0, 0),
(3410,'PRQ TRANSLUMINAL MECHANICAL THROMBECTOMY VEIN','PRQ TRANSLUMINAL MECHANICAL THROMBECTOMY VEIN','37187','1','','1','0','','','',0, 1, 0, 0),
(3411,'PRQ TRLUML MCHNL THRMBC VEIN REPEAT TX','PRQ TRLUML MCHNL THRMBC VEIN REPEAT TX','37188','1','','1','0','','','',0, 1, 0, 0),
(3412,'INS INTRVAS VC FILTR W/WO VAS ACS VSL SELXN RS&I','INS INTRVAS VC FILTR W/WO VAS ACS VSL SELXN RS&I','37191','1','','1','0','','','',0, 1, 0, 0),
(3413,'REPSNG INTRVAS VC FILTR W/WO ACS VSL SELXN RS&','REPSNG INTRVAS VC FILTR W/WO ACS VSL SELXN RS&','37192','1','','1','0','','','',0, 1, 0, 0),
(3414,'RTRVL INTRVAS VC FILTR W/WO ACS VSL SELXN RS&I','RTRVL INTRVAS VC FILTR W/WO ACS VSL SELXN RS&I','37193','1','','1','0','','','',0, 1, 0, 0),
(3415,'THROMBOLYSIS CEREBRAL IV INFUSION','THROMBOLYSIS CEREBRAL IV INFUSION','37195','1','','1','0','','','',0, 1, 0, 0),
(3416,'PRQ TRANSCATHETER RTRVL INTRVAS FB WITH IMAGING','PRQ TRANSCATHETER RTRVL INTRVAS FB WITH IMAGING','37197','1','','1','0','','','',0, 1, 0, 0),
(3417,'TRANSCATHETER BIOPSY','TRANSCATHETER BIOPSY','37200','1','','1','0','','','',0, 1, 0, 0),
(3418,'THROMBOLYSIS ARTERIAL INFUSION ICRA RS&I INIT TX','THROMBOLYSIS ARTERIAL INFUSION ICRA RS&I INIT TX','37211','1','','1','0','','','',0, 1, 0, 0),
(3419,'THROMBOLYSIS VENOUS INFUSION W/IMAGING INIT TX','THROMBOLYSIS VENOUS INFUSION W/IMAGING INIT TX','37212','1','','1','0','','','',0, 1, 0, 0),
(3420,'THROMBOLYSIS ART/VENOUS INFSN W/IMAGE SUBSQ TX','THROMBOLYSIS ART/VENOUS INFSN W/IMAGE SUBSQ TX','37213','1','','1','0','','','',0, 1, 0, 0),
(3421,'CESSATION THROMBOLYTIC THER W/CATHETER REMOVAL','CESSATION THROMBOLYTIC THER W/CATHETER REMOVAL','37214','1','','1','0','','','',0, 1, 0, 0),
(3422,'TCAT IV STENT CRV CRTD ART EMBOLIC PROTECJ','TCAT IV STENT CRV CRTD ART EMBOLIC PROTECJ','37215','1','','1','0','','','',0, 1, 0, 0),
(3423,'TCAT IV STENT CRV CRTD ART W/O EMBOLIC PROTECJ','TCAT IV STENT CRV CRTD ART W/O EMBOLIC PROTECJ','37216','1','','1','0','','','',0, 1, 0, 0),
(3424,'TCATH STENT PLACEMT RETROGRAD CAROTID/INNOMINATE','TCATH STENT PLACEMT RETROGRAD CAROTID/INNOMINATE','37217','1','','1','0','','','',0, 1, 0, 0),
(3425,'TCATH STENT PLACEMT ANTEGRADE CAROTID/INNOMINATE','TCATH STENT PLACEMT ANTEGRADE CAROTID/INNOMINATE','37218','1','','1','0','','','',0, 1, 0, 0),
(3426,'REVASCULARIZATION ILIAC ARTERY ANGIOP 1ST VSL','REVASCULARIZATION ILIAC ARTERY ANGIOP 1ST VSL','37220','1','','1','0','','','',0, 1, 0, 0),
(3427,'REVSC OPN/PRQ ILIAC ART W/STNT PLMT & ANGIOPLSTY','REVSC OPN/PRQ ILIAC ART W/STNT PLMT & ANGIOPLSTY','37221','1','','1','0','','','',0, 1, 0, 0),
(3428,'REVASCULARIZATION ILIAC ART ANGIOP EA IPSI VSL','REVASCULARIZATION ILIAC ART ANGIOP EA IPSI VSL','37222','1','','1','0','','','',0, 1, 0, 0),
(3429,'REVSC OPN/PRQ ILIAC ART W/STNT & ANGIOP IPSILATL','REVSC OPN/PRQ ILIAC ART W/STNT & ANGIOP IPSILATL','37223','1','','1','0','','','',0, 1, 0, 0),
(3430,'REVSC OPN/PRG FEM/POP W/ANGIOPLASTY UNI','REVSC OPN/PRG FEM/POP W/ANGIOPLASTY UNI','37224','1','','1','0','','','',0, 1, 0, 0),
(3431,'REVSC OPN/PRQ FEM/POP W/ATHRC/ANGIOP SM VSL','REVSC OPN/PRQ FEM/POP W/ATHRC/ANGIOP SM VSL','37225','1','','1','0','','','',0, 1, 0, 0),
(3432,'REVSC OPN/PRQ FEM/POP W/STNT/ANGIOP SM VSL','REVSC OPN/PRQ FEM/POP W/STNT/ANGIOP SM VSL','37226','1','','1','0','','','',0, 1, 0, 0),
(3433,'REVSC OPN/PRQ FEM/POP W/STNT/ATHRC/ANGIOP SM VSL','REVSC OPN/PRQ FEM/POP W/STNT/ATHRC/ANGIOP SM VSL','37227','1','','1','0','','','',0, 1, 0, 0),
(3434,'REVSC OPN/PRQ TIB/PERO W/ANGIOPLASTY UNI','REVSC OPN/PRQ TIB/PERO W/ANGIOPLASTY UNI','37228','1','','1','0','','','',0, 1, 0, 0),
(3435,'REVSC OPN/PRQ TIB/PERO W/ATHRC/ANGIOP SM VSL','REVSC OPN/PRQ TIB/PERO W/ATHRC/ANGIOP SM VSL','37229','1','','1','0','','','',0, 1, 0, 0),
(3436,'REVSC OPN/PRQ TIB/PERO W/STNT/ANGIOP SM VSL','REVSC OPN/PRQ TIB/PERO W/STNT/ANGIOP SM VSL','37230','1','','1','0','','','',0, 1, 0, 0),
(3437,'REVSC OPN/PRQ TIB/PERO W/STNT/ATHR/ANGIOP SM VSL','REVSC OPN/PRQ TIB/PERO W/STNT/ATHR/ANGIOP SM VSL','37231','1','','1','0','','','',0, 1, 0, 0),
(3438,'REVSC OPN/PRQ TIB/PERO W/ANGIOPLASTY UNI EA VSL','REVSC OPN/PRQ TIB/PERO W/ANGIOPLASTY UNI EA VSL','37232','1','','1','0','','','',0, 1, 0, 0),
(3439,'REVSC OPN/PRQ TIB/PERO W/ATHRC/ANGIOP UNI EA VSL','REVSC OPN/PRQ TIB/PERO W/ATHRC/ANGIOP UNI EA VSL','37233','1','','1','0','','','',0, 1, 0, 0),
(3440,'REVSC OPN/PRQ TIB/PERO W/STNT/ANGIOP UNI EA VSL','REVSC OPN/PRQ TIB/PERO W/STNT/ANGIOP UNI EA VSL','37234','1','','1','0','','','',0, 1, 0, 0),
(3441,'REVSC OPN/PRQ TIB/PERO W/STNT/ATHR/ANGIOP EA VSL','REVSC OPN/PRQ TIB/PERO W/STNT/ATHR/ANGIOP EA VSL','37235','1','','1','0','','','',0, 1, 0, 0),
(3442,'OPEN/PERQ PLACEMENT INTRAVASCULAR STENT INITIAL','OPEN/PERQ PLACEMENT INTRAVASCULAR STENT INITIAL','37236','1','','1','0','','','',0, 1, 0, 0),
(3443,'OPEN/PERQ PLACEMENT INTRAVASCULAR STENT EA ADDL','OPEN/PERQ PLACEMENT INTRAVASCULAR STENT EA ADDL','37237','1','','1','0','','','',0, 1, 0, 0),
(3444,'OPEN/PERQ PLACEMENT INTRAVASCULAR STENT SAME 1ST','OPEN/PERQ PLACEMENT INTRAVASCULAR STENT SAME 1ST','37238','1','','1','0','','','',0, 1, 0, 0),
(3445,'OPEN/PERQ PLACEMENT INTRAVASC STENT SAME EA ADDL','OPEN/PERQ PLACEMENT INTRAVASC STENT SAME EA ADDL','37239','1','','1','0','','','',0, 1, 0, 0),
(3446,'VASCULAR EMBOLIZATION OR OCCLUSION VENOUS RS&I','VASCULAR EMBOLIZATION OR OCCLUSION VENOUS RS&I','37241','1','','1','0','','','',0, 1, 0, 0),
(3447,'VASCULAR EMBOLIZATION OR OCCLUSION ARTERIAL RS&I','VASCULAR EMBOLIZATION OR OCCLUSION ARTERIAL RS&I','37242','1','','1','0','','','',0, 1, 0, 0),
(3448,'VASCULAR EMBOLIZE/OCCLUDE ORGAN TUMOR INFARCT','VASCULAR EMBOLIZE/OCCLUDE ORGAN TUMOR INFARCT','37243','1','','1','0','','','',0, 1, 0, 0),
(3449,'VASCULAR EMBOLIZATION OR OCCLUSION HEMORRHAGE','VASCULAR EMBOLIZATION OR OCCLUSION HEMORRHAGE','37244','1','','1','0','','','',0, 1, 0, 0),
(3450,'INTRAVASCULAR US NONCORONARY RS&I INTIAL VESSEL','INTRAVASCULAR US NONCORONARY RS&I INTIAL VESSEL','37252','1','','1','0','','','',0, 1, 0, 0),
(3451,'INTRAVASCULAR US NONCORONARY RS&I ADDL VESSEL','INTRAVASCULAR US NONCORONARY RS&I ADDL VESSEL','37253','1','','1','0','','','',0, 1, 0, 0),
(3452,'VASC ENDOSCOPY SURG W/LIG PERFORATOR VEINS SPX','VASC ENDOSCOPY SURG W/LIG PERFORATOR VEINS SPX','37500','1','','1','0','','','',0, 1, 0, 0),
(3453,'UNLISTED VASCULAR ENDOSCOPY PROCEDURE','UNLISTED VASCULAR ENDOSCOPY PROCEDURE','37501','1','','1','0','','','',0, 1, 0, 0),
(3454,'LIGATION INTERNAL JUGULAR VEIN','LIGATION INTERNAL JUGULAR VEIN','37565','1','','1','0','','','',0, 1, 0, 0),
(3455,'LIGATION EXTERNAL CAROTID ARTERY','LIGATION EXTERNAL CAROTID ARTERY','37600','1','','1','0','','','',0, 1, 0, 0),
(3456,'LIGATION INTERNAL/COMMON CAROTID ARTERY','LIGATION INTERNAL/COMMON CAROTID ARTERY','37605','1','','1','0','','','',0, 1, 0, 0),
(3457,'LIG INT/COMMON CAROTID ART W/GRADUAL OCCLUSION','LIG INT/COMMON CAROTID ART W/GRADUAL OCCLUSION','37606','1','','1','0','','','',0, 1, 0, 0),
(3458,'LIG/BANDING ANGIOACCESS ARTERIOVENOUS FISTULA','LIG/BANDING ANGIOACCESS ARTERIOVENOUS FISTULA','37607','1','','1','0','','','',0, 1, 0, 0),
(3459,'LIGATION/BIOPSY TEMPORAL ARTERY','LIGATION/BIOPSY TEMPORAL ARTERY','37609','1','','1','0','','','',0, 1, 0, 0),
(3460,'LIGATION MAJOR ARTERY NECK','LIGATION MAJOR ARTERY NECK','37615','1','','1','0','','','',0, 1, 0, 0),
(3461,'LIGATION MAJOR ARTERY CHEST','LIGATION MAJOR ARTERY CHEST','37616','1','','1','0','','','',0, 1, 0, 0),
(3462,'LIGATION MAJOR ARTERY ABDOMEN','LIGATION MAJOR ARTERY ABDOMEN','37617','1','','1','0','','','',0, 1, 0, 0),
(3463,'LIGATION MAJOR ARTERY EXTREMITY','LIGATION MAJOR ARTERY EXTREMITY','37618','1','','1','0','','','',0, 1, 0, 0),
(3464,'INS INTRVAS VC FILTR W/WO VAS ACS VSL SELXN RS&I','INS INTRVAS VC FILTR W/WO VAS ACS VSL SELXN RS&I','37619','1','','1','0','','','',0, 1, 0, 0),
(3465,'REPSNG INTRVAS VC FILTR W/WO ACS VSL SELXN RS&','REPSNG INTRVAS VC FILTR W/WO ACS VSL SELXN RS&','37650','1','','1','0','','','',0, 1, 0, 0),
(3466,'RTRVL INTRVAS VC FILTR W/WO ACS VSL SELXN RS&I','RTRVL INTRVAS VC FILTR W/WO ACS VSL SELXN RS&I','37660','1','','1','0','','','',0, 1, 0, 0),
(3467,'LIG&DIV LONG SAPH VEIN SAPHFEM JUNCT/INTERRUPJ','LIG&DIV LONG SAPH VEIN SAPHFEM JUNCT/INTERRUPJ','37700','1','','1','0','','','',0, 1, 0, 0),
(3468,'LIGJ DIVJ & STRIPPING SHORT SAPHENOUS VEIN','LIGJ DIVJ & STRIPPING SHORT SAPHENOUS VEIN','37718','1','','1','0','','','',0, 1, 0, 0),
(3469,'LIGJ DIVJ&STRIP LONG SAPH SAPHFEM JUNCT KNE/BELW','LIGJ DIVJ&STRIP LONG SAPH SAPHFEM JUNCT KNE/BELW','37722','1','','1','0','','','',0, 1, 0, 0),
(3470,'LIGJ & DIVJ RADICAL STRIP LONG/SHORT SAPHENOUS','LIGJ & DIVJ RADICAL STRIP LONG/SHORT SAPHENOUS','37735','1','','1','0','','','',0, 1, 0, 0),
(3471,'LIG PRFRATR VEIN SUBFSCAL RAD INCL SKN GRF 1 LEG','LIG PRFRATR VEIN SUBFSCAL RAD INCL SKN GRF 1 LEG','37760','1','','1','0','','','',0, 1, 0, 0),
(3472,'LIG PRFRATR VEIN SUBFSCAL OPEN INCL US GID 1 LEG','LIG PRFRATR VEIN SUBFSCAL OPEN INCL US GID 1 LEG','37761','1','','1','0','','','',0, 1, 0, 0),
(3473,'STAB PHLEBT VARICOSE VEINS 1 XTR 10-20 STAB INCS','STAB PHLEBT VARICOSE VEINS 1 XTR 10-20 STAB INCS','37765','1','','1','0','','','',0, 1, 0, 0),
(3474,'STAB PHLEBT VARICOSE VEINS 1 XTR > 20 INCS','STAB PHLEBT VARICOSE VEINS 1 XTR > 20 INCS','37766','1','','1','0','','','',0, 1, 0, 0),
(3475,'LIGJ & DIV SHORT SAPH VEIN SAPHENOPOP JUNCT SPX','LIGJ & DIV SHORT SAPH VEIN SAPHENOPOP JUNCT SPX','37780','1','','1','0','','','',0, 1, 0, 0),
(3476,'LIGJ DIVJ &/EXCJ VARICOSE VEIN CLUSTER 1 LEG','LIGJ DIVJ &/EXCJ VARICOSE VEIN CLUSTER 1 LEG','37785','1','','1','0','','','',0, 1, 0, 0),
(3477,'PENILE REVASCULARIZATION ARTERY W/WO VEIN GRAFT','PENILE REVASCULARIZATION ARTERY W/WO VEIN GRAFT','37788','1','','1','0','','','',0, 1, 0, 0),
(3478,'PENILE VENOUS OCCLUSIVE PROCEDURE','PENILE VENOUS OCCLUSIVE PROCEDURE','37790','1','','1','0','','','',0, 1, 0, 0),
(3479,'UNLISTED PROCEDURE VASCULAR SURGERY','UNLISTED PROCEDURE VASCULAR SURGERY','37799','1','','1','0','','','',0, 1, 0, 0),
(3480,'SPLENECTOMY TOTAL SEPARATE PROCEDURE','SPLENECTOMY TOTAL SEPARATE PROCEDURE','38100','1','','1','0','','','',0, 1, 0, 0),
(3481,'SPLENECTOMY TOTAL EN BLOC W/OTHER PROCEDURE','SPLENECTOMY TOTAL EN BLOC W/OTHER PROCEDURE','38101','1','','1','0','','','',0, 1, 0, 0),
(3482,'SPLENC TOT EN BLOC EXTNSV DS CONJUNCT W/OTH PX','SPLENC TOT EN BLOC EXTNSV DS CONJUNCT W/OTH PX','38102','1','','1','0','','','',0, 1, 0, 0),
(3483,'RPR RPTD SPLEEN SPLENORRHAPHY W/WO PRTL SPLENECT','RPR RPTD SPLEEN SPLENORRHAPHY W/WO PRTL SPLENECT','38115','1','','1','0','','','',0, 1, 0, 0),
(3484,'LAPAROSCOPIC SURGICAL SPLENECTOMY','LAPAROSCOPIC SURGICAL SPLENECTOMY','38120','1','','1','0','','','',0, 1, 0, 0),
(3485,'UNLISTED LAPAROSCOPY PROCEDURE SPLEEN','UNLISTED LAPAROSCOPY PROCEDURE SPLEEN','38129','1','','1','0','','','',0, 1, 0, 0),
(3486,'INJECTION PROCEDURE SPLENOPORTOGRAPY','INJECTION PROCEDURE SPLENOPORTOGRAPY','38200','1','','1','0','','','',0, 1, 0, 0),
(3487,'MGMT RCP HEMATOP PROGENITOR CELL DONOR &ACQUISJ','MGMT RCP HEMATOP PROGENITOR CELL DONOR &ACQUISJ','38204','1','','1','0','','','',0, 1, 0, 0),
(3488,'BLD-DRV HEMATOP PROGEN CELL HRVG TRNSPLJ ALGNC','BLD-DRV HEMATOP PROGEN CELL HRVG TRNSPLJ ALGNC','38205','1','','1','0','','','',0, 1, 0, 0),
(3489,'BLD-DRV HEMATOP PROGEN CELL HRVG TRNSPLJ AUTOL','BLD-DRV HEMATOP PROGEN CELL HRVG TRNSPLJ AUTOL','38206','1','','1','0','','','',0, 1, 0, 0),
(3490,'TRNSPL PREPJ HEMATOP PROGEN CELLS CRYOPRSRV STOR','TRNSPL PREPJ HEMATOP PROGEN CELLS CRYOPRSRV STOR','38207','1','','1','0','','','',0, 1, 0, 0),
(3491,'TRNSPL PREP HEMATOP PROGEN THAW PREV HRV PER DNR','TRNSPL PREP HEMATOP PROGEN THAW PREV HRV PER DNR','38208','1','','1','0','','','',0, 1, 0, 0),
(3492,'TRNSP PREP HMATOP PROG THAW PREV HRV WSH PER DNR','TRNSP PREP HMATOP PROG THAW PREV HRV WSH PER DNR','38209','1','','1','0','','','',0, 1, 0, 0),
(3493,'TRNSPL PREPJ HEMATOP PROGEN DEPLJ IN HRV T-CELL','TRNSPL PREPJ HEMATOP PROGEN DEPLJ IN HRV T-CELL','38210','1','','1','0','','','',0, 1, 0, 0),
(3494,'TRNSPL PREPJ HEMATOP PROGEN TUM CELL DEPLJ','TRNSPL PREPJ HEMATOP PROGEN TUM CELL DEPLJ','38211','1','','1','0','','','',0, 1, 0, 0),
(3495,'TRNSPL PREPJ HEMATOP PROGEN RED BLD CELL RMVL','TRNSPL PREPJ HEMATOP PROGEN RED BLD CELL RMVL','38212','1','','1','0','','','',0, 1, 0, 0),
(3496,'TRNSPL PREPJ HEMATOP PROGEN PLTLT DEPLJ','TRNSPL PREPJ HEMATOP PROGEN PLTLT DEPLJ','38213','1','','1','0','','','',0, 1, 0, 0),
(3497,'TRNSPL PREPJ HEMATOP PROGEN PLSM VOL DEPLJ','TRNSPL PREPJ HEMATOP PROGEN PLSM VOL DEPLJ','38214','1','','1','0','','','',0, 1, 0, 0),
(3498,'TRNSPL PREPJ HEMATOP PROGEN CONCENTRATION PLSM','TRNSPL PREPJ HEMATOP PROGEN CONCENTRATION PLSM','38215','1','','1','0','','','',0, 1, 0, 0),
(3499,'MARROW ASPIRATION ONLY','MARROW ASPIRATION ONLY','38220','1','','1','0','','','',0, 1, 0, 0),
(3500,'BONE MARROW BIOPSY NEEDLE/TROCAR','BONE MARROW BIOPSY NEEDLE/TROCAR','38221','1','','1','0','','','',0, 1, 0, 0),
(3501,'BONE MARROW HARVEST TRANSPLANTATION ALLOGENEIC','BONE MARROW HARVEST TRANSPLANTATION ALLOGENEIC','38230','1','','1','0','','','',0, 1, 0, 0),
(3502,'BONE MARROW HARVEST TRANSPLANTATION AUTOLOGOUS','BONE MARROW HARVEST TRANSPLANTATION AUTOLOGOUS','38232','1','','1','0','','','',0, 1, 0, 0),
(3503,'TRNSPLJ ALLOGENEIC HEMATOPOIETIC CELLS PER DONOR','TRNSPLJ ALLOGENEIC HEMATOPOIETIC CELLS PER DONOR','38240','1','','1','0','','','',0, 1, 0, 0),
(3504,'TRNSPLJ AUTOLOGOUS HEMATOPOIETIC CELLS PER DONOR','TRNSPLJ AUTOLOGOUS HEMATOPOIETIC CELLS PER DONOR','38241','1','','1','0','','','',0, 1, 0, 0),
(3505,'ALLOGENEIC LYMPHOCYTE INFUSIONS','ALLOGENEIC LYMPHOCYTE INFUSIONS','38242','1','','1','0','','','',0, 1, 0, 0),
(3506,'TRNSPLJ HEMATOPOIETIC CELL BOOST','TRNSPLJ HEMATOPOIETIC CELL BOOST','38243','1','','1','0','','','',0, 1, 0, 0),
(3507,'DRG LYMPH NODE ABSC/LYMPHADENITIS SMPL','DRG LYMPH NODE ABSC/LYMPHADENITIS SMPL','38300','1','','1','0','','','',0, 1, 0, 0),
(3508,'DRG LYMPH NODE ABSC/LYMPHADENITIS EXTNSV','DRG LYMPH NODE ABSC/LYMPHADENITIS EXTNSV','38305','1','','1','0','','','',0, 1, 0, 0),
(3509,'LYMPHANGIOTOMY/OTH OPRATIONS LYMPHATIC CHANNELS','LYMPHANGIOTOMY/OTH OPRATIONS LYMPHATIC CHANNELS','38308','1','','1','0','','','',0, 1, 0, 0),
(3510,'SUTR&/LIG THORACIC DUCT CERVICAL APPROACH','SUTR&/LIG THORACIC DUCT CERVICAL APPROACH','38380','1','','1','0','','','',0, 1, 0, 0),
(3511,'SUTR&/LIG THORACIC DUCT THORACIC APPROACH','SUTR&/LIG THORACIC DUCT THORACIC APPROACH','38381','1','','1','0','','','',0, 1, 0, 0),
(3512,'SUTR&/LIG THORACIC DUCT ABDOMINAL APPROACH','SUTR&/LIG THORACIC DUCT ABDOMINAL APPROACH','38382','1','','1','0','','','',0, 1, 0, 0),
(3513,'BX/EXC LYMPH NODE OPEN SUPERFICIAL','BX/EXC LYMPH NODE OPEN SUPERFICIAL','38500','1','','1','0','','','',0, 1, 0, 0),
(3514,'BX/EXC LYMPH NODE NEEDLE SUPERFICIAL','BX/EXC LYMPH NODE NEEDLE SUPERFICIAL','38505','1','','1','0','','','',0, 1, 0, 0),
(3515,'BX/EXC LYMPH NODE OPEN DEEP CERVICAL NODE','BX/EXC LYMPH NODE OPEN DEEP CERVICAL NODE','38510','1','','1','0','','','',0, 1, 0, 0),
(3516,'BX/EXC LYMPH NODE OPN DP CRV NODE W/EXC FAT PAD','BX/EXC LYMPH NODE OPN DP CRV NODE W/EXC FAT PAD','38520','1','','1','0','','','',0, 1, 0, 0),
(3517,'BX/EXC LYMPH NODE OPEN DEEP AXILLARY NODE','BX/EXC LYMPH NODE OPEN DEEP AXILLARY NODE','38525','1','','1','0','','','',0, 1, 0, 0),
(3518,'BX/EXC LYMPH NODE OPEN INT MAMMARY NODE','BX/EXC LYMPH NODE OPEN INT MAMMARY NODE','38530','1','','1','0','','','',0, 1, 0, 0),
(3519,'DISSECTION DEEP JUGULAR NODE','DISSECTION DEEP JUGULAR NODE','38542','1','','1','0','','','',0, 1, 0, 0),
(3520,'EXC CSTIC HYGROMA AX/CRV W/O DP NEUROVASC DSJ','EXC CSTIC HYGROMA AX/CRV W/O DP NEUROVASC DSJ','38550','1','','1','0','','','',0, 1, 0, 0),
(3521,'EXC CSTIC HYGROMA AX/CRV W/DP NEUROVASC DSJ','EXC CSTIC HYGROMA AX/CRV W/DP NEUROVASC DSJ','38555','1','','1','0','','','',0, 1, 0, 0),
(3522,'LMTD LMPHADEC STAGING SPX PEL&PARA-AORTIC','LMTD LMPHADEC STAGING SPX PEL&PARA-AORTIC','38562','1','','1','0','','','',0, 1, 0, 0),
(3523,'LMTD LMPHADEC STAGING SPX RPR AORTIC&/SPLENIC','LMTD LMPHADEC STAGING SPX RPR AORTIC&/SPLENIC','38564','1','','1','0','','','',0, 1, 0, 0),
(3524,'LAPS SURG RETROPERITONEAL LYMPH NODE BX 1/MLT','LAPS SURG RETROPERITONEAL LYMPH NODE BX 1/MLT','38570','1','','1','0','','','',0, 1, 0, 0),
(3525,'LAPS SURG BILATERAL TOTAL PELVIC LMPHADECTOMY','LAPS SURG BILATERAL TOTAL PELVIC LMPHADECTOMY','38571','1','','1','0','','','',0, 1, 0, 0),
(3526,'LAPS BI TOT PEL LMPHADEC & PRI-AORTIC LYMPH BX 1','LAPS BI TOT PEL LMPHADEC & PRI-AORTIC LYMPH BX 1','38572','1','','1','0','','','',0, 1, 0, 0),
(3527,'UNLISTED LAPAROSCOPY PX LYMPHATIC SYSTEM','UNLISTED LAPAROSCOPY PX LYMPHATIC SYSTEM','38589','1','','1','0','','','',0, 1, 0, 0),
(3528,'SUPRAHYOID LYMPHADENECTOMY','SUPRAHYOID LYMPHADENECTOMY','38700','1','','1','0','','','',0, 1, 0, 0),
(3529,'CERVICAL LYMPHADENECTOMY','CERVICAL LYMPHADENECTOMY','38720','1','','1','0','','','',0, 1, 0, 0),
(3530,'CERVICAL LYMPHADEC MODIFIED RADICAL NECK DSJ','CERVICAL LYMPHADEC MODIFIED RADICAL NECK DSJ','38724','1','','1','0','','','',0, 1, 0, 0),
(3531,'AXILLARY LYMPHADENECTOMY SUPERFICIAL','AXILLARY LYMPHADENECTOMY SUPERFICIAL','38740','1','','1','0','','','',0, 1, 0, 0),
(3532,'AXILLARY LYMPHADENECTOMY COMPLETE','AXILLARY LYMPHADENECTOMY COMPLETE','38745','1','','1','0','','','',0, 1, 0, 0),
(3533,'THORCOM THRC W/MEDSTNL & REGIONAL LMPHADEC','THORCOM THRC W/MEDSTNL & REGIONAL LMPHADEC','38746','1','','1','0','','','',0, 1, 0, 0),
(3534,'ABDL LMPHADEC REG CELIAC GSTR PORTAL PRIPNCRTC','ABDL LMPHADEC REG CELIAC GSTR PORTAL PRIPNCRTC','38747','1','','1','0','','','',0, 1, 0, 0),
(3535,'INGUINOFEM LMPHADEC SUPFC W/CLOQUETS NODE SPX','INGUINOFEM LMPHADEC SUPFC W/CLOQUETS NODE SPX','38760','1','','1','0','','','',0, 1, 0, 0),
(3536,'INGUINOFEM LMPHADEC SUPFC W/PEL LMPHADEC','INGUINOFEM LMPHADEC SUPFC W/PEL LMPHADEC','38765','1','','1','0','','','',0, 1, 0, 0),
(3537,'PEL LMPHADEC W/XTRNL ILIAC HYPOGSTR&OBTURATOR','PEL LMPHADEC W/XTRNL ILIAC HYPOGSTR&OBTURATOR','38770','1','','1','0','','','',0, 1, 0, 0),
(3538,'RPR TABDL LMPHADEC EXTNSV W/PEL AORTIC&RNL','RPR TABDL LMPHADEC EXTNSV W/PEL AORTIC&RNL','38780','1','','1','0','','','',0, 1, 0, 0),
(3539,'INJECTION PROCEDURE LYMPHANGIOGRAPHY','INJECTION PROCEDURE LYMPHANGIOGRAPHY','38790','1','','1','0','','','',0, 1, 0, 0),
(3540,'INJ RADIOACTIVE TRACER FOR ID OF SENTINEL NODE','INJ RADIOACTIVE TRACER FOR ID OF SENTINEL NODE','38792','1','','1','0','','','',0, 1, 0, 0),
(3541,'CANNULATION THORACIC DUCT','CANNULATION THORACIC DUCT','38794','1','','1','0','','','',0, 1, 0, 0),
(3542,'INTRAOP SENTINEL LYMPH NODE ID W/DYE INJECTION','INTRAOP SENTINEL LYMPH NODE ID W/DYE INJECTION','38900','1','','1','0','','','',0, 1, 0, 0),
(3543,'UNLISTED PROCEDURE HEMIC OR LYMPHATIC SYSTEM','UNLISTED PROCEDURE HEMIC OR LYMPHATIC SYSTEM','38999','1','','1','0','','','',0, 1, 0, 0),
(3544,'MEDIAST W/EXPL DRG RMVL FB/BX CRV APPR','MEDIAST W/EXPL DRG RMVL FB/BX CRV APPR','39000','1','','1','0','','','',0, 1, 0, 0),
(3545,'MEDIAST W/EXPL DRG RMVL FB/BX TTHRC APPR','MEDIAST W/EXPL DRG RMVL FB/BX TTHRC APPR','39010','1','','1','0','','','',0, 1, 0, 0),
(3546,'RESECTION OF MEDIASTINAL CYST','RESECTION OF MEDIASTINAL CYST','39200','1','','1','0','','','',0, 1, 0, 0),
(3547,'RESECTION MEDIASTINAL TUMOR','RESECTION MEDIASTINAL TUMOR','39220','1','','1','0','','','',0, 1, 0, 0),
(3548,'MEDIASTINOSCOPY INCLUDES MEDIASTINAL MASS BIOPSY','MEDIASTINOSCOPY INCLUDES MEDIASTINAL MASS BIOPSY','39401','1','','1','0','','','',0, 1, 0, 0),
(3549,'MEDIASTINOSCOPY WITH LYMPH NODE BIOPSY/IES','MEDIASTINOSCOPY WITH LYMPH NODE BIOPSY/IES','39402','1','','1','0','','','',0, 1, 0, 0),
(3550,'UNLISTED PROCEDURE MEDIASTINUM','UNLISTED PROCEDURE MEDIASTINUM','39499','1','','1','0','','','',0, 1, 0, 0),
(3551,'REPAIR LACERATION DIAPHRAGM ANY APPROACH','REPAIR LACERATION DIAPHRAGM ANY APPROACH','39501','1','','1','0','','','',0, 1, 0, 0),
(3552,'RPR NEONATAL DIPHRG HERNIA W/WO CHEST TUBE INSJ','RPR NEONATAL DIPHRG HERNIA W/WO CHEST TUBE INSJ','39503','1','','1','0','','','',0, 1, 0, 0),
(3553,'RPR DIPHRG HRNA OTH/THN NEONATAL TRAUMTC AQT','RPR DIPHRG HRNA OTH/THN NEONATAL TRAUMTC AQT','39540','1','','1','0','','','',0, 1, 0, 0),
(3554,'RPR DIPHRG HRNA OTH/THN NEONATAL TRAUMTC CHRNC','RPR DIPHRG HRNA OTH/THN NEONATAL TRAUMTC CHRNC','39541','1','','1','0','','','',0, 1, 0, 0),
(3555,'IMBRICATION DIAPHRAGM EVENTRATION','IMBRICATION DIAPHRAGM EVENTRATION','39545','1','','1','0','','','',0, 1, 0, 0),
(3556,'RESCJ DIAPHRAGM W/SIMPLE REPAIR','RESCJ DIAPHRAGM W/SIMPLE REPAIR','39560','1','','1','0','','','',0, 1, 0, 0),
(3557,'RESCJ DIAPHRAGM W/COMPLEX REPAIR','RESCJ DIAPHRAGM W/COMPLEX REPAIR','39561','1','','1','0','','','',0, 1, 0, 0),
(3558,'UNLISTED PROCEDURE DIAPHRAGM','UNLISTED PROCEDURE DIAPHRAGM','39599','1','','1','0','','','',0, 1, 0, 0),
(3559,'BIOPSY OF LIP','BIOPSY OF LIP','40490','1','','1','0','','','',0, 1, 0, 0),
(3560,'VERMILIONECTOMY LIP SHV W/MUCOSAL ADVMNT','VERMILIONECTOMY LIP SHV W/MUCOSAL ADVMNT','40500','1','','1','0','','','',0, 1, 0, 0),
(3561,'EXC LIP TRANSVRS WEDGE EXC W/PRIM CLSR','EXC LIP TRANSVRS WEDGE EXC W/PRIM CLSR','40510','1','','1','0','','','',0, 1, 0, 0),
(3562,'EXC LIP V-EXC W/PRIM DIR LINR CLSR','EXC LIP V-EXC W/PRIM DIR LINR CLSR','40520','1','','1','0','','','',0, 1, 0, 0),
(3563,'EXC LIP FULL THKNS RCNSTJ W/LOCAL FLAP','EXC LIP FULL THKNS RCNSTJ W/LOCAL FLAP','40525','1','','1','0','','','',0, 1, 0, 0),
(3564,'EXC LIP FULL THKNS RCNSTJ W/CROSS LIP FLAP','EXC LIP FULL THKNS RCNSTJ W/CROSS LIP FLAP','40527','1','','1','0','','','',0, 1, 0, 0),
(3565,'RESCJ LIP > ONE-FOURTH W/O RCNSTJ','RESCJ LIP > ONE-FOURTH W/O RCNSTJ','40530','1','','1','0','','','',0, 1, 0, 0),
(3566,'RPR LIP FULL THICKNESS VERMILION ONLY','RPR LIP FULL THICKNESS VERMILION ONLY','40650','1','','1','0','','','',0, 1, 0, 0),
(3567,'RPR LIP FULL THICKNESS HALF/< VERTICAL HEIGHT','RPR LIP FULL THICKNESS HALF/< VERTICAL HEIGHT','40652','1','','1','0','','','',0, 1, 0, 0),
(3568,'RPR LIP FULL THKNS >ONE-HALF VERT HEIGHT/COMPLE','RPR LIP FULL THKNS >ONE-HALF VERT HEIGHT/COMPLE','40654','1','','1','0','','','',0, 1, 0, 0),
(3569,'PLSTC RPR CL LIP/NSL DFRM PRIM PRTL/COMPL UNI','PLSTC RPR CL LIP/NSL DFRM PRIM PRTL/COMPL UNI','40700','1','','1','0','','','',0, 1, 0, 0),
(3570,'PLSTC RPR CL LIP/NSL DFRM PRIM BI 1 STG PX','PLSTC RPR CL LIP/NSL DFRM PRIM BI 1 STG PX','40701','1','','1','0','','','',0, 1, 0, 0),
(3571,'PLSTC RPR CL LIP/NSL DFRM PRIM BI 1 2 STGS','PLSTC RPR CL LIP/NSL DFRM PRIM BI 1 2 STGS','40702','1','','1','0','','','',0, 1, 0, 0),
(3572,'PLSTC RPR CL LIP/NSL DFRM SEC RECRTJ DFCT & RECL','PLSTC RPR CL LIP/NSL DFRM SEC RECRTJ DFCT & RECL','40720','1','','1','0','','','',0, 1, 0, 0),
(3573,'PLSTC RPR CL LIP/NSL DFRM W/CROSS LIP PEDCL FLAP','PLSTC RPR CL LIP/NSL DFRM W/CROSS LIP PEDCL FLAP','40761','1','','1','0','','','',0, 1, 0, 0),
(3574,'UNLISTED PROCEDURE LIPS','UNLISTED PROCEDURE LIPS','40799','1','','1','0','','','',0, 1, 0, 0),
(3575,'DRG ABSC CST HMTMA VESTIBULE MOUTH SMPL','DRG ABSC CST HMTMA VESTIBULE MOUTH SMPL','40800','1','','1','0','','','',0, 1, 0, 0),
(3576,'DRG ABSC CST HMTMA VESTIBULE MOUTH COMP','DRG ABSC CST HMTMA VESTIBULE MOUTH COMP','40801','1','','1','0','','','',0, 1, 0, 0),
(3577,'RMVL EMBEDDED FB VESTIBULE MOUTH SMPL','RMVL EMBEDDED FB VESTIBULE MOUTH SMPL','40804','1','','1','0','','','',0, 1, 0, 0),
(3578,'RMVL EMBEDDED FB VESTIBULE MOUTH COMP','RMVL EMBEDDED FB VESTIBULE MOUTH COMP','40805','1','','1','0','','','',0, 1, 0, 0),
(3579,'INCISION LABIAL FRENUM FRENOTOMY','INCISION LABIAL FRENUM FRENOTOMY','40806','1','','1','0','','','',0, 1, 0, 0),
(3580,'BIOPSY VESTIBULE MOUTH','BIOPSY VESTIBULE MOUTH','40808','1','','1','0','','','',0, 1, 0, 0),
(3581,'EXC LES MUCOSA & SBMCSL VESTIBULE MOUTH W/O RPR','EXC LES MUCOSA & SBMCSL VESTIBULE MOUTH W/O RPR','40810','1','','1','0','','','',0, 1, 0, 0),
(3582,'EXC LESION MUCOSA & SBMCSL VESTIBULE SMPL RPR','EXC LESION MUCOSA & SBMCSL VESTIBULE SMPL RPR','40812','1','','1','0','','','',0, 1, 0, 0),
(3583,'EXC LESION MUCOSA & SBMCSL VESTIBULE CPLX RPR','EXC LESION MUCOSA & SBMCSL VESTIBULE CPLX RPR','40814','1','','1','0','','','',0, 1, 0, 0),
(3584,'EXC LESION MUCOSA&SBMCSL VESTIBULE CPLX EXC MUSC','EXC LESION MUCOSA&SBMCSL VESTIBULE CPLX EXC MUSC','40816','1','','1','0','','','',0, 1, 0, 0),
(3585,'EXC MUCOSA VESTIBULE MOUTH AS DON GRF','EXC MUCOSA VESTIBULE MOUTH AS DON GRF','40818','1','','1','0','','','',0, 1, 0, 0),
(3586,'EXC FRENUM LABIAL/BUCCAL','EXC FRENUM LABIAL/BUCCAL','40819','1','','1','0','','','',0, 1, 0, 0),
(3587,'DSTRJ LES/SCAR VESTIBULE MOUTH PHYSICAL METHS','DSTRJ LES/SCAR VESTIBULE MOUTH PHYSICAL METHS','40820','1','','1','0','','','',0, 1, 0, 0),
(3588,'CLOSURE LACERATION VESTIBULE MOUTH 2.5 CM/<','CLOSURE LACERATION VESTIBULE MOUTH 2.5 CM/<','40830','1','','1','0','','','',0, 1, 0, 0),
(3589,'CLOSURE LACERATION VESTIBULE MOUTH > 2.5 CM/CPL','CLOSURE LACERATION VESTIBULE MOUTH > 2.5 CM/CPL','40831','1','','1','0','','','',0, 1, 0, 0),
(3590,'VESTIBULOPLASTY ANTERIOR','VESTIBULOPLASTY ANTERIOR','40840','1','','1','0','','','',0, 1, 0, 0),
(3591,'VESTIBULOPLASTY POSTERIOR UNILATERAL','VESTIBULOPLASTY POSTERIOR UNILATERAL','40842','1','','1','0','','','',0, 1, 0, 0),
(3592,'VESTIBULOPLASTY POSTERIOR BILATERAL','VESTIBULOPLASTY POSTERIOR BILATERAL','40843','1','','1','0','','','',0, 1, 0, 0),
(3593,'VESTIBULOPLASTY ENTIRE ARCH','VESTIBULOPLASTY ENTIRE ARCH','40844','1','','1','0','','','',0, 1, 0, 0),
(3594,'VESTIBULOPLASTY CPLX W/RIDGE XTN MUSC RPSG','VESTIBULOPLASTY CPLX W/RIDGE XTN MUSC RPSG','40845','1','','1','0','','','',0, 1, 0, 0),
(3595,'UNLISTED PROCEDURE VESTIBULE MOUTH','UNLISTED PROCEDURE VESTIBULE MOUTH','40899','1','','1','0','','','',0, 1, 0, 0),
(3596,'INTRAORAL I&D TONGUE/FLOOR LINGUAL','INTRAORAL I&D TONGUE/FLOOR LINGUAL','41000','1','','1','0','','','',0, 1, 0, 0),
(3597,'INTRAORAL I&D TONGUE/FLOOR SUBLNGL SUPFC','INTRAORAL I&D TONGUE/FLOOR SUBLNGL SUPFC','41005','1','','1','0','','','',0, 1, 0, 0),
(3598,'INTRAORAL I&D TONGUE/FLOOR SUBLNGL DP SPRMLHYD','INTRAORAL I&D TONGUE/FLOOR SUBLNGL DP SPRMLHYD','41006','1','','1','0','','','',0, 1, 0, 0),
(3599,'INTRAORAL I&D TONGUE/FLOOR SUBMENTAL SPACE','INTRAORAL I&D TONGUE/FLOOR SUBMENTAL SPACE','41007','1','','1','0','','','',0, 1, 0, 0),
(3600,'INTRAORAL I&D TONGUE/FLOOR SUBMNDBLR SPACE','INTRAORAL I&D TONGUE/FLOOR SUBMNDBLR SPACE','41008','1','','1','0','','','',0, 1, 0, 0),
(3601,'INTRAORAL I&D TONGUE/FLOOR MASTICATOR SPACE','INTRAORAL I&D TONGUE/FLOOR MASTICATOR SPACE','41009','1','','1','0','','','',0, 1, 0, 0),
(3602,'INCISION LINGUAL FRENUM FRENOTOMY','INCISION LINGUAL FRENUM FRENOTOMY','41010','1','','1','0','','','',0, 1, 0, 0),
(3603,'XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBLNGL','XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBLNGL','41015','1','','1','0','','','',0, 1, 0, 0),
(3604,'XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBMENT','XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBMENT','41016','1','','1','0','','','',0, 1, 0, 0),
(3605,'XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBMNDB','XTRORAL I&D ABSC CST/HMTMA FLOOR MOUTH SUBMNDB','41017','1','','1','0','','','',0, 1, 0, 0),
(3606,'XTRORAL I&D FLOOR MASTICATOR SPACE','XTRORAL I&D FLOOR MASTICATOR SPACE','41018','1','','1','0','','','',0, 1, 0, 0),
(3607,'PLACEMENT NEEDLE HEAD/NECK RADIOELEMENT APPLICAT','PLACEMENT NEEDLE HEAD/NECK RADIOELEMENT APPLICAT','41019','1','','1','0','','','',0, 1, 0, 0),
(3608,'BIOPSY TONGUE ANTERIOR TWO-THIRDS','BIOPSY TONGUE ANTERIOR TWO-THIRDS','41100','1','','1','0','','','',0, 1, 0, 0),
(3609,'BIOPSY TONGUE POSTERIOR ONE-THIRD','BIOPSY TONGUE POSTERIOR ONE-THIRD','41105','1','','1','0','','','',0, 1, 0, 0),
(3610,'BIOPSY FLOOR MOUTH','BIOPSY FLOOR MOUTH','41108','1','','1','0','','','',0, 1, 0, 0),
(3611,'EXCISION LESION TONGUE W/O CLOSURE','EXCISION LESION TONGUE W/O CLOSURE','41110','1','','1','0','','','',0, 1, 0, 0),
(3612,'EXC LESION TONGUE W/CLSR ANTERIOR TWO-THIRDS','EXC LESION TONGUE W/CLSR ANTERIOR TWO-THIRDS','41112','1','','1','0','','','',0, 1, 0, 0),
(3613,'EXC LESION TONGUE W/CLSR POSTERIOR ONE-THIRD','EXC LESION TONGUE W/CLSR POSTERIOR ONE-THIRD','41113','1','','1','0','','','',0, 1, 0, 0),
(3614,'EXC LESION TONGUE W/CLSR W/LOCAL TONGUE FLAP','EXC LESION TONGUE W/CLSR W/LOCAL TONGUE FLAP','41114','1','','1','0','','','',0, 1, 0, 0),
(3615,'EXCISION LINGUAL FRENUM FRENECTOMY','EXCISION LINGUAL FRENUM FRENECTOMY','41115','1','','1','0','','','',0, 1, 0, 0),
(3616,'EXCISION LESION FLOOR MOUTH','EXCISION LESION FLOOR MOUTH','41116','1','','1','0','','','',0, 1, 0, 0),
(3617,'GLOSSECTOMY <ONE-HALF TONGUE','GLOSSECTOMY <ONE-HALF TONGUE','41120','1','','1','0','','','',0, 1, 0, 0),
(3618,'GLOSSECTOMY HEMIGLOSSECTOMY','GLOSSECTOMY HEMIGLOSSECTOMY','41130','1','','1','0','','','',0, 1, 0, 0),
(3619,'GLOSSECTOMY PRTL W/UNI RADICAL NECK DSJ','GLOSSECTOMY PRTL W/UNI RADICAL NECK DSJ','41135','1','','1','0','','','',0, 1, 0, 0),
(3620,'GLSSC COMPL/TOT W/WOTRACHS W/O RAD NECK DSJ','GLSSC COMPL/TOT W/WOTRACHS W/O RAD NECK DSJ','41140','1','','1','0','','','',0, 1, 0, 0),
(3621,'GLSSC COMPL/TOT W/WO TRACHS W/UNI RAD NECK DSJ','GLSSC COMPL/TOT W/WO TRACHS W/UNI RAD NECK DSJ','41145','1','','1','0','','','',0, 1, 0, 0),
(3622,'GLSSC COMPOSIT W/RESCJ FLOOR & MANDIBULAR RESCJ','GLSSC COMPOSIT W/RESCJ FLOOR & MANDIBULAR RESCJ','41150','1','','1','0','','','',0, 1, 0, 0),
(3623,'GLSSC COMPOSIT RESCJ FLOOR SUPRAHYOID NCK DSJ','GLSSC COMPOSIT RESCJ FLOOR SUPRAHYOID NCK DSJ','41153','1','','1','0','','','',0, 1, 0, 0),
(3624,'GLSSC COMPOSIT RESCJ FLR MNDBLR RESCJ & RAD NECK','GLSSC COMPOSIT RESCJ FLR MNDBLR RESCJ & RAD NECK','41155','1','','1','0','','','',0, 1, 0, 0),
(3625,'RPR LAC 2.5 CM/< MOUTH&/ANT TWO-THIRDS TONG','RPR LAC 2.5 CM/< MOUTH&/ANT TWO-THIRDS TONG','41250','1','','1','0','','','',0, 1, 0, 0),
(3626,'RPR LAC 2.5 CM/< PST ONE-THIRD TONGUE','RPR LAC 2.5 CM/< PST ONE-THIRD TONGUE','41251','1','','1','0','','','',0, 1, 0, 0),
(3627,'RPR LAC TONGUE FLOOR MOUTH > 2.6 CM/CPLX','RPR LAC TONGUE FLOOR MOUTH > 2.6 CM/CPLX','41252','1','','1','0','','','',0, 1, 0, 0),
(3628,'FIXJ TONGUE MECHANICAL OTHER/THAN SUTURE','FIXJ TONGUE MECHANICAL OTHER/THAN SUTURE','41500','1','','1','0','','','',0, 1, 0, 0),
(3629,'SUTURE TONGUE LIP MICROGNATHIA','SUTURE TONGUE LIP MICROGNATHIA','41510','1','','1','0','','','',0, 1, 0, 0),
(3630,'TONGUE BASE SUSPENSION PERMANENT SUTURE TQ','TONGUE BASE SUSPENSION PERMANENT SUTURE TQ','41512','1','','1','0','','','',0, 1, 0, 0),
(3631,'FRENOPLASTY SURG REVJ FRENUM EG W/Z-PLASTY','FRENOPLASTY SURG REVJ FRENUM EG W/Z-PLASTY','41520','1','','1','0','','','',0, 1, 0, 0),
(3632,'SUBMUCOSAL ABLTJ TONGUE RF 1/> SITES PR SESSION','SUBMUCOSAL ABLTJ TONGUE RF 1/> SITES PR SESSION','41530','1','','1','0','','','',0, 1, 0, 0),
(3633,'UNLISTED PROCEDURE TONGUE FLOOR MOUTH','UNLISTED PROCEDURE TONGUE FLOOR MOUTH','41599','1','','1','0','','','',0, 1, 0, 0),
(3634,'DRG ABSC CST HMTMA FROM DENTOALVEOLAR STRUXS','DRG ABSC CST HMTMA FROM DENTOALVEOLAR STRUXS','41800','1','','1','0','','','',0, 1, 0, 0),
(3635,'RMVL EMBEDDED FB FROM DENTALVLR STRUXS SOFT TISS','RMVL EMBEDDED FB FROM DENTALVLR STRUXS SOFT TISS','41805','1','','1','0','','','',0, 1, 0, 0),
(3636,'RMVL EMBEDDED FB FROM DENTOALVEOLAR STRUXS BONE','RMVL EMBEDDED FB FROM DENTOALVEOLAR STRUXS BONE','41806','1','','1','0','','','',0, 1, 0, 0),
(3637,'GINGIVECTOMY EXC GINGIVA EACH QUADRANT','GINGIVECTOMY EXC GINGIVA EACH QUADRANT','41820','1','','1','0','','','',0, 1, 0, 0),
(3638,'OPRCULECTOMY EXC PRICORONAL TISSUE','OPRCULECTOMY EXC PRICORONAL TISSUE','41821','1','','1','0','','','',0, 1, 0, 0),
(3639,'EXC FIBROUS TUBEROSITIES DENTOALVEOLAR STRUXS','EXC FIBROUS TUBEROSITIES DENTOALVEOLAR STRUXS','41822','1','','1','0','','','',0, 1, 0, 0),
(3640,'EXC OSS TUBEROSITIES DENTOALVEOLAR STRUXS','EXC OSS TUBEROSITIES DENTOALVEOLAR STRUXS','41823','1','','1','0','','','',0, 1, 0, 0),
(3641,'EXC LESION/TUMOR DENTOALVEOLAR STRUX W/O RPR','EXC LESION/TUMOR DENTOALVEOLAR STRUX W/O RPR','41825','1','','1','0','','','',0, 1, 0, 0),
(3642,'EXC LESION/TUMOR DENTOALVEOLAR STRUX W/SMPL RPR','EXC LESION/TUMOR DENTOALVEOLAR STRUX W/SMPL RPR','41826','1','','1','0','','','',0, 1, 0, 0),
(3643,'EXC LESION/TUMOR DENTALVEOLAR STRUX W/CMPLX RPR','EXC LESION/TUMOR DENTALVEOLAR STRUX W/CMPLX RPR','41827','1','','1','0','','','',0, 1, 0, 0),
(3644,'EXC HYPRPLSTC ALVEOLAR MUCOSA EA QUADRANT SPEC','EXC HYPRPLSTC ALVEOLAR MUCOSA EA QUADRANT SPEC','41828','1','','1','0','','','',0, 1, 0, 0),
(3645,'ALVEOLECTOMY W/CURTG OSTEITIS/SEQUESTRECTOMY','ALVEOLECTOMY W/CURTG OSTEITIS/SEQUESTRECTOMY','41830','1','','1','0','','','',0, 1, 0, 0),
(3646,'DESTRUCTION LESION DENTOALVEOLAR STRUCTURES','DESTRUCTION LESION DENTOALVEOLAR STRUCTURES','41850','1','','1','0','','','',0, 1, 0, 0),
(3647,'PERIODONTAL MUCOSAL GRAFTING','PERIODONTAL MUCOSAL GRAFTING','41870','1','','1','0','','','',0, 1, 0, 0),
(3648,'GINGIVOPLASTY EACH QUADRANT SPECIFY','GINGIVOPLASTY EACH QUADRANT SPECIFY','41872','1','','1','0','','','',0, 1, 0, 0),
(3649,'ALVEOLOPLASTY EACH QUADRANT SPECIFY','ALVEOLOPLASTY EACH QUADRANT SPECIFY','41874','1','','1','0','','','',0, 1, 0, 0),
(3650,'UNLISTED PROCEDURE DENTOALVEOLAR STRUCTURES','UNLISTED PROCEDURE DENTOALVEOLAR STRUCTURES','41899','1','','1','0','','','',0, 1, 0, 0),
(3651,'DRAINAGE ABSCESS PALATE UVULA','DRAINAGE ABSCESS PALATE UVULA','42000','1','','1','0','','','',0, 1, 0, 0),
(3652,'BIOPSY PALATE UVULA','BIOPSY PALATE UVULA','42100','1','','1','0','','','',0, 1, 0, 0),
(3653,'EXC LESION PALATE UVULA W/O CLOSURE','EXC LESION PALATE UVULA W/O CLOSURE','42104','1','','1','0','','','',0, 1, 0, 0),
(3654,'EXC LESION PALATE UVULA W/SMPL PRIM CLOSURE','EXC LESION PALATE UVULA W/SMPL PRIM CLOSURE','42106','1','','1','0','','','',0, 1, 0, 0),
(3655,'EXC LESION PALATE UVULA W/LOCAL FLAP CLOSURE','EXC LESION PALATE UVULA W/LOCAL FLAP CLOSURE','42107','1','','1','0','','','',0, 1, 0, 0),
(3656,'RESCJ PALATE/EXTENSIVE RESCJ LESION','RESCJ PALATE/EXTENSIVE RESCJ LESION','42120','1','','1','0','','','',0, 1, 0, 0),
(3657,'UVULECTOMY EXCISION UVULA','UVULECTOMY EXCISION UVULA','42140','1','','1','0','','','',0, 1, 0, 0),
(3658,'PALATOPHARYNGOPLASTY','PALATOPHARYNGOPLASTY','42145','1','','1','0','','','',0, 1, 0, 0),
(3659,'DSTRJ LESION PALATE/UVULA THERMAL CRYO/CHEM','DSTRJ LESION PALATE/UVULA THERMAL CRYO/CHEM','42160','1','','1','0','','','',0, 1, 0, 0),
(3660,'REPAIR LACERATION PALATE </2 CM','REPAIR LACERATION PALATE </2 CM','42180','1','','1','0','','','',0, 1, 0, 0),
(3661,'REPAIR LACERATION PALATE >2 CM/COMPLEX','REPAIR LACERATION PALATE >2 CM/COMPLEX','42182','1','','1','0','','','',0, 1, 0, 0),
(3662,'PALATOP CL PALATE SOFT&/HARD PALATE ONLY','PALATOP CL PALATE SOFT&/HARD PALATE ONLY','42200','1','','1','0','','','',0, 1, 0, 0),
(3663,'PALATOPLASTY W/CLSR ALVEOLAR RIDGE SOFT TISSUE','PALATOPLASTY W/CLSR ALVEOLAR RIDGE SOFT TISSUE','42205','1','','1','0','','','',0, 1, 0, 0),
(3664,'PALATOP CLSR ALVEOLAR RIDGE GRF ALVEOLAR RIDGE','PALATOP CLSR ALVEOLAR RIDGE GRF ALVEOLAR RIDGE','42210','1','','1','0','','','',0, 1, 0, 0),
(3665,'PALATOPLASTY CLEFT PALATE MAJOR REVJ','PALATOPLASTY CLEFT PALATE MAJOR REVJ','42215','1','','1','0','','','',0, 1, 0, 0),
(3666,'PALATOPLASTY CLEFT PALATE SEC LNGTH PX','PALATOPLASTY CLEFT PALATE SEC LNGTH PX','42220','1','','1','0','','','',0, 1, 0, 0),
(3667,'PALATOP CL PALATE ATTACHMENT PHARYNGEAL FLAP','PALATOP CL PALATE ATTACHMENT PHARYNGEAL FLAP','42225','1','','1','0','','','',0, 1, 0, 0),
(3668,'LENGTHENING PALATE & PHARYNGEAL FLAP','LENGTHENING PALATE & PHARYNGEAL FLAP','42226','1','','1','0','','','',0, 1, 0, 0),
(3669,'LENGTHENING PALATE W/ISLAND FLAP','LENGTHENING PALATE W/ISLAND FLAP','42227','1','','1','0','','','',0, 1, 0, 0),
(3670,'REPAIR ANTERIOR PALATE W/VOMER FLAP','REPAIR ANTERIOR PALATE W/VOMER FLAP','42235','1','','1','0','','','',0, 1, 0, 0),
(3671,'REPAIR NASOLABIAL FISTULA','REPAIR NASOLABIAL FISTULA','42260','1','','1','0','','','',0, 1, 0, 0),
(3672,'MAXILLARY IMPRESJ PALATAL PROSTHESIS','MAXILLARY IMPRESJ PALATAL PROSTHESIS','42280','1','','1','0','','','',0, 1, 0, 0),
(3673,'INSJ PIN-RETAINED PALATAL PROSTHESIS','INSJ PIN-RETAINED PALATAL PROSTHESIS','42281','1','','1','0','','','',0, 1, 0, 0),
(3674,'UNLISTED PROCEDURE PALATE UVULA','UNLISTED PROCEDURE PALATE UVULA','42299','1','','1','0','','','',0, 1, 0, 0),
(3675,'DRAINAGE ABSCESS PAROTID SIMPLE','DRAINAGE ABSCESS PAROTID SIMPLE','42300','1','','1','0','','','',0, 1, 0, 0),
(3676,'DRAINAGE ABSCESS PAROTID COMPLICATED','DRAINAGE ABSCESS PAROTID COMPLICATED','42305','1','','1','0','','','',0, 1, 0, 0),
(3677,'DRG ABSC SUBMAXILLARY/SUBLINGUAL INTRAORAL','DRG ABSC SUBMAXILLARY/SUBLINGUAL INTRAORAL','42310','1','','1','0','','','',0, 1, 0, 0),
(3678,'DRAINAGE ABSCESS SUBMAXILLARY INTRAORAL','DRAINAGE ABSCESS SUBMAXILLARY INTRAORAL','42320','1','','1','0','','','',0, 1, 0, 0),
(3679,'SIALOT SUBMNDBLR SUBLNGL/PRTD UNCOMP INTRAORAL','SIALOT SUBMNDBLR SUBLNGL/PRTD UNCOMP INTRAORAL','42330','1','','1','0','','','',0, 1, 0, 0),
(3680,'SIALOLITHOTOMY SUBMNDBLR SUBMAX COMP INTRAORAL','SIALOLITHOTOMY SUBMNDBLR SUBMAX COMP INTRAORAL','42335','1','','1','0','','','',0, 1, 0, 0),
(3681,'SIALOLITHOTOMY PRTD XTRORAL/COMP INTRAORAL','SIALOLITHOTOMY PRTD XTRORAL/COMP INTRAORAL','42340','1','','1','0','','','',0, 1, 0, 0),
(3682,'BIOPSY SALIVARY GLAND NEEDLE','BIOPSY SALIVARY GLAND NEEDLE','42400','1','','1','0','','','',0, 1, 0, 0),
(3683,'BIOPSY SALIVARY GLAND INCISIONAL','BIOPSY SALIVARY GLAND INCISIONAL','42405','1','','1','0','','','',0, 1, 0, 0),
(3684,'EXC SUBLINGUAL SALIVARY CYST RANULA','EXC SUBLINGUAL SALIVARY CYST RANULA','42408','1','','1','0','','','',0, 1, 0, 0),
(3685,'MARSUPIALIZATION SUBLNGL SALIVARY CST RANULA','MARSUPIALIZATION SUBLNGL SALIVARY CST RANULA','42409','1','','1','0','','','',0, 1, 0, 0),
(3686,'EXC PRTD TUM/PRTD GLND LAT LOBE W/O NRV DSJ','EXC PRTD TUM/PRTD GLND LAT LOBE W/O NRV DSJ','42410','1','','1','0','','','',0, 1, 0, 0),
(3687,'EXC PRTD TUM/PRTD GLND LAT DSJ&PRSRV FACIAL NR','EXC PRTD TUM/PRTD GLND LAT DSJ&PRSRV FACIAL NR','42415','1','','1','0','','','',0, 1, 0, 0),
(3688,'EXC PRTD TUM/PRTD GLND TOT DSJ&PRSRV FACIAL NR','EXC PRTD TUM/PRTD GLND TOT DSJ&PRSRV FACIAL NR','42420','1','','1','0','','','',0, 1, 0, 0),
(3689,'EXCISION PAROTID TUMOR/GLAND TOTAL EN BLOC RMVL','EXCISION PAROTID TUMOR/GLAND TOTAL EN BLOC RMVL','42425','1','','1','0','','','',0, 1, 0, 0),
(3690,'EXC PRTD TUM/PRTD GLND TOT W/UNI RAD NCK DSJ','EXC PRTD TUM/PRTD GLND TOT W/UNI RAD NCK DSJ','42426','1','','1','0','','','',0, 1, 0, 0),
(3691,'EXCISION SUBMANDIBULAR SUBMAXILLARY GLAND','EXCISION SUBMANDIBULAR SUBMAXILLARY GLAND','42440','1','','1','0','','','',0, 1, 0, 0),
(3692,'EXISION OF SUBLINGUAL GLAND','EXISION OF SUBLINGUAL GLAND','42450','1','','1','0','','','',0, 1, 0, 0),
(3693,'PLSTC RPR SALIVARY DUX SIALODOCHOPLASTY PRIM','PLSTC RPR SALIVARY DUX SIALODOCHOPLASTY PRIM','42500','1','','1','0','','','',0, 1, 0, 0),
(3694,'PLSTC RPR SALIVARY DUX SIALODOCHOPLASTY SEC/COMP','PLSTC RPR SALIVARY DUX SIALODOCHOPLASTY SEC/COMP','42505','1','','1','0','','','',0, 1, 0, 0),
(3695,'PAROTID DUCT DIVERSION BILATERAL WILKE PX','PAROTID DUCT DIVERSION BILATERAL WILKE PX','42507','1','','1','0','','','',0, 1, 0, 0),
(3696,'PAROTID DUCT DVRJ BI W/EXC BOTH SUBMNDBLR GLANDS','PAROTID DUCT DVRJ BI W/EXC BOTH SUBMNDBLR GLANDS','42509','1','','1','0','','','',0, 1, 0, 0),
(3697,'PAROTID DUCT DVRJ BILATERAL WITH LIG BOTH DUCTS','PAROTID DUCT DVRJ BILATERAL WITH LIG BOTH DUCTS','42510','1','','1','0','','','',0, 1, 0, 0),
(3698,'INJECTION PROCEDURE SIALOGRAPHY','INJECTION PROCEDURE SIALOGRAPHY','42550','1','','1','0','','','',0, 1, 0, 0),
(3699,'CLOSURE SALIVARY FISTULA','CLOSURE SALIVARY FISTULA','42600','1','','1','0','','','',0, 1, 0, 0),
(3700,'DILATION SALIVARY DUCT','DILATION SALIVARY DUCT','42650','1','','1','0','','','',0, 1, 0, 0),
(3701,'DILAT&CATHJ SALIVARY DUCT W/WO INJECTION','DILAT&CATHJ SALIVARY DUCT W/WO INJECTION','42660','1','','1','0','','','',0, 1, 0, 0),
(3702,'LIGATION SALIVARY DUCT INTRAORAL','LIGATION SALIVARY DUCT INTRAORAL','42665','1','','1','0','','','',0, 1, 0, 0),
(3703,'UNLISTED PX SALIVARY GLANDS/DUCTS','UNLISTED PX SALIVARY GLANDS/DUCTS','42699','1','','1','0','','','',0, 1, 0, 0),
(3704,'I&D ABSCESS PERITONSILLAR','I&D ABSCESS PERITONSILLAR','42700','1','','1','0','','','',0, 1, 0, 0),
(3705,'I&D ABSC RTRPHRNGL/PARAPHARYNGEAL INTRAORAL','I&D ABSC RTRPHRNGL/PARAPHARYNGEAL INTRAORAL','42720','1','','1','0','','','',0, 1, 0, 0),
(3706,'I&D ABSC RTRPHRNGL/PARAPHARYNGEAL XTRNL APPR','I&D ABSC RTRPHRNGL/PARAPHARYNGEAL XTRNL APPR','42725','1','','1','0','','','',0, 1, 0, 0),
(3707,'BIOPSY OROPHARYNX','BIOPSY OROPHARYNX','42800','1','','1','0','','','',0, 1, 0, 0),
(3708,'BIOPSY NASOPHARYNX VISIBLE LESION SIMPLE','BIOPSY NASOPHARYNX VISIBLE LESION SIMPLE','42804','1','','1','0','','','',0, 1, 0, 0),
(3709,'BX NASOPHARYNX SURVEY UNKNOWN PRIMARY LESION','BX NASOPHARYNX SURVEY UNKNOWN PRIMARY LESION','42806','1','','1','0','','','',0, 1, 0, 0),
(3710,'EXCISION/DESTRUCTION LESION PHARYNX ANY METHOD','EXCISION/DESTRUCTION LESION PHARYNX ANY METHOD','42808','1','','1','0','','','',0, 1, 0, 0),
(3711,'REMOVAL FOREIGN BODY PHARYNX','REMOVAL FOREIGN BODY PHARYNX','42809','1','','1','0','','','',0, 1, 0, 0),
(3712,'EXC BRANCHIAL CLEFT CYST CONFINED SKN&SUBQ TIS','EXC BRANCHIAL CLEFT CYST CONFINED SKN&SUBQ TIS','42810','1','','1','0','','','',0, 1, 0, 0),
(3713,'EXC BRANCHIAL CLEFT CYST BELOW SUBQ TISS&/PHRYNX','EXC BRANCHIAL CLEFT CYST BELOW SUBQ TISS&/PHRYNX','42815','1','','1','0','','','',0, 1, 0, 0),
(3714,'TONSILLECTOMY & ADENOIDECTOMY <AGE 12','TONSILLECTOMY & ADENOIDECTOMY <AGE 12','42820','1','','1','0','','','',0, 1, 0, 0),
(3715,'TONSILLECTOMY & ADENOIDECTOMY AGE 12/>','TONSILLECTOMY & ADENOIDECTOMY AGE 12/>','42821','1','','1','0','','','',0, 1, 0, 0),
(3716,'TONSILLECTOMY ONE-HALF <AGE 12','TONSILLECTOMY ONE-HALF <AGE 12','42825','1','','1','0','','','',0, 1, 0, 0),
(3717,'TONSILLECTOMY ONE-HALF AGE 12/>','TONSILLECTOMY ONE-HALF AGE 12/>','42826','1','','1','0','','','',0, 1, 0, 0),
(3718,'ADENOIDECTOMY PRIMARY <AGE 12','ADENOIDECTOMY PRIMARY <AGE 12','42830','1','','1','0','','','',0, 1, 0, 0),
(3719,'ADENOIDECTOMY PRIMARY AGE 12/>','ADENOIDECTOMY PRIMARY AGE 12/>','42831','1','','1','0','','','',0, 1, 0, 0),
(3720,'ADENOIDECTOMY SECONDARY<AGE 12','ADENOIDECTOMY SECONDARY<AGE 12','42835','1','','1','0','','','',0, 1, 0, 0),
(3721,'ADENOIDECTOMY SECONDARY AGE 12/>','ADENOIDECTOMY SECONDARY AGE 12/>','42836','1','','1','0','','','',0, 1, 0, 0),
(3722,'RADICAL RESECTION TONSIL W/O CLOSURE','RADICAL RESECTION TONSIL W/O CLOSURE','42842','1','','1','0','','','',0, 1, 0, 0),
(3723,'RADICAL RESCJ TONSIL CLOSURE W/LOCAL FLAP','RADICAL RESCJ TONSIL CLOSURE W/LOCAL FLAP','42844','1','','1','0','','','',0, 1, 0, 0),
(3724,'RADICAL RESCJ TONSIL CLOSURE W/OTHER FLAP','RADICAL RESCJ TONSIL CLOSURE W/OTHER FLAP','42845','1','','1','0','','','',0, 1, 0, 0),
(3725,'EXCISION TONSIL TAGS','EXCISION TONSIL TAGS','42860','1','','1','0','','','',0, 1, 0, 0),
(3726,'EXC/DSTRJ LINGUAL TONSIL ANY METHOD SPX','EXC/DSTRJ LINGUAL TONSIL ANY METHOD SPX','42870','1','','1','0','','','',0, 1, 0, 0),
(3727,'LIMITED PHARYNGECTOMY','LIMITED PHARYNGECTOMY','42890','1','','1','0','','','',0, 1, 0, 0),
(3728,'RESCJ LAT PHRNGL WALL/PYRIFORM SINUS DIR CLSR','RESCJ LAT PHRNGL WALL/PYRIFORM SINUS DIR CLSR','42892','1','','1','0','','','',0, 1, 0, 0),
(3729,'RESCJ PHRNGL WALL CLSR W/FLP OR FLP W/MVASC ANAS','RESCJ PHRNGL WALL CLSR W/FLP OR FLP W/MVASC ANAS','42894','1','','1','0','','','',0, 1, 0, 0),
(3730,'SUTURE PHARYNX WOUND/INJURY','SUTURE PHARYNX WOUND/INJURY','42900','1','','1','0','','','',0, 1, 0, 0),
(3731,'PHARYNGOPLASTY PLSTC/RCNSTV OPRATION PHARYNX','PHARYNGOPLASTY PLSTC/RCNSTV OPRATION PHARYNX','42950','1','','1','0','','','',0, 1, 0, 0),
(3732,'PHARYNGOESOPHAGEAL REPAIR','PHARYNGOESOPHAGEAL REPAIR','42953','1','','1','0','','','',0, 1, 0, 0),
(3733,'PHARYNGOSTOMY FSTLJ PHARYNX XTRNL FEEDING','PHARYNGOSTOMY FSTLJ PHARYNX XTRNL FEEDING','42955','1','','1','0','','','',0, 1, 0, 0),
(3734,'CONTROL OROPHARYNGEAL HEMORRHAGE SIMPLE','CONTROL OROPHARYNGEAL HEMORRHAGE SIMPLE','42960','1','','1','0','','','',0, 1, 0, 0),
(3735,'CTRL OROPHARYNGEAL HEMORRHAGE COMP REQ HOSPITJ','CTRL OROPHARYNGEAL HEMORRHAGE COMP REQ HOSPITJ','42961','1','','1','0','','','',0, 1, 0, 0),
(3736,'CTRL OROPHARYNGEAL HEMORRHAGE W/SEC SURG IVNTJ','CTRL OROPHARYNGEAL HEMORRHAGE W/SEC SURG IVNTJ','42962','1','','1','0','','','',0, 1, 0, 0),
(3737,'CTRL NASOPHARYNGEAL HEMRRG SMPL W/PST NSL PACKS','CTRL NASOPHARYNGEAL HEMRRG SMPL W/PST NSL PACKS','42970','1','','1','0','','','',0, 1, 0, 0),
(3738,'CTRL NASOPHARYNGEAL HEMRRG COMP REQ HOSPIZATION','CTRL NASOPHARYNGEAL HEMRRG COMP REQ HOSPIZATION','42971','1','','1','0','','','',0, 1, 0, 0),
(3739,'CTRL NASOPHARYNGEAL HEMORRHAGE W/SEC SURG IVNTJ','CTRL NASOPHARYNGEAL HEMORRHAGE W/SEC SURG IVNTJ','42972','1','','1','0','','','',0, 1, 0, 0),
(3740,'UNLISTED PROCEDURE PHARYNX ADENOIDS/TONSILS','UNLISTED PROCEDURE PHARYNX ADENOIDS/TONSILS','42999','1','','1','0','','','',0, 1, 0, 0),
(3741,'ESOPHAGOTOMY CERVICAL APPR W/RMVL FB','ESOPHAGOTOMY CERVICAL APPR W/RMVL FB','43020','1','','1','0','','','',0, 1, 0, 0),
(3742,'CRICOPHARYNGEAL MYOTOMY','CRICOPHARYNGEAL MYOTOMY','43030','1','','1','0','','','',0, 1, 0, 0),
(3743,'ESOPHAGOTOMY THORACIC APPR W/RMVL FB','ESOPHAGOTOMY THORACIC APPR W/RMVL FB','43045','1','','1','0','','','',0, 1, 0, 0),
(3744,'EXC LESION ESOPHOGUS W/PRIM RPR CERVICAL APPR','EXC LESION ESOPHOGUS W/PRIM RPR CERVICAL APPR','43100','1','','1','0','','','',0, 1, 0, 0),
(3745,'EXC LESION ESOPHAGUS W/PRIM RPR THRC/ABDL APPR','EXC LESION ESOPHAGUS W/PRIM RPR THRC/ABDL APPR','43101','1','','1','0','','','',0, 1, 0, 0),
(3746,'TOT ESOPHAGECTOMY W/O THORCOM W/WO PYLOROPLASTY','TOT ESOPHAGECTOMY W/O THORCOM W/WO PYLOROPLASTY','43107','1','','1','0','','','',0, 1, 0, 0),
(3747,'TOT ESOPHG W/O THORCOM COLON NTRPSTJ/INT RCNSTJ','TOT ESOPHG W/O THORCOM COLON NTRPSTJ/INT RCNSTJ','43108','1','','1','0','','','',0, 1, 0, 0),
(3748,'TOTAL ESOPHAGECTOMY W/THORCOM W/WO PYLORPLASTY','TOTAL ESOPHAGECTOMY W/THORCOM W/WO PYLORPLASTY','43112','1','','1','0','','','',0, 1, 0, 0),
(3749,'TOT ESOPHG W/THORCOM W/COLON NTRPSTJ/INT RCNSTJ','TOT ESOPHG W/THORCOM W/COLON NTRPSTJ/INT RCNSTJ','43113','1','','1','0','','','',0, 1, 0, 0),
(3750,'PRTL ESOPHAGECTOMY CERVICAL W/FREE INTSTINAL GRF','PRTL ESOPHAGECTOMY CERVICAL W/FREE INTSTINAL GRF','43116','1','','1','0','','','',0, 1, 0, 0),
(3751,'PRTL ESOPHECT DSTL W/WO PROX GASTRECT/PYLORPLSTY','PRTL ESOPHECT DSTL W/WO PROX GASTRECT/PYLORPLSTY','43117','1','','1','0','','','',0, 1, 0, 0),
(3752,'PRTL ESOPH DSTL W/WO PROX GASTRC W/COLON NTRPSTJ','PRTL ESOPH DSTL W/WO PROX GASTRC W/COLON NTRPSTJ','43118','1','','1','0','','','',0, 1, 0, 0),
(3753,'PRTL ESOPHAGEC W/WO PROX GASTREC/PYLOROPLASTY','PRTL ESOPHAGEC W/WO PROX GASTREC/PYLOROPLASTY','43121','1','','1','0','','','',0, 1, 0, 0),
(3754,'PRTL ESOPHG THORACOABD W/WO PROXGASTREC/PYLOROPL','PRTL ESOPHG THORACOABD W/WO PROXGASTREC/PYLOROPL','43122','1','','1','0','','','',0, 1, 0, 0),
(3755,'PRTL ESPHG THORACOABDL/ABDL APPR NTRPSTJ/RCNSTJ','PRTL ESPHG THORACOABDL/ABDL APPR NTRPSTJ/RCNSTJ','43123','1','','1','0','','','',0, 1, 0, 0),
(3756,'TOT/PRTL ESPHG W/O RCNSTJ W/CRV ESOPHAGOSTOMY','TOT/PRTL ESPHG W/O RCNSTJ W/CRV ESOPHAGOSTOMY','43124','1','','1','0','','','',0, 1, 0, 0),
(3757,'DIVERTICULECTOMY HYPOPHARYNX/ESOPH CRV APPR','DIVERTICULECTOMY HYPOPHARYNX/ESOPH CRV APPR','43130','1','','1','0','','','',0, 1, 0, 0),
(3758,'DIVERTICULECTOMY HYPOPHARYNX/ESOPH THRC APPR','DIVERTICULECTOMY HYPOPHARYNX/ESOPH THRC APPR','43135','1','','1','0','','','',0, 1, 0, 0),
(3759,'ESOPHAGOSCP RIG TRANSORAL HYPOPHARYNX CRV ESOPH','ESOPHAGOSCP RIG TRANSORAL HYPOPHARYNX CRV ESOPH','43180','1','','1','0','','','',0, 1, 0, 0),
(3760,'ESOPHAGOSCOPY RIGID TRANSORAL DIAGNOSTIC BRUSH','ESOPHAGOSCOPY RIGID TRANSORAL DIAGNOSTIC BRUSH','43191','1','','1','0','','','',0, 1, 0, 0),
(3761,'ESOPHAGOSCOPY RIGID TRANSORAL INJ SUBMUCOSAL','ESOPHAGOSCOPY RIGID TRANSORAL INJ SUBMUCOSAL','43192','1','','1','0','','','',0, 1, 0, 0),
(3762,'ESOPHAGOSCOPY RIGID TRANSORAL WITH BIOPSY','ESOPHAGOSCOPY RIGID TRANSORAL WITH BIOPSY','43193','1','','1','0','','','',0, 1, 0, 0),
(3763,'ESOPHAGOSCOPY RIG TRANSORAL REMOVAL FOREIGN BODY','ESOPHAGOSCOPY RIG TRANSORAL REMOVAL FOREIGN BODY','43194','1','','1','0','','','',0, 1, 0, 0),
(3764,'ESOPHAGOSCOPY RIGID TRANSORAL BALLOON DILATION','ESOPHAGOSCOPY RIGID TRANSORAL BALLOON DILATION','43195','1','','1','0','','','',0, 1, 0, 0),
(3765,'ESOPHAGOSCOPY RIG TRANSORAL GUIDE WIRE DILATION','ESOPHAGOSCOPY RIG TRANSORAL GUIDE WIRE DILATION','43196','1','','1','0','','','',0, 1, 0, 0),
(3766,'ESOPHAGOSCOPY FLEXIBLE TRANSNASAL DIAGNOSTIC','ESOPHAGOSCOPY FLEXIBLE TRANSNASAL DIAGNOSTIC','43197','1','','1','0','','','',0, 1, 0, 0),
(3767,'ESOPHAGOSCOPY FLEXIBLE TRANSNASAL WITH BIOPSY','ESOPHAGOSCOPY FLEXIBLE TRANSNASAL WITH BIOPSY','43198','1','','1','0','','','',0, 1, 0, 0),
(3768,'ESOPHAGOSCOPY FLEXIBLE TRANSORAL DIAGNOSTIC','ESOPHAGOSCOPY FLEXIBLE TRANSORAL DIAGNOSTIC','43200','1','','1','0','','','',0, 1, 0, 0),
(3769,'ESOPHAGOSCOPY FLEXIBLE TRANSORAL W SUBMUCOUS INJ','ESOPHAGOSCOPY FLEXIBLE TRANSORAL W SUBMUCOUS INJ','43201','1','','1','0','','','',0, 1, 0, 0),
(3770,'ESOPHAGOSCOPY FLEXIBLE TRANSORAL WITH BIOPSY','ESOPHAGOSCOPY FLEXIBLE TRANSORAL WITH BIOPSY','43202','1','','1','0','','','',0, 1, 0, 0),
(3771,'ESOPHAGOSCOPY FLEX TRANSORAL INJECTION VARICES','ESOPHAGOSCOPY FLEX TRANSORAL INJECTION VARICES','43204','1','','1','0','','','',0, 1, 0, 0),
(3772,'ESPHGOSCOPY FLEX W/BAND LIGATION ESOPHGL VARICES','ESPHGOSCOPY FLEX W/BAND LIGATION ESOPHGL VARICES','43205','1','','1','0','','','',0, 1, 0, 0),
(3773,'ESOPHAGOSCOPY TRANSORAL W/OPTICAL ENDOMICROSCOPY','ESOPHAGOSCOPY TRANSORAL W/OPTICAL ENDOMICROSCOPY','43206','1','','1','0','','','',0, 1, 0, 0),
(3774,'EGD PARTIAL/COMPL ESOPHAGOGASTRIC FUNDOPLASTY','EGD PARTIAL/COMPL ESOPHAGOGASTRIC FUNDOPLASTY','43210','1','','1','0','','','',0, 1, 0, 0),
(3775,'ESOPHAGOSCOPY FLEXIBLE TRANSORAL MUCOSAL RESEXN','ESOPHAGOSCOPY FLEXIBLE TRANSORAL MUCOSAL RESEXN','43211','1','','1','0','','','',0, 1, 0, 0),
(3776,'ESOPHAGOSCOPY TRANSORAL STENT PLACEMENT','ESOPHAGOSCOPY TRANSORAL STENT PLACEMENT','43212','1','','1','0','','','',0, 1, 0, 0),
(3777,'ESOPHAGOSCOPY RETROGRADE DILATE BALLOON/OTHER','ESOPHAGOSCOPY RETROGRADE DILATE BALLOON/OTHER','43213','1','','1','0','','','',0, 1, 0, 0),
(3778,'ESOPHAGOSCOPY DILATE ESOPHAGUS BALLOON 30 MM','ESOPHAGOSCOPY DILATE ESOPHAGUS BALLOON 30 MM','43214','1','','1','0','','','',0, 1, 0, 0),
(3779,'ESOPHAGOSCOPY FLEXIBLE REMOVAL FOREIGN BODY','ESOPHAGOSCOPY FLEXIBLE REMOVAL FOREIGN BODY','43215','1','','1','0','','','',0, 1, 0, 0),
(3780,'ESPHAGOSCOPY FLEX LESION REMOVAL HOT BX FORCEPS','ESPHAGOSCOPY FLEX LESION REMOVAL HOT BX FORCEPS','43216','1','','1','0','','','',0, 1, 0, 0),
(3781,'ESOPHAGOSCOPY FLEXIB LESION REMOVAL TUMOR SNARE','ESOPHAGOSCOPY FLEXIB LESION REMOVAL TUMOR SNARE','43217','1','','1','0','','','',0, 1, 0, 0),
(3782,'ESOPHAGOSCOPY FLEX BALLOON DILAT <30 MM DIAM','ESOPHAGOSCOPY FLEX BALLOON DILAT <30 MM DIAM','43220','1','','1','0','','','',0, 1, 0, 0),
(3783,'ESOPHAGOSCOPY FLEXIBLE GUIDE WIRE DILATION','ESOPHAGOSCOPY FLEXIBLE GUIDE WIRE DILATION','43226','1','','1','0','','','',0, 1, 0, 0),
(3784,'ESOPHAGOSCOPY FLEXIBLE W/BLEEDING CONTROL','ESOPHAGOSCOPY FLEXIBLE W/BLEEDING CONTROL','43227','1','','1','0','','','',0, 1, 0, 0),
(3785,'ESOPHAGOSCOPY FLEX TRANSORAL LESION ABLATION','ESOPHAGOSCOPY FLEX TRANSORAL LESION ABLATION','43229','1','','1','0','','','',0, 1, 0, 0),
(3786,'ESOPHAGOSCOPY FLEXIBLE TRANSORAL ULTRASOUND EXAM','ESOPHAGOSCOPY FLEXIBLE TRANSORAL ULTRASOUND EXAM','43231','1','','1','0','','','',0, 1, 0, 0),
(3787,'ESOPHAGOSCOPY INTRA/TRANSMURAL NEEDLE ASPIRAT/BX','ESOPHAGOSCOPY INTRA/TRANSMURAL NEEDLE ASPIRAT/BX','43232','1','','1','0','','','',0, 1, 0, 0),
(3788,'EGD ESOPHAGUS BALLOON DILATION 30 MM OR LARGER','EGD ESOPHAGUS BALLOON DILATION 30 MM OR LARGER','43233','1','','1','0','','','',0, 1, 0, 0),
(3789,'ESOPHAGOGASTRODUODENOSCOPY TRANSORAL DIAGNOSTIC','ESOPHAGOGASTRODUODENOSCOPY TRANSORAL DIAGNOSTIC','43235','1','','1','0','','','',0, 1, 0, 0),
(3790,'ESOPHAGOGASTRODUODENOSCOPY SUBMUCOSAL INJECTION','ESOPHAGOGASTRODUODENOSCOPY SUBMUCOSAL INJECTION','43236','1','','1','0','','','',0, 1, 0, 0),
(3791,'ESOPHAGOGASTRODUODENOSCOPY US SCOPE W/ADJ STRXRS','ESOPHAGOGASTRODUODENOSCOPY US SCOPE W/ADJ STRXRS','43237','1','','1','0','','','',0, 1, 0, 0),
(3792,'EGD INTRMURAL US NEEDLE ASPIRATE/BIOPSY ESOPHAGS','EGD INTRMURAL US NEEDLE ASPIRATE/BIOPSY ESOPHAGS','43238','1','','1','0','','','',0, 1, 0, 0),
(3793,'EGD TRANSORAL BIOPSY SINGLE/MULTIPLE','EGD TRANSORAL BIOPSY SINGLE/MULTIPLE','43239','1','','1','0','','','',0, 1, 0, 0),
(3794,'EGD TRANSORAL TRANSMURAL DRAINAGE PSEUDOCYST','EGD TRANSORAL TRANSMURAL DRAINAGE PSEUDOCYST','43240','1','','1','0','','','',0, 1, 0, 0),
(3795,'EGD INTRALUMINAL TUBE/CATHETER INSERTION','EGD INTRALUMINAL TUBE/CATHETER INSERTION','43241','1','','1','0','','','',0, 1, 0, 0),
(3796,'EGD INTRMURAL NEEDLE ASPIR/BIOP ALTERED ANATOMY','EGD INTRMURAL NEEDLE ASPIR/BIOP ALTERED ANATOMY','43242','1','','1','0','','','',0, 1, 0, 0),
(3797,'EGD INJECTION SCLEROSIS ESOPHGL/GASTRIC VARICES','EGD INJECTION SCLEROSIS ESOPHGL/GASTRIC VARICES','43243','1','','1','0','','','',0, 1, 0, 0),
(3798,'EGD BAND LIGATION ESOPHGEAL/GASTRIC VARICES','EGD BAND LIGATION ESOPHGEAL/GASTRIC VARICES','43244','1','','1','0','','','',0, 1, 0, 0),
(3799,'EGD DILATION GASTRIC/DUODENAL STRICTURE','EGD DILATION GASTRIC/DUODENAL STRICTURE','43245','1','','1','0','','','',0, 1, 0, 0),
(3800,'EGD PERCUTANEOUS PLACEMENT GASTROSTOMY TUBE','EGD PERCUTANEOUS PLACEMENT GASTROSTOMY TUBE','43246','1','','1','0','','','',0, 1, 0, 0),
(3801,'EGD FLEXIBLE FOREIGN BODY REMOVAL','EGD FLEXIBLE FOREIGN BODY REMOVAL','43247','1','','1','0','','','',0, 1, 0, 0),
(3802,'EGD INSERT GUIDE WIRE DILATOR PASSAGE ESOPHAGUS','EGD INSERT GUIDE WIRE DILATOR PASSAGE ESOPHAGUS','43248','1','','1','0','','','',0, 1, 0, 0),
(3803,'EGD BALLOON DILATION ESOPHAGUS <30 MM DIAM','EGD BALLOON DILATION ESOPHAGUS <30 MM DIAM','43249','1','','1','0','','','',0, 1, 0, 0),
(3804,'EGD FLEX REMOVAL LESION(S) BY HOT BIOPSY FORCEPS','EGD FLEX REMOVAL LESION(S) BY HOT BIOPSY FORCEPS','43250','1','','1','0','','','',0, 1, 0, 0),
(3805,'EGD REMOVAL TUMOR POLYP/OTHER LESION SNARE TECH','EGD REMOVAL TUMOR POLYP/OTHER LESION SNARE TECH','43251','1','','1','0','','','',0, 1, 0, 0),
(3806,'EGD FLEX TRANSORAL W/OPTICAL ENDOMICROSCOPY','EGD FLEX TRANSORAL W/OPTICAL ENDOMICROSCOPY','43252','1','','1','0','','','',0, 1, 0, 0),
(3807,'EGD US GUIDED TRANSMURAL INJXN/FIDUCIAL MARKER','EGD US GUIDED TRANSMURAL INJXN/FIDUCIAL MARKER','43253','1','','1','0','','','',0, 1, 0, 0),
(3808,'EGD TRANSORAL ENDOSCOPIC MUCOSAL RESECTION','EGD TRANSORAL ENDOSCOPIC MUCOSAL RESECTION','43254','1','','1','0','','','',0, 1, 0, 0),
(3809,'EGD TRANSORAL CONTROL BLEEDING ANY METHOD','EGD TRANSORAL CONTROL BLEEDING ANY METHOD','43255','1','','1','0','','','',0, 1, 0, 0),
(3810,'EGD DELIVER THERMAL ENERGY SPHNCTR/CARDIA GERD','EGD DELIVER THERMAL ENERGY SPHNCTR/CARDIA GERD','43257','1','','1','0','','','',0, 1, 0, 0),
(3811,'EDG US EXAM SURGICAL ALTER STOM DUODENUM/JEJUNUM','EDG US EXAM SURGICAL ALTER STOM DUODENUM/JEJUNUM','43259','1','','1','0','','','',0, 1, 0, 0),
(3812,'ERCP DX COLLECTION SPECIMEN BRUSHING/WASHING','ERCP DX COLLECTION SPECIMEN BRUSHING/WASHING','43260','1','','1','0','','','',0, 1, 0, 0),
(3813,'ERCP W/BIOPSY SINGLE/MULTIPLE','ERCP W/BIOPSY SINGLE/MULTIPLE','43261','1','','1','0','','','',0, 1, 0, 0),
(3814,'ERCP W/SPHINCTEROTOMY/PAPILLOTOMY','ERCP W/SPHINCTEROTOMY/PAPILLOTOMY','43262','1','','1','0','','','',0, 1, 0, 0),
(3815,'ERCP W/PRESSURE MEASUREMENT SPHINCTER OF ODDI','ERCP W/PRESSURE MEASUREMENT SPHINCTER OF ODDI','43263','1','','1','0','','','',0, 1, 0, 0),
(3816,'ERCP REMOVE CALCULI/DEBRIS BILIARY/PANCREAS DUCT','ERCP REMOVE CALCULI/DEBRIS BILIARY/PANCREAS DUCT','43264','1','','1','0','','','',0, 1, 0, 0),
(3817,'ERCP DESTRUCTION/LITHOTRIPSY CALCULI ANY METHOD','ERCP DESTRUCTION/LITHOTRIPSY CALCULI ANY METHOD','43265','1','','1','0','','','',0, 1, 0, 0),
(3818,'EGD ENDOSCOPIC STENT PLACEMENT W/WIRE& DILATION','EGD ENDOSCOPIC STENT PLACEMENT W/WIRE& DILATION','43266','1','','1','0','','','',0, 1, 0, 0),
(3819,'EGD ABLATE TUMOR POLYP/LESION W/DILATION& WIRE','EGD ABLATE TUMOR POLYP/LESION W/DILATION& WIRE','43270','1','','1','0','','','',0, 1, 0, 0),
(3820,'ENDOSCOPIC PAPILLA CANNULATION BILE/PANCREATIC','ENDOSCOPIC PAPILLA CANNULATION BILE/PANCREATIC','43273','1','','1','0','','','',0, 1, 0, 0),
(3821,'ERCP STENT PLACEMENT BILIARY/PANCREATIC DUCT','ERCP STENT PLACEMENT BILIARY/PANCREATIC DUCT','43274','1','','1','0','','','',0, 1, 0, 0),
(3822,'ERCP REMOVE FOREIGN BODY/STENT BILIARY/PANC DUCT','ERCP REMOVE FOREIGN BODY/STENT BILIARY/PANC DUCT','43275','1','','1','0','','','',0, 1, 0, 0),
(3823,'ERCP BILIARY/PANC DUCT STENT EXCHANGE W/DIL&WIRE','ERCP BILIARY/PANC DUCT STENT EXCHANGE W/DIL&WIRE','43276','1','','1','0','','','',0, 1, 0, 0),
(3824,'ERCP BALLOON DILATE BILIARY/PANC DUCT/AMPULLA EA','ERCP BALLOON DILATE BILIARY/PANC DUCT/AMPULLA EA','43277','1','','1','0','','','',0, 1, 0, 0),
(3825,'ERCP TUMOR/POLYP/LESION ABLATION W/DILATION&WIRE','ERCP TUMOR/POLYP/LESION ABLATION W/DILATION&WIRE','43278','1','','1','0','','','',0, 1, 0, 0),
(3826,'LAPS ESOPHAGOMYOTOMY W/FUNDOPLASTY IF PERFORMED','LAPS ESOPHAGOMYOTOMY W/FUNDOPLASTY IF PERFORMED','43279','1','','1','0','','','',0, 1, 0, 0),
(3827,'LAPS SURG ESOPG/GSTR FUNDOPLASTY','LAPS SURG ESOPG/GSTR FUNDOPLASTY','43280','1','','1','0','','','',0, 1, 0, 0),
(3828,'LAPS RPR PARAESPHGL HRNA INCL FUNDPLSTY W/O MESH','LAPS RPR PARAESPHGL HRNA INCL FUNDPLSTY W/O MESH','43281','1','','1','0','','','',0, 1, 0, 0),
(3829,'LAPS RPR PARAESPHGL HRNA INCL FUNDPLSTY W/MESH','LAPS RPR PARAESPHGL HRNA INCL FUNDPLSTY W/MESH','43282','1','','1','0','','','',0, 1, 0, 0),
(3830,'LAPS ESOPHAGEAL LENGTHENING ADDL','LAPS ESOPHAGEAL LENGTHENING ADDL','43283','1','','1','0','','','',0, 1, 0, 0),
(3831,'UNLISTED LAPAROSCOPIC PROCEDURE ESOPHAGUS','UNLISTED LAPAROSCOPIC PROCEDURE ESOPHAGUS','43289','1','','1','0','','','',0, 1, 0, 0),
(3832,'ESPHGP CRV APPR W/O RPR TRACHEOESOPHGL FSTL','ESPHGP CRV APPR W/O RPR TRACHEOESOPHGL FSTL','43300','1','','1','0','','','',0, 1, 0, 0),
(3833,'ESPHGP CRV APPR W/RPR TRACHEOESOPHGL FSTL','ESPHGP CRV APPR W/RPR TRACHEOESOPHGL FSTL','43305','1','','1','0','','','',0, 1, 0, 0),
(3834,'ESPHGP THRC APPR W/O RPR TRACHEOESOPHGL FSTL','ESPHGP THRC APPR W/O RPR TRACHEOESOPHGL FSTL','43310','1','','1','0','','','',0, 1, 0, 0),
(3835,'ESPHGP THRC APPR W/RPR TRACHEOESOPHGL FSTL','ESPHGP THRC APPR W/RPR TRACHEOESOPHGL FSTL','43312','1','','1','0','','','',0, 1, 0, 0),
(3836,'ESPHGP CGEN DFCT THRC APPR W/O RPR FSTL','ESPHGP CGEN DFCT THRC APPR W/O RPR FSTL','43313','1','','1','0','','','',0, 1, 0, 0),
(3837,'ESPHGP CGEN DFCT THRC APPR W/RPR FSTL','ESPHGP CGEN DFCT THRC APPR W/RPR FSTL','43314','1','','1','0','','','',0, 1, 0, 0),
(3838,'EGST W/WO VAGOTOMY&PYLOROPLASTY TABDL/TTHRC AP','EGST W/WO VAGOTOMY&PYLOROPLASTY TABDL/TTHRC AP','43320','1','','1','0','','','',0, 1, 0, 0),
(3839,'ESOPG/GSTR FUNDOPLASTY W/FUNDIC PATCH','ESOPG/GSTR FUNDOPLASTY W/FUNDIC PATCH','43325','1','','1','0','','','',0, 1, 0, 0),
(3840,'ESOPG/GSTR FUNDOPLASTY W/LAPAROTOMY','ESOPG/GSTR FUNDOPLASTY W/LAPAROTOMY','43327','1','','1','0','','','',0, 1, 0, 0),
(3841,'ESOPG/GSTR FUNDOPLASTY W/THORACOTOMY','ESOPG/GSTR FUNDOPLASTY W/THORACOTOMY','43328','1','','1','0','','','',0, 1, 0, 0),
(3842,'ESOPHAGOMYOTOMY HELLER TYPE ABDOMINAL APPROACH','ESOPHAGOMYOTOMY HELLER TYPE ABDOMINAL APPROACH','43330','1','','1','0','','','',0, 1, 0, 0),
(3843,'ESOPHAGOMYOTOMY HELLER TYPE THORACIC APPROACH','ESOPHAGOMYOTOMY HELLER TYPE THORACIC APPROACH','43331','1','','1','0','','','',0, 1, 0, 0),
(3844,'RPR PARAESOPH HIATAL HERNIA W/LAPT W/O MESH','RPR PARAESOPH HIATAL HERNIA W/LAPT W/O MESH','43332','1','','1','0','','','',0, 1, 0, 0),
(3845,'LAPT RPR PARAESOPH HIATAL HERNIA W/MESH','LAPT RPR PARAESOPH HIATAL HERNIA W/MESH','43333','1','','1','0','','','',0, 1, 0, 0),
(3846,'RPR PARAESOPH HIATAL HERNIA W/THORCOM W/O MESH','RPR PARAESOPH HIATAL HERNIA W/THORCOM W/O MESH','43334','1','','1','0','','','',0, 1, 0, 0),
(3847,'RPR PARAESOPH HIATAL HERNIA W/THORCOM W/MESH','RPR PARAESOPH HIATAL HERNIA W/THORCOM W/MESH','43335','1','','1','0','','','',0, 1, 0, 0),
(3848,'RPR PARAESOPH HIATAL HERNIA THORCOABDOM W/O MESH','RPR PARAESOPH HIATAL HERNIA THORCOABDOM W/O MESH','43336','1','','1','0','','','',0, 1, 0, 0),
(3849,'RPR PARAESOPH HIATAL HERNIA THORCOABDOM W/MESH','RPR PARAESOPH HIATAL HERNIA THORCOABDOM W/MESH','43337','1','','1','0','','','',0, 1, 0, 0),
(3850,'ESOPHAGUS LENGTHENING','ESOPHAGUS LENGTHENING','43338','1','','1','0','','','',0, 1, 0, 0),
(3851,'ESOPHAGOJEJUNOSTOMY W/O TOT GSTRCT ABDL APPR','ESOPHAGOJEJUNOSTOMY W/O TOT GSTRCT ABDL APPR','43340','1','','1','0','','','',0, 1, 0, 0),
(3852,'ESOPHAGOJEJUNOSTOMY W/O TOT GSTRCT THRC APPR','ESOPHAGOJEJUNOSTOMY W/O TOT GSTRCT THRC APPR','43341','1','','1','0','','','',0, 1, 0, 0),
(3853,'ESOPHAGOSTOMY FSTLJ ESOPH XTRNL THRC APPR','ESOPHAGOSTOMY FSTLJ ESOPH XTRNL THRC APPR','43351','1','','1','0','','','',0, 1, 0, 0),
(3854,'ESOPHAGOSTOMY FSTLJ ESOPH XTRNL CRV APPR','ESOPHAGOSTOMY FSTLJ ESOPH XTRNL CRV APPR','43352','1','','1','0','','','',0, 1, 0, 0),
(3855,'GI RCNSTJ PREV ESPHG/EXCLUSION W/STOMACH','GI RCNSTJ PREV ESPHG/EXCLUSION W/STOMACH','43360','1','','1','0','','','',0, 1, 0, 0),
(3856,'GI RCNSTJ PREV ESPHG/EXCLUSION W/COLON SM INT','GI RCNSTJ PREV ESPHG/EXCLUSION W/COLON SM INT','43361','1','','1','0','','','',0, 1, 0, 0),
(3857,'LIGATION DIRECT ESOPHAGEAL VARICES','LIGATION DIRECT ESOPHAGEAL VARICES','43400','1','','1','0','','','',0, 1, 0, 0),
(3858,'TRNSXJ ESOPH W/RPR ESOPHAGEAL VARICES','TRNSXJ ESOPH W/RPR ESOPHAGEAL VARICES','43401','1','','1','0','','','',0, 1, 0, 0),
(3859,'LIG/STAPLING G-ESOP JUNCT PRE-ESOPHGL PRF8J','LIG/STAPLING G-ESOP JUNCT PRE-ESOPHGL PRF8J','43405','1','','1','0','','','',0, 1, 0, 0),
(3860,'SUTR ESOPHGL WND/INJ CRV APPR','SUTR ESOPHGL WND/INJ CRV APPR','43410','1','','1','0','','','',0, 1, 0, 0),
(3861,'SUTR ESOPHGL WND/INJ TTHRC/TABDL APPR','SUTR ESOPHGL WND/INJ TTHRC/TABDL APPR','43415','1','','1','0','','','',0, 1, 0, 0),
(3862,'CLSR ESOPHAGOSTOMY/FSTL CRV APPR','CLSR ESOPHAGOSTOMY/FSTL CRV APPR','43420','1','','1','0','','','',0, 1, 0, 0),
(3863,'CLSR ESOPHAGOSTOMY/FSTL TTHRC/TABDL APPR','CLSR ESOPHAGOSTOMY/FSTL TTHRC/TABDL APPR','43425','1','','1','0','','','',0, 1, 0, 0),
(3864,'DILATION ESOPH UNGUIDED SOUND/BOUGIE 1/MULT PASS','DILATION ESOPH UNGUIDED SOUND/BOUGIE 1/MULT PASS','43450','1','','1','0','','','',0, 1, 0, 0),
(3865,'DILATION ESOPHAGUS GUIDE WIRE','DILATION ESOPHAGUS GUIDE WIRE','43453','1','','1','0','','','',0, 1, 0, 0),
(3866,'ESOPG/GSTR TAMPONADE W/BALO SENGSTAKEN TYPE','ESOPG/GSTR TAMPONADE W/BALO SENGSTAKEN TYPE','43460','1','','1','0','','','',0, 1, 0, 0),
(3867,'FREE JEJUNUM TRSF W/MICROVASC ANASTOMOSIS','FREE JEJUNUM TRSF W/MICROVASC ANASTOMOSIS','43496','1','','1','0','','','',0, 1, 0, 0),
(3868,'UNLISTED PROCEDURE ESOPHAGUS','UNLISTED PROCEDURE ESOPHAGUS','43499','1','','1','0','','','',0, 1, 0, 0),
(3869,'GASTROTOMY W/EXPLORATION/FOREIGN BODY REMOVAL','GASTROTOMY W/EXPLORATION/FOREIGN BODY REMOVAL','43500','1','','1','0','','','',0, 1, 0, 0),
(3870,'GASTROTOMY W/SUTURE REPAIR BLEEDING ULCER','GASTROTOMY W/SUTURE REPAIR BLEEDING ULCER','43501','1','','1','0','','','',0, 1, 0, 0),
(3871,'GASTROTOMY W/SUTR RPR PRE-ESOPG/GASTRIC LAC','GASTROTOMY W/SUTR RPR PRE-ESOPG/GASTRIC LAC','43502','1','','1','0','','','',0, 1, 0, 0),
(3872,'GSTRT W/ESOPHGL DILAT&INSJ PRM INTRAL TUBE','GSTRT W/ESOPHGL DILAT&INSJ PRM INTRAL TUBE','43510','1','','1','0','','','',0, 1, 0, 0),
(3873,'PYLOROMYOTOMY CUTTING PYLORIC MUSC','PYLOROMYOTOMY CUTTING PYLORIC MUSC','43520','1','','1','0','','','',0, 1, 0, 0),
(3874,'BIOPSY STOMACH LAPAROTOMY','BIOPSY STOMACH LAPAROTOMY','43605','1','','1','0','','','',0, 1, 0, 0),
(3875,'EXC LOCAL ULCER/BENIGN TUMOR STOMACH','EXC LOCAL ULCER/BENIGN TUMOR STOMACH','43610','1','','1','0','','','',0, 1, 0, 0),
(3876,'EXC LOCAL MALIGNANT TUMOR STOMACH','EXC LOCAL MALIGNANT TUMOR STOMACH','43611','1','','1','0','','','',0, 1, 0, 0),
(3877,'GSTRCT TOT W/ESOPHAGOENTEROSTOMY','GSTRCT TOT W/ESOPHAGOENTEROSTOMY','43620','1','','1','0','','','',0, 1, 0, 0),
(3878,'GSTRCT TOT W/ROUX-EN-Y RCNSTJ','GSTRCT TOT W/ROUX-EN-Y RCNSTJ','43621','1','','1','0','','','',0, 1, 0, 0),
(3879,'GSTRCT TOT W/FRMJ INTSTINAL POUCH ANY TYPE','GSTRCT TOT W/FRMJ INTSTINAL POUCH ANY TYPE','43622','1','','1','0','','','',0, 1, 0, 0),
(3880,'GSTRCT PRTL DSTL W/GASTRODUODENOSTOMY','GSTRCT PRTL DSTL W/GASTRODUODENOSTOMY','43631','1','','1','0','','','',0, 1, 0, 0),
(3881,'GSTRCT PRTL DSTL W/GASTROJEJUNOSTOMY','GSTRCT PRTL DSTL W/GASTROJEJUNOSTOMY','43632','1','','1','0','','','',0, 1, 0, 0),
(3882,'GSTRCT PRTL DSTL W/ROUX-EN-Y RCNSTJ','GSTRCT PRTL DSTL W/ROUX-EN-Y RCNSTJ','43633','1','','1','0','','','',0, 1, 0, 0),
(3883,'GSTRCT PRTL DSTL W/FRMJ INTSTINAL POUCH','GSTRCT PRTL DSTL W/FRMJ INTSTINAL POUCH','43634','1','','1','0','','','',0, 1, 0, 0),
(3884,'VAGOTOMY PFRMD W/PRTL DSTL GSTRCT','VAGOTOMY PFRMD W/PRTL DSTL GSTRCT','43635','1','','1','0','','','',0, 1, 0, 0),
(3885,'VGTMY W/PYLORPLSTY W/WO GASTROST TRUNCAL/SLCTV','VGTMY W/PYLORPLSTY W/WO GASTROST TRUNCAL/SLCTV','43640','1','','1','0','','','',0, 1, 0, 0),
(3886,'VGTMY W/PYLOROPLASTY W/WO GASTROST PARIETAL CELL','VGTMY W/PYLOROPLASTY W/WO GASTROST PARIETAL CELL','43641','1','','1','0','','','',0, 1, 0, 0),
(3887,'LAPS GSTR RSTCV PX W/BYP ROUX-EN-Y LIMB <150 CM','LAPS GSTR RSTCV PX W/BYP ROUX-EN-Y LIMB <150 CM','43644','1','','1','0','','','',0, 1, 0, 0),
(3888,'LAPS GSTR RSTCV PX W/BYP&SM INT RCNSTJ','LAPS GSTR RSTCV PX W/BYP&SM INT RCNSTJ','43645','1','','1','0','','','',0, 1, 0, 0),
(3889,'LAPS IMPLTJ/RPLCMT GASTRIC NSTIM ELTRD ANTRUM','LAPS IMPLTJ/RPLCMT GASTRIC NSTIM ELTRD ANTRUM','43647','1','','1','0','','','',0, 1, 0, 0),
(3890,'LAPS REVISION/RMVL GASTRIC NSTIM ELTRD ANTRUM','LAPS REVISION/RMVL GASTRIC NSTIM ELTRD ANTRUM','43648','1','','1','0','','','',0, 1, 0, 0),
(3891,'LAPS SURG TRNSXJ VAGUS NRV TRUNCAL','LAPS SURG TRNSXJ VAGUS NRV TRUNCAL','43651','1','','1','0','','','',0, 1, 0, 0),
(3892,'LAPS SURG TRNSXJ VAGUS NRV SLCTV/HILY SLCTV','LAPS SURG TRNSXJ VAGUS NRV SLCTV/HILY SLCTV','43652','1','','1','0','','','',0, 1, 0, 0),
(3893,'LAPS SURG GASTROSTOMY W/O CONSTJ GSTR TUBE SPX','LAPS SURG GASTROSTOMY W/O CONSTJ GSTR TUBE SPX','43653','1','','1','0','','','',0, 1, 0, 0),
(3894,'UNLISTED LAPAROSCOPIC PROCEDURE STOMACH','UNLISTED LAPAROSCOPIC PROCEDURE STOMACH','43659','1','','1','0','','','',0, 1, 0, 0),
(3895,'NASO/ORO-GASTRIC TUBE PLMT REQ PHYS&FLUOR GDNCE','NASO/ORO-GASTRIC TUBE PLMT REQ PHYS&FLUOR GDNCE','43752','1','','1','0','','','',0, 1, 0, 0),
(3896,'GASTRIC INTUBATJ & ASPIRAJ W/PHYS SKILL/LAVAGE','GASTRIC INTUBATJ & ASPIRAJ W/PHYS SKILL/LAVAGE','43753','1','','1','0','','','',0, 1, 0, 0),
(3897,'GASTRIC INTUBAT DX W/ASPIRATION SINGLE SPECIMEN','GASTRIC INTUBAT DX W/ASPIRATION SINGLE SPECIMEN','43754','1','','1','0','','','',0, 1, 0, 0),
(3898,'GASTRIC INTUBATION DX & ASPIRATJ MULTIPLE SPEC','GASTRIC INTUBATION DX & ASPIRATJ MULTIPLE SPEC','43755','1','','1','0','','','',0, 1, 0, 0),
(3899,'DUODENAL INTUBAT W/IMAG GUIDED SINGLE SPECIMEN','DUODENAL INTUBAT W/IMAG GUIDED SINGLE SPECIMEN','43756','1','','1','0','','','',0, 1, 0, 0),
(3900,'DUODENAL INTUBAT W/IMAG GUIDED MULTIPLE SPECIMEN','DUODENAL INTUBAT W/IMAG GUIDED MULTIPLE SPECIMEN','43757','1','','1','0','','','',0, 1, 0, 0),
(3901,'CHANGE GASTROSTOMY TUBE PERCUTANEOUS W/O GDNCE','CHANGE GASTROSTOMY TUBE PERCUTANEOUS W/O GDNCE','43760','1','','1','0','','','',0, 1, 0, 0),
(3902,'REPOS NASO/ORO GASTRIC FEEDING TUBE THRU DUO','REPOS NASO/ORO GASTRIC FEEDING TUBE THRU DUO','43761','1','','1','0','','','',0, 1, 0, 0),
(3903,'LAPS GASTRIC RESTRICTIVE PROCEDURE PLACE DEVICE','LAPS GASTRIC RESTRICTIVE PROCEDURE PLACE DEVICE','43770','1','','1','0','','','',0, 1, 0, 0),
(3904,'LAPS GASTRIC RESTRICTIVE PX REVISION DEVICE','LAPS GASTRIC RESTRICTIVE PX REVISION DEVICE','43771','1','','1','0','','','',0, 1, 0, 0),
(3905,'LAPS GASTRIC RESTRICTIVE PX REMOVE DEVICE','LAPS GASTRIC RESTRICTIVE PX REMOVE DEVICE','43772','1','','1','0','','','',0, 1, 0, 0),
(3906,'LAPS GASTRIC RESTRICTIVE PX REMOVE&RPLCMT DEVICE','LAPS GASTRIC RESTRICTIVE PX REMOVE&RPLCMT DEVICE','43773','1','','1','0','','','',0, 1, 0, 0),
(3907,'LAPS GASTRIC RESTRICTIVE PX REMOVE DEVICE & PORT','LAPS GASTRIC RESTRICTIVE PX REMOVE DEVICE & PORT','43774','1','','1','0','','','',0, 1, 0, 0),
(3908,'LAPS GSTRC RSTRICTIV PX LONGITUDINAL GASTRECTOMY','LAPS GSTRC RSTRICTIV PX LONGITUDINAL GASTRECTOMY','43775','1','','1','0','','','',0, 1, 0, 0),
(3909,'PYLOROPLASTY','PYLOROPLASTY','43800','1','','1','0','','','',0, 1, 0, 0),
(3910,'GASTRODUODENOSTOMY','GASTRODUODENOSTOMY','43810','1','','1','0','','','',0, 1, 0, 0),
(3911,'GASTROJEJUNOSTOMY W/O VAGOTOMY','GASTROJEJUNOSTOMY W/O VAGOTOMY','43820','1','','1','0','','','',0, 1, 0, 0),
(3912,'GASTROJEJUNOSTOMY W/VAGOTOMY ANY TYPE','GASTROJEJUNOSTOMY W/VAGOTOMY ANY TYPE','43825','1','','1','0','','','',0, 1, 0, 0),
(3913,'GASTROSTOMY OPN W/O CONSTJ GSTR TUBE SPX','GASTROSTOMY OPN W/O CONSTJ GSTR TUBE SPX','43830','1','','1','0','','','',0, 1, 0, 0),
(3914,'GASTROSTOMY OPN NEONATAL FEEDING','GASTROSTOMY OPN NEONATAL FEEDING','43831','1','','1','0','','','',0, 1, 0, 0),
(3915,'GASTROSTOMY OPN W/CONSTJ GSTR TUBE','GASTROSTOMY OPN W/CONSTJ GSTR TUBE','43832','1','','1','0','','','',0, 1, 0, 0),
(3916,'GASTRORRHAPHY SUTR PRF8 DUOL/GSTR ULCER WND/INJ','GASTRORRHAPHY SUTR PRF8 DUOL/GSTR ULCER WND/INJ','43840','1','','1','0','','','',0, 1, 0, 0),
(3917,'GASTRIC RSTCV W/O BYP VERTICAL-BANDED GASTROPLY','GASTRIC RSTCV W/O BYP VERTICAL-BANDED GASTROPLY','43842','1','','1','0','','','',0, 1, 0, 0),
(3918,'GSTR RSTCV W/O BYP OTH/THN VER-BANDED GSTP','GSTR RSTCV W/O BYP OTH/THN VER-BANDED GSTP','43843','1','','1','0','','','',0, 1, 0, 0),
(3919,'GASTRIC RSTCV W/PRTL GASTRECTOMY 50-100 CM','GASTRIC RSTCV W/PRTL GASTRECTOMY 50-100 CM','43845','1','','1','0','','','',0, 1, 0, 0),
(3920,'GASTRIC RSTCV W/BYP W/SHORT LIMB 150 CM/<','GASTRIC RSTCV W/BYP W/SHORT LIMB 150 CM/<','43846','1','','1','0','','','',0, 1, 0, 0),
(3921,'GASTRIC RSTCV W/BYP W/SM INT RCNSTJ LIMIT ABSRPJ','GASTRIC RSTCV W/BYP W/SM INT RCNSTJ LIMIT ABSRPJ','43847','1','','1','0','','','',0, 1, 0, 0),
(3922,'REVISION OPEN GASTRIC RESTRICTIVE PX NOT DEVICE','REVISION OPEN GASTRIC RESTRICTIVE PX NOT DEVICE','43848','1','','1','0','','','',0, 1, 0, 0),
(3923,'REVJ GASTRODUOL ANAST W/RCNSTJ W/O VAGOTOMY','REVJ GASTRODUOL ANAST W/RCNSTJ W/O VAGOTOMY','43850','1','','1','0','','','',0, 1, 0, 0),
(3924,'REVJ GASTRODUOL ANAST W/RCNSTJ W/VGTMY','REVJ GASTRODUOL ANAST W/RCNSTJ W/VGTMY','43855','1','','1','0','','','',0, 1, 0, 0),
(3925,'REVJ GSTR/JJ ANAST W/RCNSTJ W/O VGTMY','REVJ GSTR/JJ ANAST W/RCNSTJ W/O VGTMY','43860','1','','1','0','','','',0, 1, 0, 0),
(3926,'REVJ GSTR/JJ ANAST W/RCNSTJ W/VGTMY','REVJ GSTR/JJ ANAST W/RCNSTJ W/VGTMY','43865','1','','1','0','','','',0, 1, 0, 0),
(3927,'CLOSURE GASTROSTOMY SURG','CLOSURE GASTROSTOMY SURG','43870','1','','1','0','','','',0, 1, 0, 0),
(3928,'CLOSURE GASTROCOLIC FISTULA','CLOSURE GASTROCOLIC FISTULA','43880','1','','1','0','','','',0, 1, 0, 0),
(3929,'IMPLTJ/RPLCMT GASTRIC NSTIM ELTRDE ANTRUM OPEN','IMPLTJ/RPLCMT GASTRIC NSTIM ELTRDE ANTRUM OPEN','43881','1','','1','0','','','',0, 1, 0, 0),
(3930,'REVISION/RMVL GASTRIC NSTIM ELTRDE ANTRUM OPEN','REVISION/RMVL GASTRIC NSTIM ELTRDE ANTRUM OPEN','43882','1','','1','0','','','',0, 1, 0, 0),
(3931,'GSTR RSTCV PX OPN REVJ SUBQ PORT COMPONENT ONLY','GSTR RSTCV PX OPN REVJ SUBQ PORT COMPONENT ONLY','43886','1','','1','0','','','',0, 1, 0, 0),
(3932,'GSTR RSTCV PX OPN RMVL SUBQ PORT COMPONENT ONLY','GSTR RSTCV PX OPN RMVL SUBQ PORT COMPONENT ONLY','43887','1','','1','0','','','',0, 1, 0, 0),
(3933,'GSTR RSTCV OPN RMVL & RPLCMT SUBQ PORT','GSTR RSTCV OPN RMVL & RPLCMT SUBQ PORT','43888','1','','1','0','','','',0, 1, 0, 0),
(3934,'UNLISTED PROCEDURE STOMACH','UNLISTED PROCEDURE STOMACH','43999','1','','1','0','','','',0, 1, 0, 0),
(3935,'ENTEROLSS FRING INTSTINAL ADHESION SPX','ENTEROLSS FRING INTSTINAL ADHESION SPX','44005','1','','1','0','','','',0, 1, 0, 0),
(3936,'DUODENOTOMY EXPLORATION/BX/FOREIGN BODY REMOVAL','DUODENOTOMY EXPLORATION/BX/FOREIGN BODY REMOVAL','44010','1','','1','0','','','',0, 1, 0, 0),
(3937,'TUBE/NEEDLE CATH JEJUNOSTOMY ANY METHOD','TUBE/NEEDLE CATH JEJUNOSTOMY ANY METHOD','44015','1','','1','0','','','',0, 1, 0, 0),
(3938,'ENTEROTOMY SM INT OTH/THN DUO EXPL BX/FB RMVL','ENTEROTOMY SM INT OTH/THN DUO EXPL BX/FB RMVL','44020','1','','1','0','','','',0, 1, 0, 0),
(3939,'ENTEROTOMY SM INT OTH/THN DUO DCMPRN','ENTEROTOMY SM INT OTH/THN DUO DCMPRN','44021','1','','1','0','','','',0, 1, 0, 0),
(3940,'COLOTOMY EXPLORATION/BIOPSY/FOREIGN BODY REMOVAL','COLOTOMY EXPLORATION/BIOPSY/FOREIGN BODY REMOVAL','44025','1','','1','0','','','',0, 1, 0, 0),
(3941,'RDCTJ VOLVULUS INTUSSUSCEPTION INT HRNA LAPT','RDCTJ VOLVULUS INTUSSUSCEPTION INT HRNA LAPT','44050','1','','1','0','','','',0, 1, 0, 0),
(3942,'CORRJ MALROTATION BANDS&/RDCTJ VOLVULUS','CORRJ MALROTATION BANDS&/RDCTJ VOLVULUS','44055','1','','1','0','','','',0, 1, 0, 0),
(3943,'BX INTESTINE CAPSULE TUBE PRORAL 1/> SPECIMENS','BX INTESTINE CAPSULE TUBE PRORAL 1/> SPECIMENS','44100','1','','1','0','','','',0, 1, 0, 0),
(3944,'EXC 1/> SMALL/LARGE LESIONS INTESTINE ENTEROTOM','EXC 1/> SMALL/LARGE LESIONS INTESTINE ENTEROTOM','44110','1','','1','0','','','',0, 1, 0, 0),
(3945,'EXC 1/> SM/LG LESIONS INTESTNE MULT ENTEROTOMIE','EXC 1/> SM/LG LESIONS INTESTNE MULT ENTEROTOMIE','44111','1','','1','0','','','',0, 1, 0, 0),
(3946,'ENTRC RESCJ SMALL INTESTINE 1 RESCJ & ANAST','ENTRC RESCJ SMALL INTESTINE 1 RESCJ & ANAST','44120','1','','1','0','','','',0, 1, 0, 0),
(3947,'ENTERECTOMY RESCJ SMALL INTESTINE EA RESCJ & ANA','ENTERECTOMY RESCJ SMALL INTESTINE EA RESCJ & ANA','44121','1','','1','0','','','',0, 1, 0, 0),
(3948,'ENTERECTOMY RESCJ SMALL INTESTINE W/ENTEROSTOMY','ENTERECTOMY RESCJ SMALL INTESTINE W/ENTEROSTOMY','44125','1','','1','0','','','',0, 1, 0, 0),
(3949,'ENTRC RESCJ ATRESIA RESCJ & ANAST W/O TAPRING','ENTRC RESCJ ATRESIA RESCJ & ANAST W/O TAPRING','44126','1','','1','0','','','',0, 1, 0, 0),
(3950,'ENTRC RESCJ ATRESIA RESCJ & ANAST SGM W/TAPRING','ENTRC RESCJ ATRESIA RESCJ & ANAST SGM W/TAPRING','44127','1','','1','0','','','',0, 1, 0, 0),
(3951,'ENTRC RESCJ ATRESIA EA RESCJ & ANASTOMOSIS','ENTRC RESCJ ATRESIA EA RESCJ & ANASTOMOSIS','44128','1','','1','0','','','',0, 1, 0, 0),
(3952,'ENTEROENTEROST ANAST INT W/WO CUTAN NTRSTM SPX','ENTEROENTEROST ANAST INT W/WO CUTAN NTRSTM SPX','44130','1','','1','0','','','',0, 1, 0, 0),
(3953,'DONOR ENTERECTOMY OPEN CADAVER DONOR','DONOR ENTERECTOMY OPEN CADAVER DONOR','44132','1','','1','0','','','',0, 1, 0, 0),
(3954,'DONOR ENTERECTOMY OPEN LIVING DONOR','DONOR ENTERECTOMY OPEN LIVING DONOR','44133','1','','1','0','','','',0, 1, 0, 0),
(3955,'INTESTINAL ALLOTRANSPLANTATION CADAVER DONOR','INTESTINAL ALLOTRANSPLANTATION CADAVER DONOR','44135','1','','1','0','','','',0, 1, 0, 0),
(3956,'INTESTINAL ALLOTRANSPLANTATION LIVING DONOR','INTESTINAL ALLOTRANSPLANTATION LIVING DONOR','44136','1','','1','0','','','',0, 1, 0, 0),
(3957,'RMVL TRNSPLED INTESTINAL ALLOGRAFT COMPL','RMVL TRNSPLED INTESTINAL ALLOGRAFT COMPL','44137','1','','1','0','','','',0, 1, 0, 0),
(3958,'MOBLJ SPLENIC FLXR PFRMD CONJUNCT W/PRTL COLCT','MOBLJ SPLENIC FLXR PFRMD CONJUNCT W/PRTL COLCT','44139','1','','1','0','','','',0, 1, 0, 0),
(3959,'COLECTOMY PARTIAL W/ANASTOMOSIS','COLECTOMY PARTIAL W/ANASTOMOSIS','44140','1','','1','0','','','',0, 1, 0, 0),
(3960,'COLECTOMY PRTL W/SKIN LEVEL CECOST/COLOSTOMY','COLECTOMY PRTL W/SKIN LEVEL CECOST/COLOSTOMY','44141','1','','1','0','','','',0, 1, 0, 0),
(3961,'COLECTOMY PRTL W/END COLOSTOMY & CLSR DSTL SGMT','COLECTOMY PRTL W/END COLOSTOMY & CLSR DSTL SGMT','44143','1','','1','0','','','',0, 1, 0, 0),
(3962,'COLECTOMY PRTL W/COLOST/ILEOST & MUCOFISTULA','COLECTOMY PRTL W/COLOST/ILEOST & MUCOFISTULA','44144','1','','1','0','','','',0, 1, 0, 0),
(3963,'COLECTOMY PRTL W/COLOPROCTOSTOMY','COLECTOMY PRTL W/COLOPROCTOSTOMY','44145','1','','1','0','','','',0, 1, 0, 0),
(3964,'COLECTOMY PRTL W/COLOPROCTOSTOMY & COLOSTOMY','COLECTOMY PRTL W/COLOPROCTOSTOMY & COLOSTOMY','44146','1','','1','0','','','',0, 1, 0, 0),
(3965,'COLECTOMY PRTL ABDOMINAL & TRANSANAL APPROACH','COLECTOMY PRTL ABDOMINAL & TRANSANAL APPROACH','44147','1','','1','0','','','',0, 1, 0, 0),
(3966,'COLCT TOT ABDL W/O PRCTECT W/ILEOST/ILEOPXTS','COLCT TOT ABDL W/O PRCTECT W/ILEOST/ILEOPXTS','44150','1','','1','0','','','',0, 1, 0, 0),
(3967,'COLCT TOT ABDL W/O PRCTECT W/CONTINENT ILEOST','COLCT TOT ABDL W/O PRCTECT W/CONTINENT ILEOST','44151','1','','1','0','','','',0, 1, 0, 0),
(3968,'COLECTOMY TOT ABDL W/PROCTECTOMY W/ILEOSTOMY','COLECTOMY TOT ABDL W/PROCTECTOMY W/ILEOSTOMY','44155','1','','1','0','','','',0, 1, 0, 0),
(3969,'COLECTOMY TOT ABDL W/PROCTECTOMY W/CONTNT ILEOST','COLECTOMY TOT ABDL W/PROCTECTOMY W/CONTNT ILEOST','44156','1','','1','0','','','',0, 1, 0, 0),
(3970,'COLECTOMY TOT ABD W/PROCTECTOMY ILEOANAL ANAST','COLECTOMY TOT ABD W/PROCTECTOMY ILEOANAL ANAST','44157','1','','1','0','','','',0, 1, 0, 0),
(3971,'COLCT TTL ABD W/PRCTECT ILEOANAL ANAST & RSVR','COLCT TTL ABD W/PRCTECT ILEOANAL ANAST & RSVR','44158','1','','1','0','','','',0, 1, 0, 0),
(3972,'COLECTOMY PRTL W/RMVL TERMINAL ILEUM & ILEOCOLOS','COLECTOMY PRTL W/RMVL TERMINAL ILEUM & ILEOCOLOS','44160','1','','1','0','','','',0, 1, 0, 0),
(3973,'LAPAROSCOPY ENTEROLYSIS SEPARATE PROCEDURE','LAPAROSCOPY ENTEROLYSIS SEPARATE PROCEDURE','44180','1','','1','0','','','',0, 1, 0, 0),
(3974,'LAPAROSCOPY SURGICAL JEJUNOSTOMY','LAPAROSCOPY SURGICAL JEJUNOSTOMY','44186','1','','1','0','','','',0, 1, 0, 0),
(3975,'LAPAROSCOPY SURG ILEOSTOMY/JEJUNOSTOMY NON-TUBE','LAPAROSCOPY SURG ILEOSTOMY/JEJUNOSTOMY NON-TUBE','44187','1','','1','0','','','',0, 1, 0, 0),
(3976,'LAPAROSCOPY SURG COLOSTOMY/SKN LVL CECOSTOMY','LAPAROSCOPY SURG COLOSTOMY/SKN LVL CECOSTOMY','44188','1','','1','0','','','',0, 1, 0, 0),
(3977,'LAPS ENTERECT RESCJ 1 SMALL INTEST RESCJ & ANA','LAPS ENTERECT RESCJ 1 SMALL INTEST RESCJ & ANA','44202','1','','1','0','','','',0, 1, 0, 0),
(3978,'LAPAROSCOPY SMALL INTESTINE RESCJ & ANASTOMOSIS','LAPAROSCOPY SMALL INTESTINE RESCJ & ANASTOMOSIS','44203','1','','1','0','','','',0, 1, 0, 0),
(3979,'LAPAROSCOPY COLECTOMY PARTIAL W/ANASTOMOSIS','LAPAROSCOPY COLECTOMY PARTIAL W/ANASTOMOSIS','44204','1','','1','0','','','',0, 1, 0, 0),
(3980,'LAPS COLECTOMY PRTL W/RMVL TERMINAL ILEUM','LAPS COLECTOMY PRTL W/RMVL TERMINAL ILEUM','44205','1','','1','0','','','',0, 1, 0, 0),
(3981,'LAPS COLECTOMY PRTL W/END CLST & CLSR DSTL SGM','LAPS COLECTOMY PRTL W/END CLST & CLSR DSTL SGM','44206','1','','1','0','','','',0, 1, 0, 0),
(3982,'LAPS COLECTOMY PRTL W/COLOPXTSTMY LW ANAST','LAPS COLECTOMY PRTL W/COLOPXTSTMY LW ANAST','44207','1','','1','0','','','',0, 1, 0, 0),
(3983,'LAPS COLECTMY PRTL W/COLOPXTSTMY LW ANAST W/CLST','LAPS COLECTMY PRTL W/COLOPXTSTMY LW ANAST W/CLST','44208','1','','1','0','','','',0, 1, 0, 0),
(3984,'LAPS COLECTOMY TOT W/O PRCTECT W/ILEOST/ILEOPXTS','LAPS COLECTOMY TOT W/O PRCTECT W/ILEOST/ILEOPXTS','44210','1','','1','0','','','',0, 1, 0, 0),
(3985,'LAPS COLCT TTL ABD W/PRCTECT ILEOANAL ANASTOMSIS','LAPS COLCT TTL ABD W/PRCTECT ILEOANAL ANASTOMSIS','44211','1','','1','0','','','',0, 1, 0, 0),
(3986,'LAPS COLECTOMY ABDL W/PROCTECTOMY W/ILEOSTOMY','LAPS COLECTOMY ABDL W/PROCTECTOMY W/ILEOSTOMY','44212','1','','1','0','','','',0, 1, 0, 0),
(3987,'LAPS MOBLJ SPLENIC FLXR PFRMD W/PRTL COLECTOMY','LAPS MOBLJ SPLENIC FLXR PFRMD W/PRTL COLECTOMY','44213','1','','1','0','','','',0, 1, 0, 0),
(3988,'LAPS CLSR NTRSTM LG/SM INT W/RESCJ & ANASTOMOSIS','LAPS CLSR NTRSTM LG/SM INT W/RESCJ & ANASTOMOSIS','44227','1','','1','0','','','',0, 1, 0, 0),
(3989,'UNLISTED LAPAROSCOPY PX INTESTINE XCP RECTUM','UNLISTED LAPAROSCOPY PX INTESTINE XCP RECTUM','44238','1','','1','0','','','',0, 1, 0, 0),
(3990,'PLACEMENT ENTEROSTOMY/CECOSTOMY TUBE OPEN','PLACEMENT ENTEROSTOMY/CECOSTOMY TUBE OPEN','44300','1','','1','0','','','',0, 1, 0, 0),
(3991,'ILEOSTOMY/JEJUNOSTOMY NON-TUBE','ILEOSTOMY/JEJUNOSTOMY NON-TUBE','44310','1','','1','0','','','',0, 1, 0, 0),
(3992,'REVJ ILEOSTOMY SIMPLE RLS SUPERFICIAL SCAR SPX','REVJ ILEOSTOMY SIMPLE RLS SUPERFICIAL SCAR SPX','44312','1','','1','0','','','',0, 1, 0, 0),
(3993,'REVJ ILEOSTOMY COMPLIC RCNSTJ IN-DEPTH SPX','REVJ ILEOSTOMY COMPLIC RCNSTJ IN-DEPTH SPX','44314','1','','1','0','','','',0, 1, 0, 0),
(3994,'CONTINENT ILEOSTOMY KOCK PROCEDURE SPX','CONTINENT ILEOSTOMY KOCK PROCEDURE SPX','44316','1','','1','0','','','',0, 1, 0, 0),
(3995,'COLOSTOMY/SKIN LEVEL CECOSTOMY','COLOSTOMY/SKIN LEVEL CECOSTOMY','44320','1','','1','0','','','',0, 1, 0, 0),
(3996,'COLOSTOMY/SKN LVL CECOSTOMY W/MULT BXS SPX','COLOSTOMY/SKN LVL CECOSTOMY W/MULT BXS SPX','44322','1','','1','0','','','',0, 1, 0, 0),
(3997,'REVJ COLOSTOMY SMPL RLS SUPFC SCAR SPX','REVJ COLOSTOMY SMPL RLS SUPFC SCAR SPX','44340','1','','1','0','','','',0, 1, 0, 0),
(3998,'REVJ COLOSTOMY COMP RCNSTJ IN-DEPTH SPX','REVJ COLOSTOMY COMP RCNSTJ IN-DEPTH SPX','44345','1','','1','0','','','',0, 1, 0, 0),
(3999,'REVJ COLOSTOMY W/RPR PARACLST HERNIA SPX','REVJ COLOSTOMY W/RPR PARACLST HERNIA SPX','44346','1','','1','0','','','',0, 1, 0, 0),
(4000,'ENDOSCOPY UPPER SMALL INTESTINE','ENDOSCOPY UPPER SMALL INTESTINE','44360','1','','1','0','','','',0, 1, 0, 0),
(4001,'ENDOSCOPY UPPER SMALL INTESTINE W/BIOPSY','ENDOSCOPY UPPER SMALL INTESTINE W/BIOPSY','44361','1','','1','0','','','',0, 1, 0, 0),
(4002,'ENTEROSCOPY > 2ND PRTN W/RMVL FOREIGN BODY','ENTEROSCOPY > 2ND PRTN W/RMVL FOREIGN BODY','44363','1','','1','0','','','',0, 1, 0, 0),
(4003,'ENTEROSCOPY > 2ND PRTN W/RMVL LESION SNARE','ENTEROSCOPY > 2ND PRTN W/RMVL LESION SNARE','44364','1','','1','0','','','',0, 1, 0, 0),
(4004,'ENTEROSCOPY > 2ND PRTN W/RMVL LESION CAUTERY','ENTEROSCOPY > 2ND PRTN W/RMVL LESION CAUTERY','44365','1','','1','0','','','',0, 1, 0, 0),
(4005,'ENTEROSCOPY > 2ND PRTN W/CONTROL BLEEDING','ENTEROSCOPY > 2ND PRTN W/CONTROL BLEEDING','44366','1','','1','0','','','',0, 1, 0, 0),
(4006,'ENTEROSCOPY > 2ND PRTN ABLTJ LESION','ENTEROSCOPY > 2ND PRTN ABLTJ LESION','44369','1','','1','0','','','',0, 1, 0, 0),
(4007,'ENTEROSCOPY > 2ND PRTN TNDSC STENT PLMT','ENTEROSCOPY > 2ND PRTN TNDSC STENT PLMT','44370','1','','1','0','','','',0, 1, 0, 0),
(4008,'ENTEROSCOPY > 2ND PRTN W/PLMT PRQ TUBE','ENTEROSCOPY > 2ND PRTN W/PLMT PRQ TUBE','44372','1','','1','0','','','',0, 1, 0, 0),
(4009,'ENTEROSCOPY > 2ND PRTN CONV GSTRST TUBE','ENTEROSCOPY > 2ND PRTN CONV GSTRST TUBE','44373','1','','1','0','','','',0, 1, 0, 0),
(4010,'ENTEROSC >2ND PRTN W/ILEUM W/WO COLLJ SPEC SPX','ENTEROSC >2ND PRTN W/ILEUM W/WO COLLJ SPEC SPX','44376','1','','1','0','','','',0, 1, 0, 0),
(4011,'ENTEROSC >2ND PRTN W/ILEUM W/BX SINGLE/MULTIPLE','ENTEROSC >2ND PRTN W/ILEUM W/BX SINGLE/MULTIPLE','44377','1','','1','0','','','',0, 1, 0, 0),
(4012,'ENTEROSCOPY > 2ND PRTN ILEUM CONTROL BLEEDING','ENTEROSCOPY > 2ND PRTN ILEUM CONTROL BLEEDING','44378','1','','1','0','','','',0, 1, 0, 0),
(4013,'ENTEROSCOPY > 2ND PRTN W/ILEUM W/STENT PLMT','ENTEROSCOPY > 2ND PRTN W/ILEUM W/STENT PLMT','44379','1','','1','0','','','',0, 1, 0, 0),
(4014,'ILEOSCOPY THRU STOMA DX W/COLLJ SPEC WHEN PRFMD','ILEOSCOPY THRU STOMA DX W/COLLJ SPEC WHEN PRFMD','44380','1','','1','0','','','',0, 1, 0, 0),
(4015,'ILEOSCOPY STOMA W/BALLOON DILATION','ILEOSCOPY STOMA W/BALLOON DILATION','44381','1','','1','0','','','',0, 1, 0, 0),
(4016,'ILEOSCOPY STOMA W/BX SINGLE/MULTIPLE','ILEOSCOPY STOMA W/BX SINGLE/MULTIPLE','44382','1','','1','0','','','',0, 1, 0, 0),
(4017,'ILEOSCOPY STOMA W/PLMT OF ENDOSCOPIC STENT','ILEOSCOPY STOMA W/PLMT OF ENDOSCOPIC STENT','44384','1','','1','0','','','',0, 1, 0, 0),
(4018,'NDSC EVAL INTSTINAL POUCH DX W/COLLJ SPEC SPX','NDSC EVAL INTSTINAL POUCH DX W/COLLJ SPEC SPX','44385','1','','1','0','','','',0, 1, 0, 0),
(4019,'NDSC EVAL INTSTINAL POUCH W/BX SINGLE/MULTIPLE','NDSC EVAL INTSTINAL POUCH W/BX SINGLE/MULTIPLE','44386','1','','1','0','','','',0, 1, 0, 0),
(4020,'COLONOSCOPY STOMA DX INCLUDING COLLJ SPEC SPX','COLONOSCOPY STOMA DX INCLUDING COLLJ SPEC SPX','44388','1','','1','0','','','',0, 1, 0, 0),
(4021,'COLONOSCOPY STOMA W/BIOPSY SINGLE/MULTIPLE','COLONOSCOPY STOMA W/BIOPSY SINGLE/MULTIPLE','44389','1','','1','0','','','',0, 1, 0, 0),
(4022,'COLONOSCOPY STOMA W/RMVL FOREIGN BODY','COLONOSCOPY STOMA W/RMVL FOREIGN BODY','44390','1','','1','0','','','',0, 1, 0, 0),
(4023,'COLONOSCOPY STOMA CONTROL BLEEDING','COLONOSCOPY STOMA CONTROL BLEEDING','44391','1','','1','0','','','',0, 1, 0, 0),
(4024,'COLONOSCOPY STOMA RMVL LES BY HOT BIOPSY FORCEPS','COLONOSCOPY STOMA RMVL LES BY HOT BIOPSY FORCEPS','44392','1','','1','0','','','',0, 1, 0, 0),
(4025,'COLONOSCOPY STOMA W/RMVL TUM POLYP/OTH LES SNARE','COLONOSCOPY STOMA W/RMVL TUM POLYP/OTH LES SNARE','44394','1','','1','0','','','',0, 1, 0, 0),
(4026,'COLONOSCOPY STOMA ABLATION LESION','COLONOSCOPY STOMA ABLATION LESION','44401','1','','1','0','','','',0, 1, 0, 0),
(4027,'COLONOSCOPY STOMA W/ENDOSCOPIC STENT PLCMT','COLONOSCOPY STOMA W/ENDOSCOPIC STENT PLCMT','44402','1','','1','0','','','',0, 1, 0, 0),
(4028,'COLONOSCOPY STOMA W/ENDOSCOPIC MUCOSAL RESCJ','COLONOSCOPY STOMA W/ENDOSCOPIC MUCOSAL RESCJ','44403','1','','1','0','','','',0, 1, 0, 0),
(4029,'COLONOSCOPY STOMA W/SUBMUCOSAL INJECTION','COLONOSCOPY STOMA W/SUBMUCOSAL INJECTION','44404','1','','1','0','','','',0, 1, 0, 0),
(4030,'COLONOSCOPY STOMA W/BALLOON DILATION','COLONOSCOPY STOMA W/BALLOON DILATION','44405','1','','1','0','','','',0, 1, 0, 0),
(4031,'COLONOSCOPY STOMA W/ENDOSCOPIC ULTRASOUND EXAM','COLONOSCOPY STOMA W/ENDOSCOPIC ULTRASOUND EXAM','44406','1','','1','0','','','',0, 1, 0, 0),
(4032,'COLONOSCOPY STOMA W/US GID NDL ASPIR/BX','COLONOSCOPY STOMA W/US GID NDL ASPIR/BX','44407','1','','1','0','','','',0, 1, 0, 0),
(4033,'COLONOSCOPY THROUGH STOMA WITH DECOMPRESSION','COLONOSCOPY THROUGH STOMA WITH DECOMPRESSION','44408','1','','1','0','','','',0, 1, 0, 0),
(4034,'INTRODUCTION LONG GI TUBE SEPARATE PROCEDURE','INTRODUCTION LONG GI TUBE SEPARATE PROCEDURE','44500','1','','1','0','','','',0, 1, 0, 0),
(4035,'ENTERORRHAPHY 1PERFORATION','ENTERORRHAPHY 1PERFORATION','44602','1','','1','0','','','',0, 1, 0, 0),
(4036,'ENTERORRHAPHY MULTIPLE PERFORATIONS','ENTERORRHAPHY MULTIPLE PERFORATIONS','44603','1','','1','0','','','',0, 1, 0, 0),
(4037,'SUTR LG INTESTINE 1/MULT PERFORAT W/O COLOSTOMY','SUTR LG INTESTINE 1/MULT PERFORAT W/O COLOSTOMY','44604','1','','1','0','','','',0, 1, 0, 0),
(4038,'SUTR LG INTESTINE 1/MULT PERFORAT W/COLOSTOMY','SUTR LG INTESTINE 1/MULT PERFORAT W/COLOSTOMY','44605','1','','1','0','','','',0, 1, 0, 0),
(4039,'INTSTINAL STRICTUROPLASTY W/WO DILAT OBSTRCJ','INTSTINAL STRICTUROPLASTY W/WO DILAT OBSTRCJ','44615','1','','1','0','','','',0, 1, 0, 0),
(4040,'CLOSURE ENTEROSTOMY LG/SMALL INTESTINE','CLOSURE ENTEROSTOMY LG/SMALL INTESTINE','44620','1','','1','0','','','',0, 1, 0, 0),
(4041,'CLSR NTRSTM LG/SM RESCJ & ANAST OTH/THN CLRCT','CLSR NTRSTM LG/SM RESCJ & ANAST OTH/THN CLRCT','44625','1','','1','0','','','',0, 1, 0, 0),
(4042,'CLSR NTRSTM LG/SM RESCJ & COLORECTAL ANASTOMOSIS','CLSR NTRSTM LG/SM RESCJ & COLORECTAL ANASTOMOSIS','44626','1','','1','0','','','',0, 1, 0, 0),
(4043,'CLOSURE INTESTINAL CUTANEOUS FISTULA','CLOSURE INTESTINAL CUTANEOUS FISTULA','44640','1','','1','0','','','',0, 1, 0, 0),
(4044,'CLSR ENTEROENTERIC/ENTEROCOLIC FSTL','CLSR ENTEROENTERIC/ENTEROCOLIC FSTL','44650','1','','1','0','','','',0, 1, 0, 0),
(4045,'CLSR ENTEROVES FSTL W/O INTSTINAL/BLADDER RESCJ','CLSR ENTEROVES FSTL W/O INTSTINAL/BLADDER RESCJ','44660','1','','1','0','','','',0, 1, 0, 0),
(4046,'CLSR ENTEROVES FSTL W/INTESTINE&/BLADDER RESCJ','CLSR ENTEROVES FSTL W/INTESTINE&/BLADDER RESCJ','44661','1','','1','0','','','',0, 1, 0, 0),
(4047,'INTESTINAL PLICATION SEPARATE PROCEDURE','INTESTINAL PLICATION SEPARATE PROCEDURE','44680','1','','1','0','','','',0, 1, 0, 0),
(4048,'EXCLUSION SM INT FROM PELVIS MESH/PROSTH/TISS','EXCLUSION SM INT FROM PELVIS MESH/PROSTH/TISS','44700','1','','1','0','','','',0, 1, 0, 0),
(4049,'INTRAOPERATIVE COLONIC LAVAGE','INTRAOPERATIVE COLONIC LAVAGE','44701','1','','1','0','','','',0, 1, 0, 0),
(4050,'PREPARE FECAL MICROBIOTA FOR INSTILLATION','PREPARE FECAL MICROBIOTA FOR INSTILLATION','44705','1','','1','0','','','',0, 1, 0, 0),
(4051,'BKBENCH PREP CADAVER/LIVING DONOR INTESTINE','BKBENCH PREP CADAVER/LIVING DONOR INTESTINE','44715','1','','1','0','','','',0, 1, 0, 0),
(4052,'BKBENCH RCNSTJ INT ALGRFT VEN ANAST EA','BKBENCH RCNSTJ INT ALGRFT VEN ANAST EA','44720','1','','1','0','','','',0, 1, 0, 0),
(4053,'BKBENCH RCNSTJ INT ALGRFT ARTL ANAST EA','BKBENCH RCNSTJ INT ALGRFT ARTL ANAST EA','44721','1','','1','0','','','',0, 1, 0, 0),
(4054,'UNLISTED PROCEDURE SMALL INTESTINE','UNLISTED PROCEDURE SMALL INTESTINE','44799','1','','1','0','','','',0, 1, 0, 0),
(4055,'EXC MECKEL''S DIVERTICULUM/OMPHALOMESENTERIC DUCT','EXC MECKEL''S DIVERTICULUM/OMPHALOMESENTERIC DUCT','44800','1','','1','0','','','',0, 1, 0, 0),
(4056,'EXCISION LESION MESENTERY SEPARATE PROCEDURE','EXCISION LESION MESENTERY SEPARATE PROCEDURE','44820','1','','1','0','','','',0, 1, 0, 0),
(4057,'SUTURE MESENTERY SEPARATE PROCEDURE','SUTURE MESENTERY SEPARATE PROCEDURE','44850','1','','1','0','','','',0, 1, 0, 0),
(4058,'UNLISTED PX MECKEL''S DIVERTICULUM & MESENTERY','UNLISTED PX MECKEL''S DIVERTICULUM & MESENTERY','44899','1','','1','0','','','',0, 1, 0, 0),
(4059,'INCISION AND DRAINAGE APPENDICEAL ABSCESS OPEN','INCISION AND DRAINAGE APPENDICEAL ABSCESS OPEN','44900','1','','1','0','','','',0, 1, 0, 0),
(4060,'APPENDECTOMY','APPENDECTOMY','44950','1','','1','0','','','',0, 1, 0, 0),
(4061,'APPENDEC INDICATED PURPOSE OTH MAJOR PX NOT SPX','APPENDEC INDICATED PURPOSE OTH MAJOR PX NOT SPX','44955','1','','1','0','','','',0, 1, 0, 0),
(4062,'APPENDEC RPTD APPENDIX ABSC/PRITONITIS','APPENDEC RPTD APPENDIX ABSC/PRITONITIS','44960','1','','1','0','','','',0, 1, 0, 0),
(4063,'LAPAROSCOPIC APPENDECTOMY','LAPAROSCOPIC APPENDECTOMY','44970','1','','1','0','','','',0, 1, 0, 0),
(4064,'UNLISTED LAPAROSCOPY PROCEDURE APPENDIX','UNLISTED LAPAROSCOPY PROCEDURE APPENDIX','44979','1','','1','0','','','',0, 1, 0, 0),
(4065,'TRANSRECTAL DRAINAGE OF PELVIC ABSCESS','TRANSRECTAL DRAINAGE OF PELVIC ABSCESS','45000','1','','1','0','','','',0, 1, 0, 0),
(4066,'I&D SUBMUCOSAL ABSCESS RECTUM','I&D SUBMUCOSAL ABSCESS RECTUM','45005','1','','1','0','','','',0, 1, 0, 0),
(4067,'I&D DP SUPRALEVATOR PELVIRCT/RETRORCT ABSC','I&D DP SUPRALEVATOR PELVIRCT/RETRORCT ABSC','45020','1','','1','0','','','',0, 1, 0, 0),
(4068,'BX ANORECTAL WALL ANAL APPROACH','BX ANORECTAL WALL ANAL APPROACH','45100','1','','1','0','','','',0, 1, 0, 0),
(4069,'ANORECTAL MYOMECTOMY','ANORECTAL MYOMECTOMY','45108','1','','1','0','','','',0, 1, 0, 0),
(4070,'PRCTECT COMPL CMBN ABDOMINOPRNL W/CLST','PRCTECT COMPL CMBN ABDOMINOPRNL W/CLST','45110','1','','1','0','','','',0, 1, 0, 0),
(4071,'PRCTECT PRTL RESCJ RECTUM TABDL APPR','PRCTECT PRTL RESCJ RECTUM TABDL APPR','45111','1','','1','0','','','',0, 1, 0, 0),
(4072,'PRCTECT CMBN ABDOMINOPRNL PULL-THRU PX','PRCTECT CMBN ABDOMINOPRNL PULL-THRU PX','45112','1','','1','0','','','',0, 1, 0, 0),
(4073,'PRCTECT PRTL W/MUCOSEC ILEOANAL ANAST RSVR','PRCTECT PRTL W/MUCOSEC ILEOANAL ANAST RSVR','45113','1','','1','0','','','',0, 1, 0, 0),
(4074,'PRCTECT PRTL W/ANAST ABDL & TRANSSAC APPROACH','PRCTECT PRTL W/ANAST ABDL & TRANSSAC APPROACH','45114','1','','1','0','','','',0, 1, 0, 0),
(4075,'PRCTECT PRTL W/ANAST TRANSSAC APPR ONLY','PRCTECT PRTL W/ANAST TRANSSAC APPR ONLY','45116','1','','1','0','','','',0, 1, 0, 0),
(4076,'PRCTECT CMBN PULL-THRU W/RSVR W/NTRSTM','PRCTECT CMBN PULL-THRU W/RSVR W/NTRSTM','45119','1','','1','0','','','',0, 1, 0, 0),
(4077,'PRCTECT COMPL W/PULL-THRU PX & ANASTOMOSIS','PRCTECT COMPL W/PULL-THRU PX & ANASTOMOSIS','45120','1','','1','0','','','',0, 1, 0, 0),
(4078,'PRCTECT COMPL W/STOT/TOT COLCT W/MLT BXS','PRCTECT COMPL W/STOT/TOT COLCT W/MLT BXS','45121','1','','1','0','','','',0, 1, 0, 0),
(4079,'PRCTECT PRTL W/O ANAST PRNL APPR','PRCTECT PRTL W/O ANAST PRNL APPR','45123','1','','1','0','','','',0, 1, 0, 0),
(4080,'PELVIC EXENTERATION COLORECTAL MALIGNANCY','PELVIC EXENTERATION COLORECTAL MALIGNANCY','45126','1','','1','0','','','',0, 1, 0, 0),
(4081,'EXC RCT PROCIDENTIA W/ANAST PERINEAL APPROACH','EXC RCT PROCIDENTIA W/ANAST PERINEAL APPROACH','45130','1','','1','0','','','',0, 1, 0, 0),
(4082,'EXC RCT PROCIDENTIA W/ANAST ABDL & PRNL APPROACH','EXC RCT PROCIDENTIA W/ANAST ABDL & PRNL APPROACH','45135','1','','1','0','','','',0, 1, 0, 0),
(4083,'EXC ILEOANAL RSVR W/ILEOSTOMY','EXC ILEOANAL RSVR W/ILEOSTOMY','45136','1','','1','0','','','',0, 1, 0, 0),
(4084,'DIVISION STRICTURE RECTUM','DIVISION STRICTURE RECTUM','45150','1','','1','0','','','',0, 1, 0, 0),
(4085,'EXC RCT TUM PROCTOTOMY TRANSSAC/TRANSCOCCYGEAL','EXC RCT TUM PROCTOTOMY TRANSSAC/TRANSCOCCYGEAL','45160','1','','1','0','','','',0, 1, 0, 0),
(4086,'EXC RCT TUM NOT INCL MUSCULARIS PROPRIA','EXC RCT TUM NOT INCL MUSCULARIS PROPRIA','45171','1','','1','0','','','',0, 1, 0, 0),
(4087,'EXC RCT TUM INCL MUSCULARIS PROPRIA','EXC RCT TUM INCL MUSCULARIS PROPRIA','45172','1','','1','0','','','',0, 1, 0, 0),
(4088,'DESTRUCTION RECTAL TUMOR TRANSANAL APPROACH','DESTRUCTION RECTAL TUMOR TRANSANAL APPROACH','45190','1','','1','0','','','',0, 1, 0, 0),
(4089,'PROCTOSGMDSC RGD DX W/WO COLLJ SPEC BR/WA SPX','PROCTOSGMDSC RGD DX W/WO COLLJ SPEC BR/WA SPX','45300','1','','1','0','','','',0, 1, 0, 0),
(4090,'PROCTOSGMDSC RIGID W/DILATION','PROCTOSGMDSC RIGID W/DILATION','45303','1','','1','0','','','',0, 1, 0, 0),
(4091,'PROCTOSGMDSC RIGID W/BX SINGLE/MULTIPLE','PROCTOSGMDSC RIGID W/BX SINGLE/MULTIPLE','45305','1','','1','0','','','',0, 1, 0, 0),
(4092,'PROCTOSGMDSC RIGID W/RMVL FOREIGN BODY','PROCTOSGMDSC RIGID W/RMVL FOREIGN BODY','45307','1','','1','0','','','',0, 1, 0, 0),
(4093,'PROCTOSGMDSC RIGID RMVL 1 LESION CAUTERY','PROCTOSGMDSC RIGID RMVL 1 LESION CAUTERY','45308','1','','1','0','','','',0, 1, 0, 0),
(4094,'PROCTOSGMDSC RIGID RMVL 1 LESION SNARE TQ','PROCTOSGMDSC RIGID RMVL 1 LESION SNARE TQ','45309','1','','1','0','','','',0, 1, 0, 0),
(4095,'PROCTOSGMDSC RIGID RMVL MULT TUMOR CAUTERY/SNARE','PROCTOSGMDSC RIGID RMVL MULT TUMOR CAUTERY/SNARE','45315','1','','1','0','','','',0, 1, 0, 0),
(4096,'PROCTOSGMDSC RIGID CONTROL BLEEDING','PROCTOSGMDSC RIGID CONTROL BLEEDING','45317','1','','1','0','','','',0, 1, 0, 0),
(4097,'PROCTOSGMDSC RIGID ABLATION LESION','PROCTOSGMDSC RIGID ABLATION LESION','45320','1','','1','0','','','',0, 1, 0, 0),
(4098,'PROCTOSGMDSC RIGID DCMPRN VOLVULUS','PROCTOSGMDSC RIGID DCMPRN VOLVULUS','45321','1','','1','0','','','',0, 1, 0, 0),
(4099,'PROCTOSGMDSC RIGID TNDSC STENT PLMT','PROCTOSGMDSC RIGID TNDSC STENT PLMT','45327','1','','1','0','','','',0, 1, 0, 0),
(4100,'SIGMOIDOSCOPY FLX DX W/COLLJ SPEC BR/WA IF PFRMD','SIGMOIDOSCOPY FLX DX W/COLLJ SPEC BR/WA IF PFRMD','45330','1','','1','0','','','',0, 1, 0, 0),
(4101,'SIGMOIDOSCOPY FLX W/BIOPSY SINGLE/MULTIPLE','SIGMOIDOSCOPY FLX W/BIOPSY SINGLE/MULTIPLE','45331','1','','1','0','','','',0, 1, 0, 0),
(4102,'SIGMOIDOSCOPY FLX W/RMVL FOREIGN BODY','SIGMOIDOSCOPY FLX W/RMVL FOREIGN BODY','45332','1','','1','0','','','',0, 1, 0, 0),
(4103,'SIGMOIDOSCOPY FLX W/RMVL TUMOR BY HOT BX FORCEPS','SIGMOIDOSCOPY FLX W/RMVL TUMOR BY HOT BX FORCEPS','45333','1','','1','0','','','',0, 1, 0, 0),
(4104,'SIGMOIDOSCOPY FLX CONTROL BLEEDING','SIGMOIDOSCOPY FLX CONTROL BLEEDING','45334','1','','1','0','','','',0, 1, 0, 0),
(4105,'SGMDSC FLX DIRED SBMCSL NJX ANY SBST','SGMDSC FLX DIRED SBMCSL NJX ANY SBST','45335','1','','1','0','','','',0, 1, 0, 0),
(4106,'SGMDSC FLX W/DCMPRN W/PLMT DCMPRN TUBE','SGMDSC FLX W/DCMPRN W/PLMT DCMPRN TUBE','45337','1','','1','0','','','',0, 1, 0, 0),
(4107,'SGMDSC FLX RMVL TUM POLYP/OTH LES SNARE TQ','SGMDSC FLX RMVL TUM POLYP/OTH LES SNARE TQ','45338','1','','1','0','','','',0, 1, 0, 0),
(4108,'SIGMOIDOSCOPY FLX TNDSC BALO DILAT','SIGMOIDOSCOPY FLX TNDSC BALO DILAT','45340','1','','1','0','','','',0, 1, 0, 0),
(4109,'SIGMOIDOSCOPY FLX NDSC US XM','SIGMOIDOSCOPY FLX NDSC US XM','45341','1','','1','0','','','',0, 1, 0, 0),
(4110,'SIGMOIDOSCOPY FLX TNDSC US GID NDL ASPIR/BX','SIGMOIDOSCOPY FLX TNDSC US GID NDL ASPIR/BX','45342','1','','1','0','','','',0, 1, 0, 0),
(4111,'SIGMOIDOSCOPY FLX ABLATION TUMOR POLYP/OTH LES','SIGMOIDOSCOPY FLX ABLATION TUMOR POLYP/OTH LES','45346','1','','1','0','','','',0, 1, 0, 0),
(4112,'SIGMOIDOSCOPY FLX PLACEMENT OF ENDOSCOPIC STENT','SIGMOIDOSCOPY FLX PLACEMENT OF ENDOSCOPIC STENT','45347','1','','1','0','','','',0, 1, 0, 0),
(4113,'SGMDSC FLX WITH ENDOSCOPIC MUCOSAL RESECTION','SGMDSC FLX WITH ENDOSCOPIC MUCOSAL RESECTION','45349','1','','1','0','','','',0, 1, 0, 0),
(4114,'SIGMOIDOSCOPY FLX WITH WITH BAND LIGATION(S)','SIGMOIDOSCOPY FLX WITH WITH BAND LIGATION(S)','45350','1','','1','0','','','',0, 1, 0, 0),
(4115,'COLONOSCOPY FLX DX W/COLLJ SPEC WHEN PFRMD','COLONOSCOPY FLX DX W/COLLJ SPEC WHEN PFRMD','45378','1','','1','0','','','',0, 1, 0, 0),
(4116,'COLONOSCOPY FLX W/REMOVAL OF FOREIGN BODY(S)','COLONOSCOPY FLX W/REMOVAL OF FOREIGN BODY(S)','45379','1','','1','0','','','',0, 1, 0, 0),
(4117,'COLONOSCOPY W/BIOPSY SINGLE/MULTIPLE','COLONOSCOPY W/BIOPSY SINGLE/MULTIPLE','45380','1','','1','0','','','',0, 1, 0, 0),
(4118,'COLSC FLX WITH DIRECTED SUBMUCOSAL NJX ANY SBST','COLSC FLX WITH DIRECTED SUBMUCOSAL NJX ANY SBST','45381','1','','1','0','','','',0, 1, 0, 0),
(4119,'COLSC FLEXIBLE W/CONTROL BLEEDING ANY METHOD','COLSC FLEXIBLE W/CONTROL BLEEDING ANY METHOD','45382','1','','1','0','','','',0, 1, 0, 0),
(4120,'COLSC FLX W/REMOVAL LESION BY HOT BX FORCEPS','COLSC FLX W/REMOVAL LESION BY HOT BX FORCEPS','45384','1','','1','0','','','',0, 1, 0, 0),
(4121,'COLSC FLX W/RMVL OF TUMOR POLYP LESION SNARE TQ','COLSC FLX W/RMVL OF TUMOR POLYP LESION SNARE TQ','45385','1','','1','0','','','',0, 1, 0, 0),
(4122,'COLSC FLEXIBLE W/TRANSENDOSCOPIC BALLOON DILAT','COLSC FLEXIBLE W/TRANSENDOSCOPIC BALLOON DILAT','45386','1','','1','0','','','',0, 1, 0, 0),
(4123,'COLONOSCOPY FLX ABLATION TUMOR POLYP/OTHER LES','COLONOSCOPY FLX ABLATION TUMOR POLYP/OTHER LES','45388','1','','1','0','','','',0, 1, 0, 0),
(4124,'COLONOSCOPY FLX WITH ENDOSCOPIC STENT PLACEMENT','COLONOSCOPY FLX WITH ENDOSCOPIC STENT PLACEMENT','45389','1','','1','0','','','',0, 1, 0, 0),
(4125,'COLONOSCOPY FLX W/ENDOSCOPIC MUCOSAL RESECTION','COLONOSCOPY FLX W/ENDOSCOPIC MUCOSAL RESECTION','45390','1','','1','0','','','',0, 1, 0, 0),
(4126,'COLSC FLX W/NDSC US XM RCTM ET AL LMTD&ADJ STRUX','COLSC FLX W/NDSC US XM RCTM ET AL LMTD&ADJ STRUX','45391','1','','1','0','','','',0, 1, 0, 0),
(4127,'COLSC FLX W/US GUID NDL ASPIR/BX W/US RCTM ET AL','COLSC FLX W/US GUID NDL ASPIR/BX W/US RCTM ET AL','45392','1','','1','0','','','',0, 1, 0, 0),
(4128,'COLONOSCOPY FLEXIBLE WITH DECOMPRESSION','COLONOSCOPY FLEXIBLE WITH DECOMPRESSION','45393','1','','1','0','','','',0, 1, 0, 0),
(4129,'LAPS PROCTECTOMY ABDOMINOPERINEAL W/COLOSTOMY','LAPS PROCTECTOMY ABDOMINOPERINEAL W/COLOSTOMY','45395','1','','1','0','','','',0, 1, 0, 0),
(4130,'LAPS PROCTECTOMY COMBINED PULL-THRU W/RESERVOIR','LAPS PROCTECTOMY COMBINED PULL-THRU W/RESERVOIR','45397','1','','1','0','','','',0, 1, 0, 0),
(4131,'COLONOSCOPY FLEXIBLE WITH BAND LIGATION(S)','COLONOSCOPY FLEXIBLE WITH BAND LIGATION(S)','45398','1','','1','0','','','',0, 1, 0, 0),
(4132,'UNLISTED PROCEDURE COLON','UNLISTED PROCEDURE COLON','45399','1','','1','0','','','',0, 1, 0, 0),
(4133,'LAPAROSCOPY PROCTOPEXY PROLAPSE','LAPAROSCOPY PROCTOPEXY PROLAPSE','45400','1','','1','0','','','',0, 1, 0, 0),
(4134,'LAPAROSCOPY PROCTOPEXY PROLAPSE SIGMOID RESCJ','LAPAROSCOPY PROCTOPEXY PROLAPSE SIGMOID RESCJ','45402','1','','1','0','','','',0, 1, 0, 0),
(4135,'UNLISTED LAPAROSCOPY PROCEDURE RECTUM','UNLISTED LAPAROSCOPY PROCEDURE RECTUM','45499','1','','1','0','','','',0, 1, 0, 0),
(4136,'PROCTOPLASTY STENOSIS','PROCTOPLASTY STENOSIS','45500','1','','1','0','','','',0, 1, 0, 0),
(4137,'PROCTOPLASTY PROLAPSE MUCOUS MEMBRANE','PROCTOPLASTY PROLAPSE MUCOUS MEMBRANE','45505','1','','1','0','','','',0, 1, 0, 0),
(4138,'PERIRECTAL INJ SCLEROSING SOLUTION PROLAPSE','PERIRECTAL INJ SCLEROSING SOLUTION PROLAPSE','45520','1','','1','0','','','',0, 1, 0, 0),
(4139,'PROCTOPEXY ABDOMINAL APPROACH','PROCTOPEXY ABDOMINAL APPROACH','45540','1','','1','0','','','',0, 1, 0, 0),
(4140,'PROCTOPEXY PERINEAL APPROACH','PROCTOPEXY PERINEAL APPROACH','45541','1','','1','0','','','',0, 1, 0, 0),
(4141,'PROCTOPEXY W/SIGMOID RESCJ ABDL APPR','PROCTOPEXY W/SIGMOID RESCJ ABDL APPR','45550','1','','1','0','','','',0, 1, 0, 0),
(4142,'REPAIR RECTOCELE SEPARATE PROCEDURE','REPAIR RECTOCELE SEPARATE PROCEDURE','45560','1','','1','0','','','',0, 1, 0, 0),
(4143,'EXPL RPR & PRESACRAL DRG RECTAL INJURY','EXPL RPR & PRESACRAL DRG RECTAL INJURY','45562','1','','1','0','','','',0, 1, 0, 0),
(4144,'EXPL RPR & PRESACRAL DRG RECTAL INJ W/COLOSTOMY','EXPL RPR & PRESACRAL DRG RECTAL INJ W/COLOSTOMY','45563','1','','1','0','','','',0, 1, 0, 0),
(4145,'CLOSURE RECTOVESICAL FISTULA','CLOSURE RECTOVESICAL FISTULA','45800','1','','1','0','','','',0, 1, 0, 0),
(4146,'CLSR RECTOVESICAL FISTULA W/COLOSTOMY','CLSR RECTOVESICAL FISTULA W/COLOSTOMY','45805','1','','1','0','','','',0, 1, 0, 0),
(4147,'CLOSURE RECTOURETHRAL FISTULA','CLOSURE RECTOURETHRAL FISTULA','45820','1','','1','0','','','',0, 1, 0, 0),
(4148,'CLOSURE RECTOURETHRAL FISTULA W/COLOSTOMY','CLOSURE RECTOURETHRAL FISTULA W/COLOSTOMY','45825','1','','1','0','','','',0, 1, 0, 0),
(4149,'RDCTJ PROCIDENTIA UNDER ANES SEPARATE PROCEDURE','RDCTJ PROCIDENTIA UNDER ANES SEPARATE PROCEDURE','45900','1','','1','0','','','',0, 1, 0, 0),
(4150,'DILAT ANAL SPHNCTR SPX UNDER ANES OTH/THN LOCAL','DILAT ANAL SPHNCTR SPX UNDER ANES OTH/THN LOCAL','45905','1','','1','0','','','',0, 1, 0, 0),
(4151,'DILAT RCT STRIX SPX UNDER ANES OTH/THN LOCAL','DILAT RCT STRIX SPX UNDER ANES OTH/THN LOCAL','45910','1','','1','0','','','',0, 1, 0, 0),
(4152,'RMVL FECAL IMPACTION/FB SPX UNDER ANES','RMVL FECAL IMPACTION/FB SPX UNDER ANES','45915','1','','1','0','','','',0, 1, 0, 0),
(4153,'ANRCT XM SURG REQ ANES GENERAL SPI/EDRL DX','ANRCT XM SURG REQ ANES GENERAL SPI/EDRL DX','45990','1','','1','0','','','',0, 1, 0, 0),
(4154,'UNLISTED PROCEDURE RECTUM','UNLISTED PROCEDURE RECTUM','45999','1','','1','0','','','',0, 1, 0, 0),
(4155,'PLACEMENT SETON','PLACEMENT SETON','46020','1','','1','0','','','',0, 1, 0, 0),
(4156,'REMOVAL ANAL SETON OTHER MARKER','REMOVAL ANAL SETON OTHER MARKER','46030','1','','1','0','','','',0, 1, 0, 0),
(4157,'I&D ISCHIORECTAL&/PERIRECTAL ABSCESS SPX','I&D ISCHIORECTAL&/PERIRECTAL ABSCESS SPX','46040','1','','1','0','','','',0, 1, 0, 0),
(4158,'I&D INTRAMURAL IM/ABSC TRANSANAL ANES','I&D INTRAMURAL IM/ABSC TRANSANAL ANES','46045','1','','1','0','','','',0, 1, 0, 0),
(4159,'I&D PERIANAL ABSCESS SUPERFICIAL','I&D PERIANAL ABSCESS SUPERFICIAL','46050','1','','1','0','','','',0, 1, 0, 0),
(4160,'I&D ISCHIORCT/INTRAMURAL ABSC W/WO SETON','I&D ISCHIORCT/INTRAMURAL ABSC W/WO SETON','46060','1','','1','0','','','',0, 1, 0, 0),
(4161,'INCISION ANAL SEPTUM INFANT','INCISION ANAL SEPTUM INFANT','46070','1','','1','0','','','',0, 1, 0, 0),
(4162,'SPHINCTEROTOMY ANAL DIVISION SPHINCTER SPX','SPHINCTEROTOMY ANAL DIVISION SPHINCTER SPX','46080','1','','1','0','','','',0, 1, 0, 0),
(4163,'INCISION THROMBOSED HEMORRHOID EXTERNAL','INCISION THROMBOSED HEMORRHOID EXTERNAL','46083','1','','1','0','','','',0, 1, 0, 0),
(4164,'FISSURECTOMY INCL SPHINCTEROTOMY WHEN PERFORMED','FISSURECTOMY INCL SPHINCTEROTOMY WHEN PERFORMED','46200','1','','1','0','','','',0, 1, 0, 0),
(4165,'EXCISION SINGLE EXTERNAL PAPILLA OR TAG ANUS','EXCISION SINGLE EXTERNAL PAPILLA OR TAG ANUS','46220','1','','1','0','','','',0, 1, 0, 0),
(4166,'HEMORRHOIDECTOMY INTERNAL RUBBER BAND LIGATIONS','HEMORRHOIDECTOMY INTERNAL RUBBER BAND LIGATIONS','46221','1','','1','0','','','',0, 1, 0, 0),
(4167,'EXCISION MULTIPLE EXTERNAL PAPILLAE/TAGS ANUS','EXCISION MULTIPLE EXTERNAL PAPILLAE/TAGS ANUS','46230','1','','1','0','','','',0, 1, 0, 0),
(4168,'HEMORRHOIDECTOMY XTRNL 2/> COLUMN/GROUP','HEMORRHOIDECTOMY XTRNL 2/> COLUMN/GROUP','46250','1','','1','0','','','',0, 1, 0, 0),
(4169,'HEMORRHOIDECTOMY NTRNL & XTRNL 1 COLUMN/GROUP','HEMORRHOIDECTOMY NTRNL & XTRNL 1 COLUMN/GROUP','46255','1','','1','0','','','',0, 1, 0, 0),
(4170,'HEMORRHOID NTRNL & XTRNL 1 COLUMN W/FISSURECTO','HEMORRHOID NTRNL & XTRNL 1 COLUMN W/FISSURECTO','46257','1','','1','0','','','',0, 1, 0, 0),
(4171,'HRHC 1 COL/GRP W/FSTULECTMY INCL FSSRECTOMY','HRHC 1 COL/GRP W/FSTULECTMY INCL FSSRECTOMY','46258','1','','1','0','','','',0, 1, 0, 0),
(4172,'HEMORRHOIDECTOMY INT & XTRNL 2/> COLUMN/GRO','HEMORRHOIDECTOMY INT & XTRNL 2/> COLUMN/GRO','46260','1','','1','0','','','',0, 1, 0, 0),
(4173,'HRHC NTRNL & XTRNL 2/> COLUMN/GROUP W/FISSU','HRHC NTRNL & XTRNL 2/> COLUMN/GROUP W/FISSU','46261','1','','1','0','','','',0, 1, 0, 0),
(4174,'HRHC 2/> COL/GRP W/FSTULECTMY INCL FSSRECTMY','HRHC 2/> COL/GRP W/FSTULECTMY INCL FSSRECTMY','46262','1','','1','0','','','',0, 1, 0, 0),
(4175,'SURG TX ANAL FISTULA SUBQ','SURG TX ANAL FISTULA SUBQ','46270','1','','1','0','','','',0, 1, 0, 0),
(4176,'SURG TX ANAL FISTULA INTERSPHINCTERIC','SURG TX ANAL FISTULA INTERSPHINCTERIC','46275','1','','1','0','','','',0, 1, 0, 0),
(4177,'TX ANAL FSTL TRANS/SUPRA/XTRASPHNCTRC INCL SETON','TX ANAL FSTL TRANS/SUPRA/XTRASPHNCTRC INCL SETON','46280','1','','1','0','','','',0, 1, 0, 0),
(4178,'SURG TX ANAL FISTULA 2ND STAGE','SURG TX ANAL FISTULA 2ND STAGE','46285','1','','1','0','','','',0, 1, 0, 0),
(4179,'CLSR ANAL FSTL W/RCT ADVMNT FLAP','CLSR ANAL FSTL W/RCT ADVMNT FLAP','46288','1','','1','0','','','',0, 1, 0, 0),
(4180,'EXC THROMBOSED HEMORRHOID XTRNL','EXC THROMBOSED HEMORRHOID XTRNL','46320','1','','1','0','','','',0, 1, 0, 0),
(4181,'INJECTION SCLEROSING SOLUTION HEMORRHOIDS','INJECTION SCLEROSING SOLUTION HEMORRHOIDS','46500','1','','1','0','','','',0, 1, 0, 0),
(4182,'CHEMODENERVATION INTERNAL ANAL SPHINCTER','CHEMODENERVATION INTERNAL ANAL SPHINCTER','46505','1','','1','0','','','',0, 1, 0, 0),
(4183,'ANOSCOPY DX W/COLLJ SPEC BR/WA SPX WHEN PRFRMD','ANOSCOPY DX W/COLLJ SPEC BR/WA SPX WHEN PRFRMD','46600','1','','1','0','','','',0, 1, 0, 0),
(4184,'ANOSCOPY DX W/HRA &CHEM AGNTS ENHANCEMENT','ANOSCOPY DX W/HRA &CHEM AGNTS ENHANCEMENT','46601','1','','1','0','','','',0, 1, 0, 0),
(4185,'ANOSCOPY W/DILATION','ANOSCOPY W/DILATION','46604','1','','1','0','','','',0, 1, 0, 0),
(4186,'ANOSCOPY W/BX SINGLE/MULTIPLE','ANOSCOPY W/BX SINGLE/MULTIPLE','46606','1','','1','0','','','',0, 1, 0, 0),
(4187,'ANOSCOPY DX W/HRA &CHEM AGNTS ENHANCEMENT W/BX','ANOSCOPY DX W/HRA &CHEM AGNTS ENHANCEMENT W/BX','46607','1','','1','0','','','',0, 1, 0, 0),
(4188,'ANOSCOPY W/RMVL FOREIGN BODY','ANOSCOPY W/RMVL FOREIGN BODY','46608','1','','1','0','','','',0, 1, 0, 0),
(4189,'ANOSCOPY W/RMVL LESION CAUTERY','ANOSCOPY W/RMVL LESION CAUTERY','46610','1','','1','0','','','',0, 1, 0, 0),
(4190,'ANOSC RMVL 1 TUM POLYP/OTH LES SNARE TQ','ANOSC RMVL 1 TUM POLYP/OTH LES SNARE TQ','46611','1','','1','0','','','',0, 1, 0, 0),
(4191,'ANOSC RMVL MULT TUMORS CAUTERY/SNARE','ANOSC RMVL MULT TUMORS CAUTERY/SNARE','46612','1','','1','0','','','',0, 1, 0, 0),
(4192,'ANOSCOPY CONTROL BLEEDING','ANOSCOPY CONTROL BLEEDING','46614','1','','1','0','','','',0, 1, 0, 0),
(4193,'ANOSCOPY ABLATION LESION','ANOSCOPY ABLATION LESION','46615','1','','1','0','','','',0, 1, 0, 0),
(4194,'ANOPLASTY PLASTIC OPERATION STRICTURE ADULT','ANOPLASTY PLASTIC OPERATION STRICTURE ADULT','46700','1','','1','0','','','',0, 1, 0, 0),
(4195,'ANOPLASTY PLASTIC OPERATION STRICTURE INFANT','ANOPLASTY PLASTIC OPERATION STRICTURE INFANT','46705','1','','1','0','','','',0, 1, 0, 0),
(4196,'REPAIR ANAL FISTULA W/FIBRIN GLUE','REPAIR ANAL FISTULA W/FIBRIN GLUE','46706','1','','1','0','','','',0, 1, 0, 0),
(4197,'REPAIR ANORECTAL FISTULA PLUG','REPAIR ANORECTAL FISTULA PLUG','46707','1','','1','0','','','',0, 1, 0, 0),
(4198,'RPR ILEOANAL POUCH FSTL/POUCH ADVMNT TPRNL APPR','RPR ILEOANAL POUCH FSTL/POUCH ADVMNT TPRNL APPR','46710','1','','1','0','','','',0, 1, 0, 0),
(4199,'RPR ILEOANAL POUCH FSTL/POUCH ADVMNT CMBN APPR','RPR ILEOANAL POUCH FSTL/POUCH ADVMNT CMBN APPR','46712','1','','1','0','','','',0, 1, 0, 0),
(4200,'RPR LW IMPERFORATE ANUS W/ANOPRNL FSTL CUT-BK','RPR LW IMPERFORATE ANUS W/ANOPRNL FSTL CUT-BK','46715','1','','1','0','','','',0, 1, 0, 0),
(4201,'RPR LW IMPERFORATE ANUS W/TRPOS FISTULA','RPR LW IMPERFORATE ANUS W/TRPOS FISTULA','46716','1','','1','0','','','',0, 1, 0, 0),
(4202,'RPR HI IMPRF ANUS W/O FSTL PRNL/SACROPRNL APPR','RPR HI IMPRF ANUS W/O FSTL PRNL/SACROPRNL APPR','46730','1','','1','0','','','',0, 1, 0, 0),
(4203,'RPR HI IMPRF ANUS W/O FISTULA CMBN APPR','RPR HI IMPRF ANUS W/O FISTULA CMBN APPR','46735','1','','1','0','','','',0, 1, 0, 0),
(4204,'RPR HI IMPRF ANUS W/FSTL PRNL/SACROPRNL APPR','RPR HI IMPRF ANUS W/FSTL PRNL/SACROPRNL APPR','46740','1','','1','0','','','',0, 1, 0, 0),
(4205,'RPR HI IMPRF ANUS W/FSTL TABDL & SACROPRNL','RPR HI IMPRF ANUS W/FSTL TABDL & SACROPRNL','46742','1','','1','0','','','',0, 1, 0, 0),
(4206,'RPR CLOACAL ANOMALY SACROPERINEAL','RPR CLOACAL ANOMALY SACROPERINEAL','46744','1','','1','0','','','',0, 1, 0, 0),
(4207,'RPR CLOACAL ANOMALY CMBN ABDL&SACROPRNL','RPR CLOACAL ANOMALY CMBN ABDL&SACROPRNL','46746','1','','1','0','','','',0, 1, 0, 0),
(4208,'RPR CLOACAL ANOMALY CMBN ABDL & SACROPRNL W/GRF','RPR CLOACAL ANOMALY CMBN ABDL & SACROPRNL W/GRF','46748','1','','1','0','','','',0, 1, 0, 0),
(4209,'SPHNCTROP ANAL INCONTINENCE/PROLAPSE ADULT','SPHNCTROP ANAL INCONTINENCE/PROLAPSE ADULT','46750','1','','1','0','','','',0, 1, 0, 0),
(4210,'SPHNCTROP ANAL INCONTINENCE/PROLAPSE CHLD','SPHNCTROP ANAL INCONTINENCE/PROLAPSE CHLD','46751','1','','1','0','','','',0, 1, 0, 0),
(4211,'GRAFT THIERSCH RCT INCONTINENCE &/PROLAPSE','GRAFT THIERSCH RCT INCONTINENCE &/PROLAPSE','46753','1','','1','0','','','',0, 1, 0, 0),
(4212,'RMVL THIERSCH WIRE/SUTURE ANAL CANAL','RMVL THIERSCH WIRE/SUTURE ANAL CANAL','46754','1','','1','0','','','',0, 1, 0, 0),
(4213,'SPHINCTEROPLASTY ANAL MUSCLE TRANSPLANT','SPHINCTEROPLASTY ANAL MUSCLE TRANSPLANT','46760','1','','1','0','','','',0, 1, 0, 0),
(4214,'SPHNCTROP ANAL LEVATOR MUSC IMBRCJ','SPHNCTROP ANAL LEVATOR MUSC IMBRCJ','46761','1','','1','0','','','',0, 1, 0, 0),
(4215,'SPHNCTROP ANAL IMPLTJ ARTIF SPHNCTR','SPHNCTROP ANAL IMPLTJ ARTIF SPHNCTR','46762','1','','1','0','','','',0, 1, 0, 0),
(4216,'DSTRJ LESION ANUS SIMPLE CHEMICAL','DSTRJ LESION ANUS SIMPLE CHEMICAL','46900','1','','1','0','','','',0, 1, 0, 0),
(4217,'DSTRJ LESION ANUS SMPL ELTRDSICCATION','DSTRJ LESION ANUS SMPL ELTRDSICCATION','46910','1','','1','0','','','',0, 1, 0, 0),
(4218,'DSTRJ LESION ANUS SIMPLE CRYOSURGERY','DSTRJ LESION ANUS SIMPLE CRYOSURGERY','46916','1','','1','0','','','',0, 1, 0, 0),
(4219,'DSTRJ LESION ANUS SIMPLE LASER SURG','DSTRJ LESION ANUS SIMPLE LASER SURG','46917','1','','1','0','','','',0, 1, 0, 0),
(4220,'DSTRJ LESION ANUS SIMPLE SURG EXCISION','DSTRJ LESION ANUS SIMPLE SURG EXCISION','46922','1','','1','0','','','',0, 1, 0, 0),
(4221,'DSTRJ LESION ANUS EXTENSIVE','DSTRJ LESION ANUS EXTENSIVE','46924','1','','1','0','','','',0, 1, 0, 0),
(4222,'DESTRUCTION INTERNAL HEMORRHOID THERMAL ENERGY','DESTRUCTION INTERNAL HEMORRHOID THERMAL ENERGY','46930','1','','1','0','','','',0, 1, 0, 0),
(4223,'CURTG/CAUT ANAL FISSURE W/DILAT SPHNCTR SPX 1ST','CURTG/CAUT ANAL FISSURE W/DILAT SPHNCTR SPX 1ST','46940','1','','1','0','','','',0, 1, 0, 0),
(4224,'CURTG/CAUT ANAL FISSURE W/DILAT SPHNCTR SPX SBSQ','CURTG/CAUT ANAL FISSURE W/DILAT SPHNCTR SPX SBSQ','46942','1','','1','0','','','',0, 1, 0, 0),
(4225,'HRHC NTRNL LIG OTH THAN RBBR BAND 1 COL/GRP','HRHC NTRNL LIG OTH THAN RBBR BAND 1 COL/GRP','46945','1','','1','0','','','',0, 1, 0, 0),
(4226,'HRHC NTRNL LIG OTH THAN RBBR BAND 2/> COL/GRP','HRHC NTRNL LIG OTH THAN RBBR BAND 2/> COL/GRP','46946','1','','1','0','','','',0, 1, 0, 0),
(4227,'HEMORRHOIDOPEXY STAPLING','HEMORRHOIDOPEXY STAPLING','46947','1','','1','0','','','',0, 1, 0, 0),
(4228,'UNLISTED PROCEDURE ANUS','UNLISTED PROCEDURE ANUS','46999','1','','1','0','','','',0, 1, 0, 0),
(4229,'BIOPSY LIVER NEEDLE PERCUTANEOUS','BIOPSY LIVER NEEDLE PERCUTANEOUS','47000','1','','1','0','','','',0, 1, 0, 0),
(4230,'BX LVR NDL DONE PURPOSE TM OTH MAJOR PX','BX LVR NDL DONE PURPOSE TM OTH MAJOR PX','47001','1','','1','0','','','',0, 1, 0, 0),
(4231,'HEPATOTOMY OPEN DRAINAGE ABSCESS/CYST 1/2 STAGES','HEPATOTOMY OPEN DRAINAGE ABSCESS/CYST 1/2 STAGES','47010','1','','1','0','','','',0, 1, 0, 0),
(4232,'LAPT W/ASPIR &/NJX HEPATC PARASITIC CYST/ABSCESS','LAPT W/ASPIR &/NJX HEPATC PARASITIC CYST/ABSCESS','47015','1','','1','0','','','',0, 1, 0, 0),
(4233,'BIOPSY LIVER WEDGE','BIOPSY LIVER WEDGE','47100','1','','1','0','','','',0, 1, 0, 0),
(4234,'HEPATECTOMY RESCJ PARTIAL LOBECTOMY','HEPATECTOMY RESCJ PARTIAL LOBECTOMY','47120','1','','1','0','','','',0, 1, 0, 0),
(4235,'HEPATECTOMY RESCJ TRISEGMENTECTOMY','HEPATECTOMY RESCJ TRISEGMENTECTOMY','47122','1','','1','0','','','',0, 1, 0, 0),
(4236,'HEPATECTOMY RESCJ TOTAL LEFT LOBECTOMY','HEPATECTOMY RESCJ TOTAL LEFT LOBECTOMY','47125','1','','1','0','','','',0, 1, 0, 0),
(4237,'HEPATECTOMY RESCJ TOTAL RIGHT LOBECTOMY','HEPATECTOMY RESCJ TOTAL RIGHT LOBECTOMY','47130','1','','1','0','','','',0, 1, 0, 0),
(4238,'DONOR HEPATECTOMY CADAVER DONOR','DONOR HEPATECTOMY CADAVER DONOR','47133','1','','1','0','','','',0, 1, 0, 0),
(4239,'LVR ALTRNSPLJ ORTHOTOPIC PRTL/WHL DON ANY AGE','LVR ALTRNSPLJ ORTHOTOPIC PRTL/WHL DON ANY AGE','47135','1','','1','0','','','',0, 1, 0, 0),
(4240,'DONOR HEPATECTOMY LIVING DONOR SEG II & III','DONOR HEPATECTOMY LIVING DONOR SEG II & III','47140','1','','1','0','','','',0, 1, 0, 0),
(4241,'DONOR HEPATECTOMY LIVING DONOR SEG II III & IV','DONOR HEPATECTOMY LIVING DONOR SEG II III & IV','47141','1','','1','0','','','',0, 1, 0, 0),
(4242,'DONOR HEPATECTOMY LIVING DONOR SEG V VI VII &VI','DONOR HEPATECTOMY LIVING DONOR SEG V VI VII &VI','47142','1','','1','0','','','',0, 1, 0, 0),
(4243,'BKBENCH PREP CADAVER DONOR','BKBENCH PREP CADAVER DONOR','47143','1','','1','0','','','',0, 1, 0, 0),
(4244,'BKBENCH PREPJ CADAVER WHOLE LIVER GRF I&IV VII','BKBENCH PREPJ CADAVER WHOLE LIVER GRF I&IV VII','47144','1','','1','0','','','',0, 1, 0, 0),
(4245,'BKBENCH PREPJ CADAVER DONOR WHL LVR GRF I&V VI','BKBENCH PREPJ CADAVER DONOR WHL LVR GRF I&V VI','47145','1','','1','0','','','',0, 1, 0, 0),
(4246,'BKBENCH RCNSTJ LVR GRF VENOUS ANAST EA','BKBENCH RCNSTJ LVR GRF VENOUS ANAST EA','47146','1','','1','0','','','',0, 1, 0, 0),
(4247,'BKBENCH RCNSTJ LVR GRF ARTL ANAST EA','BKBENCH RCNSTJ LVR GRF ARTL ANAST EA','47147','1','','1','0','','','',0, 1, 0, 0),
(4248,'MARSUPIALIZATION CST/ABSC LVR','MARSUPIALIZATION CST/ABSC LVR','47300','1','','1','0','','','',0, 1, 0, 0),
(4249,'MGMT LVR HEMRRG SMPL SUTR LVR WND/INJ','MGMT LVR HEMRRG SMPL SUTR LVR WND/INJ','47350','1','','1','0','','','',0, 1, 0, 0),
(4250,'MGMT LVR HEMRRG CPLX SUTR WND/INJ','MGMT LVR HEMRRG CPLX SUTR WND/INJ','47360','1','','1','0','','','',0, 1, 0, 0),
(4251,'MGMT LVR HEMRRG EXPL WND DBRDMT COAGJ/SUTR','MGMT LVR HEMRRG EXPL WND DBRDMT COAGJ/SUTR','47361','1','','1','0','','','',0, 1, 0, 0),
(4252,'MGMT LVR HEMRRG RE-EXPL WND RMVL PACKING','MGMT LVR HEMRRG RE-EXPL WND RMVL PACKING','47362','1','','1','0','','','',0, 1, 0, 0),
(4253,'LAPS SURG ABLTJ 1/> LVR TUM RF','LAPS SURG ABLTJ 1/> LVR TUM RF','47370','1','','1','0','','','',0, 1, 0, 0),
(4254,'LAPS SURG ABLTJ 1 > LVR TUM CRYOSURG','LAPS SURG ABLTJ 1 > LVR TUM CRYOSURG','47371','1','','1','0','','','',0, 1, 0, 0),
(4255,'UNLIS LAPAROSCOPIC PROCEDURE LIVER','UNLIS LAPAROSCOPIC PROCEDURE LIVER','47379','1','','1','0','','','',0, 1, 0, 0),
(4256,'ABLTJ OPN 1/> LVR TUM RF','ABLTJ OPN 1/> LVR TUM RF','47380','1','','1','0','','','',0, 1, 0, 0),
(4257,'ABLTJ OPN 1/> LVR TUM CRYOSURG','ABLTJ OPN 1/> LVR TUM CRYOSURG','47381','1','','1','0','','','',0, 1, 0, 0),
(4258,'ABLTJ 1/> LVR TUM PRQ RF','ABLTJ 1/> LVR TUM PRQ RF','47382','1','','1','0','','','',0, 1, 0, 0),
(4259,'ABLATION 1/> LIVER TUMOR PERQ CRYOABLATION','ABLATION 1/> LIVER TUMOR PERQ CRYOABLATION','47383','1','','1','0','','','',0, 1, 0, 0),
(4260,'UNLISTED PROCEDURE LIVER','UNLISTED PROCEDURE LIVER','47399','1','','1','0','','','',0, 1, 0, 0),
(4261,'HEPATCOTOMY/HEPATCOSTOMY W/EXPL DRG/RMVL ST1','HEPATCOTOMY/HEPATCOSTOMY W/EXPL DRG/RMVL ST1','47400','1','','1','0','','','',0, 1, 0, 0),
(4262,'CHOLEDOCHOT/OST W/O SPHNCTROTOMY/SPHNCTROP','CHOLEDOCHOT/OST W/O SPHNCTROTOMY/SPHNCTROP','47420','1','','1','0','','','',0, 1, 0, 0),
(4263,'CHOLEDOCHOT/OST W/SPHNCTROTOMY/SPHNCTROP','CHOLEDOCHOT/OST W/SPHNCTROTOMY/SPHNCTROP','47425','1','','1','0','','','',0, 1, 0, 0),
(4264,'TRANSDUOL SPHINCTEROT/PLASTY W/WO RMVL CALCULUS','TRANSDUOL SPHINCTEROT/PLASTY W/WO RMVL CALCULUS','47460','1','','1','0','','','',0, 1, 0, 0),
(4265,'CHOLECSTOT/CHOLECSTOST W/EXPL DRG/RMVL ST1 SPX','CHOLECSTOT/CHOLECSTOST W/EXPL DRG/RMVL ST1 SPX','47480','1','','1','0','','','',0, 1, 0, 0),
(4266,'CHOLECYSTOSTOMY PRQ W/IMAGING & CATHETER PLMT','CHOLECYSTOSTOMY PRQ W/IMAGING & CATHETER PLMT','47490','1','','1','0','','','',0, 1, 0, 0),
(4267,'NJX CHOLANGIO PRQ W/IMG GID RS&I EXISTING ACCESS','NJX CHOLANGIO PRQ W/IMG GID RS&I EXISTING ACCESS','47531','1','','1','0','','','',0, 1, 0, 0),
(4268,'NJX CHOLANGIO PRQ W/IMG GID RS&I NEW ACCESS','NJX CHOLANGIO PRQ W/IMG GID RS&I NEW ACCESS','47532','1','','1','0','','','',0, 1, 0, 0),
(4269,'PRQ PLMT BILIARY DRG CATH W/IMG GID RS&I EXTERNL','PRQ PLMT BILIARY DRG CATH W/IMG GID RS&I EXTERNL','47533','1','','1','0','','','',0, 1, 0, 0),
(4270,'PRQ PLMT BILIARY DRG CATH W/IMG GID RS&I INT-EXT','PRQ PLMT BILIARY DRG CATH W/IMG GID RS&I INT-EXT','47534','1','','1','0','','','',0, 1, 0, 0),
(4271,'CONV EXT BIL DRG CATH TO INT-EXT BIL DRG CATH','CONV EXT BIL DRG CATH TO INT-EXT BIL DRG CATH','47535','1','','1','0','','','',0, 1, 0, 0),
(4272,'EXCHANGE BILIARY DRG CATHETER PRQ W/IMG GID RS&I','EXCHANGE BILIARY DRG CATHETER PRQ W/IMG GID RS&I','47536','1','','1','0','','','',0, 1, 0, 0),
(4273,'REMOVAL BILIARY DRG CATHETER REQ FLUOR GID RS&I','REMOVAL BILIARY DRG CATHETER REQ FLUOR GID RS&I','47537','1','','1','0','','','',0, 1, 0, 0),
(4274,'PLMT BILE DUCT STENT PRQ EXISTING ACCESS','PLMT BILE DUCT STENT PRQ EXISTING ACCESS','47538','1','','1','0','','','',0, 1, 0, 0),
(4275,'PLMT BILE DUCT STENT PRQ NEW ACCESS W/O SEP CATH','PLMT BILE DUCT STENT PRQ NEW ACCESS W/O SEP CATH','47539','1','','1','0','','','',0, 1, 0, 0),
(4276,'PLMT BILE DUCT STENT PRQ NEW ACCESS W/SEP CATH','PLMT BILE DUCT STENT PRQ NEW ACCESS W/SEP CATH','47540','1','','1','0','','','',0, 1, 0, 0),
(4277,'PLMT ACCESS THRU BILIARY TREE INTO SMALL BWL NEW','PLMT ACCESS THRU BILIARY TREE INTO SMALL BWL NEW','47541','1','','1','0','','','',0, 1, 0, 0),
(4278,'BALLOON DILAT BILIARY DUCT/AMPULLA PRQ EACH DUCT','BALLOON DILAT BILIARY DUCT/AMPULLA PRQ EACH DUCT','47542','1','','1','0','','','',0, 1, 0, 0),
(4279,'ENDOLUMINAL BX BILIARY TREE PRQ ANY METH SNG/MLT','ENDOLUMINAL BX BILIARY TREE PRQ ANY METH SNG/MLT','47543','1','','1','0','','','',0, 1, 0, 0),
(4280,'REMOVAL BILIARY DUCT &/GLBLDR CALCULI PERQ RS&I','REMOVAL BILIARY DUCT &/GLBLDR CALCULI PERQ RS&I','47544','1','','1','0','','','',0, 1, 0, 0),
(4281,'BILIARY NDSC INTRAOPERATIVE','BILIARY NDSC INTRAOPERATIVE','47550','1','','1','0','','','',0, 1, 0, 0),
(4282,'BILIARY ENDO PRQ T-TUBE DX W/COLLECT SPEC BRUSH','BILIARY ENDO PRQ T-TUBE DX W/COLLECT SPEC BRUSH','47552','1','','1','0','','','',0, 1, 0, 0),
(4283,'BILIARY NDSC PRQ T-TUBE W/BX SINGLE/MULTIPLE','BILIARY NDSC PRQ T-TUBE W/BX SINGLE/MULTIPLE','47553','1','','1','0','','','',0, 1, 0, 0),
(4284,'BILIARY ENDOSCOPY PRQ VIA T-TUBE W/RMVL CALCULUS','BILIARY ENDOSCOPY PRQ VIA T-TUBE W/RMVL CALCULUS','47554','1','','1','0','','','',0, 1, 0, 0),
(4285,'BILIARY NDSC PRQ T-TUBE W/DIL DUCT W/O STENT','BILIARY NDSC PRQ T-TUBE W/DIL DUCT W/O STENT','47555','1','','1','0','','','',0, 1, 0, 0),
(4286,'BILIARY NDSC PRQ T-TUBE DILAT STRIX W/STENT','BILIARY NDSC PRQ T-TUBE DILAT STRIX W/STENT','47556','1','','1','0','','','',0, 1, 0, 0),
(4287,'LAPAROSCOPY SURG CHOLECYSTECTOMY','LAPAROSCOPY SURG CHOLECYSTECTOMY','47562','1','','1','0','','','',0, 1, 0, 0),
(4288,'LAPS SURG CHOLECYSTECTOMY W/CHOLANGIOGRAPHY','LAPS SURG CHOLECYSTECTOMY W/CHOLANGIOGRAPHY','47563','1','','1','0','','','',0, 1, 0, 0),
(4289,'LAPS SURG CHOLECSTC W/EXPL COMMON DUCT','LAPS SURG CHOLECSTC W/EXPL COMMON DUCT','47564','1','','1','0','','','',0, 1, 0, 0),
(4290,'LAPAROSCOPY SURG CHOLECYSTOENETEROSTOMY','LAPAROSCOPY SURG CHOLECYSTOENETEROSTOMY','47570','1','','1','0','','','',0, 1, 0, 0),
(4291,'UNLISTED LAPAROSCOPY PROCEDURE BILIARY TRACT','UNLISTED LAPAROSCOPY PROCEDURE BILIARY TRACT','47579','1','','1','0','','','',0, 1, 0, 0),
(4292,'CHOLECYSTECTOMY','CHOLECYSTECTOMY','47600','1','','1','0','','','',0, 1, 0, 0),
(4293,'CHOLECYSTECTOMY W/CHOLANGIOGRAPHY','CHOLECYSTECTOMY W/CHOLANGIOGRAPHY','47605','1','','1','0','','','',0, 1, 0, 0),
(4294,'CHOLECYSTECTOMY W/EXPLORATION COMMON DUCT','CHOLECYSTECTOMY W/EXPLORATION COMMON DUCT','47610','1','','1','0','','','',0, 1, 0, 0),
(4295,'CHOLECYSTECTOMY EXPL DUCT CHOLEDOCHOENTEROSTOMY','CHOLECYSTECTOMY EXPL DUCT CHOLEDOCHOENTEROSTOMY','47612','1','','1','0','','','',0, 1, 0, 0),
(4296,'CHOLECSTC EXPL DUX SPHNCTROTOMY/SPHNCTROP','CHOLECSTC EXPL DUX SPHNCTROTOMY/SPHNCTROP','47620','1','','1','0','','','',0, 1, 0, 0),
(4297,'EXPL CONGENITAL ATRESIA BILE DUCTS','EXPL CONGENITAL ATRESIA BILE DUCTS','47700','1','','1','0','','','',0, 1, 0, 0),
(4298,'PORTOENETEROSTOMY','PORTOENETEROSTOMY','47701','1','','1','0','','','',0, 1, 0, 0),
(4299,'EXC BILE DUX TUM W/WO PRIM RPR XTRHEPATC','EXC BILE DUX TUM W/WO PRIM RPR XTRHEPATC','47711','1','','1','0','','','',0, 1, 0, 0),
(4300,'EXC BILE DUX TUM W/WO PRIM RPR INTRAHEPATC','EXC BILE DUX TUM W/WO PRIM RPR INTRAHEPATC','47712','1','','1','0','','','',0, 1, 0, 0),
(4301,'EXCISION CHOLEDOCHAL CYST','EXCISION CHOLEDOCHAL CYST','47715','1','','1','0','','','',0, 1, 0, 0),
(4302,'CHOLECYSTOENTEROSTOMY DIRECT','CHOLECYSTOENTEROSTOMY DIRECT','47720','1','','1','0','','','',0, 1, 0, 0),
(4303,'CHOLECYSTOENTEROSTOMY W/GASTROENTEROSTOMY','CHOLECYSTOENTEROSTOMY W/GASTROENTEROSTOMY','47721','1','','1','0','','','',0, 1, 0, 0),
(4304,'CHOLECYSTOENTEROSTOMY ROUX-EN-Y','CHOLECYSTOENTEROSTOMY ROUX-EN-Y','47740','1','','1','0','','','',0, 1, 0, 0),
(4305,'CHOLECSTONTRSTM ROUX-EN-Y W/GASTRONTRSTM','CHOLECSTONTRSTM ROUX-EN-Y W/GASTRONTRSTM','47741','1','','1','0','','','',0, 1, 0, 0),
(4306,'ANAST XTRHEPATC BILIARY DUCTS & GI TRACT','ANAST XTRHEPATC BILIARY DUCTS & GI TRACT','47760','1','','1','0','','','',0, 1, 0, 0),
(4307,'ANAST INTRAHEPATC DUCTS & GI TRACT','ANAST INTRAHEPATC DUCTS & GI TRACT','47765','1','','1','0','','','',0, 1, 0, 0),
(4308,'ANAST ROUX-EN-Y XTRHEPATC BILIARY DUCTS & GI','ANAST ROUX-EN-Y XTRHEPATC BILIARY DUCTS & GI','47780','1','','1','0','','','',0, 1, 0, 0),
(4309,'ANAST ROUX-EN-Y INTRAHEPATC BILIARY DUCTS & GI','ANAST ROUX-EN-Y INTRAHEPATC BILIARY DUCTS & GI','47785','1','','1','0','','','',0, 1, 0, 0),
(4310,'RCNSTJ PLSTC BILIARY DUCTS W/END-TO-END ANAST','RCNSTJ PLSTC BILIARY DUCTS W/END-TO-END ANAST','47800','1','','1','0','','','',0, 1, 0, 0),
(4311,'PLACEMENT CHOLEDOCHAL STENT','PLACEMENT CHOLEDOCHAL STENT','47801','1','','1','0','','','',0, 1, 0, 0),
(4312,'U-TUBE HEPATICOENTEROSTOMY','U-TUBE HEPATICOENTEROSTOMY','47802','1','','1','0','','','',0, 1, 0, 0),
(4313,'SUTURE EXTRAHEPATIC BILE DUCT PRE-EXIST INJURY','SUTURE EXTRAHEPATIC BILE DUCT PRE-EXIST INJURY','47900','1','','1','0','','','',0, 1, 0, 0),
(4314,'UNLISTED PROCEDURE BILIARY TRACT','UNLISTED PROCEDURE BILIARY TRACT','47999','1','','1','0','','','',0, 1, 0, 0),
(4315,'PLACE DRAIN PERIPANCREATIC ACUTE PANCREATITIS','PLACE DRAIN PERIPANCREATIC ACUTE PANCREATITIS','48000','1','','1','0','','','',0, 1, 0, 0),
(4316,'PLACE DRAIN PERIPANCREATIC W/CHOLECYSTOSTOMY','PLACE DRAIN PERIPANCREATIC W/CHOLECYSTOSTOMY','48001','1','','1','0','','','',0, 1, 0, 0),
(4317,'REMOVAL PANCREATIC CALCULUS','REMOVAL PANCREATIC CALCULUS','48020','1','','1','0','','','',0, 1, 0, 0),
(4318,'BIOPSY PANCREAS OPEN','BIOPSY PANCREAS OPEN','48100','1','','1','0','','','',0, 1, 0, 0),
(4319,'BIOPSY PANCREA PERCUTANEOUS NEEDLE','BIOPSY PANCREA PERCUTANEOUS NEEDLE','48102','1','','1','0','','','',0, 1, 0, 0),
(4320,'RESECJ/DBRDMT PANCREAS NECROTIZING PANCREATITIS','RESECJ/DBRDMT PANCREAS NECROTIZING PANCREATITIS','48105','1','','1','0','','','',0, 1, 0, 0),
(4321,'EXCISION LESION PANCREAS','EXCISION LESION PANCREAS','48120','1','','1','0','','','',0, 1, 0, 0),
(4322,'PNCRTECT DSTL STOT W/O PNCRTCOJEJUNOSTOMY','PNCRTECT DSTL STOT W/O PNCRTCOJEJUNOSTOMY','48140','1','','1','0','','','',0, 1, 0, 0),
(4323,'PNCRTECT DSTL STOT W/PNCRTCOJEJUNOSTOMY','PNCRTECT DSTL STOT W/PNCRTCOJEJUNOSTOMY','48145','1','','1','0','','','',0, 1, 0, 0),
(4324,'PNCRTECT DSTL NR-TOT W/PRSRV DUO CHLD-TYP PX','PNCRTECT DSTL NR-TOT W/PRSRV DUO CHLD-TYP PX','48146','1','','1','0','','','',0, 1, 0, 0),
(4325,'EXCISION AMPULLA VATER','EXCISION AMPULLA VATER','48148','1','','1','0','','','',0, 1, 0, 0),
(4326,'PNCRTECT PROX STOT W/PANCREATOJEJUNOSTOMY','PNCRTECT PROX STOT W/PANCREATOJEJUNOSTOMY','48150','1','','1','0','','','',0, 1, 0, 0),
(4327,'PNCRTECT WHIPPLE W/O PANCREATOJEJUNOSTOMY','PNCRTECT WHIPPLE W/O PANCREATOJEJUNOSTOMY','48152','1','','1','0','','','',0, 1, 0, 0),
(4328,'PNCRTECT W/PANCREATOJEJUNOSTOMY','PNCRTECT W/PANCREATOJEJUNOSTOMY','48153','1','','1','0','','','',0, 1, 0, 0),
(4329,'PNCRTECT PROX STOT W/O PANCREATOJEJUNOSTOMY','PNCRTECT PROX STOT W/O PANCREATOJEJUNOSTOMY','48154','1','','1','0','','','',0, 1, 0, 0),
(4330,'PANCREATECTOMY TOTAL','PANCREATECTOMY TOTAL','48155','1','','1','0','','','',0, 1, 0, 0),
(4331,'PANCREATECTOMY W/TRNSPLJ PANCREAS/ISLET CELLS','PANCREATECTOMY W/TRNSPLJ PANCREAS/ISLET CELLS','48160','1','','1','0','','','',0, 1, 0, 0),
(4332,'INJECTION INTRAOPERATIVE PANCREATOGRAPHY','INJECTION INTRAOPERATIVE PANCREATOGRAPHY','48400','1','','1','0','','','',0, 1, 0, 0),
(4333,'MARSUPIALIZATION PANCREATIC CYST','MARSUPIALIZATION PANCREATIC CYST','48500','1','','1','0','','','',0, 1, 0, 0),
(4334,'EXTERNAL DRAINAGE PSEUDOCYST OF PANCREAS OPEN','EXTERNAL DRAINAGE PSEUDOCYST OF PANCREAS OPEN','48510','1','','1','0','','','',0, 1, 0, 0),
(4335,'INT ANAST PANCREATIC CYST GI TRACT DIRECT','INT ANAST PANCREATIC CYST GI TRACT DIRECT','48520','1','','1','0','','','',0, 1, 0, 0),
(4336,'INT ANAST PANCREATIC CYST GI TRACT ROUX-EN-Y','INT ANAST PANCREATIC CYST GI TRACT ROUX-EN-Y','48540','1','','1','0','','','',0, 1, 0, 0),
(4337,'PANCREATORRHAPHY INJURY','PANCREATORRHAPHY INJURY','48545','1','','1','0','','','',0, 1, 0, 0),
(4338,'DUOL EXCLUSION W/GASTROJEJUNOSTOMY PNCRTC INJ','DUOL EXCLUSION W/GASTROJEJUNOSTOMY PNCRTC INJ','48547','1','','1','0','','','',0, 1, 0, 0),
(4339,'PANCREATICOJEJUNOSTOMY SIDE-TO-SIDE ANAST','PANCREATICOJEJUNOSTOMY SIDE-TO-SIDE ANAST','48548','1','','1','0','','','',0, 1, 0, 0),
(4340,'DONOR PANCREATECTOMY DUODENAL SGM TRANSPLANT','DONOR PANCREATECTOMY DUODENAL SGM TRANSPLANT','48550','1','','1','0','','','',0, 1, 0, 0),
(4341,'BKBENCH PREPJ CADAVER DONOR PANCREAS ALLOGRAFT','BKBENCH PREPJ CADAVER DONOR PANCREAS ALLOGRAFT','48551','1','','1','0','','','',0, 1, 0, 0),
(4342,'BKBENCH RCNSTJ CDVR PNCRS ALGRFT VEN ANAST EA','BKBENCH RCNSTJ CDVR PNCRS ALGRFT VEN ANAST EA','48552','1','','1','0','','','',0, 1, 0, 0),
(4343,'TRANSPLANTATION PANCREATIC ALLOGRAFT','TRANSPLANTATION PANCREATIC ALLOGRAFT','48554','1','','1','0','','','',0, 1, 0, 0),
(4344,'RMVL TRANSPLANTED PANCREATIC ALLOGRAFT','RMVL TRANSPLANTED PANCREATIC ALLOGRAFT','48556','1','','1','0','','','',0, 1, 0, 0),
(4345,'UNLISTED PROCEDURE PANCREAS','UNLISTED PROCEDURE PANCREAS','48999','1','','1','0','','','',0, 1, 0, 0),
(4346,'EXPLORATORY LAPAROTOMY CELIOTOMY W/WO BIOPSY SPX','EXPLORATORY LAPAROTOMY CELIOTOMY W/WO BIOPSY SPX','49000','1','','1','0','','','',0, 1, 0, 0),
(4347,'REOPENING RECENT LAPAROTOMY','REOPENING RECENT LAPAROTOMY','49002','1','','1','0','','','',0, 1, 0, 0),
(4348,'EXPL RETROPERITONEUM W/WO BX SPX','EXPL RETROPERITONEUM W/WO BX SPX','49010','1','','1','0','','','',0, 1, 0, 0),
(4349,'DRAINAGE PERITON ABSCESS/LOCAL PERITONITIS OPEN','DRAINAGE PERITON ABSCESS/LOCAL PERITONITIS OPEN','49020','1','','1','0','','','',0, 1, 0, 0),
(4350,'DRAINAGE SUBDIAPHRAGMATIC/SUBPHREN ABSCESS OPEN','DRAINAGE SUBDIAPHRAGMATIC/SUBPHREN ABSCESS OPEN','49040','1','','1','0','','','',0, 1, 0, 0),
(4351,'DRAINAGE OF RETROPERITONEAL ABSCESS OPEN','DRAINAGE OF RETROPERITONEAL ABSCESS OPEN','49060','1','','1','0','','','',0, 1, 0, 0),
(4352,'DRG XTRAPERITONEAL LYMPHOCELE PERITON CAVITY OPN','DRG XTRAPERITONEAL LYMPHOCELE PERITON CAVITY OPN','49062','1','','1','0','','','',0, 1, 0, 0),
(4353,'ABDOM PARACENTESIS DX/THER W/O IMAGING GUIDANCE','ABDOM PARACENTESIS DX/THER W/O IMAGING GUIDANCE','49082','1','','1','0','','','',0, 1, 0, 0),
(4354,'ABDOM PARACENTESIS DX/THER W/IMAGING GUIDANCE','ABDOM PARACENTESIS DX/THER W/IMAGING GUIDANCE','49083','1','','1','0','','','',0, 1, 0, 0),
(4355,'PERITONEAL LAVAGE W/WO IMAGING GUIDANCE','PERITONEAL LAVAGE W/WO IMAGING GUIDANCE','49084','1','','1','0','','','',0, 1, 0, 0),
(4356,'BX ABDL/RETROPERITONEAL MASS PRQ NEEDLE','BX ABDL/RETROPERITONEAL MASS PRQ NEEDLE','49180','1','','1','0','','','',0, 1, 0, 0),
(4357,'SCLEROTHERAPY FLUID COLLECTION PRQ W/IMG GID','SCLEROTHERAPY FLUID COLLECTION PRQ W/IMG GID','49185','1','','1','0','','','',0, 1, 0, 0),
(4358,'EXCISION/DESTRUCTION OPEN ABDOMINAL TUMOR 5 CM/<','EXCISION/DESTRUCTION OPEN ABDOMINAL TUMOR 5 CM/<','49203','1','','1','0','','','',0, 1, 0, 0),
(4359,'EXC/DESTRUCTION OPEN ABDMNL TUMORS 5.1-10.0 CM','EXC/DESTRUCTION OPEN ABDMNL TUMORS 5.1-10.0 CM','49204','1','','1','0','','','',0, 1, 0, 0),
(4360,'EXC/DESTRUCTION OPEN ABDOMINAL TUMORS >10.0 CM','EXC/DESTRUCTION OPEN ABDOMINAL TUMORS >10.0 CM','49205','1','','1','0','','','',0, 1, 0, 0),
(4361,'EXC PRESAC/SACROCOCCYGEAL TUMOR','EXC PRESAC/SACROCOCCYGEAL TUMOR','49215','1','','1','0','','','',0, 1, 0, 0),
(4362,'STAGING LAPAROTOMY HODGKINS DISEASE/LYMPHOMA','STAGING LAPAROTOMY HODGKINS DISEASE/LYMPHOMA','49220','1','','1','0','','','',0, 1, 0, 0),
(4363,'UMBILECTOMY OMPHALECTOMY EXC UMBILICUS SPX','UMBILECTOMY OMPHALECTOMY EXC UMBILICUS SPX','49250','1','','1','0','','','',0, 1, 0, 0),
(4364,'OMNTC EPIPLOECTOMY RESCJ OMENTUM SPX','OMNTC EPIPLOECTOMY RESCJ OMENTUM SPX','49255','1','','1','0','','','',0, 1, 0, 0),
(4365,'LAPS ABD PRTM&OMENTUM DX W/WO SPEC BR/WA SPX','LAPS ABD PRTM&OMENTUM DX W/WO SPEC BR/WA SPX','49320','1','','1','0','','','',0, 1, 0, 0),
(4366,'LAPAROSCOPY SURG W/BX SINGLE/MULTIPLE','LAPAROSCOPY SURG W/BX SINGLE/MULTIPLE','49321','1','','1','0','','','',0, 1, 0, 0),
(4367,'LAPS SURG W/ASPIR CAVITY/CYST SINGLE/MULTIPLE','LAPS SURG W/ASPIR CAVITY/CYST SINGLE/MULTIPLE','49322','1','','1','0','','','',0, 1, 0, 0),
(4368,'LAPS SURG W/DRG LYMPHOCELE PRTL CAVITY','LAPS SURG W/DRG LYMPHOCELE PRTL CAVITY','49323','1','','1','0','','','',0, 1, 0, 0),
(4369,'LAPS INSERTION TUNNELED INTRAPERITONEAL CATHETER','LAPS INSERTION TUNNELED INTRAPERITONEAL CATHETER','49324','1','','1','0','','','',0, 1, 0, 0),
(4370,'LAPS W/REVISION INTRAPERITONEAL CATHETER','LAPS W/REVISION INTRAPERITONEAL CATHETER','49325','1','','1','0','','','',0, 1, 0, 0),
(4371,'LAPAROSCOPY W/OMENTOPEXY','LAPAROSCOPY W/OMENTOPEXY','49326','1','','1','0','','','',0, 1, 0, 0),
(4372,'LAPS W/INSERTION NTRSTL DEV W/IMG GUID 1/MLT','LAPS W/INSERTION NTRSTL DEV W/IMG GUID 1/MLT','49327','1','','1','0','','','',0, 1, 0, 0),
(4373,'UNLISTED LAPAROSCOPIC PX ABD PERTONEUM & OMENTUM','UNLISTED LAPAROSCOPIC PX ABD PERTONEUM & OMENTUM','49329','1','','1','0','','','',0, 1, 0, 0),
(4374,'INJECTION AIR/CONTRAST PERITONEAL CAVITY SPX','INJECTION AIR/CONTRAST PERITONEAL CAVITY SPX','49400','1','','1','0','','','',0, 1, 0, 0),
(4375,'REMOVAL PERITONEAL FOREIGN BODY FROM CAVITY','REMOVAL PERITONEAL FOREIGN BODY FROM CAVITY','49402','1','','1','0','','','',0, 1, 0, 0),
(4376,'IMAGE-GUIDE FLUID COLLXN DRAINAGE CATH VISC PERQ','IMAGE-GUIDE FLUID COLLXN DRAINAGE CATH VISC PERQ','49405','1','','1','0','','','',0, 1, 0, 0),
(4377,'IMG-GUIDE FLUID COLLXN DRAINAG CATH PERITON PERQ','IMG-GUIDE FLUID COLLXN DRAINAG CATH PERITON PERQ','49406','1','','1','0','','','',0, 1, 0, 0),
(4378,'IMAGE FLUID COLLXN DRAINAG CATH TRANSREC/VAGINAL','IMAGE FLUID COLLXN DRAINAG CATH TRANSREC/VAGINAL','49407','1','','1','0','','','',0, 1, 0, 0),
(4379,'INTERSTITIAL DEV PLMT RADIATION THERAPY 1/MLT','INTERSTITIAL DEV PLMT RADIATION THERAPY 1/MLT','49411','1','','1','0','','','',0, 1, 0, 0),
(4380,'PLACEMENT INTRSTL DEV OPN W/IMG GUID 1/MLT','PLACEMENT INTRSTL DEV OPN W/IMG GUID 1/MLT','49412','1','','1','0','','','',0, 1, 0, 0),
(4381,'INSJ INTRAPERITONEAL CATHETER W/IMG GUID','INSJ INTRAPERITONEAL CATHETER W/IMG GUID','49418','1','','1','0','','','',0, 1, 0, 0),
(4382,'INSERTION TUNNEL INTRAPERITONEAL CATH SUBQ PORT','INSERTION TUNNEL INTRAPERITONEAL CATH SUBQ PORT','49419','1','','1','0','','','',0, 1, 0, 0),
(4383,'INSERTION TUNNEL INTRAPERITONEAL CATH DIAL OPEN','INSERTION TUNNEL INTRAPERITONEAL CATH DIAL OPEN','49421','1','','1','0','','','',0, 1, 0, 0),
(4384,'REMOVAL TUNNELED INTRAPERITONEAL CATHETER','REMOVAL TUNNELED INTRAPERITONEAL CATHETER','49422','1','','1','0','','','',0, 1, 0, 0),
(4385,'EXCHNG ABSC/CST DRG CATH RAD GID SPX','EXCHNG ABSC/CST DRG CATH RAD GID SPX','49423','1','','1','0','','','',0, 1, 0, 0),
(4386,'CNTRST NJX ASSMT ABSC/CST VIA DRG CATH/TUBE SPX','CNTRST NJX ASSMT ABSC/CST VIA DRG CATH/TUBE SPX','49424','1','','1','0','','','',0, 1, 0, 0),
(4387,'INSERTION PERITONEAL-VENOUS SHUNT','INSERTION PERITONEAL-VENOUS SHUNT','49425','1','','1','0','','','',0, 1, 0, 0),
(4388,'REVIS PERITONEAL-VENOUS SHUNT','REVIS PERITONEAL-VENOUS SHUNT','49426','1','','1','0','','','',0, 1, 0, 0),
(4389,'INJECT EVALUATE PREVIOUS PERITONEAL-VENOUS SHUNT','INJECT EVALUATE PREVIOUS PERITONEAL-VENOUS SHUNT','49427','1','','1','0','','','',0, 1, 0, 0),
(4390,'LIGATION PERITONEAL-VENOUS SHUNT','LIGATION PERITONEAL-VENOUS SHUNT','49428','1','','1','0','','','',0, 1, 0, 0),
(4391,'RMVL PERITONEAL-VENOUS SHUNT','RMVL PERITONEAL-VENOUS SHUNT','49429','1','','1','0','','','',0, 1, 0, 0),
(4392,'INSJ SUBQ EXTENSION INTRAPERITONEAL CATHETER','INSJ SUBQ EXTENSION INTRAPERITONEAL CATHETER','49435','1','','1','0','','','',0, 1, 0, 0),
(4393,'DELAYED CREATION EXIT SITE EMBEDDED CATHETER','DELAYED CREATION EXIT SITE EMBEDDED CATHETER','49436','1','','1','0','','','',0, 1, 0, 0),
(4394,'INSERT GASTROSTOMY TUBE PERCUTANEOUS','INSERT GASTROSTOMY TUBE PERCUTANEOUS','49440','1','','1','0','','','',0, 1, 0, 0),
(4395,'INSERT DUODENOSTOMY/JEJUNOSTOMY TUBE PERQ','INSERT DUODENOSTOMY/JEJUNOSTOMY TUBE PERQ','49441','1','','1','0','','','',0, 1, 0, 0),
(4396,'INSERT CECOSTOMY/OTHER COLONIC TUBE PERCUTANEOUS','INSERT CECOSTOMY/OTHER COLONIC TUBE PERCUTANEOUS','49442','1','','1','0','','','',0, 1, 0, 0),
(4397,'CONVERT GASTROSTOMY-GASTRO-JEJUNOSTOMY TUBE PERQ','CONVERT GASTROSTOMY-GASTRO-JEJUNOSTOMY TUBE PERQ','49446','1','','1','0','','','',0, 1, 0, 0),
(4398,'REPLACE GASTROSTOMY/CECOSTOMY TUBE PERCUTANEOUS','REPLACE GASTROSTOMY/CECOSTOMY TUBE PERCUTANEOUS','49450','1','','1','0','','','',0, 1, 0, 0),
(4399,'REPLACE DUODENOSTOMY/JEJUNOSTOMY TUBE PERQ','REPLACE DUODENOSTOMY/JEJUNOSTOMY TUBE PERQ','49451','1','','1','0','','','',0, 1, 0, 0),
(4400,'REPLACEMENT GASTRO-JEJUNOSTOMY TUBE PERCUTANEOUS','REPLACEMENT GASTRO-JEJUNOSTOMY TUBE PERCUTANEOUS','49452','1','','1','0','','','',0, 1, 0, 0),
(4401,'OBSTRUCTIVE MATERIAL REMOVAL FROM GI TUBE','OBSTRUCTIVE MATERIAL REMOVAL FROM GI TUBE','49460','1','','1','0','','','',0, 1, 0, 0),
(4402,'CONTRAST INJECTION PERQ RADIOLOGIC EVAL GI TUBE','CONTRAST INJECTION PERQ RADIOLOGIC EVAL GI TUBE','49465','1','','1','0','','','',0, 1, 0, 0),
(4403,'RPR 1ST INGUN HRNA PRETERM INFT RDC','RPR 1ST INGUN HRNA PRETERM INFT RDC','49491','1','','1','0','','','',0, 1, 0, 0),
(4404,'RPR 1ST INGUN HRNA PRETERM INFT INCARCERATED','RPR 1ST INGUN HRNA PRETERM INFT INCARCERATED','49492','1','','1','0','','','',0, 1, 0, 0),
(4405,'RPR 1ST INGUN HRNA FULL TERM INFT <6 MO RDC','RPR 1ST INGUN HRNA FULL TERM INFT <6 MO RDC','49495','1','','1','0','','','',0, 1, 0, 0),
(4406,'RPR 1ST INGUN HRNA FULL TERM INFT <6 MO INCARCER','RPR 1ST INGUN HRNA FULL TERM INFT <6 MO INCARCER','49496','1','','1','0','','','',0, 1, 0, 0),
(4407,'RPR 1ST INGUN HRNA AGE 6 MO-5 YRS REDUCIBLE','RPR 1ST INGUN HRNA AGE 6 MO-5 YRS REDUCIBLE','49500','1','','1','0','','','',0, 1, 0, 0),
(4408,'RPR 1ST INGUN HRNA AGE 6 MO-5 YRS INCARCERATED','RPR 1ST INGUN HRNA AGE 6 MO-5 YRS INCARCERATED','49501','1','','1','0','','','',0, 1, 0, 0),
(4409,'RPR 1ST INGUN HRNA AGE 5 YRS/> REDUCIBLE','RPR 1ST INGUN HRNA AGE 5 YRS/> REDUCIBLE','49505','1','','1','0','','','',0, 1, 0, 0),
(4410,'RPR 1ST INGUN HRNA AGE 5 YRS/> INCARCERATED','RPR 1ST INGUN HRNA AGE 5 YRS/> INCARCERATED','49507','1','','1','0','','','',0, 1, 0, 0),
(4411,'RPR RECRT INGUINAL HERNIA ANY AGE REDUCIBLE','RPR RECRT INGUINAL HERNIA ANY AGE REDUCIBLE','49520','1','','1','0','','','',0, 1, 0, 0),
(4412,'RPR RECRT INGUN HERNIA ANY AGE INCARCERATED','RPR RECRT INGUN HERNIA ANY AGE INCARCERATED','49521','1','','1','0','','','',0, 1, 0, 0),
(4413,'RPR INGUN HERNIA SLIDING ANY AGE','RPR INGUN HERNIA SLIDING ANY AGE','49525','1','','1','0','','','',0, 1, 0, 0),
(4414,'REPAIR LUMBAR HERNIA','REPAIR LUMBAR HERNIA','49540','1','','1','0','','','',0, 1, 0, 0),
(4415,'RPR 1ST FEM HRNA ANY AGE REDUCIBLE','RPR 1ST FEM HRNA ANY AGE REDUCIBLE','49550','1','','1','0','','','',0, 1, 0, 0),
(4416,'RPR 1ST FEM HERNIA ANY AGE INCARCERATED','RPR 1ST FEM HERNIA ANY AGE INCARCERATED','49553','1','','1','0','','','',0, 1, 0, 0),
(4417,'RPR RECRT FEM HERNIA REDUCIBLE','RPR RECRT FEM HERNIA REDUCIBLE','49555','1','','1','0','','','',0, 1, 0, 0),
(4418,'RPR RECRT FEM HRNA INCARCERATED','RPR RECRT FEM HRNA INCARCERATED','49557','1','','1','0','','','',0, 1, 0, 0),
(4419,'REPAIR FIRST ABDOMINAL WALL HERNIA','REPAIR FIRST ABDOMINAL WALL HERNIA','49560','1','','1','0','','','',0, 1, 0, 0),
(4420,'RPR 1ST INCAL/VNT HERNIA INCARCERATED','RPR 1ST INCAL/VNT HERNIA INCARCERATED','49561','1','','1','0','','','',0, 1, 0, 0),
(4421,'RPR RECRT INCAL/VNT HERNIA REDUCIBLE','RPR RECRT INCAL/VNT HERNIA REDUCIBLE','49565','1','','1','0','','','',0, 1, 0, 0),
(4422,'RPR RECRT INCAL/VNT HERNIA INCARCERATED','RPR RECRT INCAL/VNT HERNIA INCARCERATED','49566','1','','1','0','','','',0, 1, 0, 0),
(4423,'IMPLANT MESH OPN HERNIA RPR/DEBRIDEMENT CLOSURE','IMPLANT MESH OPN HERNIA RPR/DEBRIDEMENT CLOSURE','49568','1','','1','0','','','',0, 1, 0, 0),
(4424,'RPR EPIGASTRIC HERNIA REDUCIBLE SPX','RPR EPIGASTRIC HERNIA REDUCIBLE SPX','49570','1','','1','0','','','',0, 1, 0, 0),
(4425,'RPR EPIGASTRIC HERNIA INCARCERATED','RPR EPIGASTRIC HERNIA INCARCERATED','49572','1','','1','0','','','',0, 1, 0, 0),
(4426,'RPR UMBILICAL HERNIA < 5 YRS REDUCIBLE','RPR UMBILICAL HERNIA < 5 YRS REDUCIBLE','49580','1','','1','0','','','',0, 1, 0, 0),
(4427,'RPR UMBILICAL HERNIA < 5 YRS INCARCERATED','RPR UMBILICAL HERNIA < 5 YRS INCARCERATED','49582','1','','1','0','','','',0, 1, 0, 0),
(4428,'RPR UMBILICAL HRNA 5 YRS/> REDUCIBLE','RPR UMBILICAL HRNA 5 YRS/> REDUCIBLE','49585','1','','1','0','','','',0, 1, 0, 0),
(4429,'RPR UMBILICAL HERNIA AGE 5 YRS/> INCARCERATED','RPR UMBILICAL HERNIA AGE 5 YRS/> INCARCERATED','49587','1','','1','0','','','',0, 1, 0, 0),
(4430,'RPR SPIGELIAN HERNIA','RPR SPIGELIAN HERNIA','49590','1','','1','0','','','',0, 1, 0, 0),
(4431,'RPR SMALL OMPHALOCELE W/PRIMARY CLOSURE','RPR SMALL OMPHALOCELE W/PRIMARY CLOSURE','49600','1','','1','0','','','',0, 1, 0, 0),
(4432,'RPR LG OMPHALOCELE/GASTROSCHISIS W/WO PROSTH','RPR LG OMPHALOCELE/GASTROSCHISIS W/WO PROSTH','49605','1','','1','0','','','',0, 1, 0, 0),
(4433,'RPR LG OMPHALOCELE/GASTROSCHISIS RMVL PROSTH','RPR LG OMPHALOCELE/GASTROSCHISIS RMVL PROSTH','49606','1','','1','0','','','',0, 1, 0, 0),
(4434,'RPR OMPHALOCELE GROSS TYP OPRATION 1ST STG','RPR OMPHALOCELE GROSS TYP OPRATION 1ST STG','49610','1','','1','0','','','',0, 1, 0, 0),
(4435,'RPR OMPHALOCELE GROSS TYP OPRATION 2ND STG','RPR OMPHALOCELE GROSS TYP OPRATION 2ND STG','49611','1','','1','0','','','',0, 1, 0, 0),
(4436,'LAPAROSCOPY SURG RPR INITIAL INGUINAL HERNIA','LAPAROSCOPY SURG RPR INITIAL INGUINAL HERNIA','49650','1','','1','0','','','',0, 1, 0, 0),
(4437,'LAPS SURG RPR RECURRENT INGUINAL HERNIA','LAPS SURG RPR RECURRENT INGUINAL HERNIA','49651','1','','1','0','','','',0, 1, 0, 0),
(4438,'LAPS REPAIR HERNIA EXCEPT INCAL/INGUN REDUCIBLE','LAPS REPAIR HERNIA EXCEPT INCAL/INGUN REDUCIBLE','49652','1','','1','0','','','',0, 1, 0, 0),
(4439,'LAP RPR HRNA XCPT INCAL/INGUN NCRC8/STRANGULATED','LAP RPR HRNA XCPT INCAL/INGUN NCRC8/STRANGULATED','49653','1','','1','0','','','',0, 1, 0, 0),
(4440,'LAPAROSCOPY REPAIR INCISIONAL HERNIA REDUCIBLE','LAPAROSCOPY REPAIR INCISIONAL HERNIA REDUCIBLE','49654','1','','1','0','','','',0, 1, 0, 0),
(4441,'LAPS RPR INCISIONAL HERNIA NCRC8/STRANGULATED','LAPS RPR INCISIONAL HERNIA NCRC8/STRANGULATED','49655','1','','1','0','','','',0, 1, 0, 0),
(4442,'LAPS RPR RECURRENT INCISIONAL HERNIA REDUCIBLE','LAPS RPR RECURRENT INCISIONAL HERNIA REDUCIBLE','49656','1','','1','0','','','',0, 1, 0, 0),
(4443,'LAPS RPR RECURRENT INCAL HRNA NCRC8/STRANGULATED','LAPS RPR RECURRENT INCAL HRNA NCRC8/STRANGULATED','49657','1','','1','0','','','',0, 1, 0, 0),
(4444,'UNLIS LAPS PX HRNAP HERNIORRHAPHY HERNIOTOMY','UNLIS LAPS PX HRNAP HERNIORRHAPHY HERNIOTOMY','49659','1','','1','0','','','',0, 1, 0, 0),
(4445,'SEC ABDOMINAL WALL SUTURE EVISCERATION/DEHSN','SEC ABDOMINAL WALL SUTURE EVISCERATION/DEHSN','49900','1','','1','0','','','',0, 1, 0, 0),
(4446,'OMENTAL FLAP EXTRA-ABDOMINAL','OMENTAL FLAP EXTRA-ABDOMINAL','49904','1','','1','0','','','',0, 1, 0, 0),
(4447,'OMENTAL FLAP INTRA-ABDOMINAL','OMENTAL FLAP INTRA-ABDOMINAL','49905','1','','1','0','','','',0, 1, 0, 0),
(4448,'FREE OMENTAL FLAP W/MICROVASCULAR ANAST','FREE OMENTAL FLAP W/MICROVASCULAR ANAST','49906','1','','1','0','','','',0, 1, 0, 0),
(4449,'UNLISTED PROCEDURE ABDOMEN PERITONEUM & OMENTUM','UNLISTED PROCEDURE ABDOMEN PERITONEUM & OMENTUM','49999','1','','1','0','','','',0, 1, 0, 0),
(4450,'RNL EXPL X NECESSITATING OTH SPEC PX','RNL EXPL X NECESSITATING OTH SPEC PX','50010','1','','1','0','','','',0, 1, 0, 0),
(4451,'DRAINAGE PERIRENAL/RENAL ABSCESS OPEN','DRAINAGE PERIRENAL/RENAL ABSCESS OPEN','50020','1','','1','0','','','',0, 1, 0, 0),
(4452,'NEPHROSTOMY/NEPHROTOMY W/DRAINAGE','NEPHROSTOMY/NEPHROTOMY W/DRAINAGE','50040','1','','1','0','','','',0, 1, 0, 0),
(4453,'NEPHROTOMY W/EXPLORATION','NEPHROTOMY W/EXPLORATION','50045','1','','1','0','','','',0, 1, 0, 0),
(4454,'NEPHROLITHOTOMY REMOVAL STAGE 1','NEPHROLITHOTOMY REMOVAL STAGE 1','50060','1','','1','0','','','',0, 1, 0, 0),
(4455,'NEPHROLITHOTOMY SECONDARY FOR CALCULUS','NEPHROLITHOTOMY SECONDARY FOR CALCULUS','50065','1','','1','0','','','',0, 1, 0, 0),
(4456,'NEPHROLITHOTOMY COMP CGEN KDN ABNORMALITY','NEPHROLITHOTOMY COMP CGEN KDN ABNORMALITY','50070','1','','1','0','','','',0, 1, 0, 0),
(4457,'NEPHROLITHOTOMY RMVL LG STAGHORN STAGE 1','NEPHROLITHOTOMY RMVL LG STAGHORN STAGE 1','50075','1','','1','0','','','',0, 1, 0, 0),
(4458,'PRQ NEPHROSTOLITHOTOMY/PYELOSTOLITHOTOMY </2 CM','PRQ NEPHROSTOLITHOTOMY/PYELOSTOLITHOTOMY </2 CM','50080','1','','1','0','','','',0, 1, 0, 0),
(4459,'PRQ NEPHROSTOLITHOTOMY/PYELOSTOLITHOTOMY > 2 CM','PRQ NEPHROSTOLITHOTOMY/PYELOSTOLITHOTOMY > 2 CM','50081','1','','1','0','','','',0, 1, 0, 0),
(4460,'TRNSXJ/REPOSITIONING ABERRANT RENAL VESSEL SPX','TRNSXJ/REPOSITIONING ABERRANT RENAL VESSEL SPX','50100','1','','1','0','','','',0, 1, 0, 0),
(4461,'PYELOTOMY W/EXPLORATION','PYELOTOMY W/EXPLORATION','50120','1','','1','0','','','',0, 1, 0, 0),
(4462,'PYELOTOMY W/DRAINAGE PYELOSTOMY','PYELOTOMY W/DRAINAGE PYELOSTOMY','50125','1','','1','0','','','',0, 1, 0, 0),
(4463,'PYELOTOMY W/REMOVAL CALCULUS','PYELOTOMY W/REMOVAL CALCULUS','50130','1','','1','0','','','',0, 1, 0, 0),
(4464,'PYELOTOMY COMPLICATED','PYELOTOMY COMPLICATED','50135','1','','1','0','','','',0, 1, 0, 0),
(4465,'RENAL BIOPSY PRQ TROCAR/NEEDLE','RENAL BIOPSY PRQ TROCAR/NEEDLE','50200','1','','1','0','','','',0, 1, 0, 0),
(4466,'RENAL BIOPSY SURG EXPOSURE KIDNEY','RENAL BIOPSY SURG EXPOSURE KIDNEY','50205','1','','1','0','','','',0, 1, 0, 0),
(4467,'NEPHRECTOMY W/PRTL URETERECTOMY W/OPEN RIB RESCJ','NEPHRECTOMY W/PRTL URETERECTOMY W/OPEN RIB RESCJ','50220','1','','1','0','','','',0, 1, 0, 0),
(4468,'NEPHRECTOMY W/PRTL URETERECT OPN RIB RESCJ COMPL','NEPHRECTOMY W/PRTL URETERECT OPN RIB RESCJ COMPL','50225','1','','1','0','','','',0, 1, 0, 0),
(4469,'NEPHRECTOMY W/PRTL URETERECT OPEN RIB RESCJ RAD','NEPHRECTOMY W/PRTL URETERECT OPEN RIB RESCJ RAD','50230','1','','1','0','','','',0, 1, 0, 0),
(4470,'NEPHRECTOMY W/TOT URETERECT&BLDR CUFF SAME INC','NEPHRECTOMY W/TOT URETERECT&BLDR CUFF SAME INC','50234','1','','1','0','','','',0, 1, 0, 0),
(4471,'NEPHRECTOMY TOT URETEREC&BLDR CUFF SEPAR INCISN','NEPHRECTOMY TOT URETEREC&BLDR CUFF SEPAR INCISN','50236','1','','1','0','','','',0, 1, 0, 0),
(4472,'NEPHRECTOMY PARTIAL','NEPHRECTOMY PARTIAL','50240','1','','1','0','','','',0, 1, 0, 0),
(4473,'OPEN ABLATION RENAL MASS CRYOSURG ULTRASOUND','OPEN ABLATION RENAL MASS CRYOSURG ULTRASOUND','50250','1','','1','0','','','',0, 1, 0, 0),
(4474,'EXCISION/UNROOFING CYST KIDNEY','EXCISION/UNROOFING CYST KIDNEY','50280','1','','1','0','','','',0, 1, 0, 0),
(4475,'EXCISION PERINEPHRIC CYST','EXCISION PERINEPHRIC CYST','50290','1','','1','0','','','',0, 1, 0, 0),
(4476,'DONOR NEPHRECTOMY CADAVER DONOR UNI/BILATERAL','DONOR NEPHRECTOMY CADAVER DONOR UNI/BILATERAL','50300','1','','1','0','','','',0, 1, 0, 0),
(4477,'DONOR NEPHRECTOMY OPEN LIVING DONOR','DONOR NEPHRECTOMY OPEN LIVING DONOR','50320','1','','1','0','','','',0, 1, 0, 0),
(4478,'BKBENCH PREPJ CADAVER DONOR RENAL ALLOGRAFT','BKBENCH PREPJ CADAVER DONOR RENAL ALLOGRAFT','50323','1','','1','0','','','',0, 1, 0, 0),
(4479,'BKBENCH PREPJ LIVING RENAL DONOR ALLOGRAFT','BKBENCH PREPJ LIVING RENAL DONOR ALLOGRAFT','50325','1','','1','0','','','',0, 1, 0, 0),
(4480,'BKBENCH RCNSTJ RENAL ALGRFT VENOUS ANAST EA','BKBENCH RCNSTJ RENAL ALGRFT VENOUS ANAST EA','50327','1','','1','0','','','',0, 1, 0, 0),
(4481,'BKBENCH RCNSTJ RENAL ALLOGRAFT ARTERIAL ANAST EA','BKBENCH RCNSTJ RENAL ALLOGRAFT ARTERIAL ANAST EA','50328','1','','1','0','','','',0, 1, 0, 0),
(4482,'BKBENCH RCNSTJ ALGRFT URETERAL ANAST EA','BKBENCH RCNSTJ ALGRFT URETERAL ANAST EA','50329','1','','1','0','','','',0, 1, 0, 0),
(4483,'RECIPIENT NEPHRECTOMY SEPARATE PROCEDURE','RECIPIENT NEPHRECTOMY SEPARATE PROCEDURE','50340','1','','1','0','','','',0, 1, 0, 0),
(4484,'RENAL ALTRNSPLJ IMPLTJ GRF W/O RCP NEPHRECTOMY','RENAL ALTRNSPLJ IMPLTJ GRF W/O RCP NEPHRECTOMY','50360','1','','1','0','','','',0, 1, 0, 0),
(4485,'RENAL ALTRNSPLJ IMPLTJ GRF W/RCP NEPHRECTOMY','RENAL ALTRNSPLJ IMPLTJ GRF W/RCP NEPHRECTOMY','50365','1','','1','0','','','',0, 1, 0, 0),
(4486,'RMVL TRNSPLED RENAL ALLOGRAFT','RMVL TRNSPLED RENAL ALLOGRAFT','50370','1','','1','0','','','',0, 1, 0, 0),
(4487,'RENAL AUTOTRNSPLJ REIMPLANTATION KIDNEY','RENAL AUTOTRNSPLJ REIMPLANTATION KIDNEY','50380','1','','1','0','','','',0, 1, 0, 0),
(4488,'RMVL & RPLCMT INTLY DWELLING URETERAL STENT PRQ','RMVL & RPLCMT INTLY DWELLING URETERAL STENT PRQ','50382','1','','1','0','','','',0, 1, 0, 0),
(4489,'REMOVAL INDWELLING URETERAL STENT PRQ','REMOVAL INDWELLING URETERAL STENT PRQ','50384','1','','1','0','','','',0, 1, 0, 0),
(4490,'REMOVE & REPLACE INDWELL URETERAL STENT TRURTHRL','REMOVE & REPLACE INDWELL URETERAL STENT TRURTHRL','50385','1','','1','0','','','',0, 1, 0, 0),
(4491,'REMOVE INT DWELL URETERAL STENT TRANSURETHRAL','REMOVE INT DWELL URETERAL STENT TRANSURETHRAL','50386','1','','1','0','','','',0, 1, 0, 0),
(4492,'RMVL & RPLCMT XTRNL ACCESSIBLE NEPHROURTRL CATH','RMVL & RPLCMT XTRNL ACCESSIBLE NEPHROURTRL CATH','50387','1','','1','0','','','',0, 1, 0, 0),
(4493,'RMVL NFROS TUBE REQ FLUORO GUIDANCE','RMVL NFROS TUBE REQ FLUORO GUIDANCE','50389','1','','1','0','','','',0, 1, 0, 0),
(4494,'ASPIR &/NJX RENAL CYST/PELVIS NEEDLE PRQ','ASPIR &/NJX RENAL CYST/PELVIS NEEDLE PRQ','50390','1','','1','0','','','',0, 1, 0, 0),
(4495,'INSTLJ THER AGENT RENAL PELVIS&/URETER VIA TUB','INSTLJ THER AGENT RENAL PELVIS&/URETER VIA TUB','50391','1','','1','0','','','',0, 1, 0, 0),
(4496,'INTRO GUIDE PELVIS&/URETER W/DILAT NFROS TRACT','INTRO GUIDE PELVIS&/URETER W/DILAT NFROS TRACT','50395','1','','1','0','','','',0, 1, 0, 0),
(4497,'MANOMETRIC STDS THRU TUBE/NDWELLG URTRL CATH','MANOMETRIC STDS THRU TUBE/NDWELLG URTRL CATH','50396','1','','1','0','','','',0, 1, 0, 0),
(4498,'PYELOPLASTY SIMPLE','PYELOPLASTY SIMPLE','50400','1','','1','0','','','',0, 1, 0, 0),
(4499,'PYELOPLASTY COMPLICATED','PYELOPLASTY COMPLICATED','50405','1','','1','0','','','',0, 1, 0, 0),
(4500,'NJX PX ANTEGRDE NFROSGRM &/URTRGRM NEW ACCESS','NJX PX ANTEGRDE NFROSGRM &/URTRGRM NEW ACCESS','50430','1','','1','0','','','',0, 1, 0, 0),
(4501,'NJX PX ANTEGRDE NFROSGRM &/URTRGRM EXSTNG ACESS','NJX PX ANTEGRDE NFROSGRM &/URTRGRM EXSTNG ACESS','50431','1','','1','0','','','',0, 1, 0, 0),
(4502,'PLMT NEPHROSTOMY CATH PRQ NEW ACCESS RS&I','PLMT NEPHROSTOMY CATH PRQ NEW ACCESS RS&I','50432','1','','1','0','','','',0, 1, 0, 0),
(4503,'PLMT NEPHROURETERAL CATH PRQ NEW ACCESS RS&I','PLMT NEPHROURETERAL CATH PRQ NEW ACCESS RS&I','50433','1','','1','0','','','',0, 1, 0, 0),
(4504,'CONVERT NEPHROSTOMY CATH TO NEPHROURTRL CATH PRQ','CONVERT NEPHROSTOMY CATH TO NEPHROURTRL CATH PRQ','50434','1','','1','0','','','',0, 1, 0, 0),
(4505,'EXCHANGE NEPHROSTOMY CATHETER PRQ W/IMG GID RS&I','EXCHANGE NEPHROSTOMY CATHETER PRQ W/IMG GID RS&I','50435','1','','1','0','','','',0, 1, 0, 0),
(4506,'NEPHRORRHAPHY SUTURE KIDNEY WOUND/INJURY','NEPHRORRHAPHY SUTURE KIDNEY WOUND/INJURY','50500','1','','1','0','','','',0, 1, 0, 0),
(4507,'CLOSURE NEPHROCUTANEOUS/PYELOCUTANEOUS FISTULA','CLOSURE NEPHROCUTANEOUS/PYELOCUTANEOUS FISTULA','50520','1','','1','0','','','',0, 1, 0, 0),
(4508,'CLSR NEPHROVISCERAL FISTULA W/VISC RPR ABDL APPR','CLSR NEPHROVISCERAL FISTULA W/VISC RPR ABDL APPR','50525','1','','1','0','','','',0, 1, 0, 0),
(4509,'CLSR NEPHROVISCERAL FISTULA W/VISC RPR THRC APPR','CLSR NEPHROVISCERAL FISTULA W/VISC RPR THRC APPR','50526','1','','1','0','','','',0, 1, 0, 0),
(4510,'SYMPHYSIOTOMY HORSESHOE KDN W/WO PLOP UNI/BI','SYMPHYSIOTOMY HORSESHOE KDN W/WO PLOP UNI/BI','50540','1','','1','0','','','',0, 1, 0, 0),
(4511,'LAPAROSCOPY SURG ABLATION RENAL CYSTS','LAPAROSCOPY SURG ABLATION RENAL CYSTS','50541','1','','1','0','','','',0, 1, 0, 0),
(4512,'LAPS ABLTJ RENAL MASS LESION W/INTRAOP US','LAPS ABLTJ RENAL MASS LESION W/INTRAOP US','50542','1','','1','0','','','',0, 1, 0, 0),
(4513,'LAPAROSCOPY SURG PARTIAL NEPHRECTOMY','LAPAROSCOPY SURG PARTIAL NEPHRECTOMY','50543','1','','1','0','','','',0, 1, 0, 0),
(4514,'LAPAROSCOPY SURG PYELOPLASTY','LAPAROSCOPY SURG PYELOPLASTY','50544','1','','1','0','','','',0, 1, 0, 0),
(4515,'LAPAROSCOPY RADICAL NEPHRECTOMY','LAPAROSCOPY RADICAL NEPHRECTOMY','50545','1','','1','0','','','',0, 1, 0, 0),
(4516,'LAPAROSCOPY NEPHRECTOMY W/PARTIAL URETERECT','LAPAROSCOPY NEPHRECTOMY W/PARTIAL URETERECT','50546','1','','1','0','','','',0, 1, 0, 0),
(4517,'LAPAROSCOPY DONOR NEPHRECTOMY LIVING DONOR','LAPAROSCOPY DONOR NEPHRECTOMY LIVING DONOR','50547','1','','1','0','','','',0, 1, 0, 0),
(4518,'LAPAROSCOPY NEPHRECTOMY W/TOTAL URETERECTOMY','LAPAROSCOPY NEPHRECTOMY W/TOTAL URETERECTOMY','50548','1','','1','0','','','',0, 1, 0, 0),
(4519,'UNLISTED LAPAROSCOPY PROCEDURE RENAL','UNLISTED LAPAROSCOPY PROCEDURE RENAL','50549','1','','1','0','','','',0, 1, 0, 0),
(4520,'RENAL ENDOSCOPY NEPHROSTOMY W/WO IRRIGATION','RENAL ENDOSCOPY NEPHROSTOMY W/WO IRRIGATION','50551','1','','1','0','','','',0, 1, 0, 0),
(4521,'RENAL NDSC NEPHROST W/URETERAL CATH W/WO DILA','RENAL NDSC NEPHROST W/URETERAL CATH W/WO DILA','50553','1','','1','0','','','',0, 1, 0, 0),
(4522,'RENAL NDSC NEPHROS/PYELOSTOMY BIOPSY','RENAL NDSC NEPHROS/PYELOSTOMY BIOPSY','50555','1','','1','0','','','',0, 1, 0, 0),
(4523,'RENAL NDSC NEPHROS/PYELOSTOMY FULG&/INC W/WO BI','RENAL NDSC NEPHROS/PYELOSTOMY FULG&/INC W/WO BI','50557','1','','1','0','','','',0, 1, 0, 0),
(4524,'RENAL NDSC NEPHROS/PYELOSTOMY RMVL FB/CALCULUS','RENAL NDSC NEPHROS/PYELOSTOMY RMVL FB/CALCULUS','50561','1','','1','0','','','',0, 1, 0, 0),
(4525,'RENAL NDSC NEPHROS/PYELOSTOMY RESCJ TUMOR','RENAL NDSC NEPHROS/PYELOSTOMY RESCJ TUMOR','50562','1','','1','0','','','',0, 1, 0, 0),
(4526,'RENAL NDSC NEPHROTOMY W/WO IRRIGATION','RENAL NDSC NEPHROTOMY W/WO IRRIGATION','50570','1','','1','0','','','',0, 1, 0, 0),
(4527,'RNL NDSC NFROT W/URTRL CATHJ W/WO DILAT URETER','RNL NDSC NFROT W/URTRL CATHJ W/WO DILAT URETER','50572','1','','1','0','','','',0, 1, 0, 0),
(4528,'RENAL NDSC NEPHROTOMY W/BIOPSY','RENAL NDSC NEPHROTOMY W/BIOPSY','50574','1','','1','0','','','',0, 1, 0, 0),
(4529,'RNL NDSC NFROT/PLOT W/ENDOPYELOTOMY','RNL NDSC NFROT/PLOT W/ENDOPYELOTOMY','50575','1','','1','0','','','',0, 1, 0, 0),
(4530,'RNL NDSC NFROT FULGURATION &/INCISION W/WO BX','RNL NDSC NFROT FULGURATION &/INCISION W/WO BX','50576','1','','1','0','','','',0, 1, 0, 0),
(4531,'RNL NDSC NFROT/PLOT W/RMVL FB/CALCULUS','RNL NDSC NFROT/PLOT W/RMVL FB/CALCULUS','50580','1','','1','0','','','',0, 1, 0, 0),
(4532,'LITHOTRIPSY XTRCORP SHOCK WAVE','LITHOTRIPSY XTRCORP SHOCK WAVE','50590','1','','1','0','','','',0, 1, 0, 0),
(4533,'ABLTJ 1/> RENAL TUMOR PRQ UNI RADIOFREQUENCY','ABLTJ 1/> RENAL TUMOR PRQ UNI RADIOFREQUENCY','50592','1','','1','0','','','',0, 1, 0, 0),
(4534,'ABLATION RENAL TUMOR UNILATERAL PERQ CRYOTHERAPY','ABLATION RENAL TUMOR UNILATERAL PERQ CRYOTHERAPY','50593','1','','1','0','','','',0, 1, 0, 0),
(4535,'URTROTOMY W/EXPL/DRG SEPARATE PROCEDURE','URTROTOMY W/EXPL/DRG SEPARATE PROCEDURE','50600','1','','1','0','','','',0, 1, 0, 0),
(4536,'URETEROTOMY INSERTION INDWELLING STENT ALL TYPES','URETEROTOMY INSERTION INDWELLING STENT ALL TYPES','50605','1','','1','0','','','',0, 1, 0, 0),
(4537,'ENDOLUMINAL BX URTR &/RNL PELVIS NONENDOSCOPIC','ENDOLUMINAL BX URTR &/RNL PELVIS NONENDOSCOPIC','50606','1','','1','0','','','',0, 1, 0, 0),
(4538,'URTROLITHOTOMY UPPER ONE-THIRD URETER','URTROLITHOTOMY UPPER ONE-THIRD URETER','50610','1','','1','0','','','',0, 1, 0, 0),
(4539,'URTROLITHOTOMY MIDDLE ONE-THIRD URETER','URTROLITHOTOMY MIDDLE ONE-THIRD URETER','50620','1','','1','0','','','',0, 1, 0, 0),
(4540,'URTROLITHOTOMY LOWER ONE-THIRD URETER','URTROLITHOTOMY LOWER ONE-THIRD URETER','50630','1','','1','0','','','',0, 1, 0, 0),
(4541,'URETRECECTOMY W/BLADDER CUFF SEPARATE PROCEDURE','URETRECECTOMY W/BLADDER CUFF SEPARATE PROCEDURE','50650','1','','1','0','','','',0, 1, 0, 0),
(4542,'URETERECTOMY TOT ECTOPIC URETER CMBN APPR','URETERECTOMY TOT ECTOPIC URETER CMBN APPR','50660','1','','1','0','','','',0, 1, 0, 0),
(4543,'INJ PX URETEROGRAPHY/URETEROPYLOGRAPHY CATH','INJ PX URETEROGRAPHY/URETEROPYLOGRAPHY CATH','50684','1','','1','0','','','',0, 1, 0, 0),
(4544,'MANOMETRIC STDS THRU URTROST/NDWELLG URTRL CATH','MANOMETRIC STDS THRU URTROST/NDWELLG URTRL CATH','50686','1','','1','0','','','',0, 1, 0, 0),
(4545,'CHNG URTROST TUBE/XTRNLLY ACCESSIBLE STENT ILEAL','CHNG URTROST TUBE/XTRNLLY ACCESSIBLE STENT ILEAL','50688','1','','1','0','','','',0, 1, 0, 0),
(4546,'NJX VISUALIZATION ILEAL CONDUIT&/URETEROPYELOG','NJX VISUALIZATION ILEAL CONDUIT&/URETEROPYELOG','50690','1','','1','0','','','',0, 1, 0, 0),
(4547,'PLMT URTRL STENT PRQ PRE-EXISTING NFROS TRACT','PLMT URTRL STENT PRQ PRE-EXISTING NFROS TRACT','50693','1','','1','0','','','',0, 1, 0, 0),
(4548,'PLMT URTRL STNT PRQ NEW ACESS W/O SEP NFROS CATH','PLMT URTRL STNT PRQ NEW ACESS W/O SEP NFROS CATH','50694','1','','1','0','','','',0, 1, 0, 0),
(4549,'PLMT URTRL STENT PRQ NEW ACCESS W/SEP NFROS CATH','PLMT URTRL STENT PRQ NEW ACCESS W/SEP NFROS CATH','50695','1','','1','0','','','',0, 1, 0, 0),
(4550,'URETEROPLASTY PLASTIC OPERATION URETER','URETEROPLASTY PLASTIC OPERATION URETER','50700','1','','1','0','','','',0, 1, 0, 0),
(4551,'URETERAL EMBOLIZATION/OCCLUSION W/IMG GID RS&I','URETERAL EMBOLIZATION/OCCLUSION W/IMG GID RS&I','50705','1','','1','0','','','',0, 1, 0, 0),
(4552,'BALLOON DILAT URETERAL STRICTURE W/IMG GID RS&I','BALLOON DILAT URETERAL STRICTURE W/IMG GID RS&I','50706','1','','1','0','','','',0, 1, 0, 0),
(4553,'URETEROLYSIS W/WORPSG URETER RETROPERIT FIBROSIS','URETEROLYSIS W/WORPSG URETER RETROPERIT FIBROSIS','50715','1','','1','0','','','',0, 1, 0, 0),
(4554,'URETEROLYSIS FOR OVARIAN VEIN SYNDROME','URETEROLYSIS FOR OVARIAN VEIN SYNDROME','50722','1','','1','0','','','',0, 1, 0, 0),
(4555,'URTROLSS RETROCAVAL URTR W/REANAST','URTROLSS RETROCAVAL URTR W/REANAST','50725','1','','1','0','','','',0, 1, 0, 0),
(4556,'REVJ URINARY-CUTANEOUS ANASTAMOSIS','REVJ URINARY-CUTANEOUS ANASTAMOSIS','50727','1','','1','0','','','',0, 1, 0, 0),
(4557,'REVJ UR-CUTAN ANAST RPR FSCAL DFCT & HERNIA','REVJ UR-CUTAN ANAST RPR FSCAL DFCT & HERNIA','50728','1','','1','0','','','',0, 1, 0, 0),
(4558,'EXC URACHAL CYST/SINUS W/WO UMBILICAL HERNIA RPR','EXC URACHAL CYST/SINUS W/WO UMBILICAL HERNIA RPR','50740','1','','1','0','','','',0, 1, 0, 0),
(4559,'URETEROCALYCOSTOMY ANAST URETER RENAL CALYX','URETEROCALYCOSTOMY ANAST URETER RENAL CALYX','50750','1','','1','0','','','',0, 1, 0, 0),
(4560,'URETEROURETEROSTOMY','URETEROURETEROSTOMY','50760','1','','1','0','','','',0, 1, 0, 0),
(4561,'TRANSURETEROURETEROSTOMY ANAST URETER CLAT URTR','TRANSURETEROURETEROSTOMY ANAST URETER CLAT URTR','50770','1','','1','0','','','',0, 1, 0, 0),
(4562,'URETERONEOCYSTOSTOMY ANAST 1 URETER BLADDER','URETERONEOCYSTOSTOMY ANAST 1 URETER BLADDER','50780','1','','1','0','','','',0, 1, 0, 0),
(4563,'URETERONEOCYSTOSTOMY ANAST DUPLICATE URETER BLDR','URETERONEOCYSTOSTOMY ANAST DUPLICATE URETER BLDR','50782','1','','1','0','','','',0, 1, 0, 0),
(4564,'URETERONEOCYSTOSTOMY W/URETERAL TAILORING','URETERONEOCYSTOSTOMY W/URETERAL TAILORING','50783','1','','1','0','','','',0, 1, 0, 0),
(4565,'URTRONEOCSTOST W/VESICO-PSOAS HITCH/BLDR FLAP','URTRONEOCSTOST W/VESICO-PSOAS HITCH/BLDR FLAP','50785','1','','1','0','','','',0, 1, 0, 0),
(4566,'URETEROENTEROSTOMY ANAST URETER INTESTINE','URETEROENTEROSTOMY ANAST URETER INTESTINE','50800','1','','1','0','','','',0, 1, 0, 0),
(4567,'URETEROSIGMOIDOSTOMY W/SIGMOID BLADDER & COLOSTO','URETEROSIGMOIDOSTOMY W/SIGMOID BLADDER & COLOSTO','50810','1','','1','0','','','',0, 1, 0, 0),
(4568,'URETEROCOLON CONDUIT INTESTINE ANASTOMOSIS','URETEROCOLON CONDUIT INTESTINE ANASTOMOSIS','50815','1','','1','0','','','',0, 1, 0, 0),
(4569,'URETEROILEAL CONDUIT W/INTESTINE ANASTOMOSIS','URETEROILEAL CONDUIT W/INTESTINE ANASTOMOSIS','50820','1','','1','0','','','',0, 1, 0, 0),
(4570,'CONTINENT DVRJ W/INT ANAST ANY SGM SM&/LG INTSTN','CONTINENT DVRJ W/INT ANAST ANY SGM SM&/LG INTSTN','50825','1','','1','0','','','',0, 1, 0, 0),
(4571,'URINARY UNIDIVERSION','URINARY UNIDIVERSION','50830','1','','1','0','','','',0, 1, 0, 0),
(4572,'RPLCMT ALL/PART URETER INTESTINE SGM W/ANAST','RPLCMT ALL/PART URETER INTESTINE SGM W/ANAST','50840','1','','1','0','','','',0, 1, 0, 0),
(4573,'CUTANANEOUS APPENDICO-VESICOSTOMY','CUTANANEOUS APPENDICO-VESICOSTOMY','50845','1','','1','0','','','',0, 1, 0, 0),
(4574,'URETEROSTOMY TRANSPLANTATION URETER SKIN','URETEROSTOMY TRANSPLANTATION URETER SKIN','50860','1','','1','0','','','',0, 1, 0, 0),
(4575,'URETERORRHAPHY SUTURE URETER SEPARATE PROCEDURE','URETERORRHAPHY SUTURE URETER SEPARATE PROCEDURE','50900','1','','1','0','','','',0, 1, 0, 0),
(4576,'CLOSURE URETEROCUTANEOUS FISTULA','CLOSURE URETEROCUTANEOUS FISTULA','50920','1','','1','0','','','',0, 1, 0, 0),
(4577,'CLOSURE URETEROCUTANEOUS FISTULA W/VISC RPR','CLOSURE URETEROCUTANEOUS FISTULA W/VISC RPR','50930','1','','1','0','','','',0, 1, 0, 0),
(4578,'DELIGATION URETER','DELIGATION URETER','50940','1','','1','0','','','',0, 1, 0, 0),
(4579,'LAPAROSCOPY URTROLITHOTOMY','LAPAROSCOPY URTROLITHOTOMY','50945','1','','1','0','','','',0, 1, 0, 0),
(4580,'LAPS URTRONEOCSTOST W/CSTSC&URTRL STENT PLMT','LAPS URTRONEOCSTOST W/CSTSC&URTRL STENT PLMT','50947','1','','1','0','','','',0, 1, 0, 0),
(4581,'LAPS URTRONEOCSTOST W/O CSTSC&URTRL STENT PLMT','LAPS URTRONEOCSTOST W/O CSTSC&URTRL STENT PLMT','50948','1','','1','0','','','',0, 1, 0, 0),
(4582,'UNLISTED LAPAROSCOPY PROCEDURE URETER','UNLISTED LAPAROSCOPY PROCEDURE URETER','50949','1','','1','0','','','',0, 1, 0, 0),
(4583,'URETERAL ENDOSCOPY VIA URETEROSTOMY','URETERAL ENDOSCOPY VIA URETEROSTOMY','50951','1','','1','0','','','',0, 1, 0, 0),
(4584,'URETERAL ENDOSCOPY VIA URETEROST W/WO DIL URETER','URETERAL ENDOSCOPY VIA URETEROST W/WO DIL URETER','50953','1','','1','0','','','',0, 1, 0, 0),
(4585,'URETERAL ENDOSCOPY VIA URETEROSTOMY W/BIOPSY','URETERAL ENDOSCOPY VIA URETEROSTOMY W/BIOPSY','50955','1','','1','0','','','',0, 1, 0, 0),
(4586,'URETERAL ENDOSCOPY W/DEST&/INC W/WO BIOPSY','URETERAL ENDOSCOPY W/DEST&/INC W/WO BIOPSY','50957','1','','1','0','','','',0, 1, 0, 0),
(4587,'URETERAL ENDOSCOPY VIA URETEROST W/RMVL FB/STONE','URETERAL ENDOSCOPY VIA URETEROST W/RMVL FB/STONE','50961','1','','1','0','','','',0, 1, 0, 0),
(4588,'URETERAL ENDOSCOPY VIA URETEROTOMY W/O IMAGING','URETERAL ENDOSCOPY VIA URETEROTOMY W/O IMAGING','50970','1','','1','0','','','',0, 1, 0, 0),
(4589,'NDSC URETEROTOMY URTRL CATHJ W/WO DILAT URETER','NDSC URETEROTOMY URTRL CATHJ W/WO DILAT URETER','50972','1','','1','0','','','',0, 1, 0, 0),
(4590,'URETERAL ENDOSCOPY VIA URETEROT W/O IMAGING W/BX','URETERAL ENDOSCOPY VIA URETEROT W/O IMAGING W/BX','50974','1','','1','0','','','',0, 1, 0, 0),
(4591,'URETERAL ENDOSC VIA URETEROT W/DEST&/INC W/WO BX','URETERAL ENDOSC VIA URETEROT W/DEST&/INC W/WO BX','50976','1','','1','0','','','',0, 1, 0, 0),
(4592,'NDSC URETEROTOMY RMVL FB/CALCULUS','NDSC URETEROTOMY RMVL FB/CALCULUS','50980','1','','1','0','','','',0, 1, 0, 0),
(4593,'CYSTOTOMY/CYSTOSTOMY FULG&/INSJ RADACT MATRL','CYSTOTOMY/CYSTOSTOMY FULG&/INSJ RADACT MATRL','51020','1','','1','0','','','',0, 1, 0, 0),
(4594,'CSTOTOMY/CSTOST CRYOSURG DSTRJ INTRAVESICAL LES','CSTOTOMY/CSTOST CRYOSURG DSTRJ INTRAVESICAL LES','51030','1','','1','0','','','',0, 1, 0, 0),
(4595,'CYSTOSTOMY CYSTOTOMY W/DRAINAGE','CYSTOSTOMY CYSTOTOMY W/DRAINAGE','51040','1','','1','0','','','',0, 1, 0, 0),
(4596,'CYSTOTOMY W/INSJ URETERAL CATH/STENT SPX','CYSTOTOMY W/INSJ URETERAL CATH/STENT SPX','51045','1','','1','0','','','',0, 1, 0, 0),
(4597,'CYSTOLITHOTOMY CYSTOTOMY W/RMVL CALCULUS','CYSTOLITHOTOMY CYSTOTOMY W/RMVL CALCULUS','51050','1','','1','0','','','',0, 1, 0, 0),
(4598,'TRANSVESICAL URETROLITHOTOMY','TRANSVESICAL URETROLITHOTOMY','51060','1','','1','0','','','',0, 1, 0, 0),
(4599,'CYSTOTOMY W/CALCULUS BASKET XTRJ&/FRAGMENTATIO','CYSTOTOMY W/CALCULUS BASKET XTRJ&/FRAGMENTATIO','51065','1','','1','0','','','',0, 1, 0, 0),
(4600,'DRG PRIVESICAL/PREVESICAL SPACE ABSC','DRG PRIVESICAL/PREVESICAL SPACE ABSC','51080','1','','1','0','','','',0, 1, 0, 0),
(4601,'ASPIRATION BLADDER NEEDLE','ASPIRATION BLADDER NEEDLE','51100','1','','1','0','','','',0, 1, 0, 0),
(4602,'ASPIRATION BLADDER TROCAR/INTRACATHETER','ASPIRATION BLADDER TROCAR/INTRACATHETER','51101','1','','1','0','','','',0, 1, 0, 0),
(4603,'ASPIRATION BLADDER INSERT SUPRAPUBIC CATHETER','ASPIRATION BLADDER INSERT SUPRAPUBIC CATHETER','51102','1','','1','0','','','',0, 1, 0, 0),
(4604,'EXC URACHAL CYST/SINUS W/WO UMBILICAL HERNIA RPR','EXC URACHAL CYST/SINUS W/WO UMBILICAL HERNIA RPR','51500','1','','1','0','','','',0, 1, 0, 0),
(4605,'CYSTOTOMY SIMPLE EXCISION VESICAL NECK','CYSTOTOMY SIMPLE EXCISION VESICAL NECK','51520','1','','1','0','','','',0, 1, 0, 0),
(4606,'CYSTOTOMY EXCISE BLADDER DIVERTICULUM 1/MULTIPLE','CYSTOTOMY EXCISE BLADDER DIVERTICULUM 1/MULTIPLE','51525','1','','1','0','','','',0, 1, 0, 0),
(4607,'CYSTOTOMY EXCISION BLADDER TUMOR','CYSTOTOMY EXCISION BLADDER TUMOR','51530','1','','1','0','','','',0, 1, 0, 0),
(4608,'CYSTOTOMY EXCISE/INCISE/REPAIR URETEROCELE','CYSTOTOMY EXCISE/INCISE/REPAIR URETEROCELE','51535','1','','1','0','','','',0, 1, 0, 0),
(4609,'CYSTECTOMY PARTIAL SIMPLE','CYSTECTOMY PARTIAL SIMPLE','51550','1','','1','0','','','',0, 1, 0, 0),
(4610,'CYSTECTOMY PARTIAL COMPLICATED','CYSTECTOMY PARTIAL COMPLICATED','51555','1','','1','0','','','',0, 1, 0, 0),
(4611,'CSTC PRTL W/RIMPLTJ URTR IN BLDR URTRONEOCSTOST','CSTC PRTL W/RIMPLTJ URTR IN BLDR URTRONEOCSTOST','51565','1','','1','0','','','',0, 1, 0, 0),
(4612,'CYSTECTOMY COMPLETE SEPARATE PROCEDURE','CYSTECTOMY COMPLETE SEPARATE PROCEDURE','51570','1','','1','0','','','',0, 1, 0, 0),
(4613,'CYSTECTOMY W/BI PELVIC LYMPHADENECTOMY','CYSTECTOMY W/BI PELVIC LYMPHADENECTOMY','51575','1','','1','0','','','',0, 1, 0, 0),
(4614,'CYSTECTOMY W/URETEROSIGMOIDOSTOMY W/NODES','CYSTECTOMY W/URETEROSIGMOIDOSTOMY W/NODES','51580','1','','1','0','','','',0, 1, 0, 0),
(4615,'CYSTECTOMY W/URETEROSIGMOID BI PELV LYMPH NODES','CYSTECTOMY W/URETEROSIGMOID BI PELV LYMPH NODES','51585','1','','1','0','','','',0, 1, 0, 0),
(4616,'CSTC COMPL W/URTROILEAL CONDUIT/BLDR W/INT ANAST','CSTC COMPL W/URTROILEAL CONDUIT/BLDR W/INT ANAST','51590','1','','1','0','','','',0, 1, 0, 0),
(4617,'CSTC COMPL W/CONDUIT/SIGMOID BLDR PEL LMPHADEC','CSTC COMPL W/CONDUIT/SIGMOID BLDR PEL LMPHADEC','51595','1','','1','0','','','',0, 1, 0, 0),
(4618,'CSTC COMPL W/CONTINENT DVRJ OPN NEOBLDR','CSTC COMPL W/CONTINENT DVRJ OPN NEOBLDR','51596','1','','1','0','','','',0, 1, 0, 0),
(4619,'PELVIC EXENTERATION COMPLETE MALIGNANCY','PELVIC EXENTERATION COMPLETE MALIGNANCY','51597','1','','1','0','','','',0, 1, 0, 0),
(4620,'NJX CSTOGRAPY/VOIDING URETHROCSTOGRAPY','NJX CSTOGRAPY/VOIDING URETHROCSTOGRAPY','51600','1','','1','0','','','',0, 1, 0, 0),
(4621,'NJX & PLACEMENT CHAIN CONTRAST&/URETHROCSTOGRAPY','NJX & PLACEMENT CHAIN CONTRAST&/URETHROCSTOGRAPY','51605','1','','1','0','','','',0, 1, 0, 0),
(4622,'NJX RETROGRADE URETHROCSTOGRAPY','NJX RETROGRADE URETHROCSTOGRAPY','51610','1','','1','0','','','',0, 1, 0, 0),
(4623,'BLDR IRRIGATION SMPL LAVAGE &/INSTLJ','BLDR IRRIGATION SMPL LAVAGE &/INSTLJ','51700','1','','1','0','','','',0, 1, 0, 0),
(4624,'INSJ NON-NDWELLG BLADDER CATHETER','INSJ NON-NDWELLG BLADDER CATHETER','51701','1','','1','0','','','',0, 1, 0, 0),
(4625,'INSJ TEMP NDWELLG BLADDER CATHETER SIMPLE','INSJ TEMP NDWELLG BLADDER CATHETER SIMPLE','51702','1','','1','0','','','',0, 1, 0, 0),
(4626,'INSJ TEMP NDWELLG BLADDER CATHETER COMPLICATED','INSJ TEMP NDWELLG BLADDER CATHETER COMPLICATED','51703','1','','1','0','','','',0, 1, 0, 0),
(4627,'CHANGE CYSTOSTOMY TUBE SIMPLE','CHANGE CYSTOSTOMY TUBE SIMPLE','51705','1','','1','0','','','',0, 1, 0, 0),
(4628,'CHANGE CYSTOSTOMY TUBE COMPLICATED','CHANGE CYSTOSTOMY TUBE COMPLICATED','51710','1','','1','0','','','',0, 1, 0, 0),
(4629,'NDSC NJX IMPLT MATRL URT&/BLDR NCK','NDSC NJX IMPLT MATRL URT&/BLDR NCK','51715','1','','1','0','','','',0, 1, 0, 0),
(4630,'BLADDER INSTILLATION ANTICARCINOGENIC AGENT','BLADDER INSTILLATION ANTICARCINOGENIC AGENT','51720','1','','1','0','','','',0, 1, 0, 0),
(4631,'SIMPLE CYSTOMETROGRAM','SIMPLE CYSTOMETROGRAM','51725','1','','1','0','','','',0, 1, 0, 0),
(4632,'BLADDER PRESSURE MEASUREMENT DURING FILLING','BLADDER PRESSURE MEASUREMENT DURING FILLING','51726','1','','1','0','','','',0, 1, 0, 0),
(4633,'COMPLEX CYSTOMETROGRAM URETHRAL PRESS PROFILE','COMPLEX CYSTOMETROGRAM URETHRAL PRESS PROFILE','51727','1','','1','0','','','',0, 1, 0, 0),
(4634,'COMPLEX CYSTOMETROGRAM VOIDING PRESSURE STUDIES','COMPLEX CYSTOMETROGRAM VOIDING PRESSURE STUDIES','51728','1','','1','0','','','',0, 1, 0, 0),
(4635,'COMPLX CYSTOMETRO W/VOID PRESS & URETHRAL PROFIL','COMPLX CYSTOMETRO W/VOID PRESS & URETHRAL PROFIL','51729','1','','1','0','','','',0, 1, 0, 0),
(4636,'SIMPLE UROFLOMETRY','SIMPLE UROFLOMETRY','51736','1','','1','0','','','',0, 1, 0, 0),
(4637,'COMPLEX UROFLOMETRY','COMPLEX UROFLOMETRY','51741','1','','1','0','','','',0, 1, 0, 0),
(4638,'EMG STDS ANAL/URTL SPHNCTR OTH/THN NDL','EMG STDS ANAL/URTL SPHNCTR OTH/THN NDL','51784','1','','1','0','','','',0, 1, 0, 0),
(4639,'NDL EMG STDS EMG ANAL/URTL SPHNCTR ANY TQ','NDL EMG STDS EMG ANAL/URTL SPHNCTR ANY TQ','51785','1','','1','0','','','',0, 1, 0, 0),
(4640,'STIMULUS EVOKED RESPONSE','STIMULUS EVOKED RESPONSE','51792','1','','1','0','','','',0, 1, 0, 0),
(4641,'VOID PRESSURE STUDIES INTRAABDOMINAL','VOID PRESSURE STUDIES INTRAABDOMINAL','51797','1','','1','0','','','',0, 1, 0, 0),
(4642,'MEAS POST-VOIDING RESIDUAL URINE&/BLADDER CAP','MEAS POST-VOIDING RESIDUAL URINE&/BLADDER CAP','51798','1','','1','0','','','',0, 1, 0, 0),
(4643,'CSTOPLASTY/CSTOURTP PLSTC ANY','CSTOPLASTY/CSTOURTP PLSTC ANY','51800','1','','1','0','','','',0, 1, 0, 0),
(4644,'CSTOURTP W/UNI/BI URTRONEOCSTOST','CSTOURTP W/UNI/BI URTRONEOCSTOST','51820','1','','1','0','','','',0, 1, 0, 0),
(4645,'ANT VESICOURETHROPEXY/URETHROPEXY SMPL','ANT VESICOURETHROPEXY/URETHROPEXY SMPL','51840','1','','1','0','','','',0, 1, 0, 0),
(4646,'ANT VESICOURETHROPEXY/URETHROPEXY COMP','ANT VESICOURETHROPEXY/URETHROPEXY COMP','51841','1','','1','0','','','',0, 1, 0, 0),
(4647,'ABDOMINO-VAG VESICAL NCK SSP W/WO NDSC CTRL','ABDOMINO-VAG VESICAL NCK SSP W/WO NDSC CTRL','51845','1','','1','0','','','',0, 1, 0, 0),
(4648,'CYSTORRHAPHY SUTR BLDR WND INJ/RPT SIMPLE','CYSTORRHAPHY SUTR BLDR WND INJ/RPT SIMPLE','51860','1','','1','0','','','',0, 1, 0, 0),
(4649,'CYSTORRHAPHY SUTR BLDR WND INJ/RPT COMPLICATED','CYSTORRHAPHY SUTR BLDR WND INJ/RPT COMPLICATED','51865','1','','1','0','','','',0, 1, 0, 0),
(4650,'CLOSURE CYSTOSTOMY SEPARATE PROCEDURE','CLOSURE CYSTOSTOMY SEPARATE PROCEDURE','51880','1','','1','0','','','',0, 1, 0, 0),
(4651,'CLSR VESICOVAGINAL FISTUL AABDL APPROACH','CLSR VESICOVAGINAL FISTUL AABDL APPROACH','51900','1','','1','0','','','',0, 1, 0, 0),
(4652,'CLOSURE VESICOUTERINE FISTULA','CLOSURE VESICOUTERINE FISTULA','51920','1','','1','0','','','',0, 1, 0, 0),
(4653,'CLSR VESICOUTERINE FISTULA W/HYSTERECTOMY','CLSR VESICOUTERINE FISTULA W/HYSTERECTOMY','51925','1','','1','0','','','',0, 1, 0, 0),
(4654,'CLOSURE EXSTROPHY BLADDER','CLOSURE EXSTROPHY BLADDER','51940','1','','1','0','','','',0, 1, 0, 0),
(4655,'ENTEROCYSTOPLASTY W/INTESTINAL ANASTOMOSIS','ENTEROCYSTOPLASTY W/INTESTINAL ANASTOMOSIS','51960','1','','1','0','','','',0, 1, 0, 0),
(4656,'CUTANEOUS VESICOSTOMY','CUTANEOUS VESICOSTOMY','51980','1','','1','0','','','',0, 1, 0, 0),
(4657,'LAPAROSCOPY URETHRAL SUSPENSION STRESS INCONT','LAPAROSCOPY URETHRAL SUSPENSION STRESS INCONT','51990','1','','1','0','','','',0, 1, 0, 0),
(4658,'LAPAROSCOPY SLING OPERATION STRESS INCONT','LAPAROSCOPY SLING OPERATION STRESS INCONT','51992','1','','1','0','','','',0, 1, 0, 0),
(4659,'UNLISTED LAPAROSCOPY PROCEDURE BLADDER','UNLISTED LAPAROSCOPY PROCEDURE BLADDER','51999','1','','1','0','','','',0, 1, 0, 0),
(4660,'CYSTOURETHROSCOPY','CYSTOURETHROSCOPY','52000','1','','1','0','','','',0, 1, 0, 0),
(4661,'CYSTO W/IRRIG & EVAC MULTPLE OBSTRUCTING CLOTS','CYSTO W/IRRIG & EVAC MULTPLE OBSTRUCTING CLOTS','52001','1','','1','0','','','',0, 1, 0, 0),
(4662,'CYSTO BLADDER W/URETERAL CATHETERIZATION','CYSTO BLADDER W/URETERAL CATHETERIZATION','52005','1','','1','0','','','',0, 1, 0, 0),
(4663,'CYSTO W/URTRL CATHJ BRUSH BX URTR&/RENAL PELVIS','CYSTO W/URTRL CATHJ BRUSH BX URTR&/RENAL PELVIS','52007','1','','1','0','','','',0, 1, 0, 0),
(4664,'CYSTO W/EJACULATORY DUCT CATHETERIZATION','CYSTO W/EJACULATORY DUCT CATHETERIZATION','52010','1','','1','0','','','',0, 1, 0, 0),
(4665,'CYSTOURETHROSCOPY WITH BIOPSY','CYSTOURETHROSCOPY WITH BIOPSY','52204','1','','1','0','','','',0, 1, 0, 0),
(4666,'CYSTO W/DESTRUCTION OF LESIONS','CYSTO W/DESTRUCTION OF LESIONS','52214','1','','1','0','','','',0, 1, 0, 0),
(4667,'CYSTO W/REMOVAL OF LESIONS SMALL','CYSTO W/REMOVAL OF LESIONS SMALL','52224','1','','1','0','','','',0, 1, 0, 0),
(4668,'CYSTO W/REMOVAL OF TUMORS SMALL','CYSTO W/REMOVAL OF TUMORS SMALL','52234','1','','1','0','','','',0, 1, 0, 0),
(4669,'CYSTOURETHROSCOPY W/DEST &/RMVL MED BLADDER TUM','CYSTOURETHROSCOPY W/DEST &/RMVL MED BLADDER TUM','52235','1','','1','0','','','',0, 1, 0, 0),
(4670,'CYSTOURETHROSCOPY W/DEST &/RMVL TUMOR LARGE','CYSTOURETHROSCOPY W/DEST &/RMVL TUMOR LARGE','52240','1','','1','0','','','',0, 1, 0, 0),
(4671,'CYSTOURETHROSCOPY INSJ RADIOACT SBST W/WOBX/FULG','CYSTOURETHROSCOPY INSJ RADIOACT SBST W/WOBX/FULG','52250','1','','1','0','','','',0, 1, 0, 0),
(4672,'CYSTOURETHROSCOPY W/DIL BLADDER GENERAL ANESTH','CYSTOURETHROSCOPY W/DIL BLADDER GENERAL ANESTH','52260','1','','1','0','','','',0, 1, 0, 0),
(4673,'CYSTOURETHROSCOPY W/DIL BLADDER LOCAL ANESTHESIA','CYSTOURETHROSCOPY W/DIL BLADDER LOCAL ANESTHESIA','52265','1','','1','0','','','',0, 1, 0, 0),
(4674,'CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY FEMALE','CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY FEMALE','52270','1','','1','0','','','',0, 1, 0, 0),
(4675,'CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY MALE','CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY MALE','52275','1','','1','0','','','',0, 1, 0, 0),
(4676,'CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY MALE','CYSTOURETHROSCOPY W/INTERNAL URETHROTOMY MALE','52276','1','','1','0','','','',0, 1, 0, 0),
(4677,'CYSTOURETHROSCOPY W/RESECJ EXTERNAL SPHINCTER','CYSTOURETHROSCOPY W/RESECJ EXTERNAL SPHINCTER','52277','1','','1','0','','','',0, 1, 0, 0),
(4678,'CYSTO CALIBRATION DILAT URTL STRIX/STENOSIS','CYSTO CALIBRATION DILAT URTL STRIX/STENOSIS','52281','1','','1','0','','','',0, 1, 0, 0),
(4679,'CYSTOURETHROSCOPY INSERTION PERM URETHRAL STENT','CYSTOURETHROSCOPY INSERTION PERM URETHRAL STENT','52282','1','','1','0','','','',0, 1, 0, 0),
(4680,'CYSTOURETHROSCOPY W/STEROID INJECTION STRICTURE','CYSTOURETHROSCOPY W/STEROID INJECTION STRICTURE','52283','1','','1','0','','','',0, 1, 0, 0),
(4681,'CYSTOURETHROSCOPY TX FEMALE URETHRAL SYNDROME','CYSTOURETHROSCOPY TX FEMALE URETHRAL SYNDROME','52285','1','','1','0','','','',0, 1, 0, 0),
(4682,'CYSTOURETHROSCOPY INJ CHEMODENERVATION BLADDER','CYSTOURETHROSCOPY INJ CHEMODENERVATION BLADDER','52287','1','','1','0','','','',0, 1, 0, 0),
(4683,'CYSTOURETHROSCOPY W/URETERAL MEATOTOMY UNI/BI','CYSTOURETHROSCOPY W/URETERAL MEATOTOMY UNI/BI','52290','1','','1','0','','','',0, 1, 0, 0),
(4684,'CYSTO W/RESCJ/FULG ORTHOPIC URETEROCELE UNI/BI','CYSTO W/RESCJ/FULG ORTHOPIC URETEROCELE UNI/BI','52300','1','','1','0','','','',0, 1, 0, 0),
(4685,'CYSTO W/RESECJ ECTOPIC URETEROCELE UNI/BI','CYSTO W/RESECJ ECTOPIC URETEROCELE UNI/BI','52301','1','','1','0','','','',0, 1, 0, 0),
(4686,'CYSTO INC/RESCJ ORIFICE BLDR DIVERTICULUM 1/MLT','CYSTO INC/RESCJ ORIFICE BLDR DIVERTICULUM 1/MLT','52305','1','','1','0','','','',0, 1, 0, 0),
(4687,'CYSTO W/SIMPLE REMOVAL STONE & STENT','CYSTO W/SIMPLE REMOVAL STONE & STENT','52310','1','','1','0','','','',0, 1, 0, 0),
(4688,'CYSTO W/COMPLEX REMOVAL STONE & STENT','CYSTO W/COMPLEX REMOVAL STONE & STENT','52315','1','','1','0','','','',0, 1, 0, 0),
(4689,'LITHOLAPAXY SMPL/SM <2.5 CM','LITHOLAPAXY SMPL/SM <2.5 CM','52317','1','','1','0','','','',0, 1, 0, 0),
(4690,'LITHOLAPAXY COMP/LG > 2.5 CM','LITHOLAPAXY COMP/LG > 2.5 CM','52318','1','','1','0','','','',0, 1, 0, 0),
(4691,'CYSTOURETHROSCOPY W/RMVL URETERAL CALCULUS','CYSTOURETHROSCOPY W/RMVL URETERAL CALCULUS','52320','1','','1','0','','','',0, 1, 0, 0),
(4692,'CYSTO FRAGMENTATION URETERAL STONE','CYSTO FRAGMENTATION URETERAL STONE','52325','1','','1','0','','','',0, 1, 0, 0),
(4693,'CYSTO W/SUBURTRIC NJX IMPLT MATRL','CYSTO W/SUBURTRIC NJX IMPLT MATRL','52327','1','','1','0','','','',0, 1, 0, 0),
(4694,'CYSTO MANJ W/O RMVL URETERAL STONE','CYSTO MANJ W/O RMVL URETERAL STONE','52330','1','','1','0','','','',0, 1, 0, 0),
(4695,'CYSTO W/INSERT URETERAL STENT','CYSTO W/INSERT URETERAL STENT','52332','1','','1','0','','','',0, 1, 0, 0),
(4696,'CYSTO INSJ URTRL GD WIRE PRQ NFROS RTRGR','CYSTO INSJ URTRL GD WIRE PRQ NFROS RTRGR','52334','1','','1','0','','','',0, 1, 0, 0),
(4697,'CYSTO W/TX URETERAL STRICTURE','CYSTO W/TX URETERAL STRICTURE','52341','1','','1','0','','','',0, 1, 0, 0),
(4698,'CYSTO W/TX URETEROPELVIC JUNCTION STRICTURE','CYSTO W/TX URETEROPELVIC JUNCTION STRICTURE','52342','1','','1','0','','','',0, 1, 0, 0),
(4699,'CYSTO W/TX INTRA-RENAL STRICTURE','CYSTO W/TX INTRA-RENAL STRICTURE','52343','1','','1','0','','','',0, 1, 0, 0),
(4700,'CYSTO W/URTROSCOPY W/TX URETERAL STRICTURE','CYSTO W/URTROSCOPY W/TX URETERAL STRICTURE','52344','1','','1','0','','','',0, 1, 0, 0),
(4701,'CYSTO W/URTROSCOPY W/TX URTROPEL JUNCT STRIX','CYSTO W/URTROSCOPY W/TX URTROPEL JUNCT STRIX','52345','1','','1','0','','','',0, 1, 0, 0),
(4702,'CYSTO W/URTROSCOPY W/TX INTRA-RENAL STRICTURE','CYSTO W/URTROSCOPY W/TX INTRA-RENAL STRICTURE','52346','1','','1','0','','','',0, 1, 0, 0),
(4703,'CYSTO W/URTROSCOPY&/PYELOSCOPY DX','CYSTO W/URTROSCOPY&/PYELOSCOPY DX','52351','1','','1','0','','','',0, 1, 0, 0),
(4704,'CYSTO W/URETEROSCOPY W/RMVL/MANJ STONES','CYSTO W/URETEROSCOPY W/RMVL/MANJ STONES','52352','1','','1','0','','','',0, 1, 0, 0),
(4705,'CYSTO W/URETEROSCOPY W/LITHOTRIPSY','CYSTO W/URETEROSCOPY W/LITHOTRIPSY','52353','1','','1','0','','','',0, 1, 0, 0),
(4706,'CYSTO/PYELOSCOPY BX&/FULGURATION PELIVC LESION','CYSTO/PYELOSCOPY BX&/FULGURATION PELIVC LESION','52354','1','','1','0','','','',0, 1, 0, 0),
(4707,'CYSTO/PYELOSCOPY RESCJ PELVIC TUMOR','CYSTO/PYELOSCOPY RESCJ PELVIC TUMOR','52355','1','','1','0','','','',0, 1, 0, 0),
(4708,'CYSTO/URETERO W/LITHOTRIPSY &INDWELL STENT INSRT','CYSTO/URETERO W/LITHOTRIPSY &INDWELL STENT INSRT','52356','1','','1','0','','','',0, 1, 0, 0),
(4709,'CYSTO INC FULG/RESCJ URTL VALVES/FOLDS','CYSTO INC FULG/RESCJ URTL VALVES/FOLDS','52400','1','','1','0','','','',0, 1, 0, 0),
(4710,'CSTO W/TRURL RESCJ/INC EJACULATORY DUXS','CSTO W/TRURL RESCJ/INC EJACULATORY DUXS','52402','1','','1','0','','','',0, 1, 0, 0),
(4711,'CYSTO INSERTION TRANSPROSTATIC IMPLANT SINGLE','CYSTO INSERTION TRANSPROSTATIC IMPLANT SINGLE','52441','1','','1','0','','','',0, 1, 0, 0),
(4712,'CYSTO INSERTION TRANSPROSTATIC IMPLANT EA ADDL','CYSTO INSERTION TRANSPROSTATIC IMPLANT EA ADDL','52442','1','','1','0','','','',0, 1, 0, 0),
(4713,'TRANSURETHRAL INCISION PROSTATE','TRANSURETHRAL INCISION PROSTATE','52450','1','','1','0','','','',0, 1, 0, 0),
(4714,'TRANSURETHRAL RESECTION PROSTATE','TRANSURETHRAL RESECTION PROSTATE','52500','1','','1','0','','','',0, 1, 0, 0),
(4715,'TRURL ELECTROSURG RESCJ PROSTATE BLEED COMPLETE','TRURL ELECTROSURG RESCJ PROSTATE BLEED COMPLETE','52601','1','','1','0','','','',0, 1, 0, 0),
(4716,'TRURL RESCJ RESIDUAL/REGROWTH OBSTR PRSTATE TISS','TRURL RESCJ RESIDUAL/REGROWTH OBSTR PRSTATE TISS','52630','1','','1','0','','','',0, 1, 0, 0),
(4717,'TRURL RESCJ POSTOP BLADDER NECK CONTRACTURE','TRURL RESCJ POSTOP BLADDER NECK CONTRACTURE','52640','1','','1','0','','','',0, 1, 0, 0),
(4718,'LASER COAGULATION OF PROSTATE FOR URINE FLOW','LASER COAGULATION OF PROSTATE FOR URINE FLOW','52647','1','','1','0','','','',0, 1, 0, 0),
(4719,'LASER VAPORIZATION OF PROSTATE FOR URINE FLOW','LASER VAPORIZATION OF PROSTATE FOR URINE FLOW','52648','1','','1','0','','','',0, 1, 0, 0),
(4720,'LASER ENUCLEATION PROSTATE W/MORCELLATION','LASER ENUCLEATION PROSTATE W/MORCELLATION','52649','1','','1','0','','','',0, 1, 0, 0),
(4721,'TRURL DRAINAGE PROSTATIC ABSCESS','TRURL DRAINAGE PROSTATIC ABSCESS','52700','1','','1','0','','','',0, 1, 0, 0),
(4722,'URTT/URTS XTRNL SPX PENDULOUS URETHRA','URTT/URTS XTRNL SPX PENDULOUS URETHRA','53000','1','','1','0','','','',0, 1, 0, 0),
(4723,'URETHROTOMY/URETHROSTOMY XT SPX PERINEAL URETHRA','URETHROTOMY/URETHROSTOMY XT SPX PERINEAL URETHRA','53010','1','','1','0','','','',0, 1, 0, 0),
(4724,'MEATOTOMY CUTTING MEATUS SPX EXCEPT INFANT','MEATOTOMY CUTTING MEATUS SPX EXCEPT INFANT','53020','1','','1','0','','','',0, 1, 0, 0),
(4725,'MEATOTOMY CUTTING MEATUS SPX INFANT','MEATOTOMY CUTTING MEATUS SPX INFANT','53025','1','','1','0','','','',0, 1, 0, 0),
(4726,'DRAINAGE DEEP PERIURETHRAL ABSCESS','DRAINAGE DEEP PERIURETHRAL ABSCESS','53040','1','','1','0','','','',0, 1, 0, 0),
(4727,'DRG OF SKENE''S GLAND ABSCESS OR CYST','DRG OF SKENE''S GLAND ABSCESS OR CYST','53060','1','','1','0','','','',0, 1, 0, 0),
(4728,'DRG PERINEAL URINARY XTRVASATION UNCOMP SPX','DRG PERINEAL URINARY XTRVASATION UNCOMP SPX','53080','1','','1','0','','','',0, 1, 0, 0),
(4729,'DRG PERINEAL URINARY XTRVASATION COMPLIC','DRG PERINEAL URINARY XTRVASATION COMPLIC','53085','1','','1','0','','','',0, 1, 0, 0),
(4730,'BIOPSY URETHRA','BIOPSY URETHRA','53200','1','','1','0','','','',0, 1, 0, 0),
(4731,'URETHRECTOMY TOT W/CYSTOST FEMALE','URETHRECTOMY TOT W/CYSTOST FEMALE','53210','1','','1','0','','','',0, 1, 0, 0),
(4732,'URETHRECTOMY TOT W/CYSTOST MALE','URETHRECTOMY TOT W/CYSTOST MALE','53215','1','','1','0','','','',0, 1, 0, 0),
(4733,'EXC/FULGURATION CARCINOMA URETHRA','EXC/FULGURATION CARCINOMA URETHRA','53220','1','','1','0','','','',0, 1, 0, 0),
(4734,'EXC URETHRAL DIVERTICULUM SPX FEMALE','EXC URETHRAL DIVERTICULUM SPX FEMALE','53230','1','','1','0','','','',0, 1, 0, 0),
(4735,'EXC URETHRAL DIVERTICULUM SPX MALE','EXC URETHRAL DIVERTICULUM SPX MALE','53235','1','','1','0','','','',0, 1, 0, 0),
(4736,'MARSUPIALIZATION URTL DIVERTICULUM MALE/FEMALE','MARSUPIALIZATION URTL DIVERTICULUM MALE/FEMALE','53240','1','','1','0','','','',0, 1, 0, 0),
(4737,'EXCISION OF BULBOURETHRAL GLAND','EXCISION OF BULBOURETHRAL GLAND','53250','1','','1','0','','','',0, 1, 0, 0),
(4738,'EXC/FULGURATION URETHRAL POLYP DSTL URETHRA','EXC/FULGURATION URETHRAL POLYP DSTL URETHRA','53260','1','','1','0','','','',0, 1, 0, 0),
(4739,'EXC/FULGURATION URETHRAL CARUNCLE','EXC/FULGURATION URETHRAL CARUNCLE','53265','1','','1','0','','','',0, 1, 0, 0),
(4740,'EXCISION OR FULGURATION SKENES GLANDS','EXCISION OR FULGURATION SKENES GLANDS','53270','1','','1','0','','','',0, 1, 0, 0),
(4741,'EXCISION/FULGURATION URETHRAL PROLAPSE','EXCISION/FULGURATION URETHRAL PROLAPSE','53275','1','','1','0','','','',0, 1, 0, 0),
(4742,'URETHROPLASTY 1ST STG FISTULA/DIVERTICULUM/STRIX','URETHROPLASTY 1ST STG FISTULA/DIVERTICULUM/STRIX','53400','1','','1','0','','','',0, 1, 0, 0),
(4743,'URETHROPLASTY 2ND STAGE W/URINARY DIVERSION','URETHROPLASTY 2ND STAGE W/URINARY DIVERSION','53405','1','','1','0','','','',0, 1, 0, 0),
(4744,'URETHROPLASTY 1 STG RECNST MALE ANTERIOR URETHRA','URETHROPLASTY 1 STG RECNST MALE ANTERIOR URETHRA','53410','1','','1','0','','','',0, 1, 0, 0),
(4745,'URTP TRANSPUBIC/PRNL 1 STG RCNSTJ/RPR URT','URTP TRANSPUBIC/PRNL 1 STG RCNSTJ/RPR URT','53415','1','','1','0','','','',0, 1, 0, 0),
(4746,'URTP 2-STG RCNSTJ/RPR PROSTAT/URETHRA 1ST STAGE','URTP 2-STG RCNSTJ/RPR PROSTAT/URETHRA 1ST STAGE','53420','1','','1','0','','','',0, 1, 0, 0),
(4747,'URTP 2-STG RCNSTJ/RPR PROSTAT/URETHRA 2ND STAGE','URTP 2-STG RCNSTJ/RPR PROSTAT/URETHRA 2ND STAGE','53425','1','','1','0','','','',0, 1, 0, 0),
(4748,'URETHROPLASTY RCNSTJ FEMALE URETHRA','URETHROPLASTY RCNSTJ FEMALE URETHRA','53430','1','','1','0','','','',0, 1, 0, 0),
(4749,'URTP W/TUBULARIZATION POST URT&/LWR BLDR','URTP W/TUBULARIZATION POST URT&/LWR BLDR','53431','1','','1','0','','','',0, 1, 0, 0),
(4750,'SLING OPRATION CORRJ MALE URINARY INCONTINENCE','SLING OPRATION CORRJ MALE URINARY INCONTINENCE','53440','1','','1','0','','','',0, 1, 0, 0),
(4751,'RMVL/REVJ SLING MALE URINARY INCONTINENCE','RMVL/REVJ SLING MALE URINARY INCONTINENCE','53442','1','','1','0','','','',0, 1, 0, 0),
(4752,'INSERTION TANDEM CUFF','INSERTION TANDEM CUFF','53444','1','','1','0','','','',0, 1, 0, 0),
(4753,'INSJ INFLATABLE URETHRAL/BLADDER NECK SPHINCTER','INSJ INFLATABLE URETHRAL/BLADDER NECK SPHINCTER','53445','1','','1','0','','','',0, 1, 0, 0),
(4754,'REMVL INFLATABLE URETHRAL/BLADDER NECK SPHINCTER','REMVL INFLATABLE URETHRAL/BLADDER NECK SPHINCTER','53446','1','','1','0','','','',0, 1, 0, 0),
(4755,'RMVL & RPLCMT NFLTL URETHRAL/BLADDER NECK SPHINC','RMVL & RPLCMT NFLTL URETHRAL/BLADDER NECK SPHINC','53447','1','','1','0','','','',0, 1, 0, 0),
(4756,'RMVL & RPLCMT NFLTBL NCK SPHNCTR THRU INFCT FLD','RMVL & RPLCMT NFLTBL NCK SPHNCTR THRU INFCT FLD','53448','1','','1','0','','','',0, 1, 0, 0),
(4757,'RPR NFLTBL URETHRAL/BLADDER NECK SPHINCTER','RPR NFLTBL URETHRAL/BLADDER NECK SPHINCTER','53449','1','','1','0','','','',0, 1, 0, 0),
(4758,'URETHROMEATOPLASTY W/MUCOSAL ADVANCEMENT','URETHROMEATOPLASTY W/MUCOSAL ADVANCEMENT','53450','1','','1','0','','','',0, 1, 0, 0),
(4759,'URETHROMEATOPLASTY W/PRTL EXC DSTL URTL SGM','URETHROMEATOPLASTY W/PRTL EXC DSTL URTL SGM','53460','1','','1','0','','','',0, 1, 0, 0),
(4760,'URETHROLSS TRVG SEC OPN W/CSTO','URETHROLSS TRVG SEC OPN W/CSTO','53500','1','','1','0','','','',0, 1, 0, 0),
(4761,'URETHRORRHAPHY SUTR URETHRAL WOUND/INJ FEMALE','URETHRORRHAPHY SUTR URETHRAL WOUND/INJ FEMALE','53502','1','','1','0','','','',0, 1, 0, 0),
(4762,'URETHRORRHAPHY SUTR URETHRAL WOUND/INJ PENILE','URETHRORRHAPHY SUTR URETHRAL WOUND/INJ PENILE','53505','1','','1','0','','','',0, 1, 0, 0),
(4763,'URETHRORRHAPHY SUTR URETHRAL WOUND/INJ PERINEAL','URETHRORRHAPHY SUTR URETHRAL WOUND/INJ PERINEAL','53510','1','','1','0','','','',0, 1, 0, 0),
(4764,'URTORR SUTR URETHRAL WND/INJ PROSTATOMEMBRANOUS','URTORR SUTR URETHRAL WND/INJ PROSTATOMEMBRANOUS','53515','1','','1','0','','','',0, 1, 0, 0),
(4765,'CLSR URETHROSTOMY/URETHROQ FSTL MALE SPX','CLSR URETHROSTOMY/URETHROQ FSTL MALE SPX','53520','1','','1','0','','','',0, 1, 0, 0),
(4766,'DILAT URETHRAL STRIX DILATOR MALE 1ST','DILAT URETHRAL STRIX DILATOR MALE 1ST','53600','1','','1','0','','','',0, 1, 0, 0),
(4767,'DILAT URETHRAL STRIX DILATOR MALE SBSQ','DILAT URETHRAL STRIX DILATOR MALE SBSQ','53601','1','','1','0','','','',0, 1, 0, 0),
(4768,'DILAT URETHRAL STRIX/VESICAL NCK DILAT MALE ANES','DILAT URETHRAL STRIX/VESICAL NCK DILAT MALE ANES','53605','1','','1','0','','','',0, 1, 0, 0),
(4769,'DILAT URETHRAL STRIX FILIFORM & FOLLWR MALE 1ST','DILAT URETHRAL STRIX FILIFORM & FOLLWR MALE 1ST','53620','1','','1','0','','','',0, 1, 0, 0),
(4770,'DILAT URETHRAL STRIX FILIFORM & FOLLWR MALE SBSQ','DILAT URETHRAL STRIX FILIFORM & FOLLWR MALE SBSQ','53621','1','','1','0','','','',0, 1, 0, 0),
(4771,'DILAT FEMALE URETHRA W/SUPPOSITORY&/INSTLJ INI','DILAT FEMALE URETHRA W/SUPPOSITORY&/INSTLJ INI','53660','1','','1','0','','','',0, 1, 0, 0),
(4772,'DILAT FEMALE URT W/SUPPOSITORY&/INSTLJ SBSQ','DILAT FEMALE URT W/SUPPOSITORY&/INSTLJ SBSQ','53661','1','','1','0','','','',0, 1, 0, 0),
(4773,'DILAT FEMALE URETHRA GENERAL/CNDJ SPINAL ANES','DILAT FEMALE URETHRA GENERAL/CNDJ SPINAL ANES','53665','1','','1','0','','','',0, 1, 0, 0),
(4774,'TRURL DSTRJ PRSTATE TISS MICROWAVE THERMOTH','TRURL DSTRJ PRSTATE TISS MICROWAVE THERMOTH','53850','1','','1','0','','','',0, 1, 0, 0),
(4775,'TRURL DSTRJ PRSTATE TISS RF THERMOTH','TRURL DSTRJ PRSTATE TISS RF THERMOTH','53852','1','','1','0','','','',0, 1, 0, 0),
(4776,'INSERT TEMP PROSTATIC URETH STENT W/MEASUREMENT','INSERT TEMP PROSTATIC URETH STENT W/MEASUREMENT','53855','1','','1','0','','','',0, 1, 0, 0),
(4777,'TRURL RF FEMALE BLADDER NECK STRS URIN INCONT','TRURL RF FEMALE BLADDER NECK STRS URIN INCONT','53860','1','','1','0','','','',0, 1, 0, 0),
(4778,'UNLISTED PROCEDURE URINARY SYSTEM','UNLISTED PROCEDURE URINARY SYSTEM','53899','1','','1','0','','','',0, 1, 0, 0),
(4779,'SLITTING PREPUCE DORSAL/LATERAL SPX NEWBORN','SLITTING PREPUCE DORSAL/LATERAL SPX NEWBORN','54000','1','','1','0','','','',0, 1, 0, 0),
(4780,'SLITTING PREPUCE DORSAL/LAT SPX XCP NEWBORN','SLITTING PREPUCE DORSAL/LAT SPX XCP NEWBORN','54001','1','','1','0','','','',0, 1, 0, 0),
(4781,'I&D PENIS DEEP','I&D PENIS DEEP','54015','1','','1','0','','','',0, 1, 0, 0),
(4782,'DSTRJ LESION PENIS SIMPLE CHEMICAL','DSTRJ LESION PENIS SIMPLE CHEMICAL','54050','1','','1','0','','','',0, 1, 0, 0),
(4783,'DSTRJ LESION PENIS SIMPLE ELECTRODESICCATION','DSTRJ LESION PENIS SIMPLE ELECTRODESICCATION','54055','1','','1','0','','','',0, 1, 0, 0),
(4784,'DSTRJ LESION PENIS SIMPLE CRYOSURGERY','DSTRJ LESION PENIS SIMPLE CRYOSURGERY','54056','1','','1','0','','','',0, 1, 0, 0),
(4785,'DSTRJ LESION PENIS SIMPLE LASER','DSTRJ LESION PENIS SIMPLE LASER','54057','1','','1','0','','','',0, 1, 0, 0),
(4786,'DSTRJ LESION PENIS SIMPLE SURG EXCISION','DSTRJ LESION PENIS SIMPLE SURG EXCISION','54060','1','','1','0','','','',0, 1, 0, 0),
(4787,'DSTRJ LESION PENIS EXTENSIVE','DSTRJ LESION PENIS EXTENSIVE','54065','1','','1','0','','','',0, 1, 0, 0),
(4788,'BIOPSY PENIS SEPARATE PROCEDURE','BIOPSY PENIS SEPARATE PROCEDURE','54100','1','','1','0','','','',0, 1, 0, 0),
(4789,'BIOPSY PENIS DEEP STRUCTURES','BIOPSY PENIS DEEP STRUCTURES','54105','1','','1','0','','','',0, 1, 0, 0),
(4790,'EXCISION OF PENILE PLAQUE','EXCISION OF PENILE PLAQUE','54110','1','','1','0','','','',0, 1, 0, 0),
(4791,'EXC PENILE PLAQUE GRAFT &/5 CM LENGTH','EXC PENILE PLAQUE GRAFT &/5 CM LENGTH','54111','1','','1','0','','','',0, 1, 0, 0),
(4792,'EXC PENILE PLAQUE GRAFT > 5 CM LENGTH','EXC PENILE PLAQUE GRAFT > 5 CM LENGTH','54112','1','','1','0','','','',0, 1, 0, 0),
(4793,'REMOVAL FOREIGN BODY DEEP PENILE TISSUE','REMOVAL FOREIGN BODY DEEP PENILE TISSUE','54115','1','','1','0','','','',0, 1, 0, 0),
(4794,'AMPUTATION PENIS PARTIAL','AMPUTATION PENIS PARTIAL','54120','1','','1','0','','','',0, 1, 0, 0),
(4795,'AMPUTATION PENIS COMPLETE','AMPUTATION PENIS COMPLETE','54125','1','','1','0','','','',0, 1, 0, 0),
(4796,'AMPUTATION PENIS RADW/BI INGUINOFEMORAL LMPHADE','AMPUTATION PENIS RADW/BI INGUINOFEMORAL LMPHADE','54130','1','','1','0','','','',0, 1, 0, 0),
(4797,'AMPUTATION PENIS RADICAL W/LYMPH NODES','AMPUTATION PENIS RADICAL W/LYMPH NODES','54135','1','','1','0','','','',0, 1, 0, 0),
(4798,'CIRCUMCISION W/CLAMP/OTH DEV W/BLOCK','CIRCUMCISION W/CLAMP/OTH DEV W/BLOCK','54150','1','','1','0','','','',0, 1, 0, 0),
(4799,'CIRCUMCISION NEONATE','CIRCUMCISION NEONATE','54160','1','','1','0','','','',0, 1, 0, 0),
(4800,'CIRCUMCISION AGE >28 DAYS','CIRCUMCISION AGE >28 DAYS','54161','1','','1','0','','','',0, 1, 0, 0),
(4801,'LYSIS/EXCISION PENILE POSTCIRCUMCISION ADHESIONS','LYSIS/EXCISION PENILE POSTCIRCUMCISION ADHESIONS','54162','1','','1','0','','','',0, 1, 0, 0),
(4802,'REPAIR INCOMPLETE CIRCUMCISION','REPAIR INCOMPLETE CIRCUMCISION','54163','1','','1','0','','','',0, 1, 0, 0),
(4803,'FRENULOTOMY PENIS','FRENULOTOMY PENIS','54164','1','','1','0','','','',0, 1, 0, 0),
(4804,'INJECTION PEYRONIE DISEASE','INJECTION PEYRONIE DISEASE','54200','1','','1','0','','','',0, 1, 0, 0),
(4805,'NJX PEYRONIE W/SURG EXPOS PLAQUE','NJX PEYRONIE W/SURG EXPOS PLAQUE','54205','1','','1','0','','','',0, 1, 0, 0),
(4806,'IRRIGATION CORPORA CAVERNOSA PRIAPISM','IRRIGATION CORPORA CAVERNOSA PRIAPISM','54220','1','','1','0','','','',0, 1, 0, 0),
(4807,'INJECTION CORPORA CAVERNOSOGRAPY','INJECTION CORPORA CAVERNOSOGRAPY','54230','1','','1','0','','','',0, 1, 0, 0),
(4808,'DYNAMIC CAVERNOSOMETRY NJX VASOACTIVE DRUGS','DYNAMIC CAVERNOSOMETRY NJX VASOACTIVE DRUGS','54231','1','','1','0','','','',0, 1, 0, 0),
(4809,'NJX C/P/A CAVERNOSA W/PHARMACOLOGIC AGT','NJX C/P/A CAVERNOSA W/PHARMACOLOGIC AGT','54235','1','','1','0','','','',0, 1, 0, 0),
(4810,'PENILE PLETHYSMOGRAPHY','PENILE PLETHYSMOGRAPHY','54240','1','','1','0','','','',0, 1, 0, 0),
(4811,'NOCTURNAL PENILE TUMESCENCE &/RIGIDITY TEST','NOCTURNAL PENILE TUMESCENCE &/RIGIDITY TEST','54250','1','','1','0','','','',0, 1, 0, 0),
(4812,'PENIS STRAIGHTENING CHORDEE','PENIS STRAIGHTENING CHORDEE','54300','1','','1','0','','','',0, 1, 0, 0),
(4813,'PENIS CORRJ CHORDEE/1ST STAGE HYPOSPADIAS RPR','PENIS CORRJ CHORDEE/1ST STAGE HYPOSPADIAS RPR','54304','1','','1','0','','','',0, 1, 0, 0),
(4814,'URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR <3 CM','URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR <3 CM','54308','1','','1','0','','','',0, 1, 0, 0),
(4815,'URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR > 3 CM','URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR > 3 CM','54312','1','','1','0','','','',0, 1, 0, 0),
(4816,'URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR SKIN GRF','URETHROPLASTY 2ND STAGE HYPOSPADIAS RPR SKIN GRF','54316','1','','1','0','','','',0, 1, 0, 0),
(4817,'URETHROPLASTY 3RD STG HYPOSPADIAS RPR RLS PENIS','URETHROPLASTY 3RD STG HYPOSPADIAS RPR RLS PENIS','54318','1','','1','0','','','',0, 1, 0, 0),
(4818,'1 STG DSTL HYPOSPADIAS RPR W/SMPL MEATAL ADVMNT','1 STG DSTL HYPOSPADIAS RPR W/SMPL MEATAL ADVMNT','54322','1','','1','0','','','',0, 1, 0, 0),
(4819,'1 STG DSTL HYPOSPADIAS RPR W/URTP SKIN FLAPS','1 STG DSTL HYPOSPADIAS RPR W/URTP SKIN FLAPS','54324','1','','1','0','','','',0, 1, 0, 0),
(4820,'1 STG DSTL HYPOSPADIAS RPR URTP SKN FLAPS','1 STG DSTL HYPOSPADIAS RPR URTP SKN FLAPS','54326','1','','1','0','','','',0, 1, 0, 0),
(4821,'1 STAGE DSTL HYPOSPADIAS RPR W/EXTENSIVE DSJ','1 STAGE DSTL HYPOSPADIAS RPR W/EXTENSIVE DSJ','54328','1','','1','0','','','',0, 1, 0, 0),
(4822,'1 STAGE PROX PENILE/PENOSCROTAL HYPOSPADIAS RPR','1 STAGE PROX PENILE/PENOSCROTAL HYPOSPADIAS RPR','54332','1','','1','0','','','',0, 1, 0, 0),
(4823,'1 STG PERINEAL HYPOSPADIAS RPR W/GRF&/FLAP','1 STG PERINEAL HYPOSPADIAS RPR W/GRF&/FLAP','54336','1','','1','0','','','',0, 1, 0, 0),
(4824,'RPR HYPOSPADIAS COMPLCTJS CLSR INC/EXC SIMPLE','RPR HYPOSPADIAS COMPLCTJS CLSR INC/EXC SIMPLE','54340','1','','1','0','','','',0, 1, 0, 0),
(4825,'RPR HYPOSPADIAS COMPLCTJS MOBLJ FLAPS & URTP','RPR HYPOSPADIAS COMPLCTJS MOBLJ FLAPS & URTP','54344','1','','1','0','','','',0, 1, 0, 0),
(4826,'RPR HYPOSPADIAS COMPLCTJS DSJ & URTP FLAP/GRF','RPR HYPOSPADIAS COMPLCTJS DSJ & URTP FLAP/GRF','54348','1','','1','0','','','',0, 1, 0, 0),
(4827,'RPR HYPOSPADIAS CRIPPLE W/DSJ & EXC & GRFS/FLAP','RPR HYPOSPADIAS CRIPPLE W/DSJ & EXC & GRFS/FLAP','54352','1','','1','0','','','',0, 1, 0, 0),
(4828,'PLASTIC RPR PENIS CORRECT ANGULATION','PLASTIC RPR PENIS CORRECT ANGULATION','54360','1','','1','0','','','',0, 1, 0, 0),
(4829,'PLASTIC RPR PENIS EPISPADIAS DSTL SPHNCTR','PLASTIC RPR PENIS EPISPADIAS DSTL SPHNCTR','54380','1','','1','0','','','',0, 1, 0, 0),
(4830,'PLASTIC PENIS EPISPADIAS DSTL SPHNCTR W/INCONT','PLASTIC PENIS EPISPADIAS DSTL SPHNCTR W/INCONT','54385','1','','1','0','','','',0, 1, 0, 0),
(4831,'PLASTIC RPR PENIS EPISPADIAS W/EXSTROPHY BLADDER','PLASTIC RPR PENIS EPISPADIAS W/EXSTROPHY BLADDER','54390','1','','1','0','','','',0, 1, 0, 0),
(4832,'INSJ PENILE PROSTHESIS NON-INFLATABLE SEMI-RIGID','INSJ PENILE PROSTHESIS NON-INFLATABLE SEMI-RIGID','54400','1','','1','0','','','',0, 1, 0, 0),
(4833,'INSJ PENILE PROSTHESOS INFLATABLE SELF-CONTAINED','INSJ PENILE PROSTHESOS INFLATABLE SELF-CONTAINED','54401','1','','1','0','','','',0, 1, 0, 0),
(4834,'INSJ MULTI-COMPONENT INFLATABLE PENILE PROSTH','INSJ MULTI-COMPONENT INFLATABLE PENILE PROSTH','54405','1','','1','0','','','',0, 1, 0, 0),
(4835,'RMVL INFLATABLE PENILE PROSTH W/O RPLCMT PROSTH','RMVL INFLATABLE PENILE PROSTH W/O RPLCMT PROSTH','54406','1','','1','0','','','',0, 1, 0, 0),
(4836,'RPR COMPONENT INFLATABLE PENILE PROSTHESIS','RPR COMPONENT INFLATABLE PENILE PROSTHESIS','54408','1','','1','0','','','',0, 1, 0, 0),
(4837,'RMVL & RPLCMT INFLATABLE PENILE PROSTH SAME SESS','RMVL & RPLCMT INFLATABLE PENILE PROSTH SAME SESS','54410','1','','1','0','','','',0, 1, 0, 0),
(4838,'RMVL & RPLCMT NFLTBL PENILE PROSTH INFECTED FIEL','RMVL & RPLCMT NFLTBL PENILE PROSTH INFECTED FIEL','54411','1','','1','0','','','',0, 1, 0, 0),
(4839,'RMVL NON-NFLTBL/NFLTBL PENILE PROSTH W/O RPLCMT','RMVL NON-NFLTBL/NFLTBL PENILE PROSTH W/O RPLCMT','54415','1','','1','0','','','',0, 1, 0, 0),
(4840,'RMVL & RPLCMT NON-NFLTBL/NFLTBL PENILE PROSTHESI','RMVL & RPLCMT NON-NFLTBL/NFLTBL PENILE PROSTHESI','54416','1','','1','0','','','',0, 1, 0, 0),
(4841,'RMVL & RPLCMT PENILE PROSTHESIS INFECTED FIELD','RMVL & RPLCMT PENILE PROSTHESIS INFECTED FIELD','54417','1','','1','0','','','',0, 1, 0, 0),
(4842,'CORPORA CAVERNOSA-SAPHENOUS VEIN SHUNT UNI/BI','CORPORA CAVERNOSA-SAPHENOUS VEIN SHUNT UNI/BI','54420','1','','1','0','','','',0, 1, 0, 0),
(4843,'CORPORA CAVERNOSA-CORPUS SPONGIOSUM SHUNT UNI/BI','CORPORA CAVERNOSA-CORPUS SPONGIOSUM SHUNT UNI/BI','54430','1','','1','0','','','',0, 1, 0, 0),
(4844,'CORPORA CAVERNOSA-GLANS PENIS FSTLJ PRIAPISM','CORPORA CAVERNOSA-GLANS PENIS FSTLJ PRIAPISM','54435','1','','1','0','','','',0, 1, 0, 0),
(4845,'REPAIR OF TRAUMATIC CORPOREAL TEAR(S)','REPAIR OF TRAUMATIC CORPOREAL TEAR(S)','54437','1','','1','0','','','',0, 1, 0, 0),
(4846,'REPLANTATION PENIS COMP AMPUTATION W/URETH REP','REPLANTATION PENIS COMP AMPUTATION W/URETH REP','54438','1','','1','0','','','',0, 1, 0, 0),
(4847,'PLASTIC OPERATION PENIS INJURY','PLASTIC OPERATION PENIS INJURY','54440','1','','1','0','','','',0, 1, 0, 0),
(4848,'FORESKN MANJ W/LSS PREPUTIAL ADS&STRETCHING','FORESKN MANJ W/LSS PREPUTIAL ADS&STRETCHING','54450','1','','1','0','','','',0, 1, 0, 0),
(4849,'BIOPSY TESTIS NEEDLE SEPARATE PROCEDURE','BIOPSY TESTIS NEEDLE SEPARATE PROCEDURE','54500','1','','1','0','','','',0, 1, 0, 0),
(4850,'BIOPSY TESTIS INCISIONAL SEPARATE PROCEDURE','BIOPSY TESTIS INCISIONAL SEPARATE PROCEDURE','54505','1','','1','0','','','',0, 1, 0, 0),
(4851,'EXC XTRPARENCHYMAL LESION TESTIS','EXC XTRPARENCHYMAL LESION TESTIS','54512','1','','1','0','','','',0, 1, 0, 0),
(4852,'ORCHIECTOMY SIMPLE SCROTAL/INGUINAL APPROACH','ORCHIECTOMY SIMPLE SCROTAL/INGUINAL APPROACH','54520','1','','1','0','','','',0, 1, 0, 0),
(4853,'ORCHIECTOMY PARTIAL','ORCHIECTOMY PARTIAL','54522','1','','1','0','','','',0, 1, 0, 0),
(4854,'ORCHIECTOMY RADICAL TUMOR INGUINAL APPROACH','ORCHIECTOMY RADICAL TUMOR INGUINAL APPROACH','54530','1','','1','0','','','',0, 1, 0, 0),
(4855,'ORCHIECTOMY RADICAL TUMOR W/ABDOMINAL EXPL','ORCHIECTOMY RADICAL TUMOR W/ABDOMINAL EXPL','54535','1','','1','0','','','',0, 1, 0, 0),
(4856,'EXPL UNDESCENDED TSTIS INGUN/SCROTAL AREA','EXPL UNDESCENDED TSTIS INGUN/SCROTAL AREA','54550','1','','1','0','','','',0, 1, 0, 0),
(4857,'EXPL UNDESCENDED TESTIS W/ABDOMINAL EXPL','EXPL UNDESCENDED TESTIS W/ABDOMINAL EXPL','54560','1','','1','0','','','',0, 1, 0, 0),
(4858,'RDCTJ TORSION TSTIS W/WO FIXJ CLAT TESTIS','RDCTJ TORSION TSTIS W/WO FIXJ CLAT TESTIS','54600','1','','1','0','','','',0, 1, 0, 0),
(4859,'FIXATION CONTRALATERAL TESTIS SEPARATE PROCEDURE','FIXATION CONTRALATERAL TESTIS SEPARATE PROCEDURE','54620','1','','1','0','','','',0, 1, 0, 0),
(4860,'ORCHIOPEXY INGUINAL APPROACH W/WO HERNIA RPR','ORCHIOPEXY INGUINAL APPROACH W/WO HERNIA RPR','54640','1','','1','0','','','',0, 1, 0, 0),
(4861,'ORCHIOPEXY ABDL APPROACH INTRA-ABDOMINAL TESTIS','ORCHIOPEXY ABDL APPROACH INTRA-ABDOMINAL TESTIS','54650','1','','1','0','','','',0, 1, 0, 0),
(4862,'INSJ TESTICULAR PROSTH SEPARATE PROCEDURE','INSJ TESTICULAR PROSTH SEPARATE PROCEDURE','54660','1','','1','0','','','',0, 1, 0, 0),
(4863,'SUTURE/REPAIR TESTICULAR INJURY','SUTURE/REPAIR TESTICULAR INJURY','54670','1','','1','0','','','',0, 1, 0, 0),
(4864,'TRANSPLANTATION TESTIS TO THIGH','TRANSPLANTATION TESTIS TO THIGH','54680','1','','1','0','','','',0, 1, 0, 0),
(4865,'LAPAROSCOPY SURGICAL ORCHIECTOMY','LAPAROSCOPY SURGICAL ORCHIECTOMY','54690','1','','1','0','','','',0, 1, 0, 0),
(4866,'LAPAROSCOPY ORCHIOPEXY INTRA-ABDOMINAL TESTIS','LAPAROSCOPY ORCHIOPEXY INTRA-ABDOMINAL TESTIS','54692','1','','1','0','','','',0, 1, 0, 0),
(4867,'UNLISTED LAPAROSCOPY PROCEDURE TESTIS','UNLISTED LAPAROSCOPY PROCEDURE TESTIS','54699','1','','1','0','','','',0, 1, 0, 0),
(4868,'I&D EPIDIDYMIS TSTIS&/SCROTAL SPACE','I&D EPIDIDYMIS TSTIS&/SCROTAL SPACE','54700','1','','1','0','','','',0, 1, 0, 0),
(4869,'BIOPSY EPIDIDYMIS NEEDLE','BIOPSY EPIDIDYMIS NEEDLE','54800','1','','1','0','','','',0, 1, 0, 0),
(4870,'EXCISION LOCAL LESION EPIDIDYMIS','EXCISION LOCAL LESION EPIDIDYMIS','54830','1','','1','0','','','',0, 1, 0, 0),
(4871,'EXCISION SPERMATOCELE W/WO EPIDIDYMECTOMY','EXCISION SPERMATOCELE W/WO EPIDIDYMECTOMY','54840','1','','1','0','','','',0, 1, 0, 0),
(4872,'EPIDIDYMECTOMY UNILATERAL','EPIDIDYMECTOMY UNILATERAL','54860','1','','1','0','','','',0, 1, 0, 0),
(4873,'EPIDIDYMECTOMY BILATERAL','EPIDIDYMECTOMY BILATERAL','54861','1','','1','0','','','',0, 1, 0, 0),
(4874,'EXPLORATION EPIDIDYMIS W/WO BIOPSY','EXPLORATION EPIDIDYMIS W/WO BIOPSY','54865','1','','1','0','','','',0, 1, 0, 0),
(4875,'EPIDIDYMOVASOSTOMY ANAST EPIDIDYMIS UNI','EPIDIDYMOVASOSTOMY ANAST EPIDIDYMIS UNI','54900','1','','1','0','','','',0, 1, 0, 0),
(4876,'EPIDIDYMOVASOSTOMY ANAST EPIDIDYMIS BI','EPIDIDYMOVASOSTOMY ANAST EPIDIDYMIS BI','54901','1','','1','0','','','',0, 1, 0, 0),
(4877,'PNXR ASPIR HYDROCELE TUNICA VAGIS W/WO NJX MED','PNXR ASPIR HYDROCELE TUNICA VAGIS W/WO NJX MED','55000','1','','1','0','','','',0, 1, 0, 0),
(4878,'EXCISION HYDROCELE UNILATERAL','EXCISION HYDROCELE UNILATERAL','55040','1','','1','0','','','',0, 1, 0, 0),
(4879,'EXCISION HYDROCELE BILATERAL','EXCISION HYDROCELE BILATERAL','55041','1','','1','0','','','',0, 1, 0, 0),
(4880,'RPR TUNICA VAGINALIS HYDROCELE BOTTLE TYPE','RPR TUNICA VAGINALIS HYDROCELE BOTTLE TYPE','55060','1','','1','0','','','',0, 1, 0, 0),
(4881,'DRAINAGE SCROTAL WALL ABSCESS','DRAINAGE SCROTAL WALL ABSCESS','55100','1','','1','0','','','',0, 1, 0, 0),
(4882,'SCROTAL EXPLORATION','SCROTAL EXPLORATION','55110','1','','1','0','','','',0, 1, 0, 0),
(4883,'REMOVAL FOREIGN BODY SCROTUM','REMOVAL FOREIGN BODY SCROTUM','55120','1','','1','0','','','',0, 1, 0, 0),
(4884,'RESECTION SCROTUM','RESECTION SCROTUM','55150','1','','1','0','','','',0, 1, 0, 0),
(4885,'SCROTOPLASTY SIMPLE','SCROTOPLASTY SIMPLE','55175','1','','1','0','','','',0, 1, 0, 0),
(4886,'SCROTOPLASTY COMPLICATED','SCROTOPLASTY COMPLICATED','55180','1','','1','0','','','',0, 1, 0, 0),
(4887,'VASOTOMY CANNULIZATION W/WO VAS INC UNI/BI SPX','VASOTOMY CANNULIZATION W/WO VAS INC UNI/BI SPX','55200','1','','1','0','','','',0, 1, 0, 0),
(4888,'VASECTOMY UNI/BI SPX W/POSTOP SEMEN EXAMS','VASECTOMY UNI/BI SPX W/POSTOP SEMEN EXAMS','55250','1','','1','0','','','',0, 1, 0, 0),
(4889,'VASOTOMY VASOGRAMS UNI/BI','VASOTOMY VASOGRAMS UNI/BI','55300','1','','1','0','','','',0, 1, 0, 0),
(4890,'VASOVASOSTOMY VASOVASORRHAPHY','VASOVASOSTOMY VASOVASORRHAPHY','55400','1','','1','0','','','',0, 1, 0, 0),
(4891,'LIGATION PRQ VAS DEFERENS UNI/BI SPX','LIGATION PRQ VAS DEFERENS UNI/BI SPX','55450','1','','1','0','','','',0, 1, 0, 0),
(4892,'EXC HYDROCELE SPRMATIC CORD UNI SPX','EXC HYDROCELE SPRMATIC CORD UNI SPX','55500','1','','1','0','','','',0, 1, 0, 0),
(4893,'EXC LESION SPERMATIC CORD SEPARATE PROCEDURE','EXC LESION SPERMATIC CORD SEPARATE PROCEDURE','55520','1','','1','0','','','',0, 1, 0, 0),
(4894,'EXC VARICOCELE/LIGATION SPERMATIC VEINS SPX','EXC VARICOCELE/LIGATION SPERMATIC VEINS SPX','55530','1','','1','0','','','',0, 1, 0, 0),
(4895,'EXC VARICOCELE/LIGATION SPERMATIC VEINS ABDL','EXC VARICOCELE/LIGATION SPERMATIC VEINS ABDL','55535','1','','1','0','','','',0, 1, 0, 0),
(4896,'EXC VARICOCELE/LIGATION VEINS W/HERNIA RPR','EXC VARICOCELE/LIGATION VEINS W/HERNIA RPR','55540','1','','1','0','','','',0, 1, 0, 0),
(4897,'LAPS LIGATION SPERMATIC VEINS VARICOCELE','LAPS LIGATION SPERMATIC VEINS VARICOCELE','55550','1','','1','0','','','',0, 1, 0, 0),
(4898,'UNLISTED LAPROSCOPY PROCEDURE SPERMATIC CORD','UNLISTED LAPROSCOPY PROCEDURE SPERMATIC CORD','55559','1','','1','0','','','',0, 1, 0, 0),
(4899,'VESICULOTOMY','VESICULOTOMY','55600','1','','1','0','','','',0, 1, 0, 0),
(4900,'VESICULOTOMY COMPLICATED','VESICULOTOMY COMPLICATED','55605','1','','1','0','','','',0, 1, 0, 0),
(4901,'VESICULECTOMY ANY APPROACH','VESICULECTOMY ANY APPROACH','55650','1','','1','0','','','',0, 1, 0, 0),
(4902,'EXCISION MULLERIAN DUCT CYST','EXCISION MULLERIAN DUCT CYST','55680','1','','1','0','','','',0, 1, 0, 0),
(4903,'PROSTATE NEEDLE BIOPSY ANY APPROACH','PROSTATE NEEDLE BIOPSY ANY APPROACH','55700','1','','1','0','','','',0, 1, 0, 0),
(4904,'BIOPSY PROSTATE INCISIONAL ANY APPROACH','BIOPSY PROSTATE INCISIONAL ANY APPROACH','55705','1','','1','0','','','',0, 1, 0, 0),
(4905,'BX PROSTATE STRTCTC SATURATION SAMPLING IMG GID','BX PROSTATE STRTCTC SATURATION SAMPLING IMG GID','55706','1','','1','0','','','',0, 1, 0, 0),
(4906,'PROSTATOTOMY EXTERNAL DRG ABSCESS SIMPLE','PROSTATOTOMY EXTERNAL DRG ABSCESS SIMPLE','55720','1','','1','0','','','',0, 1, 0, 0),
(4907,'PROSTATOTOMY EXTERNAL DRG ABSCESS COMPLICATED','PROSTATOTOMY EXTERNAL DRG ABSCESS COMPLICATED','55725','1','','1','0','','','',0, 1, 0, 0),
(4908,'PROSTATECTOMY PERINEAL SUBTOTAL','PROSTATECTOMY PERINEAL SUBTOTAL','55801','1','','1','0','','','',0, 1, 0, 0),
(4909,'PROSTATECTOMY PERINEAL RADICAL','PROSTATECTOMY PERINEAL RADICAL','55810','1','','1','0','','','',0, 1, 0, 0),
(4910,'PROSTATECTOMY PERINEAL RADICAL W/LYMPH NODE BX','PROSTATECTOMY PERINEAL RADICAL W/LYMPH NODE BX','55812','1','','1','0','','','',0, 1, 0, 0),
(4911,'PROSTATECTOMY PERINEAL RAD W/BI PELVIC LYMPH EXC','PROSTATECTOMY PERINEAL RAD W/BI PELVIC LYMPH EXC','55815','1','','1','0','','','',0, 1, 0, 0),
(4912,'PROSTATECTOMY SUPRAPUBIC SUBTOTAL 1/2 STAGES','PROSTATECTOMY SUPRAPUBIC SUBTOTAL 1/2 STAGES','55821','1','','1','0','','','',0, 1, 0, 0),
(4913,'PROSTATECTOMY RETROPUBIC SUBTOTAL','PROSTATECTOMY RETROPUBIC SUBTOTAL','55831','1','','1','0','','','',0, 1, 0, 0),
(4914,'PROSTATECTOMY RETROPUBIC W/WO NERVE SPARING','PROSTATECTOMY RETROPUBIC W/WO NERVE SPARING','55840','1','','1','0','','','',0, 1, 0, 0),
(4915,'PROSTECT RETROPUBIC RAD W/WO NRV SPAR W/LYMPH BX','PROSTECT RETROPUBIC RAD W/WO NRV SPAR W/LYMPH BX','55842','1','','1','0','','','',0, 1, 0, 0),
(4916,'PROSTECT RETROPUB RAD W/WO NRV SPAR & BI PLV LYM','PROSTECT RETROPUB RAD W/WO NRV SPAR & BI PLV LYM','55845','1','','1','0','','','',0, 1, 0, 0),
(4917,'EXPOS PROSTATE ANY APPROACH INSJ RADIOACT SUBST','EXPOS PROSTATE ANY APPROACH INSJ RADIOACT SUBST','55860','1','','1','0','','','',0, 1, 0, 0),
(4918,'EXPOS PROSTATE INSJ RADIOACT SBST W/LYMPH BX','EXPOS PROSTATE INSJ RADIOACT SBST W/LYMPH BX','55862','1','','1','0','','','',0, 1, 0, 0),
(4919,'EXPOS PROSTATE INSJ RADIOAC SBST W/BI PELV LYMPH','EXPOS PROSTATE INSJ RADIOAC SBST W/BI PELV LYMPH','55865','1','','1','0','','','',0, 1, 0, 0),
(4920,'LAPS PROSTECT RETROPUBIC RAD W/NRV SPARING ROBOT','LAPS PROSTECT RETROPUBIC RAD W/NRV SPARING ROBOT','55866','1','','1','0','','','',0, 1, 0, 0),
(4921,'ELECTROEJACULATION','ELECTROEJACULATION','55870','1','','1','0','','','',0, 1, 0, 0),
(4922,'CRYOSURGICAL ABLATION PROSTATE W/US & MONITORI','CRYOSURGICAL ABLATION PROSTATE W/US & MONITORI','55873','1','','1','0','','','',0, 1, 0, 0),
(4923,'TRANSPERINEAL PLMT NDL/CATHS PROSTATE RADJ INSJ','TRANSPERINEAL PLMT NDL/CATHS PROSTATE RADJ INSJ','55875','1','','1','0','','','',0, 1, 0, 0),
(4924,'PLMT INTERSTITIAL DEV RADIAT TX PROSTATE 1/MULT','PLMT INTERSTITIAL DEV RADIAT TX PROSTATE 1/MULT','55876','1','','1','0','','','',0, 1, 0, 0),
(4925,'UNLISTED PROCEDURE MALE GENITAL SYSTEM','UNLISTED PROCEDURE MALE GENITAL SYSTEM','55899','1','','1','0','','','',0, 1, 0, 0),
(4926,'PLACEMENT NEEDLE PELVIC ORGAN RADIOELEMENT APPL','PLACEMENT NEEDLE PELVIC ORGAN RADIOELEMENT APPL','55920','1','','1','0','','','',0, 1, 0, 0),
(4927,'INTERSEX SURG MALE FEMALE','INTERSEX SURG MALE FEMALE','55970','1','','1','0','','','',0, 1, 0, 0),
(4928,'INTERSEX SURG FEMALE MALE','INTERSEX SURG FEMALE MALE','55980','1','','1','0','','','',0, 1, 0, 0),
(4929,'I&D VULVA/PERINEAL ABSCESS','I&D VULVA/PERINEAL ABSCESS','56405','1','','1','0','','','',0, 1, 0, 0),
(4930,'I&D OF BARTHOLINS GLAND ABSCESS','I&D OF BARTHOLINS GLAND ABSCESS','56420','1','','1','0','','','',0, 1, 0, 0),
(4931,'MARSUPIALIZATION BARTHOLINS GLAND CYST','MARSUPIALIZATION BARTHOLINS GLAND CYST','56440','1','','1','0','','','',0, 1, 0, 0),
(4932,'LYSIS LABIAL ADHESIONS','LYSIS LABIAL ADHESIONS','56441','1','','1','0','','','',0, 1, 0, 0),
(4933,'HYMENOTOMY SIMPLE INCISION','HYMENOTOMY SIMPLE INCISION','56442','1','','1','0','','','',0, 1, 0, 0),
(4934,'DESTRUCTION LESIONS VULVA SIMPLE','DESTRUCTION LESIONS VULVA SIMPLE','56501','1','','1','0','','','',0, 1, 0, 0),
(4935,'DESTRUCTION LESIONS VULVA EXTENSIVE','DESTRUCTION LESIONS VULVA EXTENSIVE','56515','1','','1','0','','','',0, 1, 0, 0),
(4936,'BIOPSY VULVA/PERINEUM 1 LESION SPX','BIOPSY VULVA/PERINEUM 1 LESION SPX','56605','1','','1','0','','','',0, 1, 0, 0),
(4937,'BIOPSY VULVA/PERINEUM EACH ADDL LESION','BIOPSY VULVA/PERINEUM EACH ADDL LESION','56606','1','','1','0','','','',0, 1, 0, 0),
(4938,'VULVECTOMY SIMPLE PARTIAL','VULVECTOMY SIMPLE PARTIAL','56620','1','','1','0','','','',0, 1, 0, 0),
(4939,'VULVECTOMY SIMPLE COMPLETE','VULVECTOMY SIMPLE COMPLETE','56625','1','','1','0','','','',0, 1, 0, 0),
(4940,'VULVECTOMY RADICAL PARTIAL','VULVECTOMY RADICAL PARTIAL','56630','1','','1','0','','','',0, 1, 0, 0),
(4941,'VULVECTOMY RAD PRTL UNI INGUINOFEM LMPHADECTOMY','VULVECTOMY RAD PRTL UNI INGUINOFEM LMPHADECTOMY','56631','1','','1','0','','','',0, 1, 0, 0),
(4942,'VULVECTOMY RAD PRTL BI INGUINOFEM LMPHADECTOMY','VULVECTOMY RAD PRTL BI INGUINOFEM LMPHADECTOMY','56632','1','','1','0','','','',0, 1, 0, 0),
(4943,'VULVECTOMY RADICAL COMPLETE','VULVECTOMY RADICAL COMPLETE','56633','1','','1','0','','','',0, 1, 0, 0),
(4944,'VULVECTOMY RAD COMPL UNI INGUINOFEM LMPHADECTOMY','VULVECTOMY RAD COMPL UNI INGUINOFEM LMPHADECTOMY','56634','1','','1','0','','','',0, 1, 0, 0),
(4945,'VULVECTOMY RAD COMPL BI INGUINOFEM LMPHADECTOMY','VULVECTOMY RAD COMPL BI INGUINOFEM LMPHADECTOMY','56637','1','','1','0','','','',0, 1, 0, 0),
(4946,'VULVECTOMY RAD COMPL ILIAC & PELVIC LMPHADECTOMY','VULVECTOMY RAD COMPL ILIAC & PELVIC LMPHADECTOMY','56640','1','','1','0','','','',0, 1, 0, 0),
(4947,'PRTL HYMENECTOMY/REVJ HYMENAL RING','PRTL HYMENECTOMY/REVJ HYMENAL RING','56700','1','','1','0','','','',0, 1, 0, 0),
(4948,'EXC BARTHOLINS GLAND/CYST','EXC BARTHOLINS GLAND/CYST','56740','1','','1','0','','','',0, 1, 0, 0),
(4949,'PLASTIC REPAIR INTROITUS','PLASTIC REPAIR INTROITUS','56800','1','','1','0','','','',0, 1, 0, 0),
(4950,'CLITOROPLASTY INTERSEX STATE','CLITOROPLASTY INTERSEX STATE','56805','1','','1','0','','','',0, 1, 0, 0),
(4951,'PERINEOPLASTY RPR PERINEUM NONOBSTETRICAL SPX','PERINEOPLASTY RPR PERINEUM NONOBSTETRICAL SPX','56810','1','','1','0','','','',0, 1, 0, 0),
(4952,'COLPOSCOPY VULVA','COLPOSCOPY VULVA','56820','1','','1','0','','','',0, 1, 0, 0),
(4953,'COLPOSCOPY VULVA W/BIOPSY','COLPOSCOPY VULVA W/BIOPSY','56821','1','','1','0','','','',0, 1, 0, 0),
(4954,'COLPOTOMY W/EXPLORATION','COLPOTOMY W/EXPLORATION','57000','1','','1','0','','','',0, 1, 0, 0),
(4955,'COLPOTOMY W/DRAINAGE PELVIC ABSCESS','COLPOTOMY W/DRAINAGE PELVIC ABSCESS','57010','1','','1','0','','','',0, 1, 0, 0),
(4956,'COLPOCENTESIS SEPARATE PROCEDURE','COLPOCENTESIS SEPARATE PROCEDURE','57020','1','','1','0','','','',0, 1, 0, 0),
(4957,'I&D VAGINAL HEMATOMA OBSTETRICAL/POSTPARTUM','I&D VAGINAL HEMATOMA OBSTETRICAL/POSTPARTUM','57022','1','','1','0','','','',0, 1, 0, 0),
(4958,'I&D VAGINAL HEMATOMA NON-OBSTETRICAL','I&D VAGINAL HEMATOMA NON-OBSTETRICAL','57023','1','','1','0','','','',0, 1, 0, 0),
(4959,'DESTRUCTION VAGINAL LESIONS SIMPLE','DESTRUCTION VAGINAL LESIONS SIMPLE','57061','1','','1','0','','','',0, 1, 0, 0),
(4960,'DESTRUCTION VAGINAL LESIONS EXTENSIVE','DESTRUCTION VAGINAL LESIONS EXTENSIVE','57065','1','','1','0','','','',0, 1, 0, 0),
(4961,'BIOPSY VAGINAL MUCOSA SIMPLE','BIOPSY VAGINAL MUCOSA SIMPLE','57100','1','','1','0','','','',0, 1, 0, 0),
(4962,'BIOPSY VAGINAL MUCOSA EXTENSIVE','BIOPSY VAGINAL MUCOSA EXTENSIVE','57105','1','','1','0','','','',0, 1, 0, 0),
(4963,'VAGINECTOMY PARTIAL REMOVAL VAGINAL WALL','VAGINECTOMY PARTIAL REMOVAL VAGINAL WALL','57106','1','','1','0','','','',0, 1, 0, 0),
(4964,'VAGINECTOMY PRTL RMVL VAG WALL & PARAVAGINAL T','VAGINECTOMY PRTL RMVL VAG WALL & PARAVAGINAL T','57107','1','','1','0','','','',0, 1, 0, 0),
(4965,'VAGNC PRTL RMVL VAG WALL W/BI TOT PEL LMPHADEC','VAGNC PRTL RMVL VAG WALL W/BI TOT PEL LMPHADEC','57109','1','','1','0','','','',0, 1, 0, 0),
(4966,'VAGINECTOMY COMPLETE REMOVAL VAGINAL WALL','VAGINECTOMY COMPLETE REMOVAL VAGINAL WALL','57110','1','','1','0','','','',0, 1, 0, 0),
(4967,'VAGINECTOMY COMPL RMVL VAG WALL & PARAVAG TISS','VAGINECTOMY COMPL RMVL VAG WALL & PARAVAG TISS','57111','1','','1','0','','','',0, 1, 0, 0),
(4968,'VAGNC COMPL RMVL VAG WALL TOT PEL LMPHADEC BX','VAGNC COMPL RMVL VAG WALL TOT PEL LMPHADEC BX','57112','1','','1','0','','','',0, 1, 0, 0),
(4969,'COLPOCLEISIS LE FORT TYPE','COLPOCLEISIS LE FORT TYPE','57120','1','','1','0','','','',0, 1, 0, 0),
(4970,'EXCISION VAGINAL SEPTUM','EXCISION VAGINAL SEPTUM','57130','1','','1','0','','','',0, 1, 0, 0),
(4971,'EXCISION VAGINAL CYST/TUMOR','EXCISION VAGINAL CYST/TUMOR','57135','1','','1','0','','','',0, 1, 0, 0),
(4972,'IRRIGATION VAGINA&/APPL MEDICAMENT TX DISEASE','IRRIGATION VAGINA&/APPL MEDICAMENT TX DISEASE','57150','1','','1','0','','','',0, 1, 0, 0),
(4973,'INSERTION UTERINE TANDEM&/VAGINAL OVOIDS','INSERTION UTERINE TANDEM&/VAGINAL OVOIDS','57155','1','','1','0','','','',0, 1, 0, 0),
(4974,'INSERTION VAGINAL RADIATION DEVICE','INSERTION VAGINAL RADIATION DEVICE','57156','1','','1','0','','','',0, 1, 0, 0),
(4975,'FIT&INSJ PESSARY/OTH INTRAVAGINAL SUPPORT DEVI','FIT&INSJ PESSARY/OTH INTRAVAGINAL SUPPORT DEVI','57160','1','','1','0','','','',0, 1, 0, 0),
(4976,'DIAPHRAGM/CERVICAL CAP FITTING W/INSTRUCTIONS','DIAPHRAGM/CERVICAL CAP FITTING W/INSTRUCTIONS','57170','1','','1','0','','','',0, 1, 0, 0),
(4977,'INTRO ANY HEMOSTATIC AGENT/PACK VAG HEMRRG SPX','INTRO ANY HEMOSTATIC AGENT/PACK VAG HEMRRG SPX','57180','1','','1','0','','','',0, 1, 0, 0),
(4978,'COLPORRHAPHY SUTURE INJURY VAGINA','COLPORRHAPHY SUTURE INJURY VAGINA','57200','1','','1','0','','','',0, 1, 0, 0),
(4979,'COLPOPERINEORRHAPHY SUTURE INJ VAGINA&/PERINEU','COLPOPERINEORRHAPHY SUTURE INJ VAGINA&/PERINEU','57210','1','','1','0','','','',0, 1, 0, 0),
(4980,'PLASTIC URETHRAL SPHINCTER VAGINAL APPROACH','PLASTIC URETHRAL SPHINCTER VAGINAL APPROACH','57220','1','','1','0','','','',0, 1, 0, 0),
(4981,'PLASTIC REPAIR URETHROCELE','PLASTIC REPAIR URETHROCELE','57230','1','','1','0','','','',0, 1, 0, 0),
(4982,'ANT COLPORRHAPHY CYSTOCELE W/WO RPR URETHROCELE','ANT COLPORRHAPHY CYSTOCELE W/WO RPR URETHROCELE','57240','1','','1','0','','','',0, 1, 0, 0),
(4983,'POST COLPORRHAPHY RECTOCELE W/WO PERINEORRHAPHY','POST COLPORRHAPHY RECTOCELE W/WO PERINEORRHAPHY','57250','1','','1','0','','','',0, 1, 0, 0),
(4984,'COMBINED ANTEROPOSTERIOR COLPORRHAPHY','COMBINED ANTEROPOSTERIOR COLPORRHAPHY','57260','1','','1','0','','','',0, 1, 0, 0),
(4985,'CMBND ANTEROPOST COLPORRHAPHY W/ENTEROCELE RPR','CMBND ANTEROPOST COLPORRHAPHY W/ENTEROCELE RPR','57265','1','','1','0','','','',0, 1, 0, 0),
(4986,'INSJ MESH/PROSTH PELVIC FLOOR DEFECT EACH SITE','INSJ MESH/PROSTH PELVIC FLOOR DEFECT EACH SITE','57267','1','','1','0','','','',0, 1, 0, 0),
(4987,'REPAIR ENTEROCELE VAGINAL APPROACH SPX','REPAIR ENTEROCELE VAGINAL APPROACH SPX','57268','1','','1','0','','','',0, 1, 0, 0),
(4988,'REPAIR ENTEROCELE ABDOMINAL APPROACH SPX','REPAIR ENTEROCELE ABDOMINAL APPROACH SPX','57270','1','','1','0','','','',0, 1, 0, 0),
(4989,'COLPOPEXY ABDOMINAL APPROACH','COLPOPEXY ABDOMINAL APPROACH','57280','1','','1','0','','','',0, 1, 0, 0),
(4990,'COLPOPEXY VAGINAL EXTRAPERITONEAL APPROACH','COLPOPEXY VAGINAL EXTRAPERITONEAL APPROACH','57282','1','','1','0','','','',0, 1, 0, 0),
(4991,'COLPOPEXY VAGINAL INTRAPERITONEAL APPROACH','COLPOPEXY VAGINAL INTRAPERITONEAL APPROACH','57283','1','','1','0','','','',0, 1, 0, 0),
(4992,'PARAVAGINAL DEFECT REPAIR OPEN ABDOMINAL APPR','PARAVAGINAL DEFECT REPAIR OPEN ABDOMINAL APPR','57284','1','','1','0','','','',0, 1, 0, 0),
(4993,'PARAVAGINAL DEFECT REPAIR VAGINAL APPROACH','PARAVAGINAL DEFECT REPAIR VAGINAL APPROACH','57285','1','','1','0','','','',0, 1, 0, 0),
(4994,'RMVL/REVJ SLING STRESS INCONTINENCE','RMVL/REVJ SLING STRESS INCONTINENCE','57287','1','','1','0','','','',0, 1, 0, 0),
(4995,'SLING OPERATION STRESS INCONTINENCE','SLING OPERATION STRESS INCONTINENCE','57288','1','','1','0','','','',0, 1, 0, 0),
(4996,'PEREYRA PX W/ANTERIOR COLPORRHAPHY','PEREYRA PX W/ANTERIOR COLPORRHAPHY','57289','1','','1','0','','','',0, 1, 0, 0),
(4997,'CONSTRUCTION ARTIFICIAL VAGINA W/O GRAFT','CONSTRUCTION ARTIFICIAL VAGINA W/O GRAFT','57291','1','','1','0','','','',0, 1, 0, 0),
(4998,'CONSTRUCTION ARTIFICIAL VAGINA W/GRAFT','CONSTRUCTION ARTIFICIAL VAGINA W/GRAFT','57292','1','','1','0','','','',0, 1, 0, 0),
(4999,'REVJ/RMVL PROSTHETIC VAGINAL GRAFT VAGINAL APP','REVJ/RMVL PROSTHETIC VAGINAL GRAFT VAGINAL APP','57295','1','','1','0','','','',0, 1, 0, 0);

INSERT INTO `codes` (`id`, `code_text`, `code_text_short`, `code`, `code_type`, `modifier`, `units`, `fee`, `superbill`, `related_code`, `taxrates`, `cyp_factor`, `active`, `reportable`, `financial_reporting`) VALUES

(5000,'REVJ W/RMVL PROSTHETIC VAGINAL GRAFT ABDML APPR','REVJ W/RMVL PROSTHETIC VAGINAL GRAFT ABDML APPR','57296','1','','1','0','','','',0, 1, 0, 0),
(5001,'CLSR RECTOVAGINAL FISTULA VAGINAL/TRANSANAL APPR','CLSR RECTOVAGINAL FISTULA VAGINAL/TRANSANAL APPR','57300','1','','1','0','','','',0, 1, 0, 0),
(5002,'CLSR RECTOVAGINAL FISTULA ABDOMINAL APPROACH','CLSR RECTOVAGINAL FISTULA ABDOMINAL APPROACH','57305','1','','1','0','','','',0, 1, 0, 0),
(5003,'CLSR RECTOVAG FSTL ABDL APPR W/CONCOMITANT CLST','CLSR RECTOVAG FSTL ABDL APPR W/CONCOMITANT CLST','57307','1','','1','0','','','',0, 1, 0, 0),
(5004,'CLSR RECTOVAG FSTL TPRNL PRNL BDY RCNSTJ','CLSR RECTOVAG FSTL TPRNL PRNL BDY RCNSTJ','57308','1','','1','0','','','',0, 1, 0, 0),
(5005,'CLOSURE URETHROVAGINAL FISTULA','CLOSURE URETHROVAGINAL FISTULA','57310','1','','1','0','','','',0, 1, 0, 0),
(5006,'CLSR URETHROVAG FSTL W/BULBOCAVERNOSUS TRNSPL','CLSR URETHROVAG FSTL W/BULBOCAVERNOSUS TRNSPL','57311','1','','1','0','','','',0, 1, 0, 0),
(5007,'CLOSURE VESICOVAGINAL FISTULA VAGINAL APPROACH','CLOSURE VESICOVAGINAL FISTULA VAGINAL APPROACH','57320','1','','1','0','','','',0, 1, 0, 0),
(5008,'CLSR VESICOVAG FSTL TRANSVESICAL&VAG APPR','CLSR VESICOVAG FSTL TRANSVESICAL&VAG APPR','57330','1','','1','0','','','',0, 1, 0, 0),
(5009,'VAGINOPLASTY INTERSEX STATE','VAGINOPLASTY INTERSEX STATE','57335','1','','1','0','','','',0, 1, 0, 0),
(5010,'DILATION VAGINA W/ANESTHESIA OTHER THAN LOCAL','DILATION VAGINA W/ANESTHESIA OTHER THAN LOCAL','57400','1','','1','0','','','',0, 1, 0, 0),
(5011,'PELVIC EXAMINATION W/ANESTHESIA OTHER THAN LOCAL','PELVIC EXAMINATION W/ANESTHESIA OTHER THAN LOCAL','57410','1','','1','0','','','',0, 1, 0, 0),
(5012,'REMOVAL IMPACTED VAG FB SPX W/ANES OTH/THN LOCAL','REMOVAL IMPACTED VAG FB SPX W/ANES OTH/THN LOCAL','57415','1','','1','0','','','',0, 1, 0, 0),
(5013,'COLPOSCOPY ENTIRE VAGINA W/CERVIX IF PRESENT','COLPOSCOPY ENTIRE VAGINA W/CERVIX IF PRESENT','57420','1','','1','0','','','',0, 1, 0, 0),
(5014,'COLPOSCOPY ENTIRE VAGINA W/VAGINA/CERVIX BX','COLPOSCOPY ENTIRE VAGINA W/VAGINA/CERVIX BX','57421','1','','1','0','','','',0, 1, 0, 0),
(5015,'PARAVAGINAL DEFECT REPAIR LAPAROSCOPIC APPROACH','PARAVAGINAL DEFECT REPAIR LAPAROSCOPIC APPROACH','57423','1','','1','0','','','',0, 1, 0, 0),
(5016,'LAPAROSCOPY COLPOPEXY SUSPENSION VAGINAL APEX','LAPAROSCOPY COLPOPEXY SUSPENSION VAGINAL APEX','57425','1','','1','0','','','',0, 1, 0, 0),
(5017,'REVISION PROSTHETIC VAGINAL GRAFT LAPAROSCOPIC','REVISION PROSTHETIC VAGINAL GRAFT LAPAROSCOPIC','57426','1','','1','0','','','',0, 1, 0, 0),
(5018,'COLPOSCOPY CERVIX UPPER/ADJACENT VAGINA','COLPOSCOPY CERVIX UPPER/ADJACENT VAGINA','57452','1','','1','0','','','',0, 1, 0, 0),
(5019,'COLPOSCOPY CERVIX BX CERVIX & ENDOCRV CURRETAGE','COLPOSCOPY CERVIX BX CERVIX & ENDOCRV CURRETAGE','57454','1','','1','0','','','',0, 1, 0, 0),
(5020,'COLPOSCOPY CERVIX UPPR/ADJCNT VAGINA W/CERVIX BX','COLPOSCOPY CERVIX UPPR/ADJCNT VAGINA W/CERVIX BX','57455','1','','1','0','','','',0, 1, 0, 0),
(5021,'COLPOSCOPY CERVIX ENDOCERVICAL CURETTAGE','COLPOSCOPY CERVIX ENDOCERVICAL CURETTAGE','57456','1','','1','0','','','',0, 1, 0, 0),
(5022,'COLPOSCOPY CERVIX VAG LOOP ELTRD BX CERVIX','COLPOSCOPY CERVIX VAG LOOP ELTRD BX CERVIX','57460','1','','1','0','','','',0, 1, 0, 0),
(5023,'COLPOSCOPY CERVIX VAG ELTRD CONIZATION CERVIX','COLPOSCOPY CERVIX VAG ELTRD CONIZATION CERVIX','57461','1','','1','0','','','',0, 1, 0, 0),
(5024,'BIOPSY CERVIX SINGLE/MULT/EXCISION OF LESION SPX','BIOPSY CERVIX SINGLE/MULT/EXCISION OF LESION SPX','57500','1','','1','0','','','',0, 1, 0, 0),
(5025,'ENDOCERVICAL CURETTAGE W/DILATION & CURETTAGE','ENDOCERVICAL CURETTAGE W/DILATION & CURETTAGE','57505','1','','1','0','','','',0, 1, 0, 0),
(5026,'CAUTERY CERVIX ELECTRO/THERMAL','CAUTERY CERVIX ELECTRO/THERMAL','57510','1','','1','0','','','',0, 1, 0, 0),
(5027,'CAUTERY CERVIX CRYOCAUTERY INITIAL/REPEAT','CAUTERY CERVIX CRYOCAUTERY INITIAL/REPEAT','57511','1','','1','0','','','',0, 1, 0, 0),
(5028,'CAUTERY CERVIX LASER ABLATION','CAUTERY CERVIX LASER ABLATION','57513','1','','1','0','','','',0, 1, 0, 0),
(5029,'CONIZATION CERVIX W/WO D&C RPR KNIFE/LASER','CONIZATION CERVIX W/WO D&C RPR KNIFE/LASER','57520','1','','1','0','','','',0, 1, 0, 0),
(5030,'CONIZATION CERVIX W/WO D&C RPR ELTRD EXC','CONIZATION CERVIX W/WO D&C RPR ELTRD EXC','57522','1','','1','0','','','',0, 1, 0, 0),
(5031,'TRACHELECTOMY CERVICECTOMY AMP CERVIX SPX','TRACHELECTOMY CERVICECTOMY AMP CERVIX SPX','57530','1','','1','0','','','',0, 1, 0, 0),
(5032,'RAD TRACHELECTOMY W/BI PEL LMPHADEC','RAD TRACHELECTOMY W/BI PEL LMPHADEC','57531','1','','1','0','','','',0, 1, 0, 0),
(5033,'EXCISION CERVICAL STUMP ABDOMINAL APPROACH','EXCISION CERVICAL STUMP ABDOMINAL APPROACH','57540','1','','1','0','','','',0, 1, 0, 0),
(5034,'EXC CERVICAL STUMP ABDL APPR W/PELVIC FLOOR RPR','EXC CERVICAL STUMP ABDL APPR W/PELVIC FLOOR RPR','57545','1','','1','0','','','',0, 1, 0, 0),
(5035,'EXCISION CERVICAL STUMP VAGINAL APPROACH','EXCISION CERVICAL STUMP VAGINAL APPROACH','57550','1','','1','0','','','',0, 1, 0, 0),
(5036,'EXC CRV STUMP VAG APPR W/ANT &/POST REPAIR','EXC CRV STUMP VAG APPR W/ANT &/POST REPAIR','57555','1','','1','0','','','',0, 1, 0, 0),
(5037,'EXC CRV STUMP VAG APPR W/RPR NTRCL','EXC CRV STUMP VAG APPR W/RPR NTRCL','57556','1','','1','0','','','',0, 1, 0, 0),
(5038,'DILATION & CURETTAGE CERVICAL STUMP','DILATION & CURETTAGE CERVICAL STUMP','57558','1','','1','0','','','',0, 1, 0, 0),
(5039,'CERCLAGE UTERINE CERVIX NONOBSTETRICAL','CERCLAGE UTERINE CERVIX NONOBSTETRICAL','57700','1','','1','0','','','',0, 1, 0, 0),
(5040,'TRACHELORRHAPHY PLSTC RPR UTERINE CERVIX VAG','TRACHELORRHAPHY PLSTC RPR UTERINE CERVIX VAG','57720','1','','1','0','','','',0, 1, 0, 0),
(5041,'DILATION CERVICAL CANAL INSTRUMENTAL SPX','DILATION CERVICAL CANAL INSTRUMENTAL SPX','57800','1','','1','0','','','',0, 1, 0, 0),
(5042,'ENDOMETRIAL BX W/WO ENDOCERVIX BX W/O DILAT SPX','ENDOMETRIAL BX W/WO ENDOCERVIX BX W/O DILAT SPX','58100','1','','1','0','','','',0, 1, 0, 0),
(5043,'ENDOMETRIAL BX CONJUNCT W/COLPOSCOPY','ENDOMETRIAL BX CONJUNCT W/COLPOSCOPY','58110','1','','1','0','','','',0, 1, 0, 0),
(5044,'DILATION & CURETTAGE DX&/THER NONOBSTETRIC','DILATION & CURETTAGE DX&/THER NONOBSTETRIC','58120','1','','1','0','','','',0, 1, 0, 0),
(5045,'MYOMECTOMY 1-4 MYOMAS W/250 GM/< ABDOMINAL APPR','MYOMECTOMY 1-4 MYOMAS W/250 GM/< ABDOMINAL APPR','58140','1','','1','0','','','',0, 1, 0, 0),
(5046,'MYOMECTOMY 1-4 MYOMAS 250 GM/< VAGINAL APPR','MYOMECTOMY 1-4 MYOMAS 250 GM/< VAGINAL APPR','58145','1','','1','0','','','',0, 1, 0, 0),
(5047,'MYOMECTOMY 5/> MYOMAS &/>250 GM ABDOMINA','MYOMECTOMY 5/> MYOMAS &/>250 GM ABDOMINA','58146','1','','1','0','','','',0, 1, 0, 0),
(5048,'TOTAL ABDOMINAL HYSTERECT W/WO RMVL TUBE OVARY','TOTAL ABDOMINAL HYSTERECT W/WO RMVL TUBE OVARY','58150','1','','1','0','','','',0, 1, 0, 0),
(5049,'TOT ABD HYST W/WO RMVL TUBE OVARY W/COLPURETHRXY','TOT ABD HYST W/WO RMVL TUBE OVARY W/COLPURETHRXY','58152','1','','1','0','','','',0, 1, 0, 0),
(5050,'SUPRACERVICAL ABDL HYSTER W/WO RMVL TUBE OVARY','SUPRACERVICAL ABDL HYSTER W/WO RMVL TUBE OVARY','58180','1','','1','0','','','',0, 1, 0, 0),
(5051,'TOT ABD HYST W/PARAORTIC & PELVIC LYMPH NODE SAM','TOT ABD HYST W/PARAORTIC & PELVIC LYMPH NODE SAM','58200','1','','1','0','','','',0, 1, 0, 0),
(5052,'RAD ABDL HYSTERECTOMY W/BI PELVIC LMPHADENECTOMY','RAD ABDL HYSTERECTOMY W/BI PELVIC LMPHADENECTOMY','58210','1','','1','0','','','',0, 1, 0, 0),
(5053,'PEL EXNTJ GYNECOLOGIC MAL','PEL EXNTJ GYNECOLOGIC MAL','58240','1','','1','0','','','',0, 1, 0, 0),
(5054,'VAGINAL HYSTERECTOMY UTERUS 250 GM/<','VAGINAL HYSTERECTOMY UTERUS 250 GM/<','58260','1','','1','0','','','',0, 1, 0, 0),
(5055,'VAG HYST 250 GM/< W/RMVL TUBE&/OVARY','VAG HYST 250 GM/< W/RMVL TUBE&/OVARY','58262','1','','1','0','','','',0, 1, 0, 0),
(5056,'VAG HYST 250 GM/< W/RMVL TUBE OVARY W/RPR NTRCL','VAG HYST 250 GM/< W/RMVL TUBE OVARY W/RPR NTRCL','58263','1','','1','0','','','',0, 1, 0, 0),
(5057,'VAG HYST 250 GM/< W/COLPO-URTCSTOPEXY','VAG HYST 250 GM/< W/COLPO-URTCSTOPEXY','58267','1','','1','0','','','',0, 1, 0, 0),
(5058,'VAGINAL HYSTERECTOMY 250 GM/< W/RPR ENTEROCELE','VAGINAL HYSTERECTOMY 250 GM/< W/RPR ENTEROCELE','58270','1','','1','0','','','',0, 1, 0, 0),
(5059,'VAGINAL HYSTERECTOMY W/TOT/PRTL VAGINECTOMY','VAGINAL HYSTERECTOMY W/TOT/PRTL VAGINECTOMY','58275','1','','1','0','','','',0, 1, 0, 0),
(5060,'VAG HYSTER W/TOT/PRTL VAGINECT W/RPR ENTEROCELE','VAG HYSTER W/TOT/PRTL VAGINECT W/RPR ENTEROCELE','58280','1','','1','0','','','',0, 1, 0, 0),
(5061,'VAGINAL HYSTERECTOMY RADICAL SCHAUTA OPERATION','VAGINAL HYSTERECTOMY RADICAL SCHAUTA OPERATION','58285','1','','1','0','','','',0, 1, 0, 0),
(5062,'VAGINAL HYSTERECTOMY UTERUS > 250 GM','VAGINAL HYSTERECTOMY UTERUS > 250 GM','58290','1','','1','0','','','',0, 1, 0, 0),
(5063,'VAG HYST > 250 GM RMVL TUBE&/OVARY','VAG HYST > 250 GM RMVL TUBE&/OVARY','58291','1','','1','0','','','',0, 1, 0, 0),
(5064,'VAG HYST > 250 GM RMVL TUBE&/OVARY W/RPR ENTRCLE','VAG HYST > 250 GM RMVL TUBE&/OVARY W/RPR ENTRCLE','58292','1','','1','0','','','',0, 1, 0, 0),
(5065,'VAG HYST >250 GM COLPOURTCSTOPEXY W/WO NDSC CTR','VAG HYST >250 GM COLPOURTCSTOPEXY W/WO NDSC CTR','58293','1','','1','0','','','',0, 1, 0, 0),
(5066,'VAGINAL HYSTERECTOMY >250 GM RPR ENTEROCELE','VAGINAL HYSTERECTOMY >250 GM RPR ENTEROCELE','58294','1','','1','0','','','',0, 1, 0, 0),
(5067,'INSERTION INTRAUTERINE DEVICE IUD','INSERTION INTRAUTERINE DEVICE IUD','58300','1','','1','0','','','',0, 1, 0, 0),
(5068,'REMOVAL INTRAUTERINE DEVICE IUD','REMOVAL INTRAUTERINE DEVICE IUD','58301','1','','1','0','','','',0, 1, 0, 0),
(5069,'ARTIFICIAL INSEMINATION INTRA-CERVICAL','ARTIFICIAL INSEMINATION INTRA-CERVICAL','58321','1','','1','0','','','',0, 1, 0, 0),
(5070,'ARTIFICIAL INSEMINATION INTRA-UTERINE','ARTIFICIAL INSEMINATION INTRA-UTERINE','58322','1','','1','0','','','',0, 1, 0, 0),
(5071,'SPERM WASHING ARTIFICIAL INSEMINATION','SPERM WASHING ARTIFICIAL INSEMINATION','58323','1','','1','0','','','',0, 1, 0, 0),
(5072,'CATH & SALINE/CONTRAST SONOHYSTER/HYSTEROSALPI','CATH & SALINE/CONTRAST SONOHYSTER/HYSTEROSALPI','58340','1','','1','0','','','',0, 1, 0, 0),
(5073,'TRANSCERV FALLOPIAN TUBE CATH W/WO HYSTOSALPING','TRANSCERV FALLOPIAN TUBE CATH W/WO HYSTOSALPING','58345','1','','1','0','','','',0, 1, 0, 0),
(5074,'INSERTION HEYMAN CAPSULES CLINICAL BRACHYTHERAPY','INSERTION HEYMAN CAPSULES CLINICAL BRACHYTHERAPY','58346','1','','1','0','','','',0, 1, 0, 0),
(5075,'CHROMOTUBATION OVIDUCT W/MATERIALS','CHROMOTUBATION OVIDUCT W/MATERIALS','58350','1','','1','0','','','',0, 1, 0, 0),
(5076,'ENDOMETRIAL ABLTJ THERMAL W/O HYSTEROSCOPIC GUID','ENDOMETRIAL ABLTJ THERMAL W/O HYSTEROSCOPIC GUID','58353','1','','1','0','','','',0, 1, 0, 0),
(5077,'ENDOMETRIAL CRYOABLATION W/US & ENDOMETRIAL CR','ENDOMETRIAL CRYOABLATION W/US & ENDOMETRIAL CR','58356','1','','1','0','','','',0, 1, 0, 0),
(5078,'UTERINE SUSPENSION W/WO SHORTENING LIGAMENTS SPX','UTERINE SUSPENSION W/WO SHORTENING LIGAMENTS SPX','58400','1','','1','0','','','',0, 1, 0, 0),
(5079,'UTERINE SUSP W/WO SHORT LIGAMNTS W/SYMPATHECTOMY','UTERINE SUSP W/WO SHORT LIGAMNTS W/SYMPATHECTOMY','58410','1','','1','0','','','',0, 1, 0, 0),
(5080,'HYSTERORRHAPHY REPAIR RUPT UTERUS NONOBSTETRICAL','HYSTERORRHAPHY REPAIR RUPT UTERUS NONOBSTETRICAL','58520','1','','1','0','','','',0, 1, 0, 0),
(5081,'HYSTEROPLASTY RPR UTERINE ANOMALY','HYSTEROPLASTY RPR UTERINE ANOMALY','58540','1','','1','0','','','',0, 1, 0, 0),
(5082,'LAPAROSCOPY SUPRACERVICAL HYSTERECTOMY 250 GM/<','LAPAROSCOPY SUPRACERVICAL HYSTERECTOMY 250 GM/<','58541','1','','1','0','','','',0, 1, 0, 0),
(5083,'LAPS SUPRACRV HYSTERECT 250 GM/< RMVL TUBE/OVAR','LAPS SUPRACRV HYSTERECT 250 GM/< RMVL TUBE/OVAR','58542','1','','1','0','','','',0, 1, 0, 0),
(5084,'LAPS SUPRACERVICAL HYSTERECTOMY >250','LAPS SUPRACERVICAL HYSTERECTOMY >250','58543','1','','1','0','','','',0, 1, 0, 0),
(5085,'LAPS SUPRACRV HYSTEREC >250 G RMVL TUBE/OVARY','LAPS SUPRACRV HYSTEREC >250 G RMVL TUBE/OVARY','58544','1','','1','0','','','',0, 1, 0, 0),
(5086,'LAPS MYOMECTOMY EXC 1-4 MYOMAS 250 GM/<','LAPS MYOMECTOMY EXC 1-4 MYOMAS 250 GM/<','58545','1','','1','0','','','',0, 1, 0, 0),
(5087,'LAPS MYOMECTOMY EXC 5/> MYOMAS >250 GRAMS','LAPS MYOMECTOMY EXC 5/> MYOMAS >250 GRAMS','58546','1','','1','0','','','',0, 1, 0, 0),
(5088,'LAPS W/RAD HYST W/BILAT LMPHADEC RMVL TUBE/OVARY','LAPS W/RAD HYST W/BILAT LMPHADEC RMVL TUBE/OVARY','58548','1','','1','0','','','',0, 1, 0, 0),
(5089,'LAPS VAGINAL HYSTERECTOMY UTERUS 250 GM/<','LAPS VAGINAL HYSTERECTOMY UTERUS 250 GM/<','58550','1','','1','0','','','',0, 1, 0, 0),
(5090,'LAPS W/VAG HYSTERECT 250 GM/&RMVL TUBE&/OVARIES','LAPS W/VAG HYSTERECT 250 GM/&RMVL TUBE&/OVARIES','58552','1','','1','0','','','',0, 1, 0, 0),
(5091,'LAPS W/VAGINAL HYSTERECTOMY > 250 GRAMS','LAPS W/VAGINAL HYSTERECTOMY > 250 GRAMS','58553','1','','1','0','','','',0, 1, 0, 0),
(5092,'LAPS VAGINAL HYSTERECT > 250 GM RMVL TUBE&/OVAR','LAPS VAGINAL HYSTERECT > 250 GM RMVL TUBE&/OVAR','58554','1','','1','0','','','',0, 1, 0, 0),
(5093,'HYSTEROSCOPY DIAGNOSTIC SEPARATE PROCEDURE','HYSTEROSCOPY DIAGNOSTIC SEPARATE PROCEDURE','58555','1','','1','0','','','',0, 1, 0, 0),
(5094,'HYSTEROSCOPY BX ENDOMETRIUM&/POLYPC W/WO D&C','HYSTEROSCOPY BX ENDOMETRIUM&/POLYPC W/WO D&C','58558','1','','1','0','','','',0, 1, 0, 0),
(5095,'HYSTEROSCOPY LYSIS INTRAUTERINE ADHESIONS','HYSTEROSCOPY LYSIS INTRAUTERINE ADHESIONS','58559','1','','1','0','','','',0, 1, 0, 0),
(5096,'HYSTEROSCOPY DIV/RESCJ INTRAUTERINE SEPTUM','HYSTEROSCOPY DIV/RESCJ INTRAUTERINE SEPTUM','58560','1','','1','0','','','',0, 1, 0, 0),
(5097,'HYSTEROSCOPY REMOVAL LEIOMYOMATA','HYSTEROSCOPY REMOVAL LEIOMYOMATA','58561','1','','1','0','','','',0, 1, 0, 0),
(5098,'HYSTEROSCOPY REMOVAL IMPACTED FOREIGN BODY','HYSTEROSCOPY REMOVAL IMPACTED FOREIGN BODY','58562','1','','1','0','','','',0, 1, 0, 0),
(5099,'HYSTEROSCOPY ENDOMETRIAL ABLATION','HYSTEROSCOPY ENDOMETRIAL ABLATION','58563','1','','1','0','','','',0, 1, 0, 0),
(5100,'HYSTEROSCOPY BI TUBE OCCLUSION W/PERM IMPLNTS','HYSTEROSCOPY BI TUBE OCCLUSION W/PERM IMPLNTS','58565','1','','1','0','','','',0, 1, 0, 0),
(5101,'LAPAROSCOPY W TOTAL HYSTERECTOMY UTERUS 250 GM/<','LAPAROSCOPY W TOTAL HYSTERECTOMY UTERUS 250 GM/<','58570','1','','1','0','','','',0, 1, 0, 0),
(5102,'LAPS TOTAL HYSTERECT 250 GM/< W/RMVL TUBE/OVARY','LAPS TOTAL HYSTERECT 250 GM/< W/RMVL TUBE/OVARY','58571','1','','1','0','','','',0, 1, 0, 0),
(5103,'LAPAROSCOPY TOTAL HYSTERECTOMY UTERUS >250 GM','LAPAROSCOPY TOTAL HYSTERECTOMY UTERUS >250 GM','58572','1','','1','0','','','',0, 1, 0, 0),
(5104,'LAPAROSCOPY TOT HYSTERECTOMY >250 G W/TUBE/OVAR','LAPAROSCOPY TOT HYSTERECTOMY >250 G W/TUBE/OVAR','58573','1','','1','0','','','',0, 1, 0, 0),
(5105,'UNLISTED LAPAROSCOPY PROCEDURE UTERUS','UNLISTED LAPAROSCOPY PROCEDURE UTERUS','58578','1','','1','0','','','',0, 1, 0, 0),
(5106,'UNLISTED HYSTEROSCOPY PROCEDURE UTERUS','UNLISTED HYSTEROSCOPY PROCEDURE UTERUS','58579','1','','1','0','','','',0, 1, 0, 0),
(5107,'LIG/TRNSXJ FLP TUBE ABDL/VAG APPR UNI/BI','LIG/TRNSXJ FLP TUBE ABDL/VAG APPR UNI/BI','58600','1','','1','0','','','',0, 1, 0, 0),
(5108,'LIG/TRNSXJ FLP TUBE ABDL/VAG POSTPARTUM SPX','LIG/TRNSXJ FLP TUBE ABDL/VAG POSTPARTUM SPX','58605','1','','1','0','','','',0, 1, 0, 0),
(5109,'LIG/TRNSXJ FALOPIAN TUBE CESAREAN DEL/ABDML SURG','LIG/TRNSXJ FALOPIAN TUBE CESAREAN DEL/ABDML SURG','58611','1','','1','0','','','',0, 1, 0, 0),
(5110,'OCCLUSION FLP TUBE DEV VAG/SUPRAPUBIC APPR','OCCLUSION FLP TUBE DEV VAG/SUPRAPUBIC APPR','58615','1','','1','0','','','',0, 1, 0, 0),
(5111,'LAPAROSCOPY W/LYSIS OF ADHESIONS','LAPAROSCOPY W/LYSIS OF ADHESIONS','58660','1','','1','0','','','',0, 1, 0, 0),
(5112,'LAPAROSCOPY W/RMVL ADNEXAL STRUCTURES','LAPAROSCOPY W/RMVL ADNEXAL STRUCTURES','58661','1','','1','0','','','',0, 1, 0, 0),
(5113,'LAPS FULG/EXC OVARY VISCERA/PERITONEAL SURFACE','LAPS FULG/EXC OVARY VISCERA/PERITONEAL SURFACE','58662','1','','1','0','','','',0, 1, 0, 0),
(5114,'LAPAROSCOPY FULGURATION OVIDUCTS','LAPAROSCOPY FULGURATION OVIDUCTS','58670','1','','1','0','','','',0, 1, 0, 0),
(5115,'LAPAROSCOPY W/PLMT OCCLUSION DEVICE OVIDUCTS','LAPAROSCOPY W/PLMT OCCLUSION DEVICE OVIDUCTS','58671','1','','1','0','','','',0, 1, 0, 0),
(5116,'LAPAROSCOPY FIMBRIOPLASTY','LAPAROSCOPY FIMBRIOPLASTY','58672','1','','1','0','','','',0, 1, 0, 0),
(5117,'LAPAROSCOPY SALPINGOSTOMY','LAPAROSCOPY SALPINGOSTOMY','58673','1','','1','0','','','',0, 1, 0, 0),
(5118,'UNLISTED LAPAROSCOPY PROCEDURE OVIDUCT/OVARY','UNLISTED LAPAROSCOPY PROCEDURE OVIDUCT/OVARY','58679','1','','1','0','','','',0, 1, 0, 0),
(5119,'SALPINGECTOMY COMPLETE/PARTIAL UNI/BI SPX','SALPINGECTOMY COMPLETE/PARTIAL UNI/BI SPX','58700','1','','1','0','','','',0, 1, 0, 0),
(5120,'SALPINGO-OOPHORECTOMY COMPL/PRTL UNI/BI SPX','SALPINGO-OOPHORECTOMY COMPL/PRTL UNI/BI SPX','58720','1','','1','0','','','',0, 1, 0, 0),
(5121,'LYSIS OF ADHESIONS SALPINX/OVARY','LYSIS OF ADHESIONS SALPINX/OVARY','58740','1','','1','0','','','',0, 1, 0, 0),
(5122,'TUBOTUBAL ANASTATOMOSIS','TUBOTUBAL ANASTATOMOSIS','58750','1','','1','0','','','',0, 1, 0, 0),
(5123,'TUBOUTERINE IMPLANTATION','TUBOUTERINE IMPLANTATION','58752','1','','1','0','','','',0, 1, 0, 0),
(5124,'FIMBRIOPLASTY','FIMBRIOPLASTY','58760','1','','1','0','','','',0, 1, 0, 0),
(5125,'SALPINGOSTOMY','SALPINGOSTOMY','58770','1','','1','0','','','',0, 1, 0, 0),
(5126,'DRAINAGE OVARIAN CYST UNI/BI SPX VAGINAL APPR','DRAINAGE OVARIAN CYST UNI/BI SPX VAGINAL APPR','58800','1','','1','0','','','',0, 1, 0, 0),
(5127,'DRAINAGE OVARIAN CYST UNI/BI SPX ABDOMINAL','DRAINAGE OVARIAN CYST UNI/BI SPX ABDOMINAL','58805','1','','1','0','','','',0, 1, 0, 0),
(5128,'DRAINAGE OVARIAN ABSCESS VAGINAL APPR OPEN','DRAINAGE OVARIAN ABSCESS VAGINAL APPR OPEN','58820','1','','1','0','','','',0, 1, 0, 0),
(5129,'DRAINAGE OVARIAN ABSCESS ABDOMINAL APPROACH','DRAINAGE OVARIAN ABSCESS ABDOMINAL APPROACH','58822','1','','1','0','','','',0, 1, 0, 0),
(5130,'TRANSPOSITION OVARY','TRANSPOSITION OVARY','58825','1','','1','0','','','',0, 1, 0, 0),
(5131,'BIOPSY OVARY UNI/BI SEPARATE PROCEDURE','BIOPSY OVARY UNI/BI SEPARATE PROCEDURE','58900','1','','1','0','','','',0, 1, 0, 0),
(5132,'WEDGE RESCJ/BISCTJ OVARY UNI/BI','WEDGE RESCJ/BISCTJ OVARY UNI/BI','58920','1','','1','0','','','',0, 1, 0, 0),
(5133,'OVARIAN CYSTECTOMY UNI/BI','OVARIAN CYSTECTOMY UNI/BI','58925','1','','1','0','','','',0, 1, 0, 0),
(5134,'OOPHORECTOMY PARTIAL/TOTAL UNI/BI','OOPHORECTOMY PARTIAL/TOTAL UNI/BI','58940','1','','1','0','','','',0, 1, 0, 0),
(5135,'OOPHORECTOMY PRTL/TOT UNI/BI OVARIAN MALIGNANCY','OOPHORECTOMY PRTL/TOT UNI/BI OVARIAN MALIGNANCY','58943','1','','1','0','','','',0, 1, 0, 0),
(5136,'RESCJ OVARIAN/TUBAL/PERITONEAL MALIGNANCY W/BSO','RESCJ OVARIAN/TUBAL/PERITONEAL MALIGNANCY W/BSO','58950','1','','1','0','','','',0, 1, 0, 0),
(5137,'RESCJ PRIM PRTL MAL W/BSO & OMNTC TAH & LMPHAD','RESCJ PRIM PRTL MAL W/BSO & OMNTC TAH & LMPHAD','58951','1','','1','0','','','',0, 1, 0, 0),
(5138,'RESCJ PRIM PRTL MAL W/BSO & OMNTC RAD DEBULKING','RESCJ PRIM PRTL MAL W/BSO & OMNTC RAD DEBULKING','58952','1','','1','0','','','',0, 1, 0, 0),
(5139,'BSO W/OMENTECTOMY TAH&RAD DEBULKING DISSECTION','BSO W/OMENTECTOMY TAH&RAD DEBULKING DISSECTION','58953','1','','1','0','','','',0, 1, 0, 0),
(5140,'BSO W/OMENTECTOMY TAH DEBULKING W/LMPHADECTOMY','BSO W/OMENTECTOMY TAH DEBULKING W/LMPHADECTOMY','58954','1','','1','0','','','',0, 1, 0, 0),
(5141,'BSO W/TOT OMENTECTOMY & HYSTERECTOMY MALIGNANC','BSO W/TOT OMENTECTOMY & HYSTERECTOMY MALIGNANC','58956','1','','1','0','','','',0, 1, 0, 0),
(5142,'RESECJ RECUR OVARIAN/TUBAL/PERITONEAL MALIGNANCY','RESECJ RECUR OVARIAN/TUBAL/PERITONEAL MALIGNANCY','58957','1','','1','0','','','',0, 1, 0, 0),
(5143,'RESECTION RECRT MAL W/OMENTECTOMY PEL LMPHADEC','RESECTION RECRT MAL W/OMENTECTOMY PEL LMPHADEC','58958','1','','1','0','','','',0, 1, 0, 0),
(5144,'LAPT STG/RESTG OVARIAN TUBAL/PRIM MAL 2ND LOOK','LAPT STG/RESTG OVARIAN TUBAL/PRIM MAL 2ND LOOK','58960','1','','1','0','','','',0, 1, 0, 0),
(5145,'FOLLICLE PUNCTURE OOCYTE RETRIEVAL ANY METHOD','FOLLICLE PUNCTURE OOCYTE RETRIEVAL ANY METHOD','58970','1','','1','0','','','',0, 1, 0, 0),
(5146,'EMBRYO TRANSFER INTRAUTERINE','EMBRYO TRANSFER INTRAUTERINE','58974','1','','1','0','','','',0, 1, 0, 0),
(5147,'GAMETE ZYGOTE/EMBRYO FALLOPIAN TRANSFER ANY METH','GAMETE ZYGOTE/EMBRYO FALLOPIAN TRANSFER ANY METH','58976','1','','1','0','','','',0, 1, 0, 0),
(5148,'UNLISTED PX FEMALE GENITAL SYSTEM NONOBSTETRICAL','UNLISTED PX FEMALE GENITAL SYSTEM NONOBSTETRICAL','58999','1','','1','0','','','',0, 1, 0, 0),
(5149,'AMNIOCENTESIS DIAGNOSIC','AMNIOCENTESIS DIAGNOSIC','59000','1','','1','0','','','',0, 1, 0, 0),
(5150,'AMNIOCENTESIS THER AMNIOTIC FLUID RDCTJ US GUID','AMNIOCENTESIS THER AMNIOTIC FLUID RDCTJ US GUID','59001','1','','1','0','','','',0, 1, 0, 0),
(5151,'CORDOCENTESIS INTRAUTERINE','CORDOCENTESIS INTRAUTERINE','59012','1','','1','0','','','',0, 1, 0, 0),
(5152,'CHORIONIC VILLUS SAMPLING','CHORIONIC VILLUS SAMPLING','59015','1','','1','0','','','',0, 1, 0, 0),
(5153,'FETAL CONTRACTION STRESS TEST','FETAL CONTRACTION STRESS TEST','59020','1','','1','0','','','',0, 1, 0, 0),
(5154,'FETAL NONSTRESS TEST','FETAL NONSTRESS TEST','59025','1','','1','0','','','',0, 1, 0, 0),
(5155,'FETAL SCALP BLOOD SAMPLING','FETAL SCALP BLOOD SAMPLING','59030','1','','1','0','','','',0, 1, 0, 0),
(5156,'FETAL MONITORING LABOR PHYS WRITTEN REPORT','FETAL MONITORING LABOR PHYS WRITTEN REPORT','59050','1','','1','0','','','',0, 1, 0, 0),
(5157,'FETAL MONITR LABOR PHYS WRTTN REPRT INTERPJ ONLY','FETAL MONITR LABOR PHYS WRTTN REPRT INTERPJ ONLY','59051','1','','1','0','','','',0, 1, 0, 0),
(5158,'TRANSABDOMINAL AMNIOINFUSION W/ULTRSND GUIDANCE','TRANSABDOMINAL AMNIOINFUSION W/ULTRSND GUIDANCE','59070','1','','1','0','','','',0, 1, 0, 0),
(5159,'FETAL UMBILICAL CORD OCCLUSION W/ULTRSND GUIDNCE','FETAL UMBILICAL CORD OCCLUSION W/ULTRSND GUIDNCE','59072','1','','1','0','','','',0, 1, 0, 0),
(5160,'FETAL FLUID DRAINAGE W/ULTRASOUND GUIDANCE','FETAL FLUID DRAINAGE W/ULTRASOUND GUIDANCE','59074','1','','1','0','','','',0, 1, 0, 0),
(5161,'FETAL SHUNT PLACEMENT W/ULTRASOUND GUIDANCE','FETAL SHUNT PLACEMENT W/ULTRASOUND GUIDANCE','59076','1','','1','0','','','',0, 1, 0, 0),
(5162,'HYSTEROTOMY ABDOMINAL','HYSTEROTOMY ABDOMINAL','59100','1','','1','0','','','',0, 1, 0, 0),
(5163,'TX ECTOPIC PREGNANCY ABDOMINAL/VAGINAL APPR','TX ECTOPIC PREGNANCY ABDOMINAL/VAGINAL APPR','59120','1','','1','0','','','',0, 1, 0, 0),
(5164,'TX ECTOPIC PREGNANCY W/O SALPING&/OOPHORECTOMY','TX ECTOPIC PREGNANCY W/O SALPING&/OOPHORECTOMY','59121','1','','1','0','','','',0, 1, 0, 0),
(5165,'TX ECTOPIC PREGNANCY ABDL PREGNANCY','TX ECTOPIC PREGNANCY ABDL PREGNANCY','59130','1','','1','0','','','',0, 1, 0, 0),
(5166,'TX ECTOPIC PREGNANCY NTRSTL REQ TOT HYST','TX ECTOPIC PREGNANCY NTRSTL REQ TOT HYST','59135','1','','1','0','','','',0, 1, 0, 0),
(5167,'TX ECTOPIC PREGNANCY NTRSTL PRTL RESCJ UTER','TX ECTOPIC PREGNANCY NTRSTL PRTL RESCJ UTER','59136','1','','1','0','','','',0, 1, 0, 0),
(5168,'TX ECTOPIC PREGNANCY CERVICAL W/EVACUATION','TX ECTOPIC PREGNANCY CERVICAL W/EVACUATION','59140','1','','1','0','','','',0, 1, 0, 0),
(5169,'LAPS TX ECTOPIC PREG W/O SALPING&/OOPHORECTOMY','LAPS TX ECTOPIC PREG W/O SALPING&/OOPHORECTOMY','59150','1','','1','0','','','',0, 1, 0, 0),
(5170,'LAPS TX ECTOPIC PREG W/SALPING&/OOPHORECTOMY','LAPS TX ECTOPIC PREG W/SALPING&/OOPHORECTOMY','59151','1','','1','0','','','',0, 1, 0, 0),
(5171,'CURETTAGE POSTPARTUM','CURETTAGE POSTPARTUM','59160','1','','1','0','','','',0, 1, 0, 0),
(5172,'INSERTION CERVICAL DILATOR SEPARATE PROCEDURE','INSERTION CERVICAL DILATOR SEPARATE PROCEDURE','59200','1','','1','0','','','',0, 1, 0, 0),
(5173,'EPISIOTOMY/VAG RPR OTH/THN ATTENDING','EPISIOTOMY/VAG RPR OTH/THN ATTENDING','59300','1','','1','0','','','',0, 1, 0, 0),
(5174,'CERCLAGE CERVIX PREGNANCY VAGINAL','CERCLAGE CERVIX PREGNANCY VAGINAL','59320','1','','1','0','','','',0, 1, 0, 0),
(5175,'CERCLAGE CERVIX PREGNANCY ABDOMINAL','CERCLAGE CERVIX PREGNANCY ABDOMINAL','59325','1','','1','0','','','',0, 1, 0, 0),
(5176,'HYSTERORRHAPHY RUPTURED UTERUS','HYSTERORRHAPHY RUPTURED UTERUS','59350','1','','1','0','','','',0, 1, 0, 0),
(5177,'OB CARE ANTEPARTUM VAG DLVR & POSTPARTUM','OB CARE ANTEPARTUM VAG DLVR & POSTPARTUM','59400','1','','1','0','','','',0, 1, 0, 0),
(5178,'VAGINAL DELIVERY ONLY','VAGINAL DELIVERY ONLY','59409','1','','1','0','','','',0, 1, 0, 0),
(5179,'VAGINAL DELIVERY ONLY W/POSTPARTUM CARE','VAGINAL DELIVERY ONLY W/POSTPARTUM CARE','59410','1','','1','0','','','',0, 1, 0, 0),
(5180,'EXTERNAL CEPHALIC VERSION W/WO TOCOLYSIS','EXTERNAL CEPHALIC VERSION W/WO TOCOLYSIS','59412','1','','1','0','','','',0, 1, 0, 0),
(5181,'DELIVERY PLACENTA SEPARATE PROCEDURE','DELIVERY PLACENTA SEPARATE PROCEDURE','59414','1','','1','0','','','',0, 1, 0, 0),
(5182,'ANTEPARTUM CARE ONLY 4-6 VISITS','ANTEPARTUM CARE ONLY 4-6 VISITS','59425','1','','1','0','','','',0, 1, 0, 0),
(5183,'ANTEPARTUM CARE ONLY 7/> VISITS','ANTEPARTUM CARE ONLY 7/> VISITS','59426','1','','1','0','','','',0, 1, 0, 0),
(5184,'POSTPARTUM CARE ONLY SEPARATE PROCEDURE','POSTPARTUM CARE ONLY SEPARATE PROCEDURE','59430','1','','1','0','','','',0, 1, 0, 0),
(5185,'OB ANTEPARTUM CARE CESAREAN DLVR & POSTPARTUM','OB ANTEPARTUM CARE CESAREAN DLVR & POSTPARTUM','59510','1','','1','0','','','',0, 1, 0, 0),
(5186,'CESAREAN DELIVERY ONLY','CESAREAN DELIVERY ONLY','59514','1','','1','0','','','',0, 1, 0, 0),
(5187,'CESAREAN DELIVERY ONLY W/POSTPARTUM CARE','CESAREAN DELIVERY ONLY W/POSTPARTUM CARE','59515','1','','1','0','','','',0, 1, 0, 0),
(5188,'STOT/TOT HYSTERECTOMY AFTER CESAREAN DELIVERY','STOT/TOT HYSTERECTOMY AFTER CESAREAN DELIVERY','59525','1','','1','0','','','',0, 1, 0, 0),
(5189,'ROUTINE OB CARE VAG DLVRY & POSTPARTUM CARE VB','ROUTINE OB CARE VAG DLVRY & POSTPARTUM CARE VB','59610','1','','1','0','','','',0, 1, 0, 0),
(5190,'VAGINAL DELIVERY AFTER CESAREAN DELIVERY','VAGINAL DELIVERY AFTER CESAREAN DELIVERY','59612','1','','1','0','','','',0, 1, 0, 0),
(5191,'VAGINAL DELIVERY & POSTPARTUM CARE VBAC','VAGINAL DELIVERY & POSTPARTUM CARE VBAC','59614','1','','1','0','','','',0, 1, 0, 0),
(5192,'ROUTINE OBSTETRICAL CARE ATTEMPTED VBAC','ROUTINE OBSTETRICAL CARE ATTEMPTED VBAC','59618','1','','1','0','','','',0, 1, 0, 0),
(5193,'CESAREAN DELIVERY ATTEMPTED VBAC','CESAREAN DELIVERY ATTEMPTED VBAC','59620','1','','1','0','','','',0, 1, 0, 0),
(5194,'CESAREAN DLVRY & POSTPARTUM CARE ATTEMPTED VBA','CESAREAN DLVRY & POSTPARTUM CARE ATTEMPTED VBA','59622','1','','1','0','','','',0, 1, 0, 0),
(5195,'TX INCOMPLETE ABORTION ANY TRIMESTER SURGICAL','TX INCOMPLETE ABORTION ANY TRIMESTER SURGICAL','59812','1','','1','0','','','',0, 1, 0, 0),
(5196,'TX MISSED ABORTION FIRST TRIMESTER SURGICAL','TX MISSED ABORTION FIRST TRIMESTER SURGICAL','59820','1','','1','0','','','',0, 1, 0, 0),
(5197,'TX MISSED ABORTION SECOND TRIMESTER SURGICAL','TX MISSED ABORTION SECOND TRIMESTER SURGICAL','59821','1','','1','0','','','',0, 1, 0, 0),
(5198,'TX SEPTIC ABORTION SURGICAL','TX SEPTIC ABORTION SURGICAL','59830','1','','1','0','','','',0, 1, 0, 0),
(5199,'INDUCED ABORTION DILATION AND CURETTAGE','INDUCED ABORTION DILATION AND CURETTAGE','59840','1','','1','0','','','',0, 1, 0, 0),
(5200,'INDUCED ABORTION DILATION & EVACUATION','INDUCED ABORTION DILATION & EVACUATION','59841','1','','1','0','','','',0, 1, 0, 0),
(5201,'INDUCED ABORTION 1/> AMNIOTIC INJX W/D&C/EVACJ','INDUCED ABORTION 1/> AMNIOTIC INJX W/D&C/EVACJ','59850','1','','1','0','','','',0, 1, 0, 0),
(5202,'INDUCE ABORT 1/> AMNIOT NJXS DLVR FETUS D&C','INDUCE ABORT 1/> AMNIOT NJXS DLVR FETUS D&C','59851','1','','1','0','','','',0, 1, 0, 0),
(5203,'INDUCE ABORT 1/> AMNIOT NJXS DLVR FETUS HYSTOTM','INDUCE ABORT 1/> AMNIOT NJXS DLVR FETUS HYSTOTM','59852','1','','1','0','','','',0, 1, 0, 0),
(5204,'INDUCED ABORT 1/> VAG SUPPOSITORIES DLVR FETUS','INDUCED ABORT 1/> VAG SUPPOSITORIES DLVR FETUS','59855','1','','1','0','','','',0, 1, 0, 0),
(5205,'INDUCED ABORT 1/> VAG SUPP DLVR FETUS D&C &/EVAC','INDUCED ABORT 1/> VAG SUPP DLVR FETUS D&C &/EVAC','59856','1','','1','0','','','',0, 1, 0, 0),
(5206,'INDUCED ABORT 1/> VAG SUPPOS DLVR FETUS HYSTOT','INDUCED ABORT 1/> VAG SUPPOS DLVR FETUS HYSTOT','59857','1','','1','0','','','',0, 1, 0, 0),
(5207,'MULTIFETAL PREGNANCY REDUCTION','MULTIFETAL PREGNANCY REDUCTION','59866','1','','1','0','','','',0, 1, 0, 0),
(5208,'UTERINE EVACUATION & CURETTAGE HYDATIDIFORM MOLE','UTERINE EVACUATION & CURETTAGE HYDATIDIFORM MOLE','59870','1','','1','0','','','',0, 1, 0, 0),
(5209,'REMOVAL CERCLAGE SUTURE UNDER ANESTHESIA','REMOVAL CERCLAGE SUTURE UNDER ANESTHESIA','59871','1','','1','0','','','',0, 1, 0, 0),
(5210,'UNLISTED FETAL INVASIVE PX W/ULTRASOUND','UNLISTED FETAL INVASIVE PX W/ULTRASOUND','59897','1','','1','0','','','',0, 1, 0, 0),
(5211,'UNLISTED LAPAROSCOPY PX MATERNITY CARE&DELIVERY','UNLISTED LAPAROSCOPY PX MATERNITY CARE&DELIVERY','59898','1','','1','0','','','',0, 1, 0, 0),
(5212,'UNLISTED PROCEDURE MATERNITY CARE & DELIVERY','UNLISTED PROCEDURE MATERNITY CARE & DELIVERY','59899','1','','1','0','','','',0, 1, 0, 0),
(5213,'I&D THYROGLOSSAL DUCT CYST INFECTED','I&D THYROGLOSSAL DUCT CYST INFECTED','60000','1','','1','0','','','',0, 1, 0, 0),
(5214,'BIOPSY THYROID PERCUTANEOUS CORE NEEDLE','BIOPSY THYROID PERCUTANEOUS CORE NEEDLE','60100','1','','1','0','','','',0, 1, 0, 0),
(5215,'EXC CYST/ADENOMA THYROID/TRANSECTION ISTHMUS','EXC CYST/ADENOMA THYROID/TRANSECTION ISTHMUS','60200','1','','1','0','','','',0, 1, 0, 0),
(5216,'PRTL THYROID LOBECTOMY UNI W/WO ISTHMUSECTOMY','PRTL THYROID LOBECTOMY UNI W/WO ISTHMUSECTOMY','60210','1','','1','0','','','',0, 1, 0, 0),
(5217,'PRTL THYROID LOBEC UNI W/CONTRATLAT STOT LOBEC','PRTL THYROID LOBEC UNI W/CONTRATLAT STOT LOBEC','60212','1','','1','0','','','',0, 1, 0, 0),
(5218,'TOTAL THYROID LOBECTOMY UNI W/WO ISTHMUSECTOMY','TOTAL THYROID LOBECTOMY UNI W/WO ISTHMUSECTOMY','60220','1','','1','0','','','',0, 1, 0, 0),
(5219,'TOTAL THYROID LOBEC UNI W/CONTRALAT STOT LOBEC','TOTAL THYROID LOBEC UNI W/CONTRALAT STOT LOBEC','60225','1','','1','0','','','',0, 1, 0, 0),
(5220,'THYROIDECTOMY TOTAL/COMPLETE','THYROIDECTOMY TOTAL/COMPLETE','60240','1','','1','0','','','',0, 1, 0, 0),
(5221,'THYROIDECTOMY TOTAL/SUBTOTAL LMTD NECK DISSECT','THYROIDECTOMY TOTAL/SUBTOTAL LMTD NECK DISSECT','60252','1','','1','0','','','',0, 1, 0, 0),
(5222,'THYROIDECTOMY TOTAL/SUBTOTAL RAD NECK DISSECT','THYROIDECTOMY TOTAL/SUBTOTAL RAD NECK DISSECT','60254','1','','1','0','','','',0, 1, 0, 0),
(5223,'THYROIDECTOMY RMVL REMAINING TISS FLWG PRTL RMVL','THYROIDECTOMY RMVL REMAINING TISS FLWG PRTL RMVL','60260','1','','1','0','','','',0, 1, 0, 0),
(5224,'THYROIDECT W/SUBSTERNAL SPLIT/TRANSTHORACIC','THYROIDECT W/SUBSTERNAL SPLIT/TRANSTHORACIC','60270','1','','1','0','','','',0, 1, 0, 0),
(5225,'THYROIDECTOMY SUBSTERNAL CERVICAL APPROACH','THYROIDECTOMY SUBSTERNAL CERVICAL APPROACH','60271','1','','1','0','','','',0, 1, 0, 0),
(5226,'EXCISION THYROGLOSSAL DUCT CYST/SINUS','EXCISION THYROGLOSSAL DUCT CYST/SINUS','60280','1','','1','0','','','',0, 1, 0, 0),
(5227,'EXCISION THYROGLOSSAL DUCT CYST/SINUS RECURRENT','EXCISION THYROGLOSSAL DUCT CYST/SINUS RECURRENT','60281','1','','1','0','','','',0, 1, 0, 0),
(5228,'ASPIRATION AND/OR INJECTION THYROID CYST','ASPIRATION AND/OR INJECTION THYROID CYST','60300','1','','1','0','','','',0, 1, 0, 0),
(5229,'PARATHYROIDECTOMY/EXPLORATION PARATHYROIDS','PARATHYROIDECTOMY/EXPLORATION PARATHYROIDS','60500','1','','1','0','','','',0, 1, 0, 0),
(5230,'PARATHYROIDECTOMY/EXPLOR PARATHYROIDS RE-EXPLOR','PARATHYROIDECTOMY/EXPLOR PARATHYROIDS RE-EXPLOR','60502','1','','1','0','','','',0, 1, 0, 0),
(5231,'PARATHYRDEC/EXPL PARATHYR MEDSTNL STERNAL/TTHRC','PARATHYRDEC/EXPL PARATHYR MEDSTNL STERNAL/TTHRC','60505','1','','1','0','','','',0, 1, 0, 0),
(5232,'PARATHYROID AUTOTRANSPLANTATION ADD-ON','PARATHYROID AUTOTRANSPLANTATION ADD-ON','60512','1','','1','0','','','',0, 1, 0, 0),
(5233,'THYMECTOMY PRTL/TOT TRANSCERVICAL APPR SPX','THYMECTOMY PRTL/TOT TRANSCERVICAL APPR SPX','60520','1','','1','0','','','',0, 1, 0, 0),
(5234,'THYMECTOMY PRTL/TOT W/O RAD MEDSTNL DSJ SPX','THYMECTOMY PRTL/TOT W/O RAD MEDSTNL DSJ SPX','60521','1','','1','0','','','',0, 1, 0, 0),
(5235,'THYMECTOMY PRTL/TOT RAD MEDSTNL DSJ SPX','THYMECTOMY PRTL/TOT RAD MEDSTNL DSJ SPX','60522','1','','1','0','','','',0, 1, 0, 0),
(5236,'ADRENALECTOMY W/EXPL W/WO BX ABDL/LMBR/DRSAL SPX','ADRENALECTOMY W/EXPL W/WO BX ABDL/LMBR/DRSAL SPX','60540','1','','1','0','','','',0, 1, 0, 0),
(5237,'ADRENALECTOMY EXPL W/EXC RETROPERTINEAL TUMOR','ADRENALECTOMY EXPL W/EXC RETROPERTINEAL TUMOR','60545','1','','1','0','','','',0, 1, 0, 0),
(5238,'EXC CAROTID BODY TUMOR W/O EXC CAROTID ARTERY','EXC CAROTID BODY TUMOR W/O EXC CAROTID ARTERY','60600','1','','1','0','','','',0, 1, 0, 0),
(5239,'EXC CAROTID BODY TUMOR W EXC CAROTID ARTERY','EXC CAROTID BODY TUMOR W EXC CAROTID ARTERY','60605','1','','1','0','','','',0, 1, 0, 0),
(5240,'LAPAROSCOPY ADRENALECTOMY PRTL/COMPL TABDL','LAPAROSCOPY ADRENALECTOMY PRTL/COMPL TABDL','60650','1','','1','0','','','',0, 1, 0, 0),
(5241,'UNLISTED LAPAROSCOPY PROCEDURE ENDOCRINE SYSTEM','UNLISTED LAPAROSCOPY PROCEDURE ENDOCRINE SYSTEM','60659','1','','1','0','','','',0, 1, 0, 0),
(5242,'UNLISTED PROCEDURE ENDOCRINE SYSTEM','UNLISTED PROCEDURE ENDOCRINE SYSTEM','60699','1','','1','0','','','',0, 1, 0, 0),
(5243,'SUBDURAL TAP FONTANELLE/SUTUR INFANT UNI/BI INIT','SUBDURAL TAP FONTANELLE/SUTUR INFANT UNI/BI INIT','61000','1','','1','0','','','',0, 1, 0, 0),
(5244,'SUBDURAL TAP FONTANELLE/SUTUR INFANT UNI/BI SBSQ','SUBDURAL TAP FONTANELLE/SUTUR INFANT UNI/BI SBSQ','61001','1','','1','0','','','',0, 1, 0, 0),
(5245,'VENTRICULAR PUNCTURE PREVIOUS BURR HOLE W/O NJX','VENTRICULAR PUNCTURE PREVIOUS BURR HOLE W/O NJX','61020','1','','1','0','','','',0, 1, 0, 0),
(5246,'VENTRICULAR PUNCTURE PREVIOUS BURR HOLE W/INJ','VENTRICULAR PUNCTURE PREVIOUS BURR HOLE W/INJ','61026','1','','1','0','','','',0, 1, 0, 0),
(5247,'CISTERNAL/LATERAL C1-C2 PUNCTURE W/O INJ SPX','CISTERNAL/LATERAL C1-C2 PUNCTURE W/O INJ SPX','61050','1','','1','0','','','',0, 1, 0, 0),
(5248,'CISTERNAL/LATERAL C1-C2 PUNCTURE W/INJECTION','CISTERNAL/LATERAL C1-C2 PUNCTURE W/INJECTION','61055','1','','1','0','','','',0, 1, 0, 0),
(5249,'PUNCTURE SHUNT TUBE/RESERVOIR ASPIRATION/INJ PX','PUNCTURE SHUNT TUBE/RESERVOIR ASPIRATION/INJ PX','61070','1','','1','0','','','',0, 1, 0, 0),
(5250,'TWIST DRILL HOLE SUBDURAL/VENTRICULAR PUNCTURE','TWIST DRILL HOLE SUBDURAL/VENTRICULAR PUNCTURE','61105','1','','1','0','','','',0, 1, 0, 0),
(5251,'TWIST DRILL HOLE IMPLT VENTRICULAR CATH/DEVICE','TWIST DRILL HOLE IMPLT VENTRICULAR CATH/DEVICE','61107','1','','1','0','','','',0, 1, 0, 0),
(5252,'TWIST DRILL HOLE EVAC&/DRG SUBDURAL HEMATOMA','TWIST DRILL HOLE EVAC&/DRG SUBDURAL HEMATOMA','61108','1','','1','0','','','',0, 1, 0, 0),
(5253,'BURR HOLE VENTRICULAR PUNCTURE','BURR HOLE VENTRICULAR PUNCTURE','61120','1','','1','0','','','',0, 1, 0, 0),
(5254,'BURR HOLE/TREPHINE W/BX BRAIN/INTRACRNIAL LESION','BURR HOLE/TREPHINE W/BX BRAIN/INTRACRNIAL LESION','61140','1','','1','0','','','',0, 1, 0, 0),
(5255,'BURR HOLE/TREPHINE W/DRG BRAIN ABSCESS/CYST','BURR HOLE/TREPHINE W/DRG BRAIN ABSCESS/CYST','61150','1','','1','0','','','',0, 1, 0, 0),
(5256,'BURR HOLE/TREPHINE W/SBSQ TAPPING ICRA ABSC/CST','BURR HOLE/TREPHINE W/SBSQ TAPPING ICRA ABSC/CST','61151','1','','1','0','','','',0, 1, 0, 0),
(5257,'BURR HOLE W/EVAC&/DRG HEMATOMA XDRL/SDRL','BURR HOLE W/EVAC&/DRG HEMATOMA XDRL/SDRL','61154','1','','1','0','','','',0, 1, 0, 0),
(5258,'BURR HOLE W/ASPIR HEMATOMA/CYST INTRACEREBRAL','BURR HOLE W/ASPIR HEMATOMA/CYST INTRACEREBRAL','61156','1','','1','0','','','',0, 1, 0, 0),
(5259,'BURR HOLE IMPLANT VENTRICULAR CATH/OTHER DEVICE','BURR HOLE IMPLANT VENTRICULAR CATH/OTHER DEVICE','61210','1','','1','0','','','',0, 1, 0, 0),
(5260,'INSJ SUBQ RSVR PUMP/INFUSION SYSTEM VENTRIC CATH','INSJ SUBQ RSVR PUMP/INFUSION SYSTEM VENTRIC CATH','61215','1','','1','0','','','',0, 1, 0, 0),
(5261,'BURR HOLE/TREPHINE SUPRATENTORIAL W/O OTH SURG','BURR HOLE/TREPHINE SUPRATENTORIAL W/O OTH SURG','61250','1','','1','0','','','',0, 1, 0, 0),
(5262,'BURR HOLE/TREPHINE INFRATENTORIAL UNI/BI','BURR HOLE/TREPHINE INFRATENTORIAL UNI/BI','61253','1','','1','0','','','',0, 1, 0, 0),
(5263,'CRANIECTOMY/CRANIOTOMY EXPL SUPRATENTORIAL','CRANIECTOMY/CRANIOTOMY EXPL SUPRATENTORIAL','61304','1','','1','0','','','',0, 1, 0, 0),
(5264,'CRANIECTOMY/CRANIOTOMY EXPL INFRATENTORIAL','CRANIECTOMY/CRANIOTOMY EXPL INFRATENTORIAL','61305','1','','1','0','','','',0, 1, 0, 0),
(5265,'CRANIECTOMY HMTMA SUPRATENTORIAL EXTRA/SUBDURAL','CRANIECTOMY HMTMA SUPRATENTORIAL EXTRA/SUBDURAL','61312','1','','1','0','','','',0, 1, 0, 0),
(5266,'CRANIECTOMY HMTMA SUPRATENTORIAL INTRACEREBRAL','CRANIECTOMY HMTMA SUPRATENTORIAL INTRACEREBRAL','61313','1','','1','0','','','',0, 1, 0, 0),
(5267,'CRANIECTOMY HMTMA INFRATENTORIAL EXTRA/SUBDURAL','CRANIECTOMY HMTMA INFRATENTORIAL EXTRA/SUBDURAL','61314','1','','1','0','','','',0, 1, 0, 0),
(5268,'CRANIECTOMY HMTMA SUPRATENTORIAL INTRACEREBRAL','CRANIECTOMY HMTMA SUPRATENTORIAL INTRACEREBRAL','61315','1','','1','0','','','',0, 1, 0, 0),
(5269,'INCISION & SUBCUTANEOUS PLMT CRANIAL BONE GRAF','INCISION & SUBCUTANEOUS PLMT CRANIAL BONE GRAF','61316','1','','1','0','','','',0, 1, 0, 0),
(5270,'CRANIECTOMY/CRANIOTMY DRG ABSCESS SUPRATENTORIAL','CRANIECTOMY/CRANIOTMY DRG ABSCESS SUPRATENTORIAL','61320','1','','1','0','','','',0, 1, 0, 0),
(5271,'CRANIECTOMY/CRANIOTMY DRG ABSCESS INFRATENTORIAL','CRANIECTOMY/CRANIOTMY DRG ABSCESS INFRATENTORIAL','61321','1','','1','0','','','',0, 1, 0, 0),
(5272,'CRANIECT/CRANIOT W/WO DURAPLASTY W/O LOBECTOMY','CRANIECT/CRANIOT W/WO DURAPLASTY W/O LOBECTOMY','61322','1','','1','0','','','',0, 1, 0, 0),
(5273,'CRANIECT/CRANIOT W/WO DURAPLASTY W/LOBECTOMY','CRANIECT/CRANIOT W/WO DURAPLASTY W/LOBECTOMY','61323','1','','1','0','','','',0, 1, 0, 0),
(5274,'DECOMPRESSION ORBIT ONLY TRANSCRANIAL APPROACH','DECOMPRESSION ORBIT ONLY TRANSCRANIAL APPROACH','61330','1','','1','0','','','',0, 1, 0, 0),
(5275,'EXPLORATION ORBIT TRANSCRANIAL APPROACH W/BIOPSY','EXPLORATION ORBIT TRANSCRANIAL APPROACH W/BIOPSY','61332','1','','1','0','','','',0, 1, 0, 0),
(5276,'EXPL ORBIT TRANSCRANIAL APPROACH W/RMVL LESION','EXPL ORBIT TRANSCRANIAL APPROACH W/RMVL LESION','61333','1','','1','0','','','',0, 1, 0, 0),
(5277,'SUBTEMPORAL CRANIAL DECOMPRESSION','SUBTEMPORAL CRANIAL DECOMPRESSION','61340','1','','1','0','','','',0, 1, 0, 0),
(5278,'CRNEC SUBOCCIPITAL CRV LAM DCMPRN MEDULLA & CORD','CRNEC SUBOCCIPITAL CRV LAM DCMPRN MEDULLA & CORD','61343','1','','1','0','','','',0, 1, 0, 0),
(5279,'OTHER CRANIAL DECOMPRESSION POSTERIOR FOSSA','OTHER CRANIAL DECOMPRESSION POSTERIOR FOSSA','61345','1','','1','0','','','',0, 1, 0, 0),
(5280,'CRNEC STPL SCTJ COMPRESSION/DCMPRN GANGLION','CRNEC STPL SCTJ COMPRESSION/DCMPRN GANGLION','61450','1','','1','0','','','',0, 1, 0, 0),
(5281,'CRNEC SOPL EXPL/DCMPRN CRNL NRV','CRNEC SOPL EXPL/DCMPRN CRNL NRV','61458','1','','1','0','','','',0, 1, 0, 0),
(5282,'CRANIECTOMY SUBOCCIPITAL SECTION 1/> CRANIAL NR','CRANIECTOMY SUBOCCIPITAL SECTION 1/> CRANIAL NR','61460','1','','1','0','','','',0, 1, 0, 0),
(5283,'CRNEC SUBOCPTL MESENCEPHAL TRCOTOMY/PEDUNCULOTMY','CRNEC SUBOCPTL MESENCEPHAL TRCOTOMY/PEDUNCULOTMY','61480','1','','1','0','','','',0, 1, 0, 0),
(5284,'CRANIECTOMY W/EXCISION TUMOR/LESION SKULL','CRANIECTOMY W/EXCISION TUMOR/LESION SKULL','61500','1','','1','0','','','',0, 1, 0, 0),
(5285,'CRANIECTOMY OSTEOMYELITIS','CRANIECTOMY OSTEOMYELITIS','61501','1','','1','0','','','',0, 1, 0, 0),
(5286,'CRANIEC TREPHINE BONE FLP BRAIN TUMOR SUPRTENTOR','CRANIEC TREPHINE BONE FLP BRAIN TUMOR SUPRTENTOR','61510','1','','1','0','','','',0, 1, 0, 0),
(5287,'CRNEC TREPHINE BONE FLAP MENINGIOMA SUPRATENTOR','CRNEC TREPHINE BONE FLAP MENINGIOMA SUPRATENTOR','61512','1','','1','0','','','',0, 1, 0, 0),
(5288,'CRNEC TREPHINE BONE FLAP BRAIN ABSC SUPRATENTOR','CRNEC TREPHINE BONE FLAP BRAIN ABSC SUPRATENTOR','61514','1','','1','0','','','',0, 1, 0, 0),
(5289,'CRNEC TREPHINE BONE FLAP FENEST CYST SUPRATENTOR','CRNEC TREPHINE BONE FLAP FENEST CYST SUPRATENTOR','61516','1','','1','0','','','',0, 1, 0, 0),
(5290,'IMPLTJ BRAIN INTRACAVITARY CHEMOTHERAPY AGENT','IMPLTJ BRAIN INTRACAVITARY CHEMOTHERAPY AGENT','61517','1','','1','0','','','',0, 1, 0, 0),
(5291,'CRNEC EXC BRAIN TUMOR INFRATENTORIAL/POST FOSSA','CRNEC EXC BRAIN TUMOR INFRATENTORIAL/POST FOSSA','61518','1','','1','0','','','',0, 1, 0, 0),
(5292,'CRNEC EXC TUM INFRATENTOR/POST FOSSA MENINGIOMA','CRNEC EXC TUM INFRATENTOR/POST FOSSA MENINGIOMA','61519','1','','1','0','','','',0, 1, 0, 0),
(5293,'CRNEC TUM INFRATTL/POSTFOSSA CRBLOPNT ANGLE TUM','CRNEC TUM INFRATTL/POSTFOSSA CRBLOPNT ANGLE TUM','61520','1','','1','0','','','',0, 1, 0, 0),
(5294,'CRNEC TUM INFRATTL/PFOSSA MIDLINE TUM BASE SKULL','CRNEC TUM INFRATTL/PFOSSA MIDLINE TUM BASE SKULL','61521','1','','1','0','','','',0, 1, 0, 0),
(5295,'CRNEC INFRATNTORIAL/POST FOSSA EXC BRAIN ABSCESS','CRNEC INFRATNTORIAL/POST FOSSA EXC BRAIN ABSCESS','61522','1','','1','0','','','',0, 1, 0, 0),
(5296,'CRNEC INFRATNTOR/POSTFOSSA EXC/FENESTRATION CYST','CRNEC INFRATNTOR/POSTFOSSA EXC/FENESTRATION CYST','61524','1','','1','0','','','',0, 1, 0, 0),
(5297,'CRNEC TRANSTEMPOR EXC CEREBELLOPONTINE ANGLE TUM','CRNEC TRANSTEMPOR EXC CEREBELLOPONTINE ANGLE TUM','61526','1','','1','0','','','',0, 1, 0, 0),
(5298,'CRNEC EXC CEREBELLOPNTIN ANGLE TUM MID/POSTFOSSA','CRNEC EXC CEREBELLOPNTIN ANGLE TUM MID/POSTFOSSA','61530','1','','1','0','','','',0, 1, 0, 0),
(5299,'SUBDURAL IMPLTJ ELECTRODES SEIZURE MONITORING','SUBDURAL IMPLTJ ELECTRODES SEIZURE MONITORING','61531','1','','1','0','','','',0, 1, 0, 0),
(5300,'CRANIOT SUBDURAL IMPLT ELCTRD SEIZURE MONITORING','CRANIOT SUBDURAL IMPLT ELCTRD SEIZURE MONITORING','61533','1','','1','0','','','',0, 1, 0, 0),
(5301,'CRANIOT EPILEPTOGENIC FOC W/O ELECTRCORTICOGRPHY','CRANIOT EPILEPTOGENIC FOC W/O ELECTRCORTICOGRPHY','61534','1','','1','0','','','',0, 1, 0, 0),
(5302,'CRANIOT RMVL EPID/SUBDURL ELCTRD W/O EXC TIS SPX','CRANIOT RMVL EPID/SUBDURL ELCTRD W/O EXC TIS SPX','61535','1','','1','0','','','',0, 1, 0, 0),
(5303,'CRANIOT EPILEPTOGENIC FOCUS W/ELECTROCORTCOGRPHY','CRANIOT EPILEPTOGENIC FOCUS W/ELECTROCORTCOGRPHY','61536','1','','1','0','','','',0, 1, 0, 0),
(5304,'CRANIOT TEMPORAL LOBE W/O ELECTROCORTICOGRAPHY','CRANIOT TEMPORAL LOBE W/O ELECTROCORTICOGRAPHY','61537','1','','1','0','','','',0, 1, 0, 0),
(5305,'CRANIOT LOBEC TEMPORAL LOBE W/ELECTROCORTCOGRPHY','CRANIOT LOBEC TEMPORAL LOBE W/ELECTROCORTCOGRPHY','61538','1','','1','0','','','',0, 1, 0, 0),
(5306,'CRANIOT LOBECTOMY OTH/THN TEMPORAL LOBE W/ECOG','CRANIOT LOBECTOMY OTH/THN TEMPORAL LOBE W/ECOG','61539','1','','1','0','','','',0, 1, 0, 0),
(5307,'CRANIOT LOBECTOMY OTH/THN TEMPORAL LOBE W/O ECOG','CRANIOT LOBECTOMY OTH/THN TEMPORAL LOBE W/O ECOG','61540','1','','1','0','','','',0, 1, 0, 0),
(5308,'CRANIOTOMY TRANSECTION CORPUS CALLOSUM','CRANIOTOMY TRANSECTION CORPUS CALLOSUM','61541','1','','1','0','','','',0, 1, 0, 0),
(5309,'CRANIOTOMY PARTIAL/SUBTOTAL HEMISPHERECTOMY','CRANIOTOMY PARTIAL/SUBTOTAL HEMISPHERECTOMY','61543','1','','1','0','','','',0, 1, 0, 0),
(5310,'CRANIOTOMY EXCISION/COAGULATION CHOROID PLEXUS','CRANIOTOMY EXCISION/COAGULATION CHOROID PLEXUS','61544','1','','1','0','','','',0, 1, 0, 0),
(5311,'CRANIOTOMY EXCISION CRANIOPHARYNGIOMA','CRANIOTOMY EXCISION CRANIOPHARYNGIOMA','61545','1','','1','0','','','',0, 1, 0, 0),
(5312,'CRANIOT HYPOPHYSEC/EXC PITUITARY TUMOR ICRL APPR','CRANIOT HYPOPHYSEC/EXC PITUITARY TUMOR ICRL APPR','61546','1','','1','0','','','',0, 1, 0, 0),
(5313,'HYPOPHYSEC/EXC PITUITARY TUM TRANSNASAL/SEPTAL','HYPOPHYSEC/EXC PITUITARY TUM TRANSNASAL/SEPTAL','61548','1','','1','0','','','',0, 1, 0, 0),
(5314,'CRANIECTOMY CRANIOSYNOSTOSIS 1 CRANIAL SUTURE','CRANIECTOMY CRANIOSYNOSTOSIS 1 CRANIAL SUTURE','61550','1','','1','0','','','',0, 1, 0, 0),
(5315,'CRANIECT CRANIOSYNOSTOSIS MULT CRANIAL SUTURES','CRANIECT CRANIOSYNOSTOSIS MULT CRANIAL SUTURES','61552','1','','1','0','','','',0, 1, 0, 0),
(5316,'CRANIEC CRANIOSYNOSTOSIS FRONT/PARIET BONE FLAP','CRANIEC CRANIOSYNOSTOSIS FRONT/PARIET BONE FLAP','61556','1','','1','0','','','',0, 1, 0, 0),
(5317,'CRANIECTOMY CRANIOSYNOSTOSIS BIFRONTAL BONE FLAP','CRANIECTOMY CRANIOSYNOSTOSIS BIFRONTAL BONE FLAP','61557','1','','1','0','','','',0, 1, 0, 0),
(5318,'XTN CRANIECT MULTIPLE SUTURE CRANIOSYNOSTOSIS','XTN CRANIECT MULTIPLE SUTURE CRANIOSYNOSTOSIS','61558','1','','1','0','','','',0, 1, 0, 0),
(5319,'XTN CRNEC MLT SUTR CRANIOSYNOSTOSIS W/BONE GRAFT','XTN CRNEC MLT SUTR CRANIOSYNOSTOSIS W/BONE GRAFT','61559','1','','1','0','','','',0, 1, 0, 0),
(5320,'EXC BENIGN TUM CRANIAL BONE W/O OPTIC NRV DCMPRN','EXC BENIGN TUM CRANIAL BONE W/O OPTIC NRV DCMPRN','61563','1','','1','0','','','',0, 1, 0, 0),
(5321,'EXC BENIGN TUM CRANIAL BONE W/OPTIC NRV DCMPRN','EXC BENIGN TUM CRANIAL BONE W/OPTIC NRV DCMPRN','61564','1','','1','0','','','',0, 1, 0, 0),
(5322,'CRANIOTOMY SELECTIVE AMYGDALOHIPPOCAMPECTOMY','CRANIOTOMY SELECTIVE AMYGDALOHIPPOCAMPECTOMY','61566','1','','1','0','','','',0, 1, 0, 0),
(5323,'CRANIOTOMY MULTIPLE SUBPIAL TRANSECTIONS W/ECOG','CRANIOTOMY MULTIPLE SUBPIAL TRANSECTIONS W/ECOG','61567','1','','1','0','','','',0, 1, 0, 0),
(5324,'CRANIECTOMY/CRANIOTOMY EXC FOREIGN BODY BRAIN','CRANIECTOMY/CRANIOTOMY EXC FOREIGN BODY BRAIN','61570','1','','1','0','','','',0, 1, 0, 0),
(5325,'CRANIECTOMY/CRANIOTOMY TX PENETRATNG WOUND BRAIN','CRANIECTOMY/CRANIOTOMY TX PENETRATNG WOUND BRAIN','61571','1','','1','0','','','',0, 1, 0, 0),
(5326,'TRNSRAL SKULL BSE/BR STEM/CORD BX/DCOMPR/EXC LES','TRNSRAL SKULL BSE/BR STEM/CORD BX/DCOMPR/EXC LES','61575','1','','1','0','','','',0, 1, 0, 0),
(5327,'TRNSRL SKUL BSE/BR STM/CORD BX/DCMP/ SPLT TONGUE','TRNSRL SKUL BSE/BR STM/CORD BX/DCMP/ SPLT TONGUE','61576','1','','1','0','','','',0, 1, 0, 0),
(5328,'CRANIOFACIAL ANT CRANIAL FOSSA W/O ORBITAL EXNTJ','CRANIOFACIAL ANT CRANIAL FOSSA W/O ORBITAL EXNTJ','61580','1','','1','0','','','',0, 1, 0, 0),
(5329,'CRANIOFACIAL ANT CRANIAL FOSSA W/ORBITAL EXNTJ','CRANIOFACIAL ANT CRANIAL FOSSA W/ORBITAL EXNTJ','61581','1','','1','0','','','',0, 1, 0, 0),
(5330,'CRANFCL ANT CRANIAL FOSSA UNI/BI CRANIOT/OSTEOT','CRANFCL ANT CRANIAL FOSSA UNI/BI CRANIOT/OSTEOT','61582','1','','1','0','','','',0, 1, 0, 0),
(5331,'CRANFCL ANT CRANIAL FOSSA UNI/BIFRNTL ELEV LOBE','CRANFCL ANT CRANIAL FOSSA UNI/BIFRNTL ELEV LOBE','61583','1','','1','0','','','',0, 1, 0, 0),
(5332,'ORBITOCRANIAL ANT CRANIAL FOSSA W/O ORBIT EXNTJ','ORBITOCRANIAL ANT CRANIAL FOSSA W/O ORBIT EXNTJ','61584','1','','1','0','','','',0, 1, 0, 0),
(5333,'ORBITOCRANIAL ANT CRANIAL FOSSA W/ORBITAL EXNTJ','ORBITOCRANIAL ANT CRANIAL FOSSA W/ORBITAL EXNTJ','61585','1','','1','0','','','',0, 1, 0, 0),
(5334,'BICORONAL TRANSZYGMTC&/LEFORT I W/O BONE GRFT','BICORONAL TRANSZYGMTC&/LEFORT I W/O BONE GRFT','61586','1','','1','0','','','',0, 1, 0, 0),
(5335,'INFRATEMPORAL MID CRANIAL FOSSA W/WO DISARTICLTN','INFRATEMPORAL MID CRANIAL FOSSA W/WO DISARTICLTN','61590','1','','1','0','','','',0, 1, 0, 0),
(5336,'INFRATEMPO MID CRANIAL FOSSA W/WO DCOMPR&/MOBI','INFRATEMPO MID CRANIAL FOSSA W/WO DCOMPR&/MOBI','61591','1','','1','0','','','',0, 1, 0, 0),
(5337,'ORBITOCRNL APPR MID CRANIAL FOSSA TEMPORAL LOBE','ORBITOCRNL APPR MID CRANIAL FOSSA TEMPORAL LOBE','61592','1','','1','0','','','',0, 1, 0, 0),
(5338,'TRANSTEMP APPR POST CRAN FOSSA DCOMPR SINUS/NRV','TRANSTEMP APPR POST CRAN FOSSA DCOMPR SINUS/NRV','61595','1','','1','0','','','',0, 1, 0, 0),
(5339,'TRANSCOCHLR POST CRNL FOSSA W/WO MOBIL NRV/ART','TRANSCOCHLR POST CRNL FOSSA W/WO MOBIL NRV/ART','61596','1','','1','0','','','',0, 1, 0, 0),
(5340,'TRNSCONDLR POST CRNL FOSSA DCOMPR ART W/WO MOBIL','TRNSCONDLR POST CRNL FOSSA DCOMPR ART W/WO MOBIL','61597','1','','1','0','','','',0, 1, 0, 0),
(5341,'TRANSPTRSAL POST CRNL FOSSA CLIVUS/FORAMN MAGNUM','TRANSPTRSAL POST CRNL FOSSA CLIVUS/FORAMN MAGNUM','61598','1','','1','0','','','',0, 1, 0, 0),
(5342,'RESCJ/EXC LES BASE ANT CRANIAL FOSSA EXTRADURAL','RESCJ/EXC LES BASE ANT CRANIAL FOSSA EXTRADURAL','61600','1','','1','0','','','',0, 1, 0, 0),
(5343,'RESCJ/EXC LES BASE ANT CRNL FOSSA INDRL W/WO GRF','RESCJ/EXC LES BASE ANT CRNL FOSSA INDRL W/WO GRF','61601','1','','1','0','','','',0, 1, 0, 0),
(5344,'RESCJ/EXC LES INFRATEMPOR FOSSA SPACE APEX XDRL','RESCJ/EXC LES INFRATEMPOR FOSSA SPACE APEX XDRL','61605','1','','1','0','','','',0, 1, 0, 0),
(5345,'RESCJ/EXC LES ITPRL FOSSA SPACE APEX IDRL W/RPR','RESCJ/EXC LES ITPRL FOSSA SPACE APEX IDRL W/RPR','61606','1','','1','0','','','',0, 1, 0, 0),
(5346,'RESCJ/EXC LES PARASELLAR SINUS CLIVUS/MSB XDRL','RESCJ/EXC LES PARASELLAR SINUS CLIVUS/MSB XDRL','61607','1','','1','0','','','',0, 1, 0, 0),
(5347,'RESCJ/EXC LES PARASELLAR SINUS CLIVUS/MSB IDRL','RESCJ/EXC LES PARASELLAR SINUS CLIVUS/MSB IDRL','61608','1','','1','0','','','',0, 1, 0, 0),
(5348,'TRNSXJ/LIG CAROTID ARTERY SINUS W/RPR ANAST/GRFT','TRNSXJ/LIG CAROTID ARTERY SINUS W/RPR ANAST/GRFT','61610','1','','1','0','','','',0, 1, 0, 0),
(5349,'TRNSXJ/LIG CAROTID ARTERY PETROUS CANAL W/O RPR','TRNSXJ/LIG CAROTID ARTERY PETROUS CANAL W/O RPR','61611','1','','1','0','','','',0, 1, 0, 0),
(5350,'TRNSXJ/LIG CRTD ART PETROUS CANAL RPR ANAST/GRF','TRNSXJ/LIG CRTD ART PETROUS CANAL RPR ANAST/GRF','61612','1','','1','0','','','',0, 1, 0, 0),
(5351,'OBLTRJ CAROTID ARYSM ARTVEN CAROTID FISTULA DSJ','OBLTRJ CAROTID ARYSM ARTVEN CAROTID FISTULA DSJ','61613','1','','1','0','','','',0, 1, 0, 0),
(5352,'RESCJ/EXC LES BASE POST CRNL FOSSA JUG FRMN XDRL','RESCJ/EXC LES BASE POST CRNL FOSSA JUG FRMN XDRL','61615','1','','1','0','','','',0, 1, 0, 0),
(5353,'RESCJ/EXC LES BASE PCF FORAMEN VRT BODIES IDRL','RESCJ/EXC LES BASE PCF FORAMEN VRT BODIES IDRL','61616','1','','1','0','','','',0, 1, 0, 0),
(5354,'SECONDARY RPR DURA CSF LEAK FREE TISSUE GRAFT','SECONDARY RPR DURA CSF LEAK FREE TISSUE GRAFT','61618','1','','1','0','','','',0, 1, 0, 0),
(5355,'SEC RPR DURA CSF LEAK LOCAL/REGIONALIZED FLAP','SEC RPR DURA CSF LEAK LOCAL/REGIONALIZED FLAP','61619','1','','1','0','','','',0, 1, 0, 0),
(5356,'EVASC TEMP BALLOON ARTL OCCLUSION HEAD/NECK','EVASC TEMP BALLOON ARTL OCCLUSION HEAD/NECK','61623','1','','1','0','','','',0, 1, 0, 0),
(5357,'TCAT PERMANENT OCCLUSION/EMBOLIZATION PRQ CNS','TCAT PERMANENT OCCLUSION/EMBOLIZATION PRQ CNS','61624','1','','1','0','','','',0, 1, 0, 0),
(5358,'TCAT PERMANT OCCLUSION/EMBOLIZATION PRQ NON-CNS','TCAT PERMANT OCCLUSION/EMBOLIZATION PRQ NON-CNS','61626','1','','1','0','','','',0, 1, 0, 0),
(5359,'BALLOON ANGIOPLASTY INTRACRANIAL PERCUTANEOUS','BALLOON ANGIOPLASTY INTRACRANIAL PERCUTANEOUS','61630','1','','1','0','','','',0, 1, 0, 0),
(5360,'TCAT PLMT IV STENT ICRA W/BALO ANGIOP IF PFRMD','TCAT PLMT IV STENT ICRA W/BALO ANGIOP IF PFRMD','61635','1','','1','0','','','',0, 1, 0, 0),
(5361,'BALLOON DILAT INTRACRANIAL VASOSPASM PRQ INITIAL','BALLOON DILAT INTRACRANIAL VASOSPASM PRQ INITIAL','61640','1','','1','0','','','',0, 1, 0, 0),
(5362,'BALLOON DILAT INCRNL VASOSPSM PRQ EA VESSEL','BALLOON DILAT INCRNL VASOSPSM PRQ EA VESSEL','61641','1','','1','0','','','',0, 1, 0, 0),
(5363,'BALLOON DILAT INCRNL VASOSPSM PRQ EA VESSEL','BALLOON DILAT INCRNL VASOSPSM PRQ EA VESSEL','61642','1','','1','0','','','',0, 1, 0, 0),
(5364,'PERQ ART TRLUML M-THROMBEC &/NFS INTRACRANIAL','PERQ ART TRLUML M-THROMBEC &/NFS INTRACRANIAL','61645','1','','1','0','','','',0, 1, 0, 0),
(5365,'EVASC INTRACRANIAL PROLNG ADMN RX AGENT ART 1ST','EVASC INTRACRANIAL PROLNG ADMN RX AGENT ART 1ST','61650','1','','1','0','','','',0, 1, 0, 0),
(5366,'EVASC INTRACRANIAL PROLNG ADMN RX AGENT ART ADDL','EVASC INTRACRANIAL PROLNG ADMN RX AGENT ART ADDL','61651','1','','1','0','','','',0, 1, 0, 0),
(5367,'INTRACRANIAL ARVEN MALFRMJ SUPRATENTRL SMPL','INTRACRANIAL ARVEN MALFRMJ SUPRATENTRL SMPL','61680','1','','1','0','','','',0, 1, 0, 0),
(5368,'INTRACRANIAL ARVEN MALFRMJ SUPRATENTRL CMPL','INTRACRANIAL ARVEN MALFRMJ SUPRATENTRL CMPL','61682','1','','1','0','','','',0, 1, 0, 0),
(5369,'INTRACRANIAL ARVEN MALFRMJ INFRATENTRL SMPL','INTRACRANIAL ARVEN MALFRMJ INFRATENTRL SMPL','61684','1','','1','0','','','',0, 1, 0, 0),
(5370,'INTRACRANIAL ARVEN MALFRMJ INFRATENTRL CMPL','INTRACRANIAL ARVEN MALFRMJ INFRATENTRL CMPL','61686','1','','1','0','','','',0, 1, 0, 0),
(5371,'INTRACRANIAL ARVEN MALFRMJ DURAL SMPL','INTRACRANIAL ARVEN MALFRMJ DURAL SMPL','61690','1','','1','0','','','',0, 1, 0, 0),
(5372,'INTRACRANIAL ARVEN MALFRMJ DURAL CMPL','INTRACRANIAL ARVEN MALFRMJ DURAL CMPL','61692','1','','1','0','','','',0, 1, 0, 0),
(5373,'COMPLX INTRACRANIAL ARYSM CAROTID CIRCULATION','COMPLX INTRACRANIAL ARYSM CAROTID CIRCULATION','61697','1','','1','0','','','',0, 1, 0, 0),
(5374,'CPLX INTRACRANIAL ARYSM VERTEBROBASILAR CRCJ','CPLX INTRACRANIAL ARYSM VERTEBROBASILAR CRCJ','61698','1','','1','0','','','',0, 1, 0, 0),
(5375,'SIMPLE INTRACRANIAL ARYSM CAROTID CIRCULATION','SIMPLE INTRACRANIAL ARYSM CAROTID CIRCULATION','61700','1','','1','0','','','',0, 1, 0, 0),
(5376,'SIMPLE INTRACRANIAL ARYSM VERTEBROBASILAR CRCJ','SIMPLE INTRACRANIAL ARYSM VERTEBROBASILAR CRCJ','61702','1','','1','0','','','',0, 1, 0, 0),
(5377,'ICRA CRV APPL OCCLUDING CLAMP CRV CRTD ART','ICRA CRV APPL OCCLUDING CLAMP CRV CRTD ART','61703','1','','1','0','','','',0, 1, 0, 0),
(5378,'ARYSM VASC MALFRMJ/CRTD-OCCLUSION CRTD ART','ARYSM VASC MALFRMJ/CRTD-OCCLUSION CRTD ART','61705','1','','1','0','','','',0, 1, 0, 0),
(5379,'ARYSM VASC MALFRMJ/ICRA ELECTROTHROMBOSIS','ARYSM VASC MALFRMJ/ICRA ELECTROTHROMBOSIS','61708','1','','1','0','','','',0, 1, 0, 0),
(5380,'ARYSM VASC MALFRMJ IA EMBOLIZATION','ARYSM VASC MALFRMJ IA EMBOLIZATION','61710','1','','1','0','','','',0, 1, 0, 0),
(5381,'ANAST ARTL EXTRACRANIAL-INTRACRANIAL ARTERIES','ANAST ARTL EXTRACRANIAL-INTRACRANIAL ARTERIES','61711','1','','1','0','','','',0, 1, 0, 0),
(5382,'CRTJ LES STRTCTC BURR GLOBUS PALLIDUS/THALAMUS','CRTJ LES STRTCTC BURR GLOBUS PALLIDUS/THALAMUS','61720','1','','1','0','','','',0, 1, 0, 0),
(5383,'CRTJ LES STRTCTC BURR SUBCORTICAL STRUX OTH/THN','CRTJ LES STRTCTC BURR SUBCORTICAL STRUX OTH/THN','61735','1','','1','0','','','',0, 1, 0, 0),
(5384,'STEREOTACTIC BX ASPIR/EXC BURR INTRACRANIAL LES','STEREOTACTIC BX ASPIR/EXC BURR INTRACRANIAL LES','61750','1','','1','0','','','',0, 1, 0, 0),
(5385,'STRTCTC BX ASPIR/EXC BURR ICRA LESION W/CT&I/MR','STRTCTC BX ASPIR/EXC BURR ICRA LESION W/CT&I/MR','61751','1','','1','0','','','',0, 1, 0, 0),
(5386,'STRTCTC IMPLTJ ELTRD CEREBRUM SEIZURE MONITORING','STRTCTC IMPLTJ ELTRD CEREBRUM SEIZURE MONITORING','61760','1','','1','0','','','',0, 1, 0, 0),
(5387,'STRTCTC LOCLZJ INSJ CATH/PRB PLMT RADJ SRC','STRTCTC LOCLZJ INSJ CATH/PRB PLMT RADJ SRC','61770','1','','1','0','','','',0, 1, 0, 0),
(5388,'STRTCTC CPTR ASSTD PX CRANIAL INTRADURAL','STRTCTC CPTR ASSTD PX CRANIAL INTRADURAL','61781','1','','1','0','','','',0, 1, 0, 0),
(5389,'STRTCTC CPTR ASSTD PX EXTRADURAL CRANIAL','STRTCTC CPTR ASSTD PX EXTRADURAL CRANIAL','61782','1','','1','0','','','',0, 1, 0, 0),
(5390,'STEREOTACTIC COMPUTER ASSISTED PX SPINAL','STEREOTACTIC COMPUTER ASSISTED PX SPINAL','61783','1','','1','0','','','',0, 1, 0, 0),
(5391,'CREATE LESION STRTCTC PRQ NEUROLYTIC GASSERIAN','CREATE LESION STRTCTC PRQ NEUROLYTIC GASSERIAN','61790','1','','1','0','','','',0, 1, 0, 0),
(5392,'CREATE LES STRTCTC PRQ NEUROLYTIC TRIGEMINAL TRC','CREATE LES STRTCTC PRQ NEUROLYTIC TRIGEMINAL TRC','61791','1','','1','0','','','',0, 1, 0, 0),
(5393,'STEREOTACTIC RADIOSURGERY 1 SIMPLE CRANIAL LES','STEREOTACTIC RADIOSURGERY 1 SIMPLE CRANIAL LES','61796','1','','1','0','','','',0, 1, 0, 0),
(5394,'STRTCTC RADIOSURGERY EA ADDL CRANIAL LES SIMPLE','STRTCTC RADIOSURGERY EA ADDL CRANIAL LES SIMPLE','61797','1','','1','0','','','',0, 1, 0, 0),
(5395,'STEREOTACTIC RADIOSURGERY 1 COMPLEX CRANIAL LES','STEREOTACTIC RADIOSURGERY 1 COMPLEX CRANIAL LES','61798','1','','1','0','','','',0, 1, 0, 0),
(5396,'STRTCTC RADIOSURGERY EA ADDL CRANIAL LES COMPLEX','STRTCTC RADIOSURGERY EA ADDL CRANIAL LES COMPLEX','61799','1','','1','0','','','',0, 1, 0, 0),
(5397,'APPL STRTCTC HEADFRAME STEREOTACTIC RADIOSURGERY','APPL STRTCTC HEADFRAME STEREOTACTIC RADIOSURGERY','61800','1','','1','0','','','',0, 1, 0, 0),
(5398,'TWIST/BURR HOLE IMPLTJ NSTIM ELTRD CORTICAL','TWIST/BURR HOLE IMPLTJ NSTIM ELTRD CORTICAL','61850','1','','1','0','','','',0, 1, 0, 0),
(5399,'CRNEC/CRX IMPLTJ NSTIM ELTRD CERE CORTICAL','CRNEC/CRX IMPLTJ NSTIM ELTRD CERE CORTICAL','61860','1','','1','0','','','',0, 1, 0, 0),
(5400,'STRTCTC IMPLTJ NSTIM ELTRD W/O RECORD 1ST ARRAY','STRTCTC IMPLTJ NSTIM ELTRD W/O RECORD 1ST ARRAY','61863','1','','1','0','','','',0, 1, 0, 0),
(5401,'STRTCTC IMPLTJ NSTIM ELTRD W/O RECORD EA ARRAY','STRTCTC IMPLTJ NSTIM ELTRD W/O RECORD EA ARRAY','61864','1','','1','0','','','',0, 1, 0, 0),
(5402,'STRTCTC IMPLTJ NSTIM ELTRD W/RECORD 1ST ARRAY','STRTCTC IMPLTJ NSTIM ELTRD W/RECORD 1ST ARRAY','61867','1','','1','0','','','',0, 1, 0, 0),
(5403,'STRTCTC IMPLTJ NSTIM ELTRD W/RECORD EA ARRAY','STRTCTC IMPLTJ NSTIM ELTRD W/RECORD EA ARRAY','61868','1','','1','0','','','',0, 1, 0, 0),
(5404,'CRNEC IMPLTJ NSTIM ELTRD CEREBELLAR CORTICAL','CRNEC IMPLTJ NSTIM ELTRD CEREBELLAR CORTICAL','61870','1','','1','0','','','',0, 1, 0, 0),
(5405,'REVJ/RMVL INTRACRANIAL NEUROSTIMULATOR ELTRDS','REVJ/RMVL INTRACRANIAL NEUROSTIMULATOR ELTRDS','61880','1','','1','0','','','',0, 1, 0, 0),
(5406,'INSJ/RPLCMT CRANIAL NEUROSTIM PULSE GENERATOR','INSJ/RPLCMT CRANIAL NEUROSTIM PULSE GENERATOR','61885','1','','1','0','','','',0, 1, 0, 0),
(5407,'INSJ/RPLCMT CRANIAL NEUROSTIM GENER 2/> ELTRDS','INSJ/RPLCMT CRANIAL NEUROSTIM GENER 2/> ELTRDS','61886','1','','1','0','','','',0, 1, 0, 0),
(5408,'REVJ/RMVL NEUROSTIMULATOR PULSE GENERATOR','REVJ/RMVL NEUROSTIMULATOR PULSE GENERATOR','61888','1','','1','0','','','',0, 1, 0, 0),
(5409,'ELEVATION DEPRESSED SKULL FX SIMPLE EXTRADURAL','ELEVATION DEPRESSED SKULL FX SIMPLE EXTRADURAL','62000','1','','1','0','','','',0, 1, 0, 0),
(5410,'ELVTN DEPRS SKL FX COMPOUND/COMMIND XDRL','ELVTN DEPRS SKL FX COMPOUND/COMMIND XDRL','62005','1','','1','0','','','',0, 1, 0, 0),
(5411,'ELVTN DEPRS SKL FX W/RPR DURA&/DBRDMT BRN','ELVTN DEPRS SKL FX W/RPR DURA&/DBRDMT BRN','62010','1','','1','0','','','',0, 1, 0, 0),
(5412,'CRX RPR DURAL/CSF LEAK RHINORRHEA/OTORRHEA','CRX RPR DURAL/CSF LEAK RHINORRHEA/OTORRHEA','62100','1','','1','0','','','',0, 1, 0, 0),
(5413,'RDCTJ CRANIOMEGALIC SKULL W/O GRAFT/CRANIOPLASTY','RDCTJ CRANIOMEGALIC SKULL W/O GRAFT/CRANIOPLASTY','62115','1','','1','0','','','',0, 1, 0, 0),
(5414,'RDCTJ CRANIOMEGALIC CRANIO&RECNSTJ W/WO GRAFT','RDCTJ CRANIOMEGALIC CRANIO&RECNSTJ W/WO GRAFT','62117','1','','1','0','','','',0, 1, 0, 0),
(5415,'RPR ENCEPHALOCELE SKULL VAULT W/CRANIOPLASTY','RPR ENCEPHALOCELE SKULL VAULT W/CRANIOPLASTY','62120','1','','1','0','','','',0, 1, 0, 0),
(5416,'CRANIOTOMY FOR ENCEPHALOCELE REPAIR SKULL BASE','CRANIOTOMY FOR ENCEPHALOCELE REPAIR SKULL BASE','62121','1','','1','0','','','',0, 1, 0, 0),
(5417,'CRANIOPLASTY SKULL DEFECT </5 CM DIAMETER','CRANIOPLASTY SKULL DEFECT </5 CM DIAMETER','62140','1','','1','0','','','',0, 1, 0, 0),
(5418,'CRANIOPLASTY SKULL DEFECT >5 CM DIAMETER','CRANIOPLASTY SKULL DEFECT >5 CM DIAMETER','62141','1','','1','0','','','',0, 1, 0, 0),
(5419,'RMVL BONE FLAP/PROSTHETIC PLATE SKULL','RMVL BONE FLAP/PROSTHETIC PLATE SKULL','62142','1','','1','0','','','',0, 1, 0, 0),
(5420,'RPLCMT BONE FLAP/PROSTHETIC PLATE SKULL','RPLCMT BONE FLAP/PROSTHETIC PLATE SKULL','62143','1','','1','0','','','',0, 1, 0, 0),
(5421,'CRANIOPLASTY SKULL DEFECT REPARATIVE BRAIN SURG','CRANIOPLASTY SKULL DEFECT REPARATIVE BRAIN SURG','62145','1','','1','0','','','',0, 1, 0, 0),
(5422,'CRANIOPLASTY W/AUTOGRAFT </ 5 CM DIAMETER','CRANIOPLASTY W/AUTOGRAFT </ 5 CM DIAMETER','62146','1','','1','0','','','',0, 1, 0, 0),
(5423,'CRANIOPLASTY W/AUTOGRAFT > 5 CM DIAMETER','CRANIOPLASTY W/AUTOGRAFT > 5 CM DIAMETER','62147','1','','1','0','','','',0, 1, 0, 0),
(5424,'INCISE&RETRIEVAL SUBQ CRANIOPLASTY BONE GRAFT','INCISE&RETRIEVAL SUBQ CRANIOPLASTY BONE GRAFT','62148','1','','1','0','','','',0, 1, 0, 0),
(5425,'NUNDSC ICRA PLMT/RPLCMT VENTR CATH SHUNT SYS','NUNDSC ICRA PLMT/RPLCMT VENTR CATH SHUNT SYS','62160','1','','1','0','','','',0, 1, 0, 0),
(5426,'NUNDSC ICRA DSJ ADS FENESTRATION SEPTUM CSTS','NUNDSC ICRA DSJ ADS FENESTRATION SEPTUM CSTS','62161','1','','1','0','','','',0, 1, 0, 0),
(5427,'NUNDSC ICRA FENESTEXC CYST W/VENTRIC CATH DRG','NUNDSC ICRA FENESTEXC CYST W/VENTRIC CATH DRG','62162','1','','1','0','','','',0, 1, 0, 0),
(5428,'NEUROENDOSCOPY ICRA W/RETRIEVAL FOREIGN BODY','NEUROENDOSCOPY ICRA W/RETRIEVAL FOREIGN BODY','62163','1','','1','0','','','',0, 1, 0, 0),
(5429,'NEUROENDOSCOPY ICRA W/RETRIEVAL FOREIGN BODY','NEUROENDOSCOPY ICRA W/RETRIEVAL FOREIGN BODY','62164','1','','1','0','','','',0, 1, 0, 0),
(5430,'NUNDSC ICRA EXC PITUITRY TUM TRNSNSL/SPHENOID','NUNDSC ICRA EXC PITUITRY TUM TRNSNSL/SPHENOID','62165','1','','1','0','','','',0, 1, 0, 0),
(5431,'VENTRICULOCISTERNOSTOMY','VENTRICULOCISTERNOSTOMY','62180','1','','1','0','','','',0, 1, 0, 0),
(5432,'CRTJ SHUNT SARACH/SDRL-ATR-JUG-AUR','CRTJ SHUNT SARACH/SDRL-ATR-JUG-AUR','62190','1','','1','0','','','',0, 1, 0, 0),
(5433,'CRTJ SHUNT SARACH/SDRL-PRTL-PLEURAL OTH','CRTJ SHUNT SARACH/SDRL-PRTL-PLEURAL OTH','62192','1','','1','0','','','',0, 1, 0, 0),
(5434,'RPLCMT/IRRG SUBARACHNOID/SUBDURAL CATHETER','RPLCMT/IRRG SUBARACHNOID/SUBDURAL CATHETER','62194','1','','1','0','','','',0, 1, 0, 0),
(5435,'VENTRICULOCISTERNOSTOMY 3RD VENTRICLE','VENTRICULOCISTERNOSTOMY 3RD VENTRICLE','62200','1','','1','0','','','',0, 1, 0, 0),
(5436,'VENTRICULOCISTERNOSTOMY 3RD VNTRC NEURONDSC','VENTRICULOCISTERNOSTOMY 3RD VNTRC NEURONDSC','62201','1','','1','0','','','',0, 1, 0, 0),
(5437,'CRTJ SHUNT VENTRICULO-ATR-JUG-AUR','CRTJ SHUNT VENTRICULO-ATR-JUG-AUR','62220','1','','1','0','','','',0, 1, 0, 0),
(5438,'CRTJ SHUNT VENTRICULO-PERITNEAL-PLEURAL TERMINUS','CRTJ SHUNT VENTRICULO-PERITNEAL-PLEURAL TERMINUS','62223','1','','1','0','','','',0, 1, 0, 0),
(5439,'RPLCMT/IRRIGATION VENTRICULAR CATHETER','RPLCMT/IRRIGATION VENTRICULAR CATHETER','62225','1','','1','0','','','',0, 1, 0, 0),
(5440,'RPLCMT/REVJ CSF SHUNT VALVE/CATH SHUNT SYS','RPLCMT/REVJ CSF SHUNT VALVE/CATH SHUNT SYS','62230','1','','1','0','','','',0, 1, 0, 0),
(5441,'REPRGRMG PROGRAMMABLE CEREBROSPINAL SHUNT','REPRGRMG PROGRAMMABLE CEREBROSPINAL SHUNT','62252','1','','1','0','','','',0, 1, 0, 0),
(5442,'RMVL COMPL CSF SHUNT SYSTEM W/O RPLCMT SHUNT','RMVL COMPL CSF SHUNT SYSTEM W/O RPLCMT SHUNT','62256','1','','1','0','','','',0, 1, 0, 0),
(5443,'RMVL COMPLETE CSF SHUNT SYSTEM W/RPLCMT SHUNT','RMVL COMPLETE CSF SHUNT SYSTEM W/RPLCMT SHUNT','62258','1','','1','0','','','',0, 1, 0, 0),
(5444,'PRQ LYSIS EPIDURAL ADHESIONS MULT SESS 2/> DAYS','PRQ LYSIS EPIDURAL ADHESIONS MULT SESS 2/> DAYS','62263','1','','1','0','','','',0, 1, 0, 0),
(5445,'PRQ LYSIS EPIDURAL ADHESIONS MULT SESSIONS 1 DAY','PRQ LYSIS EPIDURAL ADHESIONS MULT SESSIONS 1 DAY','62264','1','','1','0','','','',0, 1, 0, 0),
(5446,'PRQ ASPIR PULPOSUS/INTERVERTEBRAL DISC/PVRT TISS','PRQ ASPIR PULPOSUS/INTERVERTEBRAL DISC/PVRT TISS','62267','1','','1','0','','','',0, 1, 0, 0),
(5447,'PERCUTANEOUS ASPIRATION SPINAL CORD CYST/SYRINX','PERCUTANEOUS ASPIRATION SPINAL CORD CYST/SYRINX','62268','1','','1','0','','','',0, 1, 0, 0),
(5448,'BIOPSY SPINAL CORD PERCUTANEOUS NEEDLE','BIOPSY SPINAL CORD PERCUTANEOUS NEEDLE','62269','1','','1','0','','','',0, 1, 0, 0),
(5449,'SPINAL PUNCTURE LUMBAR DIAGNOSTIC','SPINAL PUNCTURE LUMBAR DIAGNOSTIC','62270','1','','1','0','','','',0, 1, 0, 0),
(5450,'SPINAL PUNCTURE THER DRAIN CEREBROSPINAL FLUID','SPINAL PUNCTURE THER DRAIN CEREBROSPINAL FLUID','62272','1','','1','0','','','',0, 1, 0, 0),
(5451,'INJECTION EPIDURAL BLOOD/CLOT PATCH','INJECTION EPIDURAL BLOOD/CLOT PATCH','62273','1','','1','0','','','',0, 1, 0, 0),
(5452,'INJX/INFUSION NEUROLYTIC SUBSTANCE SUBARACHNOID','INJX/INFUSION NEUROLYTIC SUBSTANCE SUBARACHNOID','62280','1','','1','0','','','',0, 1, 0, 0),
(5453,'INJX/INFUS NEUROLYT SUBST EPIDURAL CERV/THORACIC','INJX/INFUS NEUROLYT SUBST EPIDURAL CERV/THORACIC','62281','1','','1','0','','','',0, 1, 0, 0),
(5454,'INJX/INFUS NEUROLYT SBST EPIDURAL LUMBAR/SACRAL','INJX/INFUS NEUROLYT SBST EPIDURAL LUMBAR/SACRAL','62282','1','','1','0','','','',0, 1, 0, 0),
(5455,'INJECTION PROCEDURE MYELOGRAPHY/CT LUMBAR','INJECTION PROCEDURE MYELOGRAPHY/CT LUMBAR','62284','1','','1','0','','','',0, 1, 0, 0),
(5456,'DCMPRN PERQ NUCLEUS PULPOSUS 1/> LEVELS LUMBAR','DCMPRN PERQ NUCLEUS PULPOSUS 1/> LEVELS LUMBAR','62287','1','','1','0','','','',0, 1, 0, 0),
(5457,'INJECTION PX DISCOGRAPHY EACH LEVEL LUMBAR','INJECTION PX DISCOGRAPHY EACH LEVEL LUMBAR','62290','1','','1','0','','','',0, 1, 0, 0),
(5458,'INJECTION PX DISCOGRPHY EA LVL CERVICAL/THORACIC','INJECTION PX DISCOGRPHY EA LVL CERVICAL/THORACIC','62291','1','','1','0','','','',0, 1, 0, 0),
(5459,'INJECTION PX DISCOGRPHY EA LVL CERVICAL/THORACIC','INJECTION PX DISCOGRPHY EA LVL CERVICAL/THORACIC','62292','1','','1','0','','','',0, 1, 0, 0),
(5460,'NJX ARTERIAL OCCLUSION ARVEN MALFRMJ SPINAL','NJX ARTERIAL OCCLUSION ARVEN MALFRMJ SPINAL','62294','1','','1','0','','','',0, 1, 0, 0),
(5461,'MYELOGRAPHY VIA LUMBAR INJECTION RS&I CERVICAL','MYELOGRAPHY VIA LUMBAR INJECTION RS&I CERVICAL','62302','1','','1','0','','','',0, 1, 0, 0),
(5462,'MYELOGRAPHY VIA LUMBAR INJECTION RS&I THORACIC','MYELOGRAPHY VIA LUMBAR INJECTION RS&I THORACIC','62303','1','','1','0','','','',0, 1, 0, 0),
(5463,'MYELOGRAPHY VIA LUMBAR INJECT RS&I LUMBOSACRAL','MYELOGRAPHY VIA LUMBAR INJECT RS&I LUMBOSACRAL','62304','1','','1','0','','','',0, 1, 0, 0),
(5464,'MYELOGRAPHY VIA LUMBAR INJECTION RS&I 2+ REGIONS','MYELOGRAPHY VIA LUMBAR INJECTION RS&I 2+ REGIONS','62305','1','','1','0','','','',0, 1, 0, 0),
(5465,'NJX DX/THER SBST EPIDURAL/SUBRACH CERV/THORACIC','NJX DX/THER SBST EPIDURAL/SUBRACH CERV/THORACIC','62310','1','','1','0','','','',0, 1, 0, 0),
(5466,'NJX DX/THER SBST EPIDURAL/SUBARACH LUMBAR/SACRAL','NJX DX/THER SBST EPIDURAL/SUBARACH LUMBAR/SACRAL','62311','1','','1','0','','','',0, 1, 0, 0),
(5467,'NJXS INFUS/BOLUS DX/SBST EDRL/SUBARACH CRV/THRC','NJXS INFUS/BOLUS DX/SBST EDRL/SUBARACH CRV/THRC','62318','1','','1','0','','','',0, 1, 0, 0),
(5468,'NJX INFUS/BOLUS DX/SBST EDRL/SUBARACH LUM/SACRAL','NJX INFUS/BOLUS DX/SBST EDRL/SUBARACH LUM/SACRAL','62319','1','','1','0','','','',0, 1, 0, 0),
(5469,'IMPLTJ REVJ/RPSG ITHCL/EDRL CATH PMP W/O LAM','IMPLTJ REVJ/RPSG ITHCL/EDRL CATH PMP W/O LAM','62350','1','','1','0','','','',0, 1, 0, 0),
(5470,'IMPLTJ REVJ/RPSG ITHCL/EDRL CATH W/LAM','IMPLTJ REVJ/RPSG ITHCL/EDRL CATH W/LAM','62351','1','','1','0','','','',0, 1, 0, 0),
(5471,'RMVL PREVIOUSLY IMPLTED ITHCL/EDRL CATH','RMVL PREVIOUSLY IMPLTED ITHCL/EDRL CATH','62355','1','','1','0','','','',0, 1, 0, 0),
(5472,'IMPLTJ/RPLCMT ITHCL/EDRL DRUG NFS SUBQ RSVR','IMPLTJ/RPLCMT ITHCL/EDRL DRUG NFS SUBQ RSVR','62360','1','','1','0','','','',0, 1, 0, 0),
(5473,'IMPLTJ/RPLCMT FS NON-PRGRBL PUMP','IMPLTJ/RPLCMT FS NON-PRGRBL PUMP','62361','1','','1','0','','','',0, 1, 0, 0),
(5474,'IMPLTJ/RPLCMT ITHCL/EDRL DRUG NFS PRGRBL PUMP','IMPLTJ/RPLCMT ITHCL/EDRL DRUG NFS PRGRBL PUMP','62362','1','','1','0','','','',0, 1, 0, 0),
(5475,'RMVL SUBQ RSVR/PUMP INTRATHECAL/EPIDURAL INFUS','RMVL SUBQ RSVR/PUMP INTRATHECAL/EPIDURAL INFUS','62365','1','','1','0','','','',0, 1, 0, 0),
(5476,'ELECT ANLYS IMPLT ITHCL/EDRL PMP W/O REPRG/REFIL','ELECT ANLYS IMPLT ITHCL/EDRL PMP W/O REPRG/REFIL','62367','1','','1','0','','','',0, 1, 0, 0),
(5477,'ELECT ANALYS IMPLT ITHCL/EDRL PUMP W/REPRGRMG','ELECT ANALYS IMPLT ITHCL/EDRL PUMP W/REPRGRMG','62368','1','','1','0','','','',0, 1, 0, 0),
(5478,'ELECT ANLYS IMPLT ITHCL/EDRL PMP W/REPRG&REFIL','ELECT ANLYS IMPLT ITHCL/EDRL PMP W/REPRG&REFIL','62369','1','','1','0','','','',0, 1, 0, 0),
(5479,'ELEC ANLYS IMPLT ITHCL/EDRL PMP W/REPR PHYS/QHP','ELEC ANLYS IMPLT ITHCL/EDRL PMP W/REPR PHYS/QHP','62370','1','','1','0','','','',0, 1, 0, 0),
(5480,'LAM W/O FACETEC FORAMOT/DSKC 1/2 VRT SEG CRV','LAM W/O FACETEC FORAMOT/DSKC 1/2 VRT SEG CRV','63001','1','','1','0','','','',0, 1, 0, 0),
(5481,'LAMINECTOMY W/O FFD 1/2 VERT SEG THORACIC','LAMINECTOMY W/O FFD 1/2 VERT SEG THORACIC','63003','1','','1','0','','','',0, 1, 0, 0),
(5482,'LAMINECTOMY W/O FFD 1/2 VERT SEG LUMBAR','LAMINECTOMY W/O FFD 1/2 VERT SEG LUMBAR','63005','1','','1','0','','','',0, 1, 0, 0),
(5483,'LAMINECTOMY W/O FFD 1/2 VERT SEG SACRAL','LAMINECTOMY W/O FFD 1/2 VERT SEG SACRAL','63011','1','','1','0','','','',0, 1, 0, 0),
(5484,'LAMINECTOMY W/RMVL ABNORMAL FACETS LUMBAR','LAMINECTOMY W/RMVL ABNORMAL FACETS LUMBAR','63012','1','','1','0','','','',0, 1, 0, 0),
(5485,'LAMINECTOMY W/O FFD > 2 VERT SEG CERVICAL','LAMINECTOMY W/O FFD > 2 VERT SEG CERVICAL','63015','1','','1','0','','','',0, 1, 0, 0),
(5486,'LAMINECTOMY W/O FFD > 2 VERT SEG THORACIC','LAMINECTOMY W/O FFD > 2 VERT SEG THORACIC','63016','1','','1','0','','','',0, 1, 0, 0),
(5487,'LAMINECTOMY W/O FFD > 2 VERT SEG LUMBAR','LAMINECTOMY W/O FFD > 2 VERT SEG LUMBAR','63017','1','','1','0','','','',0, 1, 0, 0),
(5488,'LAMNOTMY INCL W/DCMPRSN NRV ROOT 1 INTRSPC CERVC','LAMNOTMY INCL W/DCMPRSN NRV ROOT 1 INTRSPC CERVC','63020','1','','1','0','','','',0, 1, 0, 0),
(5489,'LAMNOTMY INCL W/DCMPRSN NRV ROOT 1 INTRSPC LUMBR','LAMNOTMY INCL W/DCMPRSN NRV ROOT 1 INTRSPC LUMBR','63030','1','','1','0','','','',0, 1, 0, 0),
(5490,'LAMNOTMY W/DCMPRSN NRV EACH ADDL CRVCL/LMBR','LAMNOTMY W/DCMPRSN NRV EACH ADDL CRVCL/LMBR','63035','1','','1','0','','','',0, 1, 0, 0),
(5491,'LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC CERVICAL','LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC CERVICAL','63040','1','','1','0','','','',0, 1, 0, 0),
(5492,'LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC LUMBAR','LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC LUMBAR','63042','1','','1','0','','','',0, 1, 0, 0),
(5493,'LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC EA CRV','LAMOT PRTL FFD EXC DISC REEXPL 1 NTRSPC EA CRV','63043','1','','1','0','','','',0, 1, 0, 0),
(5494,'LAMOT W/PRTL FFD HRNA8 REEXPL 1 NTRSPC EA LMBR','LAMOT W/PRTL FFD HRNA8 REEXPL 1 NTRSPC EA LMBR','63044','1','','1','0','','','',0, 1, 0, 0),
(5495,'LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT CERVICAL','LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT CERVICAL','63045','1','','1','0','','','',0, 1, 0, 0),
(5496,'LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT THORACIC','LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT THORACIC','63046','1','','1','0','','','',0, 1, 0, 0),
(5497,'LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT LUMBAR','LAM FACETECTOMY & FORAMOTOMY 1 SEGMENT LUMBAR','63047','1','','1','0','','','',0, 1, 0, 0),
(5498,'LAM FACETECTOMY&FORAMTOMY 1 SGM EA CRV THRC/LMBR','LAM FACETECTOMY&FORAMTOMY 1 SGM EA CRV THRC/LMBR','63048','1','','1','0','','','',0, 1, 0, 0),
(5499,'LAMOP CERVICAL W/DCMPRN SPI CORD 2/> VERT SEG','LAMOP CERVICAL W/DCMPRN SPI CORD 2/> VERT SEG','63050','1','','1','0','','','',0, 1, 0, 0),
(5500,'LAMOPLASTY CERVICAL DCMPRN CORD 2/> SEG RCNSTJ','LAMOPLASTY CERVICAL DCMPRN CORD 2/> SEG RCNSTJ','63051','1','','1','0','','','',0, 1, 0, 0),
(5501,'TRANSPEDICULAR DCMPRN SPINAL CORD 1 SEG THORACIC','TRANSPEDICULAR DCMPRN SPINAL CORD 1 SEG THORACIC','63055','1','','1','0','','','',0, 1, 0, 0),
(5502,'TRANSPEDICULAR DCMPRN SPINAL CORD 1 SEG LUMBAR','TRANSPEDICULAR DCMPRN SPINAL CORD 1 SEG LUMBAR','63056','1','','1','0','','','',0, 1, 0, 0),
(5503,'TRANSPEDICULAR DCMPRN 1 SEG EA THORACIC/LUMBAR','TRANSPEDICULAR DCMPRN 1 SEG EA THORACIC/LUMBAR','63057','1','','1','0','','','',0, 1, 0, 0),
(5504,'COSTOVERTEBRAL DCMPRN SPINAL CORD THORACIC 1 SEG','COSTOVERTEBRAL DCMPRN SPINAL CORD THORACIC 1 SEG','63064','1','','1','0','','','',0, 1, 0, 0),
(5505,'COSTOVERTEBRAL DCMPRN SPINE CORD THORACIC EA SEG','COSTOVERTEBRAL DCMPRN SPINE CORD THORACIC EA SEG','63066','1','','1','0','','','',0, 1, 0, 0),
(5506,'DISCECTOMY ANT DCMPRN CORD CERVICAL 1 NTRSPC','DISCECTOMY ANT DCMPRN CORD CERVICAL 1 NTRSPC','63075','1','','1','0','','','',0, 1, 0, 0),
(5507,'DISCECTOMY ANT DCMPRN CORD CERVICAL EA NTRSPC','DISCECTOMY ANT DCMPRN CORD CERVICAL EA NTRSPC','63076','1','','1','0','','','',0, 1, 0, 0),
(5508,'DISCECTOMY ANT DCMPRN CORD THORACIC 1 NTRSPC','DISCECTOMY ANT DCMPRN CORD THORACIC 1 NTRSPC','63077','1','','1','0','','','',0, 1, 0, 0),
(5509,'DISCECTOMY ANT DCMPRN CORD THORACIC EA NTRSPC','DISCECTOMY ANT DCMPRN CORD THORACIC EA NTRSPC','63078','1','','1','0','','','',0, 1, 0, 0),
(5510,'VERTEBRAL CORPECTOMY ANT DCMPRN CERVICAL 1 SEG','VERTEBRAL CORPECTOMY ANT DCMPRN CERVICAL 1 SEG','63081','1','','1','0','','','',0, 1, 0, 0),
(5511,'VERTEBRAL CORPECTOMY DCMPRN CERVICAL EA SEG','VERTEBRAL CORPECTOMY DCMPRN CERVICAL EA SEG','63082','1','','1','0','','','',0, 1, 0, 0),
(5512,'VERTEBRAL CORPECTOMY DCMPRN CORD THORACIC 1 SEG','VERTEBRAL CORPECTOMY DCMPRN CORD THORACIC 1 SEG','63085','1','','1','0','','','',0, 1, 0, 0),
(5513,'VERTEBRAL CORPECTOMY DCMPRN CORD THORACIC EA SEG','VERTEBRAL CORPECTOMY DCMPRN CORD THORACIC EA SEG','63086','1','','1','0','','','',0, 1, 0, 0),
(5514,'VCRPEC THORACOLMBR DCMPRN LWR THRC/LMBR 1 SEG','VCRPEC THORACOLMBR DCMPRN LWR THRC/LMBR 1 SEG','63087','1','','1','0','','','',0, 1, 0, 0),
(5515,'VCRPEC THORACOLMBR DCMPRN LWR THRC/LMBR EA SEG','VCRPEC THORACOLMBR DCMPRN LWR THRC/LMBR EA SEG','63088','1','','1','0','','','',0, 1, 0, 0),
(5516,'VCRPEC TRANSPRTL/RPR DCMPRN THRC LMBR/SAC 1 SEG','VCRPEC TRANSPRTL/RPR DCMPRN THRC LMBR/SAC 1 SEG','63090','1','','1','0','','','',0, 1, 0, 0),
(5517,'VCRPEC TRANSPRTL/RPR DCMPRN THRC LMBR/SAC EA SEG','VCRPEC TRANSPRTL/RPR DCMPRN THRC LMBR/SAC EA SEG','63091','1','','1','0','','','',0, 1, 0, 0),
(5518,'VERTEB CORPECT LAT XTRCAVITARY DCMPRN THRC 1 SEG','VERTEB CORPECT LAT XTRCAVITARY DCMPRN THRC 1 SEG','63101','1','','1','0','','','',0, 1, 0, 0),
(5519,'VERTEB CORPECT LAT XTRCAVITARY DCMPRN LMBR 1 SEG','VERTEB CORPECT LAT XTRCAVITARY DCMPRN LMBR 1 SEG','63102','1','','1','0','','','',0, 1, 0, 0),
(5520,'VCRPEC LAT XTRCAVITARY DCMPRN THRC/LMBR EA SEG','VCRPEC LAT XTRCAVITARY DCMPRN THRC/LMBR EA SEG','63103','1','','1','0','','','',0, 1, 0, 0),
(5521,'LAM W/MYELOTOMY CERVICAL/THORACIC/THORACOLUMBAR','LAM W/MYELOTOMY CERVICAL/THORACIC/THORACOLUMBAR','63170','1','','1','0','','','',0, 1, 0, 0),
(5522,'LAM W/DRG INTRMEDULLARY CYST/SYRINX SUBARACHNOID','LAM W/DRG INTRMEDULLARY CYST/SYRINX SUBARACHNOID','63172','1','','1','0','','','',0, 1, 0, 0),
(5523,'LAM W/DRG INTRMEDULRY CYST/SYRINX PRTL/PLEURAL','LAM W/DRG INTRMEDULRY CYST/SYRINX PRTL/PLEURAL','63173','1','','1','0','','','',0, 1, 0, 0),
(5524,'LAM&SCTJ DENTATE LIG W/WO DURAL GRF CRV 1/2 SEG','LAM&SCTJ DENTATE LIG W/WO DURAL GRF CRV 1/2 SEG','63180','1','','1','0','','','',0, 1, 0, 0),
(5525,'LAM&SCTJ DENTATE LIG W/WO DURAL GRF CRV >2 SEG','LAM&SCTJ DENTATE LIG W/WO DURAL GRF CRV >2 SEG','63182','1','','1','0','','','',0, 1, 0, 0),
(5526,'LAMINECTOMY W/RHIZOTOMY 1/2 SEGMENTS','LAMINECTOMY W/RHIZOTOMY 1/2 SEGMENTS','63185','1','','1','0','','','',0, 1, 0, 0),
(5527,'LAMINECTOMY W/RHIZOTOMY > 2 SEGMENTS','LAMINECTOMY W/RHIZOTOMY > 2 SEGMENTS','63190','1','','1','0','','','',0, 1, 0, 0),
(5528,'LAMINECTOMY W/SECTION SPINAL ACCESSORY NERVE','LAMINECTOMY W/SECTION SPINAL ACCESSORY NERVE','63191','1','','1','0','','','',0, 1, 0, 0),
(5529,'LAM CORDOTOMY SCTJ 1 SPINOTHALMIC TRACT CERVICAL','LAM CORDOTOMY SCTJ 1 SPINOTHALMIC TRACT CERVICAL','63194','1','','1','0','','','',0, 1, 0, 0),
(5530,'LAM CORDOTOMY SCTJ 1 SPINOTHALMIC TRACT THORACIC','LAM CORDOTOMY SCTJ 1 SPINOTHALMIC TRACT THORACIC','63195','1','','1','0','','','',0, 1, 0, 0),
(5531,'LAM CORDOTOMY SCTJ BOTH SPINOTHALMIC TRACTS CRV','LAM CORDOTOMY SCTJ BOTH SPINOTHALMIC TRACTS CRV','63196','1','','1','0','','','',0, 1, 0, 0),
(5532,'LAM CORDOTOMY SCTJ BOTH SPINOTHALMIC TRACT THRC','LAM CORDOTOMY SCTJ BOTH SPINOTHALMIC TRACT THRC','63197','1','','1','0','','','',0, 1, 0, 0),
(5533,'LAM CORDOTOMY SCTJ BOTH TRACTS 2 STAGES CERVICAL','LAM CORDOTOMY SCTJ BOTH TRACTS 2 STAGES CERVICAL','63198','1','','1','0','','','',0, 1, 0, 0),
(5534,'LAM CORDOTOMY SCTJ BOTH TRACTS 2 STAGES THORACIC','LAM CORDOTOMY SCTJ BOTH TRACTS 2 STAGES THORACIC','63199','1','','1','0','','','',0, 1, 0, 0),
(5535,'LAMINECTOMY RELEASE TETHERED SPINAL CORD LUMBAR','LAMINECTOMY RELEASE TETHERED SPINAL CORD LUMBAR','63200','1','','1','0','','','',0, 1, 0, 0),
(5536,'LAM EXC/OCCLUSION AVM SPINAL CORD CERVICAL','LAM EXC/OCCLUSION AVM SPINAL CORD CERVICAL','63250','1','','1','0','','','',0, 1, 0, 0),
(5537,'LAM EXC/OCCLUSION AVM SPINAL CORD THORACIC','LAM EXC/OCCLUSION AVM SPINAL CORD THORACIC','63251','1','','1','0','','','',0, 1, 0, 0),
(5538,'LAM EXC/OCCLUSION AVM SPI CORD THORACOLUMBAR','LAM EXC/OCCLUSION AVM SPI CORD THORACOLUMBAR','63252','1','','1','0','','','',0, 1, 0, 0),
(5539,'LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL CERVICAL','LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL CERVICAL','63265','1','','1','0','','','',0, 1, 0, 0),
(5540,'LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL THORACIC','LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL THORACIC','63266','1','','1','0','','','',0, 1, 0, 0),
(5541,'LAM EXC/EVAC ISPI LESION OTH/THN NEO XDRL LUMBAR','LAM EXC/EVAC ISPI LESION OTH/THN NEO XDRL LUMBAR','63267','1','','1','0','','','',0, 1, 0, 0),
(5542,'LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL SACRAL','LAM EXC/EVAC ISPI LES OTH/THN NEO XDRL SACRAL','63268','1','','1','0','','','',0, 1, 0, 0),
(5543,'LAM EXC ISPI LES OTH/THN NEO IDRL CERVICAL','LAM EXC ISPI LES OTH/THN NEO IDRL CERVICAL','63270','1','','1','0','','','',0, 1, 0, 0),
(5544,'LAM EXC ISPI LES OTH/THN NEO IDRL THORACIC','LAM EXC ISPI LES OTH/THN NEO IDRL THORACIC','63271','1','','1','0','','','',0, 1, 0, 0),
(5545,'LAM EXC ISPI LES OTH/THN NEO IDRL LUMBAR','LAM EXC ISPI LES OTH/THN NEO IDRL LUMBAR','63272','1','','1','0','','','',0, 1, 0, 0),
(5546,'LAM EXC ISPI LES OTH/THN NEO IDRL SACRAL','LAM EXC ISPI LES OTH/THN NEO IDRL SACRAL','63273','1','','1','0','','','',0, 1, 0, 0),
(5547,'LAMINECTOMY BX/EXC ISPI NEO XDRL CERVICAL','LAMINECTOMY BX/EXC ISPI NEO XDRL CERVICAL','63275','1','','1','0','','','',0, 1, 0, 0),
(5548,'LAMINECTOMY BX/EXC ISPI NEO XDRL THORACIC','LAMINECTOMY BX/EXC ISPI NEO XDRL THORACIC','63276','1','','1','0','','','',0, 1, 0, 0),
(5549,'LAMINECTOMY BX/EXC ISPI NEO XDRL LUMBAR','LAMINECTOMY BX/EXC ISPI NEO XDRL LUMBAR','63277','1','','1','0','','','',0, 1, 0, 0),
(5550,'LAMINECTOMY BX/EXC ISPI NEO XDRL SACRAL','LAMINECTOMY BX/EXC ISPI NEO XDRL SACRAL','63278','1','','1','0','','','',0, 1, 0, 0),
(5551,'LAM BX/EXC ISPI NEO IDRL XMED CERVICAL','LAM BX/EXC ISPI NEO IDRL XMED CERVICAL','63280','1','','1','0','','','',0, 1, 0, 0),
(5552,'LAM BX/EXC ISPI NEO IDRL XMED THORACIC','LAM BX/EXC ISPI NEO IDRL XMED THORACIC','63281','1','','1','0','','','',0, 1, 0, 0),
(5553,'LAM BX/EXC ISPI NEO IDRL XMED LUMBAR','LAM BX/EXC ISPI NEO IDRL XMED LUMBAR','63282','1','','1','0','','','',0, 1, 0, 0),
(5554,'LAM BX/EXC ISPI NEO IDRL SACRAL','LAM BX/EXC ISPI NEO IDRL SACRAL','63283','1','','1','0','','','',0, 1, 0, 0),
(5555,'LAM BX/EXC ISPI NEO IDRL IMED CERVICAL','LAM BX/EXC ISPI NEO IDRL IMED CERVICAL','63285','1','','1','0','','','',0, 1, 0, 0),
(5556,'LAM BX/EXC ISPI NEO IDRL IMED THORACIC','LAM BX/EXC ISPI NEO IDRL IMED THORACIC','63286','1','','1','0','','','',0, 1, 0, 0),
(5557,'LAM BX/EXC ISPI NEO IDRL IMED THORACOLMBR','LAM BX/EXC ISPI NEO IDRL IMED THORACOLMBR','63287','1','','1','0','','','',0, 1, 0, 0),
(5558,'LAM BX/EXC ISPI NEO XDRL-IDRL LES ANY LVL','LAM BX/EXC ISPI NEO XDRL-IDRL LES ANY LVL','63290','1','','1','0','','','',0, 1, 0, 0),
(5559,'OSTPL RCNSTJ DORSAL SPI ELMNTS FLWG ISPI PX','OSTPL RCNSTJ DORSAL SPI ELMNTS FLWG ISPI PX','63295','1','','1','0','','','',0, 1, 0, 0),
(5560,'VCRPEC LES 1 SGM XDRL CERVICAL','VCRPEC LES 1 SGM XDRL CERVICAL','63300','1','','1','0','','','',0, 1, 0, 0),
(5561,'VCRPEC LES 1 SGM XDRL THORACIC TTHRC','VCRPEC LES 1 SGM XDRL THORACIC TTHRC','63301','1','','1','0','','','',0, 1, 0, 0),
(5562,'VCRPEC LES 1 SEG XDRL THRC THORACOLMBR','VCRPEC LES 1 SEG XDRL THRC THORACOLMBR','63302','1','','1','0','','','',0, 1, 0, 0),
(5563,'VCRPEC LES 1 SEG XDRL LMBR/SAC TRANSPRTL/RPR','VCRPEC LES 1 SEG XDRL LMBR/SAC TRANSPRTL/RPR','63303','1','','1','0','','','',0, 1, 0, 0),
(5564,'VERTEBRAL CORPECTOMY EXC LES 1 SEG IDRL CERVICAL','VERTEBRAL CORPECTOMY EXC LES 1 SEG IDRL CERVICAL','63304','1','','1','0','','','',0, 1, 0, 0),
(5565,'VERTEBRAL CORPECTOMY LES 1 SEG IDRL THRC TTHRC','VERTEBRAL CORPECTOMY LES 1 SEG IDRL THRC TTHRC','63305','1','','1','0','','','',0, 1, 0, 0),
(5566,'VERTEBRL CORPECT LES 1 SEG IDRL THRC THORACOLMBR','VERTEBRL CORPECT LES 1 SEG IDRL THRC THORACOLMBR','63306','1','','1','0','','','',0, 1, 0, 0),
(5567,'VCRPEC LES 1 SEG IDRL LMBR/SAC TRANSPRTL/RPR','VCRPEC LES 1 SEG IDRL LMBR/SAC TRANSPRTL/RPR','63307','1','','1','0','','','',0, 1, 0, 0),
(5568,'VERTEBRAL CORPECTOMY EXC INDRL LES EACH SEG','VERTEBRAL CORPECTOMY EXC INDRL LES EACH SEG','63308','1','','1','0','','','',0, 1, 0, 0),
(5569,'CREATION LES SPINAL CORD STEREOTACTIC METHOD PRQ','CREATION LES SPINAL CORD STEREOTACTIC METHOD PRQ','63600','1','','1','0','','','',0, 1, 0, 0),
(5570,'STRTCTC STIMJ SPI CORD PRQ SPX N/FLWD OTH SURG','STRTCTC STIMJ SPI CORD PRQ SPX N/FLWD OTH SURG','63610','1','','1','0','','','',0, 1, 0, 0),
(5571,'STRTCTC BX ASPIRAT/EXC LESION SPINAL CORD','STRTCTC BX ASPIRAT/EXC LESION SPINAL CORD','63615','1','','1','0','','','',0, 1, 0, 0),
(5572,'STEREOTACTIC RADIOSURGERY 1 SPINAL LESION','STEREOTACTIC RADIOSURGERY 1 SPINAL LESION','63620','1','','1','0','','','',0, 1, 0, 0),
(5573,'STEREOTACTIC RADIOSURGERY EA ADDL SPINAL LESION','STEREOTACTIC RADIOSURGERY EA ADDL SPINAL LESION','63621','1','','1','0','','','',0, 1, 0, 0),
(5574,'PRQ IMPLTJ NSTIM ELECTRODE ARRAY EPIDURAL','PRQ IMPLTJ NSTIM ELECTRODE ARRAY EPIDURAL','63650','1','','1','0','','','',0, 1, 0, 0),
(5575,'LAM IMPLTJ NSTIM ELTRDS PLATE/PADDLE EDRL','LAM IMPLTJ NSTIM ELTRDS PLATE/PADDLE EDRL','63655','1','','1','0','','','',0, 1, 0, 0),
(5576,'RMVL SPINAL NSTIM ELTRD PRQ ARRAY INCL FLUOR','RMVL SPINAL NSTIM ELTRD PRQ ARRAY INCL FLUOR','63661','1','','1','0','','','',0, 1, 0, 0),
(5577,'RMVL SPINAL NSTIM ELTRD PLATE/PADDLE INCL FLUOR','RMVL SPINAL NSTIM ELTRD PLATE/PADDLE INCL FLUOR','63662','1','','1','0','','','',0, 1, 0, 0),
(5578,'REVJ INCL RPLCMT NSTIM ELTRD PRQ RA INCL FLUOR','REVJ INCL RPLCMT NSTIM ELTRD PRQ RA INCL FLUOR','63663','1','','1','0','','','',0, 1, 0, 0),
(5579,'REVJ INCL RPLCMT NSTIM ELTRD PLT/PDLE INCL FLUOR','REVJ INCL RPLCMT NSTIM ELTRD PLT/PDLE INCL FLUOR','63664','1','','1','0','','','',0, 1, 0, 0),
(5580,'INSJ/RPLCMT SPI NPGR DIR/INDUXIVE COUPLING','INSJ/RPLCMT SPI NPGR DIR/INDUXIVE COUPLING','63685','1','','1','0','','','',0, 1, 0, 0),
(5581,'REVJ/RMVL IMPLANTED SPINAL NEUROSTIM GENERATOR','REVJ/RMVL IMPLANTED SPINAL NEUROSTIM GENERATOR','63688','1','','1','0','','','',0, 1, 0, 0),
(5582,'REPAIR MENINGOCELE < 5 CM DIAMETER','REPAIR MENINGOCELE < 5 CM DIAMETER','63700','1','','1','0','','','',0, 1, 0, 0),
(5583,'REPAIR MENINGOCELE > 5 CM DIAMETER','REPAIR MENINGOCELE > 5 CM DIAMETER','63702','1','','1','0','','','',0, 1, 0, 0),
(5584,'REPAIR MYELOMENINGOCELE < 5 CM DIAMETER','REPAIR MYELOMENINGOCELE < 5 CM DIAMETER','63704','1','','1','0','','','',0, 1, 0, 0),
(5585,'REPAIR MYELOMENINGOCELE > 5 CM DIAMETER','REPAIR MYELOMENINGOCELE > 5 CM DIAMETER','63706','1','','1','0','','','',0, 1, 0, 0),
(5586,'RPR DURAL/CEREBROSPINAL FLUID LEAK X REQ LAM','RPR DURAL/CEREBROSPINAL FLUID LEAK X REQ LAM','63707','1','','1','0','','','',0, 1, 0, 0),
(5587,'RPR DURAL/CSF LEAK/PSEUDOMENINGOCELE W/LAM','RPR DURAL/CSF LEAK/PSEUDOMENINGOCELE W/LAM','63709','1','','1','0','','','',0, 1, 0, 0),
(5588,'DURAL GRAFT SPINAL','DURAL GRAFT SPINAL','63710','1','','1','0','','','',0, 1, 0, 0),
(5589,'CRTJ SHUNT LMBR SARACH-PRTL-PLEURAL/OTH W/LAM','CRTJ SHUNT LMBR SARACH-PRTL-PLEURAL/OTH W/LAM','63740','1','','1','0','','','',0, 1, 0, 0),
(5590,'CRTJ SHUNT LMBR SARACH-PRTL-PLEURAL PRQ X LAM','CRTJ SHUNT LMBR SARACH-PRTL-PLEURAL PRQ X LAM','63741','1','','1','0','','','',0, 1, 0, 0),
(5591,'RPLCMT IRRIGATION/REVJ LUMBOSARACH SHUNT','RPLCMT IRRIGATION/REVJ LUMBOSARACH SHUNT','63744','1','','1','0','','','',0, 1, 0, 0),
(5592,'RMVL ENTIRE LUMBOSARACH SHUNT SYS W/O RPLCMT','RMVL ENTIRE LUMBOSARACH SHUNT SYS W/O RPLCMT','63746','1','','1','0','','','',0, 1, 0, 0),
(5593,'NJX ANES TRIGEMINAL NRV ANY DIV/BRANCH','NJX ANES TRIGEMINAL NRV ANY DIV/BRANCH','64400','1','','1','0','','','',0, 1, 0, 0),
(5594,'INJECTION ANESTHETIC AGENT FACIAL NERVE','INJECTION ANESTHETIC AGENT FACIAL NERVE','64402','1','','1','0','','','',0, 1, 0, 0),
(5595,'INJECTION ANESTHETIC AGENT GREATER OCCIPITAL NRV','INJECTION ANESTHETIC AGENT GREATER OCCIPITAL NRV','64405','1','','1','0','','','',0, 1, 0, 0),
(5596,'INJECTION ANESTHETIC AGENT VAGUS NERVE','INJECTION ANESTHETIC AGENT VAGUS NERVE','64408','1','','1','0','','','',0, 1, 0, 0),
(5597,'INJECTION ANESTHETIC AGENT PHRENIC NERVE','INJECTION ANESTHETIC AGENT PHRENIC NERVE','64410','1','','1','0','','','',0, 1, 0, 0),
(5598,'INJECTION ANESTHETIC AGENT CERVICAL PLEXUS','INJECTION ANESTHETIC AGENT CERVICAL PLEXUS','64413','1','','1','0','','','',0, 1, 0, 0),
(5599,'SINGLE NERVE BLOCK INJECTION ARM NERVE','SINGLE NERVE BLOCK INJECTION ARM NERVE','64415','1','','1','0','','','',0, 1, 0, 0),
(5600,'INJECTION ANES BRACHIAL PLEXUS CONT NFS CATH','INJECTION ANES BRACHIAL PLEXUS CONT NFS CATH','64416','1','','1','0','','','',0, 1, 0, 0),
(5601,'INJECTION ANESTHETIC AGENT AXILLARY NERVE','INJECTION ANESTHETIC AGENT AXILLARY NERVE','64417','1','','1','0','','','',0, 1, 0, 0),
(5602,'INJECTION ANESTHETIC AGENT SUPRASCAPULAR NERVE','INJECTION ANESTHETIC AGENT SUPRASCAPULAR NERVE','64418','1','','1','0','','','',0, 1, 0, 0),
(5603,'INJECTION ANESTHETIC AGENT 1 INTERCOSTAL NERVE','INJECTION ANESTHETIC AGENT 1 INTERCOSTAL NERVE','64420','1','','1','0','','','',0, 1, 0, 0),
(5604,'MULTIPLE NERVE BLOCK INJECTIONS RIB NERVES','MULTIPLE NERVE BLOCK INJECTIONS RIB NERVES','64421','1','','1','0','','','',0, 1, 0, 0),
(5605,'INJECTION ANES ILIOINGUINAL ILIOHYPOGASTRIC NRVS','INJECTION ANES ILIOINGUINAL ILIOHYPOGASTRIC NRVS','64425','1','','1','0','','','',0, 1, 0, 0),
(5606,'INJECTION ANESTHETIC AGENT PUDENDAL NERVE','INJECTION ANESTHETIC AGENT PUDENDAL NERVE','64430','1','','1','0','','','',0, 1, 0, 0),
(5607,'INJECTION ANESTHETIC PARACERVICAL UTERINE NERVE','INJECTION ANESTHETIC PARACERVICAL UTERINE NERVE','64435','1','','1','0','','','',0, 1, 0, 0),
(5608,'INJECTION ANESTHETIC AGENT SCIATIC NRV SINGLE','INJECTION ANESTHETIC AGENT SCIATIC NRV SINGLE','64445','1','','1','0','','','',0, 1, 0, 0),
(5609,'INJECTION ANES SCIATIC NERVE CONT INFUSION CATH','INJECTION ANES SCIATIC NERVE CONT INFUSION CATH','64446','1','','1','0','','','',0, 1, 0, 0),
(5610,'INJECTION ANESTHETIC AGENT FEMORAL NERVE SINGLE','INJECTION ANESTHETIC AGENT FEMORAL NERVE SINGLE','64447','1','','1','0','','','',0, 1, 0, 0),
(5611,'INJECTION ANES FEMORAL NERVE CONT INFUSION CATH','INJECTION ANES FEMORAL NERVE CONT INFUSION CATH','64448','1','','1','0','','','',0, 1, 0, 0),
(5612,'INJECTION ANES LUMBAR PLEXUS POST CONT NFS CATH','INJECTION ANES LUMBAR PLEXUS POST CONT NFS CATH','64449','1','','1','0','','','',0, 1, 0, 0),
(5613,'INJECTION ANES OTHER PERIPHERAL NERVE/BRANCH','INJECTION ANES OTHER PERIPHERAL NERVE/BRANCH','64450','1','','1','0','','','',0, 1, 0, 0),
(5614,'NJX ANES&/STEROID PLANTAR COMMON DIGITAL NERVE','NJX ANES&/STEROID PLANTAR COMMON DIGITAL NERVE','64455','1','','1','0','','','',0, 1, 0, 0),
(5615,'PVB THORACIC SINGLE INJECTION SITE W/IMG GID','PVB THORACIC SINGLE INJECTION SITE W/IMG GID','64461','1','','1','0','','','',0, 1, 0, 0),
(5616,'PVB THORACIC SECOND & ADDL INJ SITE W/IMG GID','PVB THORACIC SECOND & ADDL INJ SITE W/IMG GID','64462','1','','1','0','','','',0, 1, 0, 0),
(5617,'PVB THORACIC CONT CATHETER INFUSION W/IMG GID','PVB THORACIC CONT CATHETER INFUSION W/IMG GID','64463','1','','1','0','','','',0, 1, 0, 0),
(5618,'NJX ANES&/STRD W/IMG TFRML EDRL CRV/THRC 1 LVL','NJX ANES&/STRD W/IMG TFRML EDRL CRV/THRC 1 LVL','64479','1','','1','0','','','',0, 1, 0, 0),
(5619,'NJX ANES&/STRD W/IMG TFRML EDRL CRV/THRC EA LV','NJX ANES&/STRD W/IMG TFRML EDRL CRV/THRC EA LV','64480','1','','1','0','','','',0, 1, 0, 0),
(5620,'NJX ANES&/STRD W/IMG TFRML EDRL LMBR/SAC 1 LVL','NJX ANES&/STRD W/IMG TFRML EDRL LMBR/SAC 1 LVL','64483','1','','1','0','','','',0, 1, 0, 0),
(5621,'NJX ANES&/STRD W/IMG TFRML EDRL LMBR/SAC EA LV','NJX ANES&/STRD W/IMG TFRML EDRL LMBR/SAC EA LV','64484','1','','1','0','','','',0, 1, 0, 0),
(5622,'TAP BLOCK UNILATERAL BY INJECTION(S)','TAP BLOCK UNILATERAL BY INJECTION(S)','64486','1','','1','0','','','',0, 1, 0, 0),
(5623,'TAP BLOCK UNILATERAL BY CONTINUOUS INFUSION(S)','TAP BLOCK UNILATERAL BY CONTINUOUS INFUSION(S)','64487','1','','1','0','','','',0, 1, 0, 0),
(5624,'TAP BLOCK BILATERAL BY INJECTION(S)','TAP BLOCK BILATERAL BY INJECTION(S)','64488','1','','1','0','','','',0, 1, 0, 0),
(5625,'TAP BLOCK BILATERAL BY CONTINUOUS INFUSION(S)','TAP BLOCK BILATERAL BY CONTINUOUS INFUSION(S)','64489','1','','1','0','','','',0, 1, 0, 0),
(5626,'NJX DX/THER AGT PVRT FACET JT CRV/THRC 1 LEVEL','NJX DX/THER AGT PVRT FACET JT CRV/THRC 1 LEVEL','64490','1','','1','0','','','',0, 1, 0, 0),
(5627,'NJX DX/THER AGT PVRT FACET JT CRV/THRC 2ND LEVEL','NJX DX/THER AGT PVRT FACET JT CRV/THRC 2ND LEVEL','64491','1','','1','0','','','',0, 1, 0, 0),
(5628,'NJX DX/THER AGT PVRT FACET JT CRV/THRC 3+ LEVEL','NJX DX/THER AGT PVRT FACET JT CRV/THRC 3+ LEVEL','64492','1','','1','0','','','',0, 1, 0, 0),
(5629,'NJX DX/THER AGT PVRT FACET JT LMBR/SAC 1 LEVEL','NJX DX/THER AGT PVRT FACET JT LMBR/SAC 1 LEVEL','64493','1','','1','0','','','',0, 1, 0, 0),
(5630,'NJX DX/THER AGT PVRT FACET JT LMBR/SAC 2ND LEVEL','NJX DX/THER AGT PVRT FACET JT LMBR/SAC 2ND LEVEL','64494','1','','1','0','','','',0, 1, 0, 0),
(5631,'NJX DX/THER AGT PVRT FACET JT LMBR/SAC 3+ LEVEL','NJX DX/THER AGT PVRT FACET JT LMBR/SAC 3+ LEVEL','64495','1','','1','0','','','',0, 1, 0, 0),
(5632,'INJECTION ANES AGENT SPHENOPALATINE GANGLION','INJECTION ANES AGENT SPHENOPALATINE GANGLION','64505','1','','1','0','','','',0, 1, 0, 0),
(5633,'INJECTION ANESTHETIC AGENT CAROTID SINUS SPX','INJECTION ANESTHETIC AGENT CAROTID SINUS SPX','64508','1','','1','0','','','',0, 1, 0, 0),
(5634,'NJX ANES STELLATE GANGLION CRV SYMPATHETIC','NJX ANES STELLATE GANGLION CRV SYMPATHETIC','64510','1','','1','0','','','',0, 1, 0, 0),
(5635,'INJECTION ANES SUPERIOR HYPOGASTRIC PLEXUS','INJECTION ANES SUPERIOR HYPOGASTRIC PLEXUS','64517','1','','1','0','','','',0, 1, 0, 0),
(5636,'INJECTION ANES LMBR/THRC PARAVERTBRL SYMPATHETIC','INJECTION ANES LMBR/THRC PARAVERTBRL SYMPATHETIC','64520','1','','1','0','','','',0, 1, 0, 0),
(5637,'INJX ANES CELIAC PLEXUS W/WO RADIOLOGIC MONITRNG','INJX ANES CELIAC PLEXUS W/WO RADIOLOGIC MONITRNG','64530','1','','1','0','','','',0, 1, 0, 0),
(5638,'APPLICATION SURFACE NEUROSTIMULATOR','APPLICATION SURFACE NEUROSTIMULATOR','64550','1','','1','0','','','',0, 1, 0, 0),
(5639,'PRQ IMPLTJ NEUROSTIMULATOR ELTRD CRANIAL NERVE','PRQ IMPLTJ NEUROSTIMULATOR ELTRD CRANIAL NERVE','64553','1','','1','0','','','',0, 1, 0, 0),
(5640,'PRQ IMPLTJ NEUROSTIMULATOR ELTRD PERIPHERAL NRV','PRQ IMPLTJ NEUROSTIMULATOR ELTRD PERIPHERAL NRV','64555','1','','1','0','','','',0, 1, 0, 0),
(5641,'PRQ IMPLTJ NEUROSTIM ELTRD SACRAL NRVE W/IMAGING','PRQ IMPLTJ NEUROSTIM ELTRD SACRAL NRVE W/IMAGING','64561','1','','1','0','','','',0, 1, 0, 0),
(5642,'PRQ IMPLTJ NSTIM ELTRD NEUROMUSCULAR','PRQ IMPLTJ NSTIM ELTRD NEUROMUSCULAR','64565','1','','1','0','','','',0, 1, 0, 0),
(5643,'POST TIB NEUROSTIMULATION PRQ NEEDLE ELECTRODE','POST TIB NEUROSTIMULATION PRQ NEEDLE ELECTRODE','64566','1','','1','0','','','',0, 1, 0, 0),
(5644,'INC IMPLTJ CRNL NRV NSTIM ELTRDS & PULSE GENER','INC IMPLTJ CRNL NRV NSTIM ELTRDS & PULSE GENER','64568','1','','1','0','','','',0, 1, 0, 0),
(5645,'REVISION/REPLMT NEUROSTIMLATOR ELTRD CRANIAL NRV','REVISION/REPLMT NEUROSTIMLATOR ELTRD CRANIAL NRV','64569','1','','1','0','','','',0, 1, 0, 0),
(5646,'REMOVAL CRNL NRV NSTIM ELTRDS & PULSE GENERATO','REMOVAL CRNL NRV NSTIM ELTRDS & PULSE GENERATO','64570','1','','1','0','','','',0, 1, 0, 0),
(5647,'INC IMPLTJ PERIPH NERVE NEUROSTIMULATOR ELTRD','INC IMPLTJ PERIPH NERVE NEUROSTIMULATOR ELTRD','64575','1','','1','0','','','',0, 1, 0, 0),
(5648,'INC IMPLTJ NSTIM ELTRD NEUROMUSCULAR','INC IMPLTJ NSTIM ELTRD NEUROMUSCULAR','64580','1','','1','0','','','',0, 1, 0, 0),
(5649,'INC IMPLTJ NEUROSTIMULATOR ELTRD SACRAL NERVE','INC IMPLTJ NEUROSTIMULATOR ELTRD SACRAL NERVE','64581','1','','1','0','','','',0, 1, 0, 0),
(5650,'REVJ/RMVL PERIPHERAL NEUROSTIMULATOR ELECTRODE','REVJ/RMVL PERIPHERAL NEUROSTIMULATOR ELECTRODE','64585','1','','1','0','','','',0, 1, 0, 0),
(5651,'INSERTION/RPLCMT PERIPHERAL/GASTRIC NPGR','INSERTION/RPLCMT PERIPHERAL/GASTRIC NPGR','64590','1','','1','0','','','',0, 1, 0, 0),
(5652,'REVISION/RMVL PERIPHERAL/GASTRIC NPGR','REVISION/RMVL PERIPHERAL/GASTRIC NPGR','64595','1','','1','0','','','',0, 1, 0, 0),
(5653,'DSTRJ TRIGEMINAL NRV SUPRAORB INFRAORB BRANCH','DSTRJ TRIGEMINAL NRV SUPRAORB INFRAORB BRANCH','64600','1','','1','0','','','',0, 1, 0, 0),
(5654,'DSTRJ NEUROLYTIC TRIGEMINAL NRV 2/3 DIV BRANCH','DSTRJ NEUROLYTIC TRIGEMINAL NRV 2/3 DIV BRANCH','64605','1','','1','0','','','',0, 1, 0, 0),
(5655,'DSTRJ NEURLYTIC TRIGEM NRV 2/3 DIV RADIO MONITOR','DSTRJ NEURLYTIC TRIGEM NRV 2/3 DIV RADIO MONITOR','64610','1','','1','0','','','',0, 1, 0, 0),
(5656,'CHEMODENERV PAROTID&SUBMANDIBL SALIVARY GLNDS','CHEMODENERV PAROTID&SUBMANDIBL SALIVARY GLNDS','64611','1','','1','0','','','',0, 1, 0, 0),
(5657,'CHEMODNRVTJ MUSC MUSC INNERVATED FACIAL NRV UNIL','CHEMODNRVTJ MUSC MUSC INNERVATED FACIAL NRV UNIL','64612','1','','1','0','','','',0, 1, 0, 0),
(5658,'CHEMODERVATE FACIAL/TRIGEM/CERV MUSC MIGRAINE','CHEMODERVATE FACIAL/TRIGEM/CERV MUSC MIGRAINE','64615','1','','1','0','','','',0, 1, 0, 0),
(5659,'CHEMODENERVATION MUSCLE NECK UNILAT FOR DYSTONIA','CHEMODENERVATION MUSCLE NECK UNILAT FOR DYSTONIA','64616','1','','1','0','','','',0, 1, 0, 0),
(5660,'CHEMODENERVATION MUSCLE LARYNX UNILAT W/EMG','CHEMODENERVATION MUSCLE LARYNX UNILAT W/EMG','64617','1','','1','0','','','',0, 1, 0, 0),
(5661,'DSTRJ NEUROLYTIC AGENT INTERCOSTAL NERVE','DSTRJ NEUROLYTIC AGENT INTERCOSTAL NERVE','64620','1','','1','0','','','',0, 1, 0, 0),
(5662,'DSTRJ NEUROLYTIC AGENT PUDENDAL NERVE','DSTRJ NEUROLYTIC AGENT PUDENDAL NERVE','64630','1','','1','0','','','',0, 1, 0, 0),
(5663,'DSTRJ NEUROLYTIC PLANTAR COMMON DIGITAL NERVE','DSTRJ NEUROLYTIC PLANTAR COMMON DIGITAL NERVE','64632','1','','1','0','','','',0, 1, 0, 0),
(5664,'DSTR NROLYTC AGNT PARVERTEB FCT SNGL CRVCL/THORA','DSTR NROLYTC AGNT PARVERTEB FCT SNGL CRVCL/THORA','64633','1','','1','0','','','',0, 1, 0, 0),
(5665,'DSTR NROLYTC AGNT PARVERTEB FCT ADDL CRVCL/THORA','DSTR NROLYTC AGNT PARVERTEB FCT ADDL CRVCL/THORA','64634','1','','1','0','','','',0, 1, 0, 0),
(5666,'DSTR NROLYTC AGNT PARVERTEB FCT SNGL LMBR/SACRAL','DSTR NROLYTC AGNT PARVERTEB FCT SNGL LMBR/SACRAL','64635','1','','1','0','','','',0, 1, 0, 0),
(5667,'DSTR NROLYTC AGNT PARVERTEB FCT ADDL LMBR/SACRAL','DSTR NROLYTC AGNT PARVERTEB FCT ADDL LMBR/SACRAL','64636','1','','1','0','','','',0, 1, 0, 0),
(5668,'DSTRJ NEUROLYTIC AGENT OTHER PERIPHERAL NERVE','DSTRJ NEUROLYTIC AGENT OTHER PERIPHERAL NERVE','64640','1','','1','0','','','',0, 1, 0, 0),
(5669,'CHEMODENERVATION ONE EXTREMITY 1-4 MUSCLE','CHEMODENERVATION ONE EXTREMITY 1-4 MUSCLE','64642','1','','1','0','','','',0, 1, 0, 0),
(5670,'CHEMODENERVATION 1 EXTREMITY EA ADDL 1-4 MUSCLE','CHEMODENERVATION 1 EXTREMITY EA ADDL 1-4 MUSCLE','64643','1','','1','0','','','',0, 1, 0, 0),
(5671,'CHEMODENERVATION 1 EXTREMITY 5 OR MORE MUSCLES','CHEMODENERVATION 1 EXTREMITY 5 OR MORE MUSCLES','64644','1','','1','0','','','',0, 1, 0, 0),
(5672,'CHEMODENERVATION 1 EXTREMITY EA ADDL 5/> MUSCLES','CHEMODENERVATION 1 EXTREMITY EA ADDL 5/> MUSCLES','64645','1','','1','0','','','',0, 1, 0, 0),
(5673,'CHEMODENERVATION OF TRUNK MUSCLE 1-5 MUSCLES','CHEMODENERVATION OF TRUNK MUSCLE 1-5 MUSCLES','64646','1','','1','0','','','',0, 1, 0, 0),
(5674,'CHEMODENERVATION OF TRUNK 6 OR MORE MUSCLES','CHEMODENERVATION OF TRUNK 6 OR MORE MUSCLES','64647','1','','1','0','','','',0, 1, 0, 0),
(5675,'CHEMODENERVATION ECCRINE GLANDS BOTH AXILLAE','CHEMODENERVATION ECCRINE GLANDS BOTH AXILLAE','64650','1','','1','0','','','',0, 1, 0, 0),
(5676,'CHEMODENERVATION ECCRINE GLANDS OTH AREA PER DAY','CHEMODENERVATION ECCRINE GLANDS OTH AREA PER DAY','64653','1','','1','0','','','',0, 1, 0, 0),
(5677,'DSTRJ NEUROLYTIC W/WO RAD MONITOR CELIAC PLEXUS','DSTRJ NEUROLYTIC W/WO RAD MONITOR CELIAC PLEXUS','64680','1','','1','0','','','',0, 1, 0, 0),
(5678,'DSTRJ NULYT W/WORAD MNTR SUPRIOR HYPOGSTR PLEXUS','DSTRJ NULYT W/WORAD MNTR SUPRIOR HYPOGSTR PLEXUS','64681','1','','1','0','','','',0, 1, 0, 0),
(5679,'NEUROPLASTY DIGITAL 1/BOTH SAME DIGIT','NEUROPLASTY DIGITAL 1/BOTH SAME DIGIT','64702','1','','1','0','','','',0, 1, 0, 0),
(5680,'NEUROPLASTY NERVE HAND/FOOT','NEUROPLASTY NERVE HAND/FOOT','64704','1','','1','0','','','',0, 1, 0, 0),
(5681,'NEURP MAJOR PRPH NRV ARM/LEG OPN OTH/THN SPEC','NEURP MAJOR PRPH NRV ARM/LEG OPN OTH/THN SPEC','64708','1','','1','0','','','',0, 1, 0, 0),
(5682,'NEURP MAJOR PRPH NRV OPN ARM/LEG SCIATIC NRV','NEURP MAJOR PRPH NRV OPN ARM/LEG SCIATIC NRV','64712','1','','1','0','','','',0, 1, 0, 0),
(5683,'NEURP MAJOR PRPH NRV OPN ARM/LEG BRACH PLEXUS','NEURP MAJOR PRPH NRV OPN ARM/LEG BRACH PLEXUS','64713','1','','1','0','','','',0, 1, 0, 0),
(5684,'NEURP MAJOR PRPH NRV OPN ARM/LEG LMBR PLEXUS','NEURP MAJOR PRPH NRV OPN ARM/LEG LMBR PLEXUS','64714','1','','1','0','','','',0, 1, 0, 0),
(5685,'NEUROPLASTY &/TRANSPOSITION CRANIAL NERVE','NEUROPLASTY &/TRANSPOSITION CRANIAL NERVE','64716','1','','1','0','','','',0, 1, 0, 0),
(5686,'NEUROPLASTY &/TRANSPOSITION ULNAR NERVE ELBOW','NEUROPLASTY &/TRANSPOSITION ULNAR NERVE ELBOW','64718','1','','1','0','','','',0, 1, 0, 0),
(5687,'NEUROPLASTY &/TRANSPOSITION ULNAR NERVE WRIST','NEUROPLASTY &/TRANSPOSITION ULNAR NERVE WRIST','64719','1','','1','0','','','',0, 1, 0, 0),
(5688,'NEUROPLASTY &/TRANSPOS MEDIAN NRV CARPAL TUNNE','NEUROPLASTY &/TRANSPOS MEDIAN NRV CARPAL TUNNE','64721','1','','1','0','','','',0, 1, 0, 0),
(5689,'DECOMPRESSION UNSPECIFIED NERVE','DECOMPRESSION UNSPECIFIED NERVE','64722','1','','1','0','','','',0, 1, 0, 0),
(5690,'DECOMPRESSION PLANTAR DIGITAL NERVE','DECOMPRESSION PLANTAR DIGITAL NERVE','64726','1','','1','0','','','',0, 1, 0, 0),
(5691,'INTERNAL NEUROLYSIS REQ OPERATING MICROSCOPE','INTERNAL NEUROLYSIS REQ OPERATING MICROSCOPE','64727','1','','1','0','','','',0, 1, 0, 0),
(5692,'TRANSECTION/AVULSION SUPRAORBITAL NERVE','TRANSECTION/AVULSION SUPRAORBITAL NERVE','64732','1','','1','0','','','',0, 1, 0, 0),
(5693,'TRANSECTION/AVULSION INFRAORBITAL NERVE','TRANSECTION/AVULSION INFRAORBITAL NERVE','64734','1','','1','0','','','',0, 1, 0, 0),
(5694,'TRANSECTION/AVULSION MENTAL NERVE','TRANSECTION/AVULSION MENTAL NERVE','64736','1','','1','0','','','',0, 1, 0, 0),
(5695,'TRANSECTION/AVULSION INF ALVEOLAR NRV W/OSTEO','TRANSECTION/AVULSION INF ALVEOLAR NRV W/OSTEO','64738','1','','1','0','','','',0, 1, 0, 0),
(5696,'TRANSECTION/AVULSION LINGUAL NERVE','TRANSECTION/AVULSION LINGUAL NERVE','64740','1','','1','0','','','',0, 1, 0, 0),
(5697,'TRANSECTION/AVULSION FACIAL NRV DIFFERENT/CMPL','TRANSECTION/AVULSION FACIAL NRV DIFFERENT/CMPL','64742','1','','1','0','','','',0, 1, 0, 0),
(5698,'TRANSECTION/AVULSION GREATER OCCIPITAL NERVE','TRANSECTION/AVULSION GREATER OCCIPITAL NERVE','64744','1','','1','0','','','',0, 1, 0, 0),
(5699,'TRANSECTION/AVULSION PHRENIC NERVE','TRANSECTION/AVULSION PHRENIC NERVE','64746','1','','1','0','','','',0, 1, 0, 0),
(5700,'TRANSECTION/AVULSION VAGUS NERVES','TRANSECTION/AVULSION VAGUS NERVES','64755','1','','1','0','','','',0, 1, 0, 0),
(5701,'TRANSECTION/AVULSION VAGUS NERVE ABDOMINAL','TRANSECTION/AVULSION VAGUS NERVE ABDOMINAL','64760','1','','1','0','','','',0, 1, 0, 0),
(5702,'TRNSXJ/AVLSN OBTURAT NRV XPELV W/WO TENOTOMY','TRNSXJ/AVLSN OBTURAT NRV XPELV W/WO TENOTOMY','64763','1','','1','0','','','',0, 1, 0, 0),
(5703,'TRNSXJ/AVLSN OBTURAT NRV INPELV W/WO TENOTOMY','TRNSXJ/AVLSN OBTURAT NRV INPELV W/WO TENOTOMY','64766','1','','1','0','','','',0, 1, 0, 0),
(5704,'TRANSECTION/AVULSION OTH CRANIAL NRV XDRL','TRANSECTION/AVULSION OTH CRANIAL NRV XDRL','64771','1','','1','0','','','',0, 1, 0, 0),
(5705,'TRANSECTION/AVULSION OTH SPINAL NRV XDRL','TRANSECTION/AVULSION OTH SPINAL NRV XDRL','64772','1','','1','0','','','',0, 1, 0, 0),
(5706,'EXC NEUROMA CUTAN NRV SURGLY IDENTIFIABLE','EXC NEUROMA CUTAN NRV SURGLY IDENTIFIABLE','64774','1','','1','0','','','',0, 1, 0, 0),
(5707,'EXC NEUROMA DIGITAL NERVE 1 OR BOTH SAME DIGIT','EXC NEUROMA DIGITAL NERVE 1 OR BOTH SAME DIGIT','64776','1','','1','0','','','',0, 1, 0, 0),
(5708,'EXCISION NEUROMA DIGITAL NRV EA ADDL DIGIT','EXCISION NEUROMA DIGITAL NRV EA ADDL DIGIT','64778','1','','1','0','','','',0, 1, 0, 0),
(5709,'EXC NEUROMA HAND/FOOT XCP DIGITAL NERVE','EXC NEUROMA HAND/FOOT XCP DIGITAL NERVE','64782','1','','1','0','','','',0, 1, 0, 0),
(5710,'EXC NEUROMA HAND/FOOT EA NRV XCP SM DGT','EXC NEUROMA HAND/FOOT EA NRV XCP SM DGT','64783','1','','1','0','','','',0, 1, 0, 0),
(5711,'EXC NEUROMA MAJOR PERIPHERAL NRV XCP SCIATIC','EXC NEUROMA MAJOR PERIPHERAL NRV XCP SCIATIC','64784','1','','1','0','','','',0, 1, 0, 0),
(5712,'EXCISION NEUROMA SCIATIC NERVE','EXCISION NEUROMA SCIATIC NERVE','64786','1','','1','0','','','',0, 1, 0, 0),
(5713,'IMPLANTATION NERVE END BONE/MUSCLE','IMPLANTATION NERVE END BONE/MUSCLE','64787','1','','1','0','','','',0, 1, 0, 0),
(5714,'EXC NEUROFIBROMA/NEUROLEMMOMA CUTAN NRV','EXC NEUROFIBROMA/NEUROLEMMOMA CUTAN NRV','64788','1','','1','0','','','',0, 1, 0, 0),
(5715,'EXC NEUROFIBROMA/NEUROLEMMOMA MAJOR PRPH NRV','EXC NEUROFIBROMA/NEUROLEMMOMA MAJOR PRPH NRV','64790','1','','1','0','','','',0, 1, 0, 0),
(5716,'EXC NEUROFIBROMA/NEUROLEMMOMA EXTNSV','EXC NEUROFIBROMA/NEUROLEMMOMA EXTNSV','64792','1','','1','0','','','',0, 1, 0, 0),
(5717,'BIOPSY NERVE','BIOPSY NERVE','64795','1','','1','0','','','',0, 1, 0, 0),
(5718,'SYMPATHECTOMY CERVICAL','SYMPATHECTOMY CERVICAL','64802','1','','1','0','','','',0, 1, 0, 0),
(5719,'SYMPATHECTOMY CERVICOTHORACIC','SYMPATHECTOMY CERVICOTHORACIC','64804','1','','1','0','','','',0, 1, 0, 0),
(5720,'SYMPATHECTOMY THORACOLUMBAR','SYMPATHECTOMY THORACOLUMBAR','64809','1','','1','0','','','',0, 1, 0, 0),
(5721,'SYMPATHECTOMY LUMBAR','SYMPATHECTOMY LUMBAR','64818','1','','1','0','','','',0, 1, 0, 0),
(5722,'SYMPATHECTOMY DIGITAL ARTERIES EACH DIGIT','SYMPATHECTOMY DIGITAL ARTERIES EACH DIGIT','64820','1','','1','0','','','',0, 1, 0, 0),
(5723,'SYMPATHECTOMY RADIAL ARTERY','SYMPATHECTOMY RADIAL ARTERY','64821','1','','1','0','','','',0, 1, 0, 0),
(5724,'SYMPATHECTOMY ULNAR ARTERY','SYMPATHECTOMY ULNAR ARTERY','64822','1','','1','0','','','',0, 1, 0, 0),
(5725,'SYMPATHECTOMY SUPERFICIAL PALMAR ARCH','SYMPATHECTOMY SUPERFICIAL PALMAR ARCH','64823','1','','1','0','','','',0, 1, 0, 0),
(5726,'SUTURE DIGITAL NERVE HAND/FOOT 1 NERVE','SUTURE DIGITAL NERVE HAND/FOOT 1 NERVE','64831','1','','1','0','','','',0, 1, 0, 0),
(5727,'SUTR DIGITAL NRV HAND/FOOT EA DGTAL NRV','SUTR DIGITAL NRV HAND/FOOT EA DGTAL NRV','64832','1','','1','0','','','',0, 1, 0, 0),
(5728,'SUTURE 1 NERVE HAND/FOOT COMMON SENSORY NERVE','SUTURE 1 NERVE HAND/FOOT COMMON SENSORY NERVE','64834','1','','1','0','','','',0, 1, 0, 0),
(5729,'SUTURE 1 NERVE MEDIAN MOTOR THENAR','SUTURE 1 NERVE MEDIAN MOTOR THENAR','64835','1','','1','0','','','',0, 1, 0, 0),
(5730,'SUTURE 1 NERVE ULNAR MOTOR','SUTURE 1 NERVE ULNAR MOTOR','64836','1','','1','0','','','',0, 1, 0, 0),
(5731,'SUTURE EACH ADDITIONAL NERVE HAND/FOOT','SUTURE EACH ADDITIONAL NERVE HAND/FOOT','64837','1','','1','0','','','',0, 1, 0, 0),
(5732,'SUTURE POSTERIOR TIBIAL NERVE','SUTURE POSTERIOR TIBIAL NERVE','64840','1','','1','0','','','',0, 1, 0, 0),
(5733,'SUTR PRPH NRV ARM/LEG XCP SCIATIC W/TRPOS','SUTR PRPH NRV ARM/LEG XCP SCIATIC W/TRPOS','64856','1','','1','0','','','',0, 1, 0, 0),
(5734,'SUTR PRPH NRV ARM/LEG XCP SCIATIC W/O TRPOS','SUTR PRPH NRV ARM/LEG XCP SCIATIC W/O TRPOS','64857','1','','1','0','','','',0, 1, 0, 0),
(5735,'SUTURE SCIATIC NERVE','SUTURE SCIATIC NERVE','64858','1','','1','0','','','',0, 1, 0, 0),
(5736,'SUTURE EACH ADDITIONAL PERIPHERAL NERVE','SUTURE EACH ADDITIONAL PERIPHERAL NERVE','64859','1','','1','0','','','',0, 1, 0, 0),
(5737,'SUTURE BRACHIAL PLEXUS','SUTURE BRACHIAL PLEXUS','64861','1','','1','0','','','',0, 1, 0, 0),
(5738,'SUTURE LUMBAR PLEXUS','SUTURE LUMBAR PLEXUS','64862','1','','1','0','','','',0, 1, 0, 0),
(5739,'SUTURE FACIAL NERVE EXTRACRANIAL','SUTURE FACIAL NERVE EXTRACRANIAL','64864','1','','1','0','','','',0, 1, 0, 0),
(5740,'SUTURE FACIAL NERVE INFRATEMPORAL W/WO GRAFT','SUTURE FACIAL NERVE INFRATEMPORAL W/WO GRAFT','64865','1','','1','0','','','',0, 1, 0, 0),
(5741,'ANASTOMOSIS FACIAL-SPINAL ACCESSORY','ANASTOMOSIS FACIAL-SPINAL ACCESSORY','64866','1','','1','0','','','',0, 1, 0, 0),
(5742,'ANASTOMOSIS FACIAL HYPOGLOSSAL','ANASTOMOSIS FACIAL HYPOGLOSSAL','64868','1','','1','0','','','',0, 1, 0, 0),
(5743,'SUTURE NERVE REQ SECONDARY/DELAYED SUTURE','SUTURE NERVE REQ SECONDARY/DELAYED SUTURE','64872','1','','1','0','','','',0, 1, 0, 0),
(5744,'SUTURE NERVE REQ XTNSV MOBIL/TRPOS NERVE','SUTURE NERVE REQ XTNSV MOBIL/TRPOS NERVE','64874','1','','1','0','','','',0, 1, 0, 0),
(5745,'SUTURE NERVE REQ SHORTENING BONE EXTREMITY','SUTURE NERVE REQ SHORTENING BONE EXTREMITY','64876','1','','1','0','','','',0, 1, 0, 0),
(5746,'NERVE GRAFT HEAD/NECK </ 4 CM','NERVE GRAFT HEAD/NECK </ 4 CM','64885','1','','1','0','','','',0, 1, 0, 0),
(5747,'NERVE GRAFT HEAD/NECK >4 CM','NERVE GRAFT HEAD/NECK >4 CM','64886','1','','1','0','','','',0, 1, 0, 0),
(5748,'NERVE GRAFT 1 STRAND HAND/FOOT </4 CM','NERVE GRAFT 1 STRAND HAND/FOOT </4 CM','64890','1','','1','0','','','',0, 1, 0, 0),
(5749,'NRV GRF 1 STRAND HAND/FOOT >4 CM','NRV GRF 1 STRAND HAND/FOOT >4 CM','64891','1','','1','0','','','',0, 1, 0, 0),
(5750,'NERVE GRAFT 1 STRAND ARM/LEG <4 CM','NERVE GRAFT 1 STRAND ARM/LEG <4 CM','64892','1','','1','0','','','',0, 1, 0, 0),
(5751,'NERVE GRAFT 1 STRAND ARM/LEG >4 CM','NERVE GRAFT 1 STRAND ARM/LEG >4 CM','64893','1','','1','0','','','',0, 1, 0, 0),
(5752,'NERVE GRAFT MLT STRANDS HAND/FOOT </4 CM','NERVE GRAFT MLT STRANDS HAND/FOOT </4 CM','64895','1','','1','0','','','',0, 1, 0, 0),
(5753,'NERVE GRAFT MLT STRANDS HAND/FOOT > 4 CM','NERVE GRAFT MLT STRANDS HAND/FOOT > 4 CM','64896','1','','1','0','','','',0, 1, 0, 0),
(5754,'NERVE GRAFT MLT STRANDS ARM/LEG </4 CM','NERVE GRAFT MLT STRANDS ARM/LEG </4 CM','64897','1','','1','0','','','',0, 1, 0, 0),
(5755,'NERVE GRAFT MLT STRANDS ARM/LEG >4 CM','NERVE GRAFT MLT STRANDS ARM/LEG >4 CM','64898','1','','1','0','','','',0, 1, 0, 0),
(5756,'NERVE GRAFT EACH NERVE 1 STRAND','NERVE GRAFT EACH NERVE 1 STRAND','64901','1','','1','0','','','',0, 1, 0, 0),
(5757,'NERVE GRAFT EACH NERVE MULTIPLE STRANDS','NERVE GRAFT EACH NERVE MULTIPLE STRANDS','64902','1','','1','0','','','',0, 1, 0, 0),
(5758,'NERVE PEDICLE TRANSFER FIRST STAGE','NERVE PEDICLE TRANSFER FIRST STAGE','64905','1','','1','0','','','',0, 1, 0, 0),
(5759,'NERVE PEDICAL TRANSFER SECOND STAGE','NERVE PEDICAL TRANSFER SECOND STAGE','64907','1','','1','0','','','',0, 1, 0, 0),
(5760,'NERVE REPAIR W/CONDUIT EACH NERVE','NERVE REPAIR W/CONDUIT EACH NERVE','64910','1','','1','0','','','',0, 1, 0, 0),
(5761,'NERVE REPAIR W/AUTOGENOUS VEIN GRAFT EA NERVE','NERVE REPAIR W/AUTOGENOUS VEIN GRAFT EA NERVE','64911','1','','1','0','','','',0, 1, 0, 0),
(5762,'UNLISTED PROCEDURE NERVOUS SYSTEM','UNLISTED PROCEDURE NERVOUS SYSTEM','64999','1','','1','0','','','',0, 1, 0, 0),
(5763,'EVISCERATION OCULAR CONTENTS W/O IMPLANT','EVISCERATION OCULAR CONTENTS W/O IMPLANT','65091','1','','1','0','','','',0, 1, 0, 0),
(5764,'EVISCERATION OCULAR CONTENTS W/IMPLANT','EVISCERATION OCULAR CONTENTS W/IMPLANT','65093','1','','1','0','','','',0, 1, 0, 0),
(5765,'ENUCLEATION OF EYE W/O IMPLANT','ENUCLEATION OF EYE W/O IMPLANT','65101','1','','1','0','','','',0, 1, 0, 0),
(5766,'ENUCLEATION EYE IMPLT MUSC X ATTACHED IMPLT','ENUCLEATION EYE IMPLT MUSC X ATTACHED IMPLT','65103','1','','1','0','','','',0, 1, 0, 0),
(5767,'ENUCLEATION EYE IMPLT MUSC ATTACHED IMPLT','ENUCLEATION EYE IMPLT MUSC ATTACHED IMPLT','65105','1','','1','0','','','',0, 1, 0, 0),
(5768,'EXENTERATION ORBIT REMVL ORBITAL CONTENTS ONLY','EXENTERATION ORBIT REMVL ORBITAL CONTENTS ONLY','65110','1','','1','0','','','',0, 1, 0, 0),
(5769,'EXENTERATION ORBIT RMVL ORBIT CONTENTS & BONE','EXENTERATION ORBIT RMVL ORBIT CONTENTS & BONE','65112','1','','1','0','','','',0, 1, 0, 0),
(5770,'EXNTJ ORBIT RMVL ORB CNTS W/MUSC/MYOQ FLAP','EXNTJ ORBIT RMVL ORB CNTS W/MUSC/MYOQ FLAP','65114','1','','1','0','','','',0, 1, 0, 0),
(5771,'MODIFICAJ OC IMPLT W/PLMT/RPLCMT PEGS SPX','MODIFICAJ OC IMPLT W/PLMT/RPLCMT PEGS SPX','65125','1','','1','0','','','',0, 1, 0, 0),
(5772,'INSJ OC IMPLT SEC AFTER EVSC SCLL SHELL','INSJ OC IMPLT SEC AFTER EVSC SCLL SHELL','65130','1','','1','0','','','',0, 1, 0, 0),
(5773,'INSJ OC IMPLT AFTER ENCL MUSC X ATTACHED','INSJ OC IMPLT AFTER ENCL MUSC X ATTACHED','65135','1','','1','0','','','',0, 1, 0, 0),
(5774,'INSJ OC IMPLT AFTER ENCL MUSC ATTACHED','INSJ OC IMPLT AFTER ENCL MUSC ATTACHED','65140','1','','1','0','','','',0, 1, 0, 0),
(5775,'REINSERTION OCULAR IMPLT W/WO CONJUNCTIVAL GRAFT','REINSERTION OCULAR IMPLT W/WO CONJUNCTIVAL GRAFT','65150','1','','1','0','','','',0, 1, 0, 0),
(5776,'REINSERTION OCULAR IMPLT RNFCMT &/ ATTACH MUSCLE','REINSERTION OCULAR IMPLT RNFCMT &/ ATTACH MUSCLE','65155','1','','1','0','','','',0, 1, 0, 0),
(5777,'REMOVAL OCULAR IMPLANT','REMOVAL OCULAR IMPLANT','65175','1','','1','0','','','',0, 1, 0, 0),
(5778,'REMOVAL FB EYE CONJUNCTIVAL SUPERFICIAL','REMOVAL FB EYE CONJUNCTIVAL SUPERFICIAL','65205','1','','1','0','','','',0, 1, 0, 0),
(5779,'RMVL FB XTRNL EYE EMBED SCJNCL/SCLERAL NONPERFOR','RMVL FB XTRNL EYE EMBED SCJNCL/SCLERAL NONPERFOR','65210','1','','1','0','','','',0, 1, 0, 0),
(5780,'RMVL FB XTRNL EYE CORNEAL W/O SLIT LAMP','RMVL FB XTRNL EYE CORNEAL W/O SLIT LAMP','65220','1','','1','0','','','',0, 1, 0, 0),
(5781,'RMVL FB XTRNL EYE CORNEAL W/SLIT LAMP','RMVL FB XTRNL EYE CORNEAL W/SLIT LAMP','65222','1','','1','0','','','',0, 1, 0, 0),
(5782,'RMVL FB INTRAOCULAR ANT CHAMBER EYE/LENS','RMVL FB INTRAOCULAR ANT CHAMBER EYE/LENS','65235','1','','1','0','','','',0, 1, 0, 0),
(5783,'RMVL FB IO FROM POST SEG MAG XTRJ ANT/POST ROUTE','RMVL FB IO FROM POST SEG MAG XTRJ ANT/POST ROUTE','65260','1','','1','0','','','',0, 1, 0, 0),
(5784,'RMVL FB IO FROM POST SEG NONMAGNETIC XTRJ','RMVL FB IO FROM POST SEG NONMAGNETIC XTRJ','65265','1','','1','0','','','',0, 1, 0, 0),
(5785,'RPR LAC CJNC W/WO NONPERFOR LAC SCLERA DIR CLSR','RPR LAC CJNC W/WO NONPERFOR LAC SCLERA DIR CLSR','65270','1','','1','0','','','',0, 1, 0, 0),
(5786,'RPR LAC CJNC MOBLJ& REARGMT W/O HOSPITALIZATION','RPR LAC CJNC MOBLJ& REARGMT W/O HOSPITALIZATION','65272','1','','1','0','','','',0, 1, 0, 0),
(5787,'RPR LAC CJNC MOBLJ & REARGMT W/HOSPIZATION','RPR LAC CJNC MOBLJ & REARGMT W/HOSPIZATION','65273','1','','1','0','','','',0, 1, 0, 0),
(5788,'RPR LAC CORNEA NONPERFOR W/WO RMVL FOREIGN BODY','RPR LAC CORNEA NONPERFOR W/WO RMVL FOREIGN BODY','65275','1','','1','0','','','',0, 1, 0, 0),
(5789,'RPR LAC CORNEA&/SCLERA PERFOR X INVG UVEAL TIS','RPR LAC CORNEA&/SCLERA PERFOR X INVG UVEAL TIS','65280','1','','1','0','','','',0, 1, 0, 0),
(5790,'RPR LAC CORN&/SCLRA PERF W/REPOS/RESCJ UVEAL T','RPR LAC CORN&/SCLRA PERF W/REPOS/RESCJ UVEAL T','65285','1','','1','0','','','',0, 1, 0, 0),
(5791,'RPR LAC APPL TISSUE GLUE WOUND CORNEA&/SCLERA','RPR LAC APPL TISSUE GLUE WOUND CORNEA&/SCLERA','65286','1','','1','0','','','',0, 1, 0, 0),
(5792,'RPR WND EXTRAOCULAR MUSCLE TENDON&/TENON CAPSU','RPR WND EXTRAOCULAR MUSCLE TENDON&/TENON CAPSU','65290','1','','1','0','','','',0, 1, 0, 0),
(5793,'EXCISION LESION CORNEA XCP PTERYGIUM','EXCISION LESION CORNEA XCP PTERYGIUM','65400','1','','1','0','','','',0, 1, 0, 0),
(5794,'BIOPSY CORNEA','BIOPSY CORNEA','65410','1','','1','0','','','',0, 1, 0, 0),
(5795,'EXCISION/TRANSPOSITION PTERYGIUM W/O GRAFT','EXCISION/TRANSPOSITION PTERYGIUM W/O GRAFT','65420','1','','1','0','','','',0, 1, 0, 0),
(5796,'EXCISION/TRANSPOSITION PTERYGIUM W/GRAFG','EXCISION/TRANSPOSITION PTERYGIUM W/GRAFG','65426','1','','1','0','','','',0, 1, 0, 0),
(5797,'CORNEA SCRAPING DIAGNOSTIC SMEAR &/CULTURE','CORNEA SCRAPING DIAGNOSTIC SMEAR &/CULTURE','65430','1','','1','0','','','',0, 1, 0, 0),
(5798,'RMVL CORNEAL EPITHELIUM W/WO CHEMOCAUTERIZATION','RMVL CORNEAL EPITHELIUM W/WO CHEMOCAUTERIZATION','65435','1','','1','0','','','',0, 1, 0, 0),
(5799,'RMVL CORNEAL EPITHELIUM W/APPL CHELATING AGENT','RMVL CORNEAL EPITHELIUM W/APPL CHELATING AGENT','65436','1','','1','0','','','',0, 1, 0, 0),
(5800,'DSTRJ LESION CRYOTHER PHOTO/THERMOCAUTZATION','DSTRJ LESION CRYOTHER PHOTO/THERMOCAUTZATION','65450','1','','1','0','','','',0, 1, 0, 0),
(5801,'MULTIPLE PUNCTURES ANTERIOR CORNEA','MULTIPLE PUNCTURES ANTERIOR CORNEA','65600','1','','1','0','','','',0, 1, 0, 0),
(5802,'KERATOPLASTY ANTERIOR LAMELLAR','KERATOPLASTY ANTERIOR LAMELLAR','65710','1','','1','0','','','',0, 1, 0, 0),
(5803,'KERATOPLASTY PENTRG EXCEPT APHAKIA/PSEUDOPHAKIA','KERATOPLASTY PENTRG EXCEPT APHAKIA/PSEUDOPHAKIA','65730','1','','1','0','','','',0, 1, 0, 0),
(5804,'KERATOPLASTY PENETRAING APHAKIA','KERATOPLASTY PENETRAING APHAKIA','65750','1','','1','0','','','',0, 1, 0, 0),
(5805,'KERATOPLASTY PENETRATING PSEUDOPHAKIA','KERATOPLASTY PENETRATING PSEUDOPHAKIA','65755','1','','1','0','','','',0, 1, 0, 0),
(5806,'KERATOPLASTY ENDOTHELIAL','KERATOPLASTY ENDOTHELIAL','65756','1','','1','0','','','',0, 1, 0, 0),
(5807,'BACKBENCH PREPJ CORNEAL ENDOTHELIAL ALLOGRAFT','BACKBENCH PREPJ CORNEAL ENDOTHELIAL ALLOGRAFT','65757','1','','1','0','','','',0, 1, 0, 0),
(5808,'KERATOMILEUSIS','KERATOMILEUSIS','65760','1','','1','0','','','',0, 1, 0, 0),
(5809,'KERATOPHAKIA','KERATOPHAKIA','65765','1','','1','0','','','',0, 1, 0, 0),
(5810,'EPIKERATOPLASTY','EPIKERATOPLASTY','65767','1','','1','0','','','',0, 1, 0, 0),
(5811,'KERATOPROSTHESIS','KERATOPROSTHESIS','65770','1','','1','0','','','',0, 1, 0, 0),
(5812,'RADIAL KERATOTOMY','RADIAL KERATOTOMY','65771','1','','1','0','','','',0, 1, 0, 0),
(5813,'CRNL RELAXING INC CORRJ INDUCED ASTIGMATISM','CRNL RELAXING INC CORRJ INDUCED ASTIGMATISM','65772','1','','1','0','','','',0, 1, 0, 0),
(5814,'CRNL WEDGE RESCJ CORRJ INDUCED ASTIGMATISM','CRNL WEDGE RESCJ CORRJ INDUCED ASTIGMATISM','65775','1','','1','0','','','',0, 1, 0, 0),
(5815,'PLACE AMNIOTIC MEMBRA OCULAR SURFACE W/O SUTURES','PLACE AMNIOTIC MEMBRA OCULAR SURFACE W/O SUTURES','65778','1','','1','0','','','',0, 1, 0, 0),
(5816,'PLACE AMNIOTIC MEMBRANE OCULAR SURFACE SUTURED','PLACE AMNIOTIC MEMBRANE OCULAR SURFACE SUTURED','65779','1','','1','0','','','',0, 1, 0, 0),
(5817,'OCULAR SURFACE RECONSTRUCTION AMNIOTIC MEMBRANE','OCULAR SURFACE RECONSTRUCTION AMNIOTIC MEMBRANE','65780','1','','1','0','','','',0, 1, 0, 0),
(5818,'OCULAR SURFACE RECONSTRUCTION LIMBAL ALLOGRAFT','OCULAR SURFACE RECONSTRUCTION LIMBAL ALLOGRAFT','65781','1','','1','0','','','',0, 1, 0, 0),
(5819,'OCCULAR SURFACE RECONSTRUCTION LIMBAL AUTOGRAFT','OCCULAR SURFACE RECONSTRUCTION LIMBAL AUTOGRAFT','65782','1','','1','0','','','',0, 1, 0, 0),
(5820,'IMPLANTATION INTRASTROMAL CORNEAL RING SEGMENTS','IMPLANTATION INTRASTROMAL CORNEAL RING SEGMENTS','65785','1','','1','0','','','',0, 1, 0, 0),
(5821,'PARACENTSIS ANT CHAMB EYE ASPIR AQUEOUS SPX','PARACENTSIS ANT CHAMB EYE ASPIR AQUEOUS SPX','65800','1','','1','0','','','',0, 1, 0, 0),
(5822,'PARACENTSIS ANT CHAM RMVL VITREOUS W/WO AIR INJX','PARACENTSIS ANT CHAM RMVL VITREOUS W/WO AIR INJX','65810','1','','1','0','','','',0, 1, 0, 0),
(5823,'PARACEN ANT CHAM RMVL BLOOD W/WO IRRIG&/AIR IN','PARACEN ANT CHAM RMVL BLOOD W/WO IRRIG&/AIR IN','65815','1','','1','0','','','',0, 1, 0, 0),
(5824,'GONIOTOMY','GONIOTOMY','65820','1','','1','0','','','',0, 1, 0, 0),
(5825,'TRABECULOTOMY AB EXTERNO','TRABECULOTOMY AB EXTERNO','65850','1','','1','0','','','',0, 1, 0, 0),
(5826,'TRABECULOPLASTY BY LASER SURGERY','TRABECULOPLASTY BY LASER SURGERY','65855','1','','1','0','','','',0, 1, 0, 0),
(5827,'SEVERING ADHESIONS ANTERIOR SEGMENT LASER SPX','SEVERING ADHESIONS ANTERIOR SEGMENT LASER SPX','65860','1','','1','0','','','',0, 1, 0, 0),
(5828,'SEVERING ADS ANT SEG INCAL TQ SPX GONIOSYNECHIAE','SEVERING ADS ANT SEG INCAL TQ SPX GONIOSYNECHIAE','65865','1','','1','0','','','',0, 1, 0, 0),
(5829,'SEVERING ADS ANT SEG INCAL SPX ANT SYNECHIAE','SEVERING ADS ANT SEG INCAL SPX ANT SYNECHIAE','65870','1','','1','0','','','',0, 1, 0, 0),
(5830,'SEVERING ADS ANT SEG INCAL SPX POST SYNECHIAE','SEVERING ADS ANT SEG INCAL SPX POST SYNECHIAE','65875','1','','1','0','','','',0, 1, 0, 0),
(5831,'SEVERING ADS ANT SEG INCAL SPX CORNEOVITREAL','SEVERING ADS ANT SEG INCAL SPX CORNEOVITREAL','65880','1','','1','0','','','',0, 1, 0, 0),
(5832,'RMVL EPITHELIAL DOWNGROWTH ANT CHAMBER EYE','RMVL EPITHELIAL DOWNGROWTH ANT CHAMBER EYE','65900','1','','1','0','','','',0, 1, 0, 0),
(5833,'RMVL IMPLANTED MATERIAL ANTERIO SEGMENT EYE','RMVL IMPLANTED MATERIAL ANTERIO SEGMENT EYE','65920','1','','1','0','','','',0, 1, 0, 0),
(5834,'RMVL BLOOD CLOT ANTERIOR SEGMENT EYE','RMVL BLOOD CLOT ANTERIOR SEGMENT EYE','65930','1','','1','0','','','',0, 1, 0, 0),
(5835,'INJX ANTERIOR CHAMBER EYE AIR/LIQUID SPX','INJX ANTERIOR CHAMBER EYE AIR/LIQUID SPX','66020','1','','1','0','','','',0, 1, 0, 0),
(5836,'INJX ANTERIOR CHAMBER EYE MEDICATION SPX','INJX ANTERIOR CHAMBER EYE MEDICATION SPX','66030','1','','1','0','','','',0, 1, 0, 0),
(5837,'EXCISION LESION SCLERA','EXCISION LESION SCLERA','66130','1','','1','0','','','',0, 1, 0, 0),
(5838,'FSTLJ SCLERA GLAUCOMA TREPHIN W/IRIDECTOMY','FSTLJ SCLERA GLAUCOMA TREPHIN W/IRIDECTOMY','66150','1','','1','0','','','',0, 1, 0, 0),
(5839,'FSTLJ SCLERA GLAUCOMA THERMOCAUT IRRIDEC','FSTLJ SCLERA GLAUCOMA THERMOCAUT IRRIDEC','66155','1','','1','0','','','',0, 1, 0, 0),
(5840,'FSTLJ SCLERA SCLERECTOMY PUNCH/SCISSORS IRIDECT','FSTLJ SCLERA SCLERECTOMY PUNCH/SCISSORS IRIDECT','66160','1','','1','0','','','',0, 1, 0, 0),
(5841,'FSTLJ SCLERA GLAUCOMA TRABECULECT AB EXTERNO','FSTLJ SCLERA GLAUCOMA TRABECULECT AB EXTERNO','66170','1','','1','0','','','',0, 1, 0, 0),
(5842,'FSTLJ SCLERA GLC TRBEC AB EXTERNO SCARRING','FSTLJ SCLERA GLC TRBEC AB EXTERNO SCARRING','66172','1','','1','0','','','',0, 1, 0, 0),
(5843,'TRLUML DILAT AQUEOUS CANAL W/O DEVICE/STENT','TRLUML DILAT AQUEOUS CANAL W/O DEVICE/STENT','66174','1','','1','0','','','',0, 1, 0, 0),
(5844,'TRLUML DILAT AQUEOUS CANAL W/DEVICE/STENT','TRLUML DILAT AQUEOUS CANAL W/DEVICE/STENT','66175','1','','1','0','','','',0, 1, 0, 0),
(5845,'AQUEOUS SHUNT EXTRAOCULAR RESERVOIR W/O GRAFT','AQUEOUS SHUNT EXTRAOCULAR RESERVOIR W/O GRAFT','66179','1','','1','0','','','',0, 1, 0, 0),
(5846,'AQUEOUS SHUNT EXTRAOC EQUAT PLATE RSVR W/GRAFT','AQUEOUS SHUNT EXTRAOC EQUAT PLATE RSVR W/GRAFT','66180','1','','1','0','','','',0, 1, 0, 0),
(5847,'INSERT ANTER DRAINAGE DEV W/O EXTRAOC RESERVOIR','INSERT ANTER DRAINAGE DEV W/O EXTRAOC RESERVOIR','66183','1','','1','0','','','',0, 1, 0, 0),
(5848,'REVJ SHUNT EXTRAOCULAR RESERVOIR W/O GRAFT','REVJ SHUNT EXTRAOCULAR RESERVOIR W/O GRAFT','66184','1','','1','0','','','',0, 1, 0, 0),
(5849,'REVJ AQUEOUS SHUNT EXTRAOCULAR RESERVOIR W/GRAFT','REVJ AQUEOUS SHUNT EXTRAOCULAR RESERVOIR W/GRAFT','66185','1','','1','0','','','',0, 1, 0, 0),
(5850,'REPAIR SCLERAL STAPHYLOMA W/O GRAFT','REPAIR SCLERAL STAPHYLOMA W/O GRAFT','66220','1','','1','0','','','',0, 1, 0, 0),
(5851,'REPAIR SCLERAL STAPHYLOMA W/GRAFT','REPAIR SCLERAL STAPHYLOMA W/GRAFT','66225','1','','1','0','','','',0, 1, 0, 0),
(5852,'REVJ/RPR OPRATIVE WOUND ANTERIOR SEGMENT','REVJ/RPR OPRATIVE WOUND ANTERIOR SEGMENT','66250','1','','1','0','','','',0, 1, 0, 0),
(5853,'IRIDOTOMY STAB INC SPX XCP TRANSFIXION','IRIDOTOMY STAB INC SPX XCP TRANSFIXION','66500','1','','1','0','','','',0, 1, 0, 0),
(5854,'IRIDOTOMY STAB INC SPX TRANSFIXION','IRIDOTOMY STAB INC SPX TRANSFIXION','66505','1','','1','0','','','',0, 1, 0, 0),
(5855,'IRDEC CRNLSCLRL/CRNL SCTJ RMVL LES','IRDEC CRNLSCLRL/CRNL SCTJ RMVL LES','66600','1','','1','0','','','',0, 1, 0, 0),
(5856,'IRDEC CRNLSCLRL/CRNL SCTJ CYCLECTOMY','IRDEC CRNLSCLRL/CRNL SCTJ CYCLECTOMY','66605','1','','1','0','','','',0, 1, 0, 0),
(5857,'IRDEC CRNLSCLRL/CRNL SCTJ PRPH GLC SPX','IRDEC CRNLSCLRL/CRNL SCTJ PRPH GLC SPX','66625','1','','1','0','','','',0, 1, 0, 0),
(5858,'IRDEC CRNLSCLRL/CRNL SCTJ SECTOR GLC SPX','IRDEC CRNLSCLRL/CRNL SCTJ SECTOR GLC SPX','66630','1','','1','0','','','',0, 1, 0, 0),
(5859,'IRDEC CRNLSCLRL/CRNL SCTJ OPTICAL SPX','IRDEC CRNLSCLRL/CRNL SCTJ OPTICAL SPX','66635','1','','1','0','','','',0, 1, 0, 0),
(5860,'REPAIR IRIS CILIARY BODY','REPAIR IRIS CILIARY BODY','66680','1','','1','0','','','',0, 1, 0, 0),
(5861,'SUTURE IRIS CILIARY BODY SPX RETRIEVAL SUTURE','SUTURE IRIS CILIARY BODY SPX RETRIEVAL SUTURE','66682','1','','1','0','','','',0, 1, 0, 0),
(5862,'CILIARY BODY DESTRUCTION DIATHERMY','CILIARY BODY DESTRUCTION DIATHERMY','66700','1','','1','0','','','',0, 1, 0, 0),
(5863,'CILIARY BODY DSTRJ CYCLOPHOTOCOAG TRANSSCERAL','CILIARY BODY DSTRJ CYCLOPHOTOCOAG TRANSSCERAL','66710','1','','1','0','','','',0, 1, 0, 0),
(5864,'CILIARY BODY DSTRJ CYCLOPHOTOCOAG ENDOSCOPIC','CILIARY BODY DSTRJ CYCLOPHOTOCOAG ENDOSCOPIC','66711','1','','1','0','','','',0, 1, 0, 0),
(5865,'CILIARY BODY DESTRUCTION CRYOTHERAPY','CILIARY BODY DESTRUCTION CRYOTHERAPY','66720','1','','1','0','','','',0, 1, 0, 0),
(5866,'CILIARY BODY DESTRUCTION CYCLODIAL','CILIARY BODY DESTRUCTION CYCLODIAL','66740','1','','1','0','','','',0, 1, 0, 0),
(5867,'IRIDOTOMY/IRRIDECTOMY LASER SURG PER SESSION','IRIDOTOMY/IRRIDECTOMY LASER SURG PER SESSION','66761','1','','1','0','','','',0, 1, 0, 0),
(5868,'IRIDOPLASTY PHOTOCOAGULATION 1/> SESSIONS','IRIDOPLASTY PHOTOCOAGULATION 1/> SESSIONS','66762','1','','1','0','','','',0, 1, 0, 0),
(5869,'DSTRJ CYST/LESION IRIS/CILIARY BODY','DSTRJ CYST/LESION IRIS/CILIARY BODY','66770','1','','1','0','','','',0, 1, 0, 0),
(5870,'DISCISSION SECONDARY MEMBRANOUS CATARACT','DISCISSION SECONDARY MEMBRANOUS CATARACT','66820','1','','1','0','','','',0, 1, 0, 0),
(5871,'POST-CATARACT LASER SURGERY','POST-CATARACT LASER SURGERY','66821','1','','1','0','','','',0, 1, 0, 0),
(5872,'REPOSITIONING IO LENS PROSTHESIS REQ INC SPX','REPOSITIONING IO LENS PROSTHESIS REQ INC SPX','66825','1','','1','0','','','',0, 1, 0, 0),
(5873,'RMVL SEC MEMBRANOUS CTRC CORNEO-SCLL SCTJ','RMVL SEC MEMBRANOUS CTRC CORNEO-SCLL SCTJ','66830','1','','1','0','','','',0, 1, 0, 0),
(5874,'RMVL LENS MATERIAL ASPIR TQ 1/> STAGES','RMVL LENS MATERIAL ASPIR TQ 1/> STAGES','66840','1','','1','0','','','',0, 1, 0, 0),
(5875,'RMVL LENS MATERIAL PHACOFRAGMENTATION ASPIR','RMVL LENS MATERIAL PHACOFRAGMENTATION ASPIR','66850','1','','1','0','','','',0, 1, 0, 0),
(5876,'RMVL LENS MATERIAL PARS PLANA W/WO VITRECTOMY','RMVL LENS MATERIAL PARS PLANA W/WO VITRECTOMY','66852','1','','1','0','','','',0, 1, 0, 0),
(5877,'RMVL LENS MATERIAL INTRACAPSULAR','RMVL LENS MATERIAL INTRACAPSULAR','66920','1','','1','0','','','',0, 1, 0, 0),
(5878,'REMOVAL LENS MATRL INTRACAPSULAR DISLOCATED LENS','REMOVAL LENS MATRL INTRACAPSULAR DISLOCATED LENS','66930','1','','1','0','','','',0, 1, 0, 0),
(5879,'REMOVAL LENS MATERIAL EXTRACAPSULAR','REMOVAL LENS MATERIAL EXTRACAPSULAR','66940','1','','1','0','','','',0, 1, 0, 0),
(5880,'XCAPSULAR CATARACT RMVL INSJ LENS PROSTH 1 STG','XCAPSULAR CATARACT RMVL INSJ LENS PROSTH 1 STG','66982','1','','1','0','','','',0, 1, 0, 0),
(5881,'ICAPSULAR CATARACT XTRJ INSJ IO LENS PRSTH 1 STG','ICAPSULAR CATARACT XTRJ INSJ IO LENS PRSTH 1 STG','66983','1','','1','0','','','',0, 1, 0, 0),
(5882,'CATARACT REMOVAL INSERTION OF LENS','CATARACT REMOVAL INSERTION OF LENS','66984','1','','1','0','','','',0, 1, 0, 0),
(5883,'INSJ IO LENS PROSTHESIS NOT W/CONCURRENT RMVL','INSJ IO LENS PROSTHESIS NOT W/CONCURRENT RMVL','66985','1','','1','0','','','',0, 1, 0, 0),
(5884,'EXCHANGE INTRAOCULAR LENS','EXCHANGE INTRAOCULAR LENS','66986','1','','1','0','','','',0, 1, 0, 0),
(5885,'USE OPHTHALMIC ENDOSCOPE','USE OPHTHALMIC ENDOSCOPE','66990','1','','1','0','','','',0, 1, 0, 0),
(5886,'UNLISTED PROCEDURE ANTERIOR SEGMENT EYE','UNLISTED PROCEDURE ANTERIOR SEGMENT EYE','66999','1','','1','0','','','',0, 1, 0, 0),
(5887,'RMVL VITREOUS ANT APPR PARTIAL REMOVAL','RMVL VITREOUS ANT APPR PARTIAL REMOVAL','67005','1','','1','0','','','',0, 1, 0, 0),
(5888,'RMVL VITREOUS ANT APPR SUBTOT RMVL MECH VITRECT','RMVL VITREOUS ANT APPR SUBTOT RMVL MECH VITRECT','67010','1','','1','0','','','',0, 1, 0, 0),
(5889,'ASPIRATION/RELEASE VITREOUS SUBRETINAL/CHOROIDAL','ASPIRATION/RELEASE VITREOUS SUBRETINAL/CHOROIDAL','67015','1','','1','0','','','',0, 1, 0, 0),
(5890,'INJ SUBSTITUTE PARS PLANA/LIMBL W/WO ASPIR SPX','INJ SUBSTITUTE PARS PLANA/LIMBL W/WO ASPIR SPX','67025','1','','1','0','','','',0, 1, 0, 0),
(5891,'IMPLTJ INTRAVITREAL DRUG DLVR SYS RMVL VTS','IMPLTJ INTRAVITREAL DRUG DLVR SYS RMVL VTS','67027','1','','1','0','','','',0, 1, 0, 0),
(5892,'INTRAVITREAL NJX PHARMACOLOGIC AGT SPX','INTRAVITREAL NJX PHARMACOLOGIC AGT SPX','67028','1','','1','0','','','',0, 1, 0, 0),
(5893,'DISCISSION VITREOUS STRANS PARS PLANA APPROACH','DISCISSION VITREOUS STRANS PARS PLANA APPROACH','67030','1','','1','0','','','',0, 1, 0, 0),
(5894,'SEVERING VITREOUS STRANS LASER 1/> STAGES','SEVERING VITREOUS STRANS LASER 1/> STAGES','67031','1','','1','0','','','',0, 1, 0, 0),
(5895,'VITRECTOMY MECHANICAL PARS PLANA','VITRECTOMY MECHANICAL PARS PLANA','67036','1','','1','0','','','',0, 1, 0, 0),
(5896,'VITRECTOMY MCHNL PARS PLNA FOCAL ENDOLASER PC','VITRECTOMY MCHNL PARS PLNA FOCAL ENDOLASER PC','67039','1','','1','0','','','',0, 1, 0, 0),
(5897,'VTRECTOMY MCHNL PARS PLNA ENDOLASER PANRTA PC','VTRECTOMY MCHNL PARS PLNA ENDOLASER PANRTA PC','67040','1','','1','0','','','',0, 1, 0, 0),
(5898,'VITRECTOMY PARS PLANA REMOVE PRERETINAL MEMBRANE','VITRECTOMY PARS PLANA REMOVE PRERETINAL MEMBRANE','67041','1','','1','0','','','',0, 1, 0, 0),
(5899,'VITRECTOMY PARS PLANA REMOVE INT MEMB RETINA','VITRECTOMY PARS PLANA REMOVE INT MEMB RETINA','67042','1','','1','0','','','',0, 1, 0, 0),
(5900,'VITRECTOMY PARS PLANA REMOVE SUBRETINAL MEMBRANE','VITRECTOMY PARS PLANA REMOVE SUBRETINAL MEMBRANE','67043','1','','1','0','','','',0, 1, 0, 0),
(5901,'RPR RETINAL DTCHMNT 1/>SES CRYOTX/DTHRM INCL DRG','RPR RETINAL DTCHMNT 1/>SES CRYOTX/DTHRM INCL DRG','67101','1','','1','0','','','',0, 1, 0, 0),
(5902,'RPR RETINAL DTCHMNT 1/> SES PC INCL SUBRETI DRG','RPR RETINAL DTCHMNT 1/> SES PC INCL SUBRETI DRG','67105','1','','1','0','','','',0, 1, 0, 0),
(5903,'REPAIR RETINAL DETACHMENT SCLERAL BUCKLING','REPAIR RETINAL DETACHMENT SCLERAL BUCKLING','67107','1','','1','0','','','',0, 1, 0, 0),
(5904,'RPR RETINAL DTCHMNT W/VITRECTOMY ANY METH','RPR RETINAL DTCHMNT W/VITRECTOMY ANY METH','67108','1','','1','0','','','',0, 1, 0, 0),
(5905,'RPR RETINAL DTCHMNT INJECTION AIR/OTHER GAS','RPR RETINAL DTCHMNT INJECTION AIR/OTHER GAS','67110','1','','1','0','','','',0, 1, 0, 0),
(5906,'RPR COMPLEX RETINA DETACH VITRECT &MEMBRANE PEEL','RPR COMPLEX RETINA DETACH VITRECT &MEMBRANE PEEL','67113','1','','1','0','','','',0, 1, 0, 0),
(5907,'RELEASE ENCIRCLING MATERIAL POSTERIOR SEGMENT','RELEASE ENCIRCLING MATERIAL POSTERIOR SEGMENT','67115','1','','1','0','','','',0, 1, 0, 0),
(5908,'RMVL IMPLNT MATL POSTERIOR SEGMENT EXTRAOCULAR','RMVL IMPLNT MATL POSTERIOR SEGMENT EXTRAOCULAR','67120','1','','1','0','','','',0, 1, 0, 0),
(5909,'RMVL IMPLT MATRL POSTERIOR SEGMENT INTRAOCULAR','RMVL IMPLT MATRL POSTERIOR SEGMENT INTRAOCULAR','67121','1','','1','0','','','',0, 1, 0, 0),
(5910,'PROPH RTA DTCHMNT W/O DRG 1/> SESS CRTX DTHRM','PROPH RTA DTCHMNT W/O DRG 1/> SESS CRTX DTHRM','67141','1','','1','0','','','',0, 1, 0, 0),
(5911,'PROPH RTA DTCHMNT W/O DRG 1/> SESS','PROPH RTA DTCHMNT W/O DRG 1/> SESS','67145','1','','1','0','','','',0, 1, 0, 0),
(5912,'DSTRJ LOCLZD LESION RETINA 1/> SESS CRTX DTHRM','DSTRJ LOCLZD LESION RETINA 1/> SESS CRTX DTHRM','67208','1','','1','0','','','',0, 1, 0, 0),
(5913,'DSTRJ LOCLZD LESION RETINA 1/> SESS PC','DSTRJ LOCLZD LESION RETINA 1/> SESS PC','67210','1','','1','0','','','',0, 1, 0, 0),
(5914,'DSTRJ LESION RETINA 1/> SESS RADJ IMPLTJ','DSTRJ LESION RETINA 1/> SESS RADJ IMPLTJ','67218','1','','1','0','','','',0, 1, 0, 0),
(5915,'DSTRJ LESION CHOROID PC 1/> SESS','DSTRJ LESION CHOROID PC 1/> SESS','67220','1','','1','0','','','',0, 1, 0, 0),
(5916,'DSTRJ LESION CHOROID PHOTODYNAMIC THERAPY','DSTRJ LESION CHOROID PHOTODYNAMIC THERAPY','67221','1','','1','0','','','',0, 1, 0, 0),
(5917,'DSTRJ LESION CHOROID PDT 2ND EYE 1 SESSION','DSTRJ LESION CHOROID PDT 2ND EYE 1 SESSION','67225','1','','1','0','','','',0, 1, 0, 0),
(5918,'DESTRUCTION RETINOPATHY CRYOTHERAPY DIATHERMY','DESTRUCTION RETINOPATHY CRYOTHERAPY DIATHERMY','67227','1','','1','0','','','',0, 1, 0, 0),
(5919,'TREATMENT EXTENSIVE RETINOPATHY PHOTOCOAGULATION','TREATMENT EXTENSIVE RETINOPATHY PHOTOCOAGULATION','67228','1','','1','0','','','',0, 1, 0, 0),
(5920,'EXTENSIVE RETINOPATHY 1/> SESS PRETERM INFANT','EXTENSIVE RETINOPATHY 1/> SESS PRETERM INFANT','67229','1','','1','0','','','',0, 1, 0, 0),
(5921,'SCLERAL REINFORCEMENT SPX W/O GRAFT','SCLERAL REINFORCEMENT SPX W/O GRAFT','67250','1','','1','0','','','',0, 1, 0, 0),
(5922,'SCLERAL REINFORCEMENT SPX W/GRAFT','SCLERAL REINFORCEMENT SPX W/GRAFT','67255','1','','1','0','','','',0, 1, 0, 0),
(5923,'UNLISTED PROCEDURE POSTERIOR SEGMENT','UNLISTED PROCEDURE POSTERIOR SEGMENT','67299','1','','1','0','','','',0, 1, 0, 0),
(5924,'STRABISMUS RECESSION/RESCJ 1 HRZNTL MUSC','STRABISMUS RECESSION/RESCJ 1 HRZNTL MUSC','67311','1','','1','0','','','',0, 1, 0, 0),
(5925,'STRABISMUS RECESSION/RESCJ 2 HRZNTL MUSC','STRABISMUS RECESSION/RESCJ 2 HRZNTL MUSC','67312','1','','1','0','','','',0, 1, 0, 0),
(5926,'STRABISMUS RECESSION/RESCJ 1 VER MUSC','STRABISMUS RECESSION/RESCJ 1 VER MUSC','67314','1','','1','0','','','',0, 1, 0, 0),
(5927,'STRABISMUS RECESSION/RESCJ 2/MORE VER MUSC','STRABISMUS RECESSION/RESCJ 2/MORE VER MUSC','67316','1','','1','0','','','',0, 1, 0, 0),
(5928,'STRABISMUS ANY SUPERIOR OBLIQUE MUSCLE','STRABISMUS ANY SUPERIOR OBLIQUE MUSCLE','67318','1','','1','0','','','',0, 1, 0, 0),
(5929,'TRANSPOSITION PROCEDURE EXTRAOCULAR MUSC','TRANSPOSITION PROCEDURE EXTRAOCULAR MUSC','67320','1','','1','0','','','',0, 1, 0, 0),
(5930,'STRABISMUS PREVIOUS EYE X INVOLVE EO MUSC','STRABISMUS PREVIOUS EYE X INVOLVE EO MUSC','67331','1','','1','0','','','',0, 1, 0, 0),
(5931,'STRABISMUS SCARRING EO MUSC/RSTCV MYOPATHY','STRABISMUS SCARRING EO MUSC/RSTCV MYOPATHY','67332','1','','1','0','','','',0, 1, 0, 0),
(5932,'STRABISMUS POST FIXJ SUTR TQ W/WO MUSC RECESSION','STRABISMUS POST FIXJ SUTR TQ W/WO MUSC RECESSION','67334','1','','1','0','','','',0, 1, 0, 0),
(5933,'PLACEMENT ADJUSTABLE SUTURE STRABISMUS','PLACEMENT ADJUSTABLE SUTURE STRABISMUS','67335','1','','1','0','','','',0, 1, 0, 0),
(5934,'STRABISMUS EXPL&/RPR DETACHED EXTROCULAR MUSC','STRABISMUS EXPL&/RPR DETACHED EXTROCULAR MUSC','67340','1','','1','0','','','',0, 1, 0, 0),
(5935,'RLS XTNSV SCAR TISS W/O DETACHING EO MUSC SPX','RLS XTNSV SCAR TISS W/O DETACHING EO MUSC SPX','67343','1','','1','0','','','',0, 1, 0, 0),
(5936,'CHEMODENERVATION EXTRAOCULAR MUSCLE','CHEMODENERVATION EXTRAOCULAR MUSCLE','67345','1','','1','0','','','',0, 1, 0, 0),
(5937,'BIOPSY EXTRAOCULAR MUSCLE','BIOPSY EXTRAOCULAR MUSCLE','67346','1','','1','0','','','',0, 1, 0, 0),
(5938,'UNLISTED PROCEDURE EXTRAOCULAR MUSCLE','UNLISTED PROCEDURE EXTRAOCULAR MUSCLE','67399','1','','1','0','','','',0, 1, 0, 0),
(5939,'ORBITOTOMY W/O BONE FLAP EXPL W/WO BIOPSY','ORBITOTOMY W/O BONE FLAP EXPL W/WO BIOPSY','67400','1','','1','0','','','',0, 1, 0, 0),
(5940,'ORBITOTOMY W/O BONE FLAP EXPL W/DRAINAGE ONLY','ORBITOTOMY W/O BONE FLAP EXPL W/DRAINAGE ONLY','67405','1','','1','0','','','',0, 1, 0, 0),
(5941,'ORBITOTOMY W/O BONE FLAP W/REMOVAL LESION','ORBITOTOMY W/O BONE FLAP W/REMOVAL LESION','67412','1','','1','0','','','',0, 1, 0, 0),
(5942,'ORBITOTOMY W/O BONE FLAP W/RMVL FOREIGN BODY','ORBITOTOMY W/O BONE FLAP W/RMVL FOREIGN BODY','67413','1','','1','0','','','',0, 1, 0, 0),
(5943,'ORBITOTOMY W/O BONE FLAP W/RMVL BONE DCMPRN','ORBITOTOMY W/O BONE FLAP W/RMVL BONE DCMPRN','67414','1','','1','0','','','',0, 1, 0, 0),
(5944,'FINE NEEDLE ASPIRATION ORBITAL CONTENTS','FINE NEEDLE ASPIRATION ORBITAL CONTENTS','67415','1','','1','0','','','',0, 1, 0, 0),
(5945,'ORBITOTOMY BONE FLAP/WINDOW LAT RMVL LESION','ORBITOTOMY BONE FLAP/WINDOW LAT RMVL LESION','67420','1','','1','0','','','',0, 1, 0, 0),
(5946,'ORBITOTOMY BONE FLAP/WINDOW LATERAL RMVL FB','ORBITOTOMY BONE FLAP/WINDOW LATERAL RMVL FB','67430','1','','1','0','','','',0, 1, 0, 0),
(5947,'ORBITOTOMY BONE FLAP/WINDOW LATERAL W/DRG','ORBITOTOMY BONE FLAP/WINDOW LATERAL W/DRG','67440','1','','1','0','','','',0, 1, 0, 0),
(5948,'ORBITOTOMY BONE FLAP/WINDOW LAT RMVL BONE DCMPRN','ORBITOTOMY BONE FLAP/WINDOW LAT RMVL BONE DCMPRN','67445','1','','1','0','','','',0, 1, 0, 0),
(5949,'ORBITOTOMY BONE FLAP/WINDOW LAT EXPL W/WO BX','ORBITOTOMY BONE FLAP/WINDOW LAT EXPL W/WO BX','67450','1','','1','0','','','',0, 1, 0, 0),
(5950,'RETROBULBAR INJECTION MEDICATION SPX','RETROBULBAR INJECTION MEDICATION SPX','67500','1','','1','0','','','',0, 1, 0, 0),
(5951,'RETROBULBAR INJECTION ALCOHOL','RETROBULBAR INJECTION ALCOHOL','67505','1','','1','0','','','',0, 1, 0, 0),
(5952,'INJECTION MEDICATION/OTHER SUBST TENON CAPSULE','INJECTION MEDICATION/OTHER SUBST TENON CAPSULE','67515','1','','1','0','','','',0, 1, 0, 0),
(5953,'ORBITAL IMPLANT INSERTION','ORBITAL IMPLANT INSERTION','67550','1','','1','0','','','',0, 1, 0, 0),
(5954,'ORBITAL IMPLANT REMOVAL/REVISION','ORBITAL IMPLANT REMOVAL/REVISION','67560','1','','1','0','','','',0, 1, 0, 0),
(5955,'OPTIC NERVE DECOMPRESSION','OPTIC NERVE DECOMPRESSION','67570','1','','1','0','','','',0, 1, 0, 0),
(5956,'UNLISTED PROCEDURE ORBIT','UNLISTED PROCEDURE ORBIT','67599','1','','1','0','','','',0, 1, 0, 0),
(5957,'BLEPHAROTOMY DRAINAGE ABSCESS EYELID','BLEPHAROTOMY DRAINAGE ABSCESS EYELID','67700','1','','1','0','','','',0, 1, 0, 0),
(5958,'SEVERING TARSORRHAPHY','SEVERING TARSORRHAPHY','67710','1','','1','0','','','',0, 1, 0, 0),
(5959,'CANTHOTOMY SEPARATE PROCEDURE','CANTHOTOMY SEPARATE PROCEDURE','67715','1','','1','0','','','',0, 1, 0, 0),
(5960,'EXCISION CHALAZION SINGLE','EXCISION CHALAZION SINGLE','67800','1','','1','0','','','',0, 1, 0, 0),
(5961,'EXCISION CHALAZION MULTIPLE SAME LID','EXCISION CHALAZION MULTIPLE SAME LID','67801','1','','1','0','','','',0, 1, 0, 0),
(5962,'EXCISION CHALAZION MULTIPLE DIFFERENT LIDS','EXCISION CHALAZION MULTIPLE DIFFERENT LIDS','67805','1','','1','0','','','',0, 1, 0, 0),
(5963,'EXC CHALAZION ANES REQ HOSPIZATION SINGLE/MULT','EXC CHALAZION ANES REQ HOSPIZATION SINGLE/MULT','67808','1','','1','0','','','',0, 1, 0, 0),
(5964,'INCISIONAL BIOPSY EYELID SKIN & LID MARGIN','INCISIONAL BIOPSY EYELID SKIN & LID MARGIN','67810','1','','1','0','','','',0, 1, 0, 0),
(5965,'CORRECTION TRICHIASIS EPILATION FORCEPS ONLY','CORRECTION TRICHIASIS EPILATION FORCEPS ONLY','67820','1','','1','0','','','',0, 1, 0, 0),
(5966,'CORRECTION TRICHIASIS EPILATION OTH/THAN FORCEPS','CORRECTION TRICHIASIS EPILATION OTH/THAN FORCEPS','67825','1','','1','0','','','',0, 1, 0, 0),
(5967,'CORRECTION TRICHIASIS INCCISION LID MARGIN','CORRECTION TRICHIASIS INCCISION LID MARGIN','67830','1','','1','0','','','',0, 1, 0, 0),
(5968,'CORRJ TRICHIASIS INC LID MRGN W/FR MUC MEMB GRF','CORRJ TRICHIASIS INC LID MRGN W/FR MUC MEMB GRF','67835','1','','1','0','','','',0, 1, 0, 0),
(5969,'EXC LESION EYELID W/O CLSR/W/SIMPLE DIR CLOSURE','EXC LESION EYELID W/O CLSR/W/SIMPLE DIR CLOSURE','67840','1','','1','0','','','',0, 1, 0, 0),
(5970,'DESTRUCTION LESION LID MARGIN </ 1 CM','DESTRUCTION LESION LID MARGIN </ 1 CM','67850','1','','1','0','','','',0, 1, 0, 0),
(5971,'TEMPORARY CLOSURE EYELIDS SUTURE','TEMPORARY CLOSURE EYELIDS SUTURE','67875','1','','1','0','','','',0, 1, 0, 0),
(5972,'CONSTJ INTERMARGIN ADHES/TARSORRH/CANTHORRHAPY','CONSTJ INTERMARGIN ADHES/TARSORRH/CANTHORRHAPY','67880','1','','1','0','','','',0, 1, 0, 0),
(5973,'CONSTJ INTERMARGIN ADHES/TARSOR/CANTHOR W/TRPOS','CONSTJ INTERMARGIN ADHES/TARSOR/CANTHOR W/TRPOS','67882','1','','1','0','','','',0, 1, 0, 0),
(5974,'REPAIR BROW PTOSIS','REPAIR BROW PTOSIS','67900','1','','1','0','','','',0, 1, 0, 0),
(5975,'RPR BLEPHAROPTOSIS FRONTALIS MUSC SUTR/OTH MATRL','RPR BLEPHAROPTOSIS FRONTALIS MUSC SUTR/OTH MATRL','67901','1','','1','0','','','',0, 1, 0, 0),
(5976,'RPR BLEPHAROPT FRONTALIS MUSC AUTOL FASCAL SLING','RPR BLEPHAROPT FRONTALIS MUSC AUTOL FASCAL SLING','67902','1','','1','0','','','',0, 1, 0, 0),
(5977,'RPR BLEPHAROPTOSIS LEVATOR RESCJ/ADVMNT INTERNAL','RPR BLEPHAROPTOSIS LEVATOR RESCJ/ADVMNT INTERNAL','67903','1','','1','0','','','',0, 1, 0, 0),
(5978,'RPR BLEPHAROPTOSIS LEVATOR RESCJ/ADVMNT XTRNL','RPR BLEPHAROPTOSIS LEVATOR RESCJ/ADVMNT XTRNL','67904','1','','1','0','','','',0, 1, 0, 0),
(5979,'RPR BLEPHAROPTOSIS SUPERIOR RECTUS FASCIAL SLING','RPR BLEPHAROPTOSIS SUPERIOR RECTUS FASCIAL SLING','67906','1','','1','0','','','',0, 1, 0, 0),
(5980,'RPR BLPOS CONJUNCTIVO-TARSO-MUSC-LEVATOR RESCJ','RPR BLPOS CONJUNCTIVO-TARSO-MUSC-LEVATOR RESCJ','67908','1','','1','0','','','',0, 1, 0, 0),
(5981,'REDUCTION OVERCORRECTION PTOSIS','REDUCTION OVERCORRECTION PTOSIS','67909','1','','1','0','','','',0, 1, 0, 0),
(5982,'CORRECTION LID RETRACTION','CORRECTION LID RETRACTION','67911','1','','1','0','','','',0, 1, 0, 0),
(5983,'CORRJ LAGOPHTHALMOS IMPLTJ UPR EYELID LID LOAD','CORRJ LAGOPHTHALMOS IMPLTJ UPR EYELID LID LOAD','67912','1','','1','0','','','',0, 1, 0, 0),
(5984,'REPAIR ECTROPION SUTURE','REPAIR ECTROPION SUTURE','67914','1','','1','0','','','',0, 1, 0, 0),
(5985,'REPAIR ECTROPION THERMOCAUTERIZATION','REPAIR ECTROPION THERMOCAUTERIZATION','67915','1','','1','0','','','',0, 1, 0, 0),
(5986,'REPAIR ECTROPION EXCISION TARSAL WEDGE','REPAIR ECTROPION EXCISION TARSAL WEDGE','67916','1','','1','0','','','',0, 1, 0, 0),
(5987,'REPAIR ECTROPION EXTENSIVE','REPAIR ECTROPION EXTENSIVE','67917','1','','1','0','','','',0, 1, 0, 0),
(5988,'REPAIR ENTROPION SUTURE','REPAIR ENTROPION SUTURE','67921','1','','1','0','','','',0, 1, 0, 0),
(5989,'REPAIR ENTROPION THERMOCAUTERIZATION','REPAIR ENTROPION THERMOCAUTERIZATION','67922','1','','1','0','','','',0, 1, 0, 0),
(5990,'REPAIR ENTROPION EXCISION TARSAL WEDGE','REPAIR ENTROPION EXCISION TARSAL WEDGE','67923','1','','1','0','','','',0, 1, 0, 0),
(5991,'REPAIR ENTROPION EXTENSIVE','REPAIR ENTROPION EXTENSIVE','67924','1','','1','0','','','',0, 1, 0, 0),
(5992,'SUTR WND EYELID/MARGIN/TARSUS/CONJUNC PRTL THICK','SUTR WND EYELID/MARGIN/TARSUS/CONJUNC PRTL THICK','67930','1','','1','0','','','',0, 1, 0, 0),
(5993,'SUTR WND EYELID/MARGIN/TARSUS/CONJUNC FULL THICK','SUTR WND EYELID/MARGIN/TARSUS/CONJUNC FULL THICK','67935','1','','1','0','','','',0, 1, 0, 0),
(5994,'REMOVAL EMBEDDED FOREIGN BODY EYELID','REMOVAL EMBEDDED FOREIGN BODY EYELID','67938','1','','1','0','','','',0, 1, 0, 0),
(5995,'CANTHOPLASTY','CANTHOPLASTY','67950','1','','1','0','','','',0, 1, 0, 0),
(5996,'EXCISION & REPAIR EYELID > ONE-FOURTH LID MARGIN','EXCISION & REPAIR EYELID > ONE-FOURTH LID MARGIN','67961','1','','1','0','','','',0, 1, 0, 0),
(5997,'EXCISION & REPAIR EYELID ONE-FOURTH LID MARGIN','EXCISION & REPAIR EYELID ONE-FOURTH LID MARGIN','67966','1','','1','0','','','',0, 1, 0, 0),
(5998,'RCNSTJ EYELID FULL THICKNESS </TWO-THIRDS 1 STG','RCNSTJ EYELID FULL THICKNESS </TWO-THIRDS 1 STG','67971','1','','1','0','','','',0, 1, 0, 0),
(5999,'RCNSTJ EYELID FULL THICKNESS LOWER EYELID 1 STG','RCNSTJ EYELID FULL THICKNESS LOWER EYELID 1 STG','67973','1','','1','0','','','',0, 1, 0, 0),
(6000,'RCNSTJ EYELID FULL THICKNESS UPPER EYELID 1 STG','RCNSTJ EYELID FULL THICKNESS UPPER EYELID 1 STG','67974','1','','1','0','','','',0, 1, 0, 0),
(6001,'RCNSTJ EYELID FULL THICKNESS SECOND STAGE','RCNSTJ EYELID FULL THICKNESS SECOND STAGE','67975','1','','1','0','','','',0, 1, 0, 0),
(6002,'UNLISTED PROCEDURE EYELIDS','UNLISTED PROCEDURE EYELIDS','67999','1','','1','0','','','',0, 1, 0, 0),
(6003,'INCISION CONJUNCTIVA DRAINAGE OF CYST','INCISION CONJUNCTIVA DRAINAGE OF CYST','68020','1','','1','0','','','',0, 1, 0, 0),
(6004,'EXPRESSION CONJUNCTIVAL FOLLICLES','EXPRESSION CONJUNCTIVAL FOLLICLES','68040','1','','1','0','','','',0, 1, 0, 0),
(6005,'BIOPSY CONJUNCTIVA','BIOPSY CONJUNCTIVA','68100','1','','1','0','','','',0, 1, 0, 0),
(6006,'EXCISION LESION CONJUNCTIVA </1 CM','EXCISION LESION CONJUNCTIVA </1 CM','68110','1','','1','0','','','',0, 1, 0, 0),
(6007,'EXCISION LESION CONJUNCTIVA > 1 CM','EXCISION LESION CONJUNCTIVA > 1 CM','68115','1','','1','0','','','',0, 1, 0, 0),
(6008,'EXCISION LESION CONJUNCTIVA ADJACENT SCLERA','EXCISION LESION CONJUNCTIVA ADJACENT SCLERA','68130','1','','1','0','','','',0, 1, 0, 0),
(6009,'DESTRUCTION LESION CONJUNCTIVA','DESTRUCTION LESION CONJUNCTIVA','68135','1','','1','0','','','',0, 1, 0, 0),
(6010,'SUBCONJUNCTIVAL INJECTION','SUBCONJUNCTIVAL INJECTION','68200','1','','1','0','','','',0, 1, 0, 0),
(6011,'CONJUNCTIVOPLASTY W/GRF/XTNSV REARRANGEMENT','CONJUNCTIVOPLASTY W/GRF/XTNSV REARRANGEMENT','68320','1','','1','0','','','',0, 1, 0, 0),
(6012,'CONJUNCTIVOPLASTY W/BUCCAL MUC MEMB GRAFT','CONJUNCTIVOPLASTY W/BUCCAL MUC MEMB GRAFT','68325','1','','1','0','','','',0, 1, 0, 0),
(6013,'CJP RCNSTJ CUL-DE-SAC BUCCAL GRF/XTNSV REARRGMT','CJP RCNSTJ CUL-DE-SAC BUCCAL GRF/XTNSV REARRGMT','68326','1','','1','0','','','',0, 1, 0, 0),
(6014,'CONJUNCTPL CUL-DE-SAC W/BUCCAL MUC MEMB GRAFT','CONJUNCTPL CUL-DE-SAC W/BUCCAL MUC MEMB GRAFT','68328','1','','1','0','','','',0, 1, 0, 0),
(6015,'RPR SYMBLEPHARON CONJUNCTIVOPLASTY W/O GRAFT','RPR SYMBLEPHARON CONJUNCTIVOPLASTY W/O GRAFT','68330','1','','1','0','','','',0, 1, 0, 0),
(6016,'RPR SYMBLEPHARON FR GRF CJNC/BUCCAL MUC MEMB','RPR SYMBLEPHARON FR GRF CJNC/BUCCAL MUC MEMB','68335','1','','1','0','','','',0, 1, 0, 0),
(6017,'RPR & DIV SYMBLEPHARON W/WO CONFORM/CONTACT LE','RPR & DIV SYMBLEPHARON W/WO CONFORM/CONTACT LE','68340','1','','1','0','','','',0, 1, 0, 0),
(6018,'CONJUNCTIVAL FLAP BRIDGE/PARTIAL SPX','CONJUNCTIVAL FLAP BRIDGE/PARTIAL SPX','68360','1','','1','0','','','',0, 1, 0, 0),
(6019,'CONJUNCTIVAL FLAP TOTAL','CONJUNCTIVAL FLAP TOTAL','68362','1','','1','0','','','',0, 1, 0, 0),
(6020,'HARVESTING CONJUNCIVAL ALLOGRAPHY LIVING DONOR','HARVESTING CONJUNCIVAL ALLOGRAPHY LIVING DONOR','68371','1','','1','0','','','',0, 1, 0, 0),
(6021,'UNLISTED PROCEDURE CONJUNCTIVA','UNLISTED PROCEDURE CONJUNCTIVA','68399','1','','1','0','','','',0, 1, 0, 0),
(6022,'INCISION DRAINAGE LACRIMAL GLAND','INCISION DRAINAGE LACRIMAL GLAND','68400','1','','1','0','','','',0, 1, 0, 0),
(6023,'INCISION DRAINAGE LACRIMAL SAC','INCISION DRAINAGE LACRIMAL SAC','68420','1','','1','0','','','',0, 1, 0, 0),
(6024,'SNIP INCISION LACRIMAL PUNCTUM','SNIP INCISION LACRIMAL PUNCTUM','68440','1','','1','0','','','',0, 1, 0, 0),
(6025,'EXCISION LACRIMAL GLAND XCPT TUMOR TOTAL','EXCISION LACRIMAL GLAND XCPT TUMOR TOTAL','68500','1','','1','0','','','',0, 1, 0, 0),
(6026,'EXCISION LACRIMAL GLAND XCPT TUMOR PRTL','EXCISION LACRIMAL GLAND XCPT TUMOR PRTL','68505','1','','1','0','','','',0, 1, 0, 0),
(6027,'BIOPSY LACRIMAL GLAND','BIOPSY LACRIMAL GLAND','68510','1','','1','0','','','',0, 1, 0, 0),
(6028,'EXCISION LACRIMAL SAC','EXCISION LACRIMAL SAC','68520','1','','1','0','','','',0, 1, 0, 0),
(6029,'BIOPSY LACRIMAL SAC','BIOPSY LACRIMAL SAC','68525','1','','1','0','','','',0, 1, 0, 0),
(6030,'RMVL FB/DACRYOLITH LACRIMAL PASSAGES','RMVL FB/DACRYOLITH LACRIMAL PASSAGES','68530','1','','1','0','','','',0, 1, 0, 0),
(6031,'EXC LACRIMAL GLAND TUMOR FRONTAL APPROACH','EXC LACRIMAL GLAND TUMOR FRONTAL APPROACH','68540','1','','1','0','','','',0, 1, 0, 0),
(6032,'EXC LACRIMAL GLAND TUMOR W/OSTEOTOMY','EXC LACRIMAL GLAND TUMOR W/OSTEOTOMY','68550','1','','1','0','','','',0, 1, 0, 0),
(6033,'PLASTIC REPAIR CANALICULI','PLASTIC REPAIR CANALICULI','68700','1','','1','0','','','',0, 1, 0, 0),
(6034,'CORRECTION EVERTED PUNCTUM CAUTERY','CORRECTION EVERTED PUNCTUM CAUTERY','68705','1','','1','0','','','',0, 1, 0, 0),
(6035,'DACRYOCSTORHINOSTOMY','DACRYOCSTORHINOSTOMY','68720','1','','1','0','','','',0, 1, 0, 0),
(6036,'CONJUNCTIVORHINOSTOMY W/O TUBE','CONJUNCTIVORHINOSTOMY W/O TUBE','68745','1','','1','0','','','',0, 1, 0, 0),
(6037,'CONJUNCTIVORHINOSTOMY INSJ TUBE/STENT','CONJUNCTIVORHINOSTOMY INSJ TUBE/STENT','68750','1','','1','0','','','',0, 1, 0, 0),
(6038,'CLSR LACRIMAL PUNCTUM THERMOCAUT LIG/LASER','CLSR LACRIMAL PUNCTUM THERMOCAUT LIG/LASER','68760','1','','1','0','','','',0, 1, 0, 0),
(6039,'CLSR LACRIMAL PUNCTUM PLUG EACH','CLSR LACRIMAL PUNCTUM PLUG EACH','68761','1','','1','0','','','',0, 1, 0, 0),
(6040,'CLOSURE LACRIMAL FISTULA SPX','CLOSURE LACRIMAL FISTULA SPX','68770','1','','1','0','','','',0, 1, 0, 0),
(6041,'DILATION LACRIMAL PUNCTUM W/WO IRRGATION','DILATION LACRIMAL PUNCTUM W/WO IRRGATION','68801','1','','1','0','','','',0, 1, 0, 0),
(6042,'PROBE NASOLACRIMAL DUCT W/WO IRRIGATION','PROBE NASOLACRIMAL DUCT W/WO IRRIGATION','68810','1','','1','0','','','',0, 1, 0, 0),
(6043,'PROBE NASOLACRIMAL DUCT W/WO IRRIG REQ GEN ANES','PROBE NASOLACRIMAL DUCT W/WO IRRIG REQ GEN ANES','68811','1','','1','0','','','',0, 1, 0, 0),
(6044,'PROBE NASOLACRIMAL DUCT W/WO IRRG INSJ TUBE/STNT','PROBE NASOLACRIMAL DUCT W/WO IRRG INSJ TUBE/STNT','68815','1','','1','0','','','',0, 1, 0, 0),
(6045,'PROBE NASOLACRIMAL DUCT WITH CATHETER DILATION','PROBE NASOLACRIMAL DUCT WITH CATHETER DILATION','68816','1','','1','0','','','',0, 1, 0, 0),
(6046,'PROBE LACRIMAL CANALICULI W/WO IRRIGATION','PROBE LACRIMAL CANALICULI W/WO IRRIGATION','68840','1','','1','0','','','',0, 1, 0, 0),
(6047,'INJECTION CONTRAST MEDIUM DACRYOCYSTOGRAPY','INJECTION CONTRAST MEDIUM DACRYOCYSTOGRAPY','68850','1','','1','0','','','',0, 1, 0, 0),
(6048,'UNLISTED PROCEDURE LACRIMAL SYSTEM','UNLISTED PROCEDURE LACRIMAL SYSTEM','68899','1','','1','0','','','',0, 1, 0, 0),
(6049,'DRAINAGE EXTERNAL EAR ABSCESS/HEMATOMA SIMPLE','DRAINAGE EXTERNAL EAR ABSCESS/HEMATOMA SIMPLE','69000','1','','1','0','','','',0, 1, 0, 0),
(6050,'DRAINAGE EXTERNAL EAR ABSCESS/HEMATOMA CMPLX','DRAINAGE EXTERNAL EAR ABSCESS/HEMATOMA CMPLX','69005','1','','1','0','','','',0, 1, 0, 0),
(6051,'DRAINAGE EXTERNAL AUDITORY CANAL ABSCESS','DRAINAGE EXTERNAL AUDITORY CANAL ABSCESS','69020','1','','1','0','','','',0, 1, 0, 0),
(6052,'EAR PIERCING','EAR PIERCING','69090','1','','1','0','','','',0, 1, 0, 0),
(6053,'BIOPSY EXTERNAL EAR','BIOPSY EXTERNAL EAR','69100','1','','1','0','','','',0, 1, 0, 0),
(6054,'BIOPSY EXTERNAL AUDITORY CANAL','BIOPSY EXTERNAL AUDITORY CANAL','69105','1','','1','0','','','',0, 1, 0, 0),
(6055,'EXCISION EXTERNAL EAR PARTIAL SIMPLE REPAIR','EXCISION EXTERNAL EAR PARTIAL SIMPLE REPAIR','69110','1','','1','0','','','',0, 1, 0, 0),
(6056,'EXCISION EXTERNAL EAR COMPLETE AMPUTATION','EXCISION EXTERNAL EAR COMPLETE AMPUTATION','69120','1','','1','0','','','',0, 1, 0, 0),
(6057,'EXCISION EXOSTOSIS EXTERNAL AUDITORY CANAL','EXCISION EXOSTOSIS EXTERNAL AUDITORY CANAL','69140','1','','1','0','','','',0, 1, 0, 0),
(6058,'EXCISION SOFT TIS LESION EXTERNAL AUDITORY CANAL','EXCISION SOFT TIS LESION EXTERNAL AUDITORY CANAL','69145','1','','1','0','','','',0, 1, 0, 0),
(6059,'RAD EXC XTRNL AUDITORY CANAL LES W/O NCK DSJ','RAD EXC XTRNL AUDITORY CANAL LES W/O NCK DSJ','69150','1','','1','0','','','',0, 1, 0, 0),
(6060,'RAD EXC XTRNL AUDITORY CANAL LES NCK DSJ','RAD EXC XTRNL AUDITORY CANAL LES NCK DSJ','69155','1','','1','0','','','',0, 1, 0, 0),
(6061,'RMVL FB XTRNL AUDITORY CANAL W/O ANES','RMVL FB XTRNL AUDITORY CANAL W/O ANES','69200','1','','1','0','','','',0, 1, 0, 0),
(6062,'RMVL FB XTRNL AUDITORY CANAL ANES','RMVL FB XTRNL AUDITORY CANAL ANES','69205','1','','1','0','','','',0, 1, 0, 0),
(6063,'REMOVAL IMPACTED CERUMEN IRRIGATION/LVG UNILAT','REMOVAL IMPACTED CERUMEN IRRIGATION/LVG UNILAT','69209','1','','1','0','','','',0, 1, 0, 0),
(6064,'REMOVAL IMPACTED CERUMEN INSTRUMENTATION UNILAT','REMOVAL IMPACTED CERUMEN INSTRUMENTATION UNILAT','69210','1','','1','0','','','',0, 1, 0, 0),
(6065,'DEBRIDEMENT MASTOIDECTOMY CAVITY SIMPLE','DEBRIDEMENT MASTOIDECTOMY CAVITY SIMPLE','69220','1','','1','0','','','',0, 1, 0, 0),
(6066,'DEBRIDEMENT MASTOIDECTOMY CAVITY CMPLX','DEBRIDEMENT MASTOIDECTOMY CAVITY CMPLX','69222','1','','1','0','','','',0, 1, 0, 0),
(6067,'OTOPLASTY PROTRUDING EAR W/WO SIZE RDCTJ','OTOPLASTY PROTRUDING EAR W/WO SIZE RDCTJ','69300','1','','1','0','','','',0, 1, 0, 0),
(6068,'RECONSTRUCTION EXTERNAL AUDITORY CANAL SPX','RECONSTRUCTION EXTERNAL AUDITORY CANAL SPX','69310','1','','1','0','','','',0, 1, 0, 0),
(6069,'RCNSTJ XTRNL AUD CANAL CONGENITAL ATRESIA 1 STG','RCNSTJ XTRNL AUD CANAL CONGENITAL ATRESIA 1 STG','69320','1','','1','0','','','',0, 1, 0, 0),
(6070,'UNLISTED PROCEDURE EXTERNAL EAR','UNLISTED PROCEDURE EXTERNAL EAR','69399','1','','1','0','','','',0, 1, 0, 0),
(6071,'MYRINGOTOMY ASPIR&/EUSTACHIAN TUBE NFLTJ','MYRINGOTOMY ASPIR&/EUSTACHIAN TUBE NFLTJ','69420','1','','1','0','','','',0, 1, 0, 0),
(6072,'MYRINGOTOMY ASPIR&/EUSTACHIAN TUBE NFLTJ ANES','MYRINGOTOMY ASPIR&/EUSTACHIAN TUBE NFLTJ ANES','69421','1','','1','0','','','',0, 1, 0, 0),
(6073,'VENTILATING TUBE RMVL REQUIRING GENERAL ANES','VENTILATING TUBE RMVL REQUIRING GENERAL ANES','69424','1','','1','0','','','',0, 1, 0, 0),
(6074,'TYMPANOSTOMY LOCAL/TOPICAL ANESTHESIA','TYMPANOSTOMY LOCAL/TOPICAL ANESTHESIA','69433','1','','1','0','','','',0, 1, 0, 0),
(6075,'TYMPANOSTOMY GENERAL ANESTHESIA','TYMPANOSTOMY GENERAL ANESTHESIA','69436','1','','1','0','','','',0, 1, 0, 0),
(6076,'MIDDLE EAR EXPL THRU POSTAUR/EAR CANAL INC','MIDDLE EAR EXPL THRU POSTAUR/EAR CANAL INC','69440','1','','1','0','','','',0, 1, 0, 0),
(6077,'TYMPANOLYSIS TRANSCANAL','TYMPANOLYSIS TRANSCANAL','69450','1','','1','0','','','',0, 1, 0, 0),
(6078,'TRANSMASTOID ANTROTOMY','TRANSMASTOID ANTROTOMY','69501','1','','1','0','','','',0, 1, 0, 0),
(6079,'MASTOIDECTOMY COMPLETE','MASTOIDECTOMY COMPLETE','69502','1','','1','0','','','',0, 1, 0, 0),
(6080,'MASTOIDECTOMY MODIFIED RADICAL','MASTOIDECTOMY MODIFIED RADICAL','69505','1','','1','0','','','',0, 1, 0, 0),
(6081,'MASTOIDECTOMY RADICAL','MASTOIDECTOMY RADICAL','69511','1','','1','0','','','',0, 1, 0, 0),
(6082,'PETROUS APICECTOMY RADICAL MASTOIDECTOMY','PETROUS APICECTOMY RADICAL MASTOIDECTOMY','69530','1','','1','0','','','',0, 1, 0, 0),
(6083,'RESCJ TEMPORAL BONE EXTERNAL APPROACH','RESCJ TEMPORAL BONE EXTERNAL APPROACH','69535','1','','1','0','','','',0, 1, 0, 0),
(6084,'EXCISION AURAL POLYP','EXCISION AURAL POLYP','69540','1','','1','0','','','',0, 1, 0, 0),
(6085,'EXCISION AURAL GLOMUS TUMOR TRANSCANAL','EXCISION AURAL GLOMUS TUMOR TRANSCANAL','69550','1','','1','0','','','',0, 1, 0, 0),
(6086,'EXCISION AURAL GLOMUS TUMOR TRANSMASTOID','EXCISION AURAL GLOMUS TUMOR TRANSMASTOID','69552','1','','1','0','','','',0, 1, 0, 0),
(6087,'EXCISION AURAL GLOMUS TUMOR EXTENDED','EXCISION AURAL GLOMUS TUMOR EXTENDED','69554','1','','1','0','','','',0, 1, 0, 0),
(6088,'REVJ MASTOIDECTOMY RSLTG COMPL MASTOIDECTOMY','REVJ MASTOIDECTOMY RSLTG COMPL MASTOIDECTOMY','69601','1','','1','0','','','',0, 1, 0, 0),
(6089,'REVJ MASTOIDECTOMY RSLTG MODF RAD MSTDC','REVJ MASTOIDECTOMY RSLTG MODF RAD MSTDC','69602','1','','1','0','','','',0, 1, 0, 0),
(6090,'REVJ MASTOIDECTOMY RSLTG RAD MASTOIDECTOMY','REVJ MASTOIDECTOMY RSLTG RAD MASTOIDECTOMY','69603','1','','1','0','','','',0, 1, 0, 0),
(6091,'REVJ MASTOIDECTOMY RSLTG TYMPANOPLASTY','REVJ MASTOIDECTOMY RSLTG TYMPANOPLASTY','69604','1','','1','0','','','',0, 1, 0, 0),
(6092,'REVJ MASTOIDECTOMY W/APICECTOMY','REVJ MASTOIDECTOMY W/APICECTOMY','69605','1','','1','0','','','',0, 1, 0, 0),
(6093,'TYMPANIC MEMB RPR W/WO PREPJ PERFOR PATCH','TYMPANIC MEMB RPR W/WO PREPJ PERFOR PATCH','69610','1','','1','0','','','',0, 1, 0, 0),
(6094,'MYRINGOPLASTY','MYRINGOPLASTY','69620','1','','1','0','','','',0, 1, 0, 0),
(6095,'TYMPANOPLASTY W/O MASTOIDECT W/O OSSICLE RECNSTJ','TYMPANOPLASTY W/O MASTOIDECT W/O OSSICLE RECNSTJ','69631','1','','1','0','','','',0, 1, 0, 0),
(6096,'TYMPNOPLSTY W/O MSTDC 1ST/REVJ W/OSICLE RECNSTJ','TYMPNOPLSTY W/O MSTDC 1ST/REVJ W/OSICLE RECNSTJ','69632','1','','1','0','','','',0, 1, 0, 0),
(6097,'TYMPANOPLASTY W/O MASTOIDEC 1ST/REVJ PROSTH TORP','TYMPANOPLASTY W/O MASTOIDEC 1ST/REVJ PROSTH TORP','69633','1','','1','0','','','',0, 1, 0, 0),
(6098,'TYMPP ANTRT/MASTOID W/O OSSICULAR CHAIN RECNSTJ','TYMPP ANTRT/MASTOID W/O OSSICULAR CHAIN RECNSTJ','69635','1','','1','0','','','',0, 1, 0, 0),
(6099,'TYMPP ANTRT/MASTOID W/OSSICULAR CHAIN RECNSTJ','TYMPP ANTRT/MASTOID W/OSSICULAR CHAIN RECNSTJ','69636','1','','1','0','','','',0, 1, 0, 0),
(6100,'TMPP ANTRT/MASTOIDOTOMY PROSTHESIS TORP','TMPP ANTRT/MASTOIDOTOMY PROSTHESIS TORP','69637','1','','1','0','','','',0, 1, 0, 0),
(6101,'TMPP MASTOIDECTOMY W/O OSSICULAR CHAIN RECNSTJ','TMPP MASTOIDECTOMY W/O OSSICULAR CHAIN RECNSTJ','69641','1','','1','0','','','',0, 1, 0, 0),
(6102,'TMPP MASTOIDECTOMY W/OSSICULAR CHAIN RECNSTJ','TMPP MASTOIDECTOMY W/OSSICULAR CHAIN RECNSTJ','69642','1','','1','0','','','',0, 1, 0, 0),
(6103,'TMPP MASTOIDECT NTC/RCNSTED WALL W/O OCR','TMPP MASTOIDECT NTC/RCNSTED WALL W/O OCR','69643','1','','1','0','','','',0, 1, 0, 0),
(6104,'TMPP MASTOIDECT NTC/RCNSTED CANAL WALL OCR','TMPP MASTOIDECT NTC/RCNSTED CANAL WALL OCR','69644','1','','1','0','','','',0, 1, 0, 0),
(6105,'TYMPANOPLASTY MASTOIDECTOMY RAD/COMPL W/O OCR','TYMPANOPLASTY MASTOIDECTOMY RAD/COMPL W/O OCR','69645','1','','1','0','','','',0, 1, 0, 0),
(6106,'TYMPANOPLASTY MASTOIDECTOMY RAD/COMPL W/OCR','TYMPANOPLASTY MASTOIDECTOMY RAD/COMPL W/OCR','69646','1','','1','0','','','',0, 1, 0, 0),
(6107,'STAPES MOBILIZATION','STAPES MOBILIZATION','69650','1','','1','0','','','',0, 1, 0, 0),
(6108,'STAPEDECTOMY/STAPEDOTOMY','STAPEDECTOMY/STAPEDOTOMY','69660','1','','1','0','','','',0, 1, 0, 0),
(6109,'STAPEDECTOMY/STAPEDOTOMY W/FOOTPLATE DRILL OUT','STAPEDECTOMY/STAPEDOTOMY W/FOOTPLATE DRILL OUT','69661','1','','1','0','','','',0, 1, 0, 0),
(6110,'REVISION STAPEDECTOMY/STAPEDOTOMY','REVISION STAPEDECTOMY/STAPEDOTOMY','69662','1','','1','0','','','',0, 1, 0, 0),
(6111,'REPAIR OVAL WINDOW FISTULA','REPAIR OVAL WINDOW FISTULA','69666','1','','1','0','','','',0, 1, 0, 0),
(6112,'REPAIR ROUND WINDOW FISTULA','REPAIR ROUND WINDOW FISTULA','69667','1','','1','0','','','',0, 1, 0, 0),
(6113,'MASTOID OBLITERATION SEPARATE PROCEDURE','MASTOID OBLITERATION SEPARATE PROCEDURE','69670','1','','1','0','','','',0, 1, 0, 0),
(6114,'TYMPANIC NEURECTOMY','TYMPANIC NEURECTOMY','69676','1','','1','0','','','',0, 1, 0, 0),
(6115,'CLOSURE POSTAURICULAR FISTULA MASTOID SPX','CLOSURE POSTAURICULAR FISTULA MASTOID SPX','69700','1','','1','0','','','',0, 1, 0, 0),
(6116,'IMPLTJ/RPLCMT EMGNT BONE CNDJ DEV TEMPORAL BONE','IMPLTJ/RPLCMT EMGNT BONE CNDJ DEV TEMPORAL BONE','69710','1','','1','0','','','',0, 1, 0, 0),
(6117,'RMVL/RPR EMGNT BONE CNDJ DEV TEMPORAL BONE','RMVL/RPR EMGNT BONE CNDJ DEV TEMPORAL BONE','69711','1','','1','0','','','',0, 1, 0, 0),
(6118,'IMPLTJ OSSEOINTEGRATED TEMPORAL BONE W/MASTOID','IMPLTJ OSSEOINTEGRATED TEMPORAL BONE W/MASTOID','69714','1','','1','0','','','',0, 1, 0, 0),
(6119,'IMPLJ OSSEOINTEGRATED TEMPORAL BONE W/O MASTOID','IMPLJ OSSEOINTEGRATED TEMPORAL BONE W/O MASTOID','69715','1','','1','0','','','',0, 1, 0, 0),
(6120,'RPLMCT OSSEOINTEGRATE IMPLNT W/O MASTOIDECTOMY','RPLMCT OSSEOINTEGRATE IMPLNT W/O MASTOIDECTOMY','69717','1','','1','0','','','',0, 1, 0, 0),
(6121,'RPLMCT OSSEOINTEGRATE IMPLNT W/MASTOIDECTOMY','RPLMCT OSSEOINTEGRATE IMPLNT W/MASTOIDECTOMY','69718','1','','1','0','','','',0, 1, 0, 0),
(6122,'DCMPRN FACIAL NRV INTRATEMPORAL LAT GANGLION','DCMPRN FACIAL NRV INTRATEMPORAL LAT GANGLION','69720','1','','1','0','','','',0, 1, 0, 0),
(6123,'DCMPRN NRV INTRATEMPORAL MEDIAL GENICULATE','DCMPRN NRV INTRATEMPORAL MEDIAL GENICULATE','69725','1','','1','0','','','',0, 1, 0, 0),
(6124,'SUTR NRV ITPRL W/WO GRF/DCMPRN LAT GENICULATE','SUTR NRV ITPRL W/WO GRF/DCMPRN LAT GENICULATE','69740','1','','1','0','','','',0, 1, 0, 0),
(6125,'SUTR NRV ITPRL W/WO GRF/DCMPRN MEDIAL GENICULATE','SUTR NRV ITPRL W/WO GRF/DCMPRN MEDIAL GENICULATE','69745','1','','1','0','','','',0, 1, 0, 0),
(6126,'UNLISTED PROCEDURE MIDDLE EAR','UNLISTED PROCEDURE MIDDLE EAR','69799','1','','1','0','','','',0, 1, 0, 0),
(6127,'LABYRINTHOTOMY TRANSCANAL','LABYRINTHOTOMY TRANSCANAL','69801','1','','1','0','','','',0, 1, 0, 0),
(6128,'ENDOLYMPHATIC SAC W/O SHUNT','ENDOLYMPHATIC SAC W/O SHUNT','69805','1','','1','0','','','',0, 1, 0, 0),
(6129,'ENDOLYMPHATIC SAC SHUNT','ENDOLYMPHATIC SAC SHUNT','69806','1','','1','0','','','',0, 1, 0, 0),
(6130,'FENESTRATION SEMICIRCULAR CANAL','FENESTRATION SEMICIRCULAR CANAL','69820','1','','1','0','','','',0, 1, 0, 0),
(6131,'REVISION FENESTRATION OPERATION','REVISION FENESTRATION OPERATION','69840','1','','1','0','','','',0, 1, 0, 0),
(6132,'LABYRINTHECTOMY TRANSCANAL','LABYRINTHECTOMY TRANSCANAL','69905','1','','1','0','','','',0, 1, 0, 0),
(6133,'LABYRINTHECTOMY W/MASTOIDECTOMY','LABYRINTHECTOMY W/MASTOIDECTOMY','69910','1','','1','0','','','',0, 1, 0, 0),
(6134,'VESTIBULAR NRV SECTION TRANSLABYRINTHINE APPR','VESTIBULAR NRV SECTION TRANSLABYRINTHINE APPR','69915','1','','1','0','','','',0, 1, 0, 0),
(6135,'COCHLEAR DEVICE IMPLANTATION W/WO MASTOIDECTOMY','COCHLEAR DEVICE IMPLANTATION W/WO MASTOIDECTOMY','69930','1','','1','0','','','',0, 1, 0, 0),
(6136,'UNLISTED PROCEDURE INNER EAR','UNLISTED PROCEDURE INNER EAR','69949','1','','1','0','','','',0, 1, 0, 0),
(6137,'VESTIBULAR NRV SECTION TRANSCRANIAL APPROACH','VESTIBULAR NRV SECTION TRANSCRANIAL APPROACH','69950','1','','1','0','','','',0, 1, 0, 0),
(6138,'TOTAL FACIAL NERVE DECOMPRESSION &/REPAIR','TOTAL FACIAL NERVE DECOMPRESSION &/REPAIR','69955','1','','1','0','','','',0, 1, 0, 0),
(6139,'DECOMPRESSION INTERNAL AUDITORY CANAL','DECOMPRESSION INTERNAL AUDITORY CANAL','69960','1','','1','0','','','',0, 1, 0, 0),
(6140,'REMOVAL TUMOR TEMPORAL BONE','REMOVAL TUMOR TEMPORAL BONE','69970','1','','1','0','','','',0, 1, 0, 0),
(6141,'UNLISTED PROCEDURE TEMPORAL BONE MIDDLE FOSSA','UNLISTED PROCEDURE TEMPORAL BONE MIDDLE FOSSA','69979','1','','1','0','','','',0, 1, 0, 0),
(6142,'MICROSURG TQS REQ USE OPERATING MICROSCOPE','MICROSURG TQS REQ USE OPERATING MICROSCOPE','69990','1','','1','0','','','',0, 1, 0, 0),
(6143,'MYELOGRAPY POST FOSSA RS&I','MYELOGRAPY POST FOSSA RS&I','70010','1','','1','0','','','',0, 1, 0, 0),
(6144,'CISTERNOGRAPHY POSITIVE CONTRAST RS&I','CISTERNOGRAPHY POSITIVE CONTRAST RS&I','70015','1','','1','0','','','',0, 1, 0, 0),
(6145,'RADIOLOGIC EXAMINATION EYE DETECT FOREIGN BODY','RADIOLOGIC EXAMINATION EYE DETECT FOREIGN BODY','70030','1','','1','0','','','',0, 1, 0, 0),
(6146,'RADIOLOGIC EXAMINATION MANDIPLE PRTL <4 VIEWS','RADIOLOGIC EXAMINATION MANDIPLE PRTL <4 VIEWS','70100','1','','1','0','','','',0, 1, 0, 0),
(6147,'RADIOLOG EXAM MANDIBLE COMPL MINIMUM 4 VIEWS','RADIOLOG EXAM MANDIBLE COMPL MINIMUM 4 VIEWS','70110','1','','1','0','','','',0, 1, 0, 0),
(6148,'RADIOLOGIC EXAM MASTOIDS < 3 VIEWS PER SIDE','RADIOLOGIC EXAM MASTOIDS < 3 VIEWS PER SIDE','70120','1','','1','0','','','',0, 1, 0, 0),
(6149,'RADEX MASTOIDS COMPL MINIMUM 3 VIEWS PR SIDE','RADEX MASTOIDS COMPL MINIMUM 3 VIEWS PR SIDE','70130','1','','1','0','','','',0, 1, 0, 0),
(6150,'RADEX INTERNAL AUDITORY MEATI COMPLETE','RADEX INTERNAL AUDITORY MEATI COMPLETE','70134','1','','1','0','','','',0, 1, 0, 0),
(6151,'RADEX FACIAL BONES < 3 VIEWS','RADEX FACIAL BONES < 3 VIEWS','70140','1','','1','0','','','',0, 1, 0, 0),
(6152,'RADEX FACIAL BONES COMPLETE MINIMUM 3 VIEWS','RADEX FACIAL BONES COMPLETE MINIMUM 3 VIEWS','70150','1','','1','0','','','',0, 1, 0, 0),
(6153,'RADEX NASAL BONES COMPLETE MINIMUM 3 VIEWS','RADEX NASAL BONES COMPLETE MINIMUM 3 VIEWS','70160','1','','1','0','','','',0, 1, 0, 0),
(6154,'DACRYOCSTOGRAPY NASOLACRIMAL DUCT RS&I','DACRYOCSTOGRAPY NASOLACRIMAL DUCT RS&I','70170','1','','1','0','','','',0, 1, 0, 0),
(6155,'RADEX OPTIC FORAMINA','RADEX OPTIC FORAMINA','70190','1','','1','0','','','',0, 1, 0, 0),
(6156,'RADEX ORBITS COMPLETE MINIMUM 4 VIEWS','RADEX ORBITS COMPLETE MINIMUM 4 VIEWS','70200','1','','1','0','','','',0, 1, 0, 0),
(6157,'RADEX SINUSES PARANASAL <3 VIEWS','RADEX SINUSES PARANASAL <3 VIEWS','70210','1','','1','0','','','',0, 1, 0, 0),
(6158,'RADEX SINUSES PARANASAL COMPL MINIMUM 3 VIEWS','RADEX SINUSES PARANASAL COMPL MINIMUM 3 VIEWS','70220','1','','1','0','','','',0, 1, 0, 0),
(6159,'RADIOLOGIC EXAMINATION SELLA TURCICA','RADIOLOGIC EXAMINATION SELLA TURCICA','70240','1','','1','0','','','',0, 1, 0, 0),
(6160,'RADIOLOGIC EXAMINATION SKULL 4/> VIEWS','RADIOLOGIC EXAMINATION SKULL 4/> VIEWS','70250','1','','1','0','','','',0, 1, 0, 0),
(6161,'RADIOLOGIC EXAM SKULL COMPLETE MINIMUM 4 VIEWS','RADIOLOGIC EXAM SKULL COMPLETE MINIMUM 4 VIEWS','70260','1','','1','0','','','',0, 1, 0, 0),
(6162,'RADIOLOGIC EXAMINATION TEETH 1 VIEW','RADIOLOGIC EXAMINATION TEETH 1 VIEW','70300','1','','1','0','','','',0, 1, 0, 0),
(6163,'RADIOLOGIC EXAM TEETH PRTL EXAM < FULL MOUTH','RADIOLOGIC EXAM TEETH PRTL EXAM < FULL MOUTH','70310','1','','1','0','','','',0, 1, 0, 0),
(6164,'RADIOLOGIC EXAM TEETH COMPLETE FULL MOUTH','RADIOLOGIC EXAM TEETH COMPLETE FULL MOUTH','70320','1','','1','0','','','',0, 1, 0, 0),
(6165,'RADEX TEMPOROMANDBLE JT OPN & CLSD MOUTH UNILAT','RADEX TEMPOROMANDBLE JT OPN & CLSD MOUTH UNILAT','70328','1','','1','0','','','',0, 1, 0, 0),
(6166,'RADEX TEMPOROMANDBLE JT OPN & CLSD MOUTH BILAT','RADEX TEMPOROMANDBLE JT OPN & CLSD MOUTH BILAT','70330','1','','1','0','','','',0, 1, 0, 0),
(6167,'TEMPOROMANDBLE JT ARTHROGRAPHY RS&I','TEMPOROMANDBLE JT ARTHROGRAPHY RS&I','70332','1','','1','0','','','',0, 1, 0, 0),
(6168,'MRI TEMPOROMANDIBULAR JOINT','MRI TEMPOROMANDIBULAR JOINT','70336','1','','1','0','','','',0, 1, 0, 0),
(6169,'CEPHALOGRAM ORTHODONTIC','CEPHALOGRAM ORTHODONTIC','70350','1','','1','0','','','',0, 1, 0, 0),
(6170,'ORTHOPANTOGRAM','ORTHOPANTOGRAM','70355','1','','1','0','','','',0, 1, 0, 0),
(6171,'RADIOLOGIC EXAMINATION NECK SOFT TISSUE','RADIOLOGIC EXAMINATION NECK SOFT TISSUE','70360','1','','1','0','','','',0, 1, 0, 0),
(6172,'RADEX PHARYNX/LARX W/FLUOR&/MAGNIFICATION TQ','RADEX PHARYNX/LARX W/FLUOR&/MAGNIFICATION TQ','70370','1','','1','0','','','',0, 1, 0, 0),
(6173,'CPLX DYNAMIC PHARYNGEAL&SP EVAL C/V REC','CPLX DYNAMIC PHARYNGEAL&SP EVAL C/V REC','70371','1','','1','0','','','',0, 1, 0, 0),
(6174,'RADIOLOGIC EXAMINATION SALIVARY GLAND CALCULUS','RADIOLOGIC EXAMINATION SALIVARY GLAND CALCULUS','70380','1','','1','0','','','',0, 1, 0, 0),
(6175,'SIALOGRAPHY RS&I','SIALOGRAPHY RS&I','70390','1','','1','0','','','',0, 1, 0, 0),
(6176,'CT HEAD/BRAIN W/O CONTRAST MATERIAL','CT HEAD/BRAIN W/O CONTRAST MATERIAL','70450','1','','1','0','','','',0, 1, 0, 0),
(6177,'CT HEAD/BRAIN W/CONTRAST MATERIAL','CT HEAD/BRAIN W/CONTRAST MATERIAL','70460','1','','1','0','','','',0, 1, 0, 0),
(6178,'CT HEAD/BRAIN W/O & W/CONTRAST MATERIAL','CT HEAD/BRAIN W/O & W/CONTRAST MATERIAL','70470','1','','1','0','','','',0, 1, 0, 0),
(6179,'CT ORBIT SELLA/POST FOSSA/EAR W/O CONTRAST MATRL','CT ORBIT SELLA/POST FOSSA/EAR W/O CONTRAST MATRL','70480','1','','1','0','','','',0, 1, 0, 0),
(6180,'CT ORBIT SELLA/POST FOSSA/EAR W/CONTRAST MATRL','CT ORBIT SELLA/POST FOSSA/EAR W/CONTRAST MATRL','70481','1','','1','0','','','',0, 1, 0, 0),
(6181,'CT ORBIT SELLA/POST FOSSA/EAR W/O & W/CONTR MATR','CT ORBIT SELLA/POST FOSSA/EAR W/O & W/CONTR MATR','70482','1','','1','0','','','',0, 1, 0, 0),
(6182,'CT MAXILLOFACIAL W/O CONTRAST MATERIAL','CT MAXILLOFACIAL W/O CONTRAST MATERIAL','70486','1','','1','0','','','',0, 1, 0, 0),
(6183,'CT MAXILLOFACIAL W/CONTRAST MATERIAL','CT MAXILLOFACIAL W/CONTRAST MATERIAL','70487','1','','1','0','','','',0, 1, 0, 0),
(6184,'CT MAXILLOFACIAL W/O & W/CONTRAST MATERIAL','CT MAXILLOFACIAL W/O & W/CONTRAST MATERIAL','70488','1','','1','0','','','',0, 1, 0, 0),
(6185,'CT SOFT TISSUE NECK W/O CONTRAST MATERIAL','CT SOFT TISSUE NECK W/O CONTRAST MATERIAL','70490','1','','1','0','','','',0, 1, 0, 0),
(6186,'CT SOFT TISSUE NECK W/CONTRAST MATERIAL','CT SOFT TISSUE NECK W/CONTRAST MATERIAL','70491','1','','1','0','','','',0, 1, 0, 0),
(6187,'CT SOFT TISSUE NECK W/O & W/CONTRAST MATERIAL','CT SOFT TISSUE NECK W/O & W/CONTRAST MATERIAL','70492','1','','1','0','','','',0, 1, 0, 0),
(6188,'CT ANGIOGRAPHY HEAD W/CONTRAST/NONCONTRAST','CT ANGIOGRAPHY HEAD W/CONTRAST/NONCONTRAST','70496','1','','1','0','','','',0, 1, 0, 0),
(6189,'CT ANGIOGRAPHY NECK W/CONTRAST/NONCONTRAST','CT ANGIOGRAPHY NECK W/CONTRAST/NONCONTRAST','70498','1','','1','0','','','',0, 1, 0, 0),
(6190,'MRI ORBIT FACE &/NECK W/O CONTRAST','MRI ORBIT FACE &/NECK W/O CONTRAST','70540','1','','1','0','','','',0, 1, 0, 0),
(6191,'MRI ORBIT FACE & NECK W/CONTRAST MATERIAL','MRI ORBIT FACE & NECK W/CONTRAST MATERIAL','70542','1','','1','0','','','',0, 1, 0, 0),
(6192,'MRI ORBIT FACE & NECK W/O & W/CONTRAST MATRL','MRI ORBIT FACE & NECK W/O & W/CONTRAST MATRL','70543','1','','1','0','','','',0, 1, 0, 0),
(6193,'MRA HEAD W/O CONTRST MATERIAL','MRA HEAD W/O CONTRST MATERIAL','70544','1','','1','0','','','',0, 1, 0, 0),
(6194,'MRA HEAD W/CONTRAST MATERIAL','MRA HEAD W/CONTRAST MATERIAL','70545','1','','1','0','','','',0, 1, 0, 0),
(6195,'MRA HEAD W/O & W/CONTRAST MATERIAL','MRA HEAD W/O & W/CONTRAST MATERIAL','70546','1','','1','0','','','',0, 1, 0, 0),
(6196,'MRA NECK W/O CONTRST MATERIAL','MRA NECK W/O CONTRST MATERIAL','70547','1','','1','0','','','',0, 1, 0, 0),
(6197,'MRA NECK W/CONTRAST MATERIAL','MRA NECK W/CONTRAST MATERIAL','70548','1','','1','0','','','',0, 1, 0, 0),
(6198,'MRA NECK W/O &W/CONTRAST MATERIAL','MRA NECK W/O &W/CONTRAST MATERIAL','70549','1','','1','0','','','',0, 1, 0, 0),
(6199,'MRI BRAIN BRAIN STEM W/O CONTRAST MATERIAL','MRI BRAIN BRAIN STEM W/O CONTRAST MATERIAL','70551','1','','1','0','','','',0, 1, 0, 0),
(6200,'MRI BRAIN BRAIN STEM W/CONTRAST MATERIAL','MRI BRAIN BRAIN STEM W/CONTRAST MATERIAL','70552','1','','1','0','','','',0, 1, 0, 0),
(6201,'MRI BRAIN BRAIN STEM W/O W/CONTRAST MATERIAL','MRI BRAIN BRAIN STEM W/O W/CONTRAST MATERIAL','70553','1','','1','0','','','',0, 1, 0, 0),
(6202,'MRI BRAIN FUNCTIONAL W/O PHYSICIAN ADMNISTRATION','MRI BRAIN FUNCTIONAL W/O PHYSICIAN ADMNISTRATION','70554','1','','1','0','','','',0, 1, 0, 0),
(6203,'MRI BRAIN FUNCTIONAL W/PHYSICIAN ADMNISTRATION','MRI BRAIN FUNCTIONAL W/PHYSICIAN ADMNISTRATION','70555','1','','1','0','','','',0, 1, 0, 0),
(6204,'MRI BRAIN OPEN INTRACRANIAL PX W/O CONTRAST MATL','MRI BRAIN OPEN INTRACRANIAL PX W/O CONTRAST MATL','70557','1','','1','0','','','',0, 1, 0, 0),
(6205,'MRI BRAIN OPEN INTRACRANIAL PX W/CONTRAST MATL','MRI BRAIN OPEN INTRACRANIAL PX W/CONTRAST MATL','70558','1','','1','0','','','',0, 1, 0, 0),
(6206,'MRI BRAIN OPEN INTRACRANIAL PX W/O & W/CONTRAST','MRI BRAIN OPEN INTRACRANIAL PX W/O & W/CONTRAST','70559','1','','1','0','','','',0, 1, 0, 0),
(6207,'RADIOLOGIC EXAMINATION CHEST SINGLE VIEW FRONTAL','RADIOLOGIC EXAMINATION CHEST SINGLE VIEW FRONTAL','71010','1','','1','0','','','',0, 1, 0, 0),
(6208,'RADIOLOGIC EXAMINATION CHEST STERO FRONTAL','RADIOLOGIC EXAMINATION CHEST STERO FRONTAL','71015','1','','1','0','','','',0, 1, 0, 0),
(6209,'RADIOLOGIC EXAM CHEST 2 VIEWS FRONTAL&LATERAL','RADIOLOGIC EXAM CHEST 2 VIEWS FRONTAL&LATERAL','71020','1','','1','0','','','',0, 1, 0, 0),
(6210,'RADEX CH 2 VIEWS FRNT & LAT APICAL LORDOTIC PX','RADEX CH 2 VIEWS FRNT & LAT APICAL LORDOTIC PX','71021','1','','1','0','','','',0, 1, 0, 0),
(6211,'RADEX CH 2 VIEWS FRONTAL & LATERAL OBLIQUE PRJCJ','RADEX CH 2 VIEWS FRONTAL & LATERAL OBLIQUE PRJCJ','71022','1','','1','0','','','',0, 1, 0, 0),
(6212,'RADEX CH 2 VIEWS FRONTAL & LATERAL W/FLUORO','RADEX CH 2 VIEWS FRONTAL & LATERAL W/FLUORO','71023','1','','1','0','','','',0, 1, 0, 0),
(6213,'RADEX CHEST COMPLETE MINIMUM 4 VIEWS','RADEX CHEST COMPLETE MINIMUM 4 VIEWS','71030','1','','1','0','','','',0, 1, 0, 0),
(6214,'RADEX CHEST COMPLETE MINIMUM 4 VIEWS W/FLUORO','RADEX CHEST COMPLETE MINIMUM 4 VIEWS W/FLUORO','71034','1','','1','0','','','',0, 1, 0, 0),
(6215,'RADEX CHEST SPECIAL VIEWS','RADEX CHEST SPECIAL VIEWS','71035','1','','1','0','','','',0, 1, 0, 0),
(6216,'RADEX RIBS UNILATERAL 2 VIEWS','RADEX RIBS UNILATERAL 2 VIEWS','71100','1','','1','0','','','',0, 1, 0, 0),
(6217,'RADEX RIBS UNI W/POSTEROANT CH MINIMUM 3 VIEWS','RADEX RIBS UNI W/POSTEROANT CH MINIMUM 3 VIEWS','71101','1','','1','0','','','',0, 1, 0, 0),
(6218,'RADEX RIBS BILATERAL 3 VIEWS','RADEX RIBS BILATERAL 3 VIEWS','71110','1','','1','0','','','',0, 1, 0, 0),
(6219,'RADEX RIBS BI W/POSTEROANT CH MINIMUM 4 VIEWS','RADEX RIBS BI W/POSTEROANT CH MINIMUM 4 VIEWS','71111','1','','1','0','','','',0, 1, 0, 0),
(6220,'RADEX STERNUM MINIMUM 2 VIEWS','RADEX STERNUM MINIMUM 2 VIEWS','71120','1','','1','0','','','',0, 1, 0, 0),
(6221,'RADEX STERNOCLAVICULAR JT/JTS MINIMUM 3 VIEWS','RADEX STERNOCLAVICULAR JT/JTS MINIMUM 3 VIEWS','71130','1','','1','0','','','',0, 1, 0, 0),
(6222,'CT THORAX W/O CONTRAST MATERIAL','CT THORAX W/O CONTRAST MATERIAL','71250','1','','1','0','','','',0, 1, 0, 0),
(6223,'CT THORAX W/CONTRAST MATERIAL','CT THORAX W/CONTRAST MATERIAL','71260','1','','1','0','','','',0, 1, 0, 0),
(6224,'CT THORAX W/O & W/CONTRAST MATERIAL','CT THORAX W/O & W/CONTRAST MATERIAL','71270','1','','1','0','','','',0, 1, 0, 0),
(6225,'CT ANGIOGRAPHY CHEST W/CONTRAST/NONCONTRAST','CT ANGIOGRAPHY CHEST W/CONTRAST/NONCONTRAST','71275','1','','1','0','','','',0, 1, 0, 0),
(6226,'MRI CHEST W/O CONTRAST MATERIAL','MRI CHEST W/O CONTRAST MATERIAL','71550','1','','1','0','','','',0, 1, 0, 0),
(6227,'MRI CHEST W/CONTRAST MATERIAL','MRI CHEST W/CONTRAST MATERIAL','71551','1','','1','0','','','',0, 1, 0, 0),
(6228,'MRI CHEST W/O & W/CONTRAST MATERIAL','MRI CHEST W/O & W/CONTRAST MATERIAL','71552','1','','1','0','','','',0, 1, 0, 0),
(6229,'MRA CHEST W/O & W/CONTRAST MATERIAL','MRA CHEST W/O & W/CONTRAST MATERIAL','71555','1','','1','0','','','',0, 1, 0, 0),
(6230,'RADEX SPINE 1 VIEW SPECIFY LEVEL','RADEX SPINE 1 VIEW SPECIFY LEVEL','72020','1','','1','0','','','',0, 1, 0, 0),
(6231,'RADEX SPINE CERVICAL 2 OR 3 VIEWS','RADEX SPINE CERVICAL 2 OR 3 VIEWS','72040','1','','1','0','','','',0, 1, 0, 0),
(6232,'RADEX SPINE CERVICAL 4 OR 5 VIEWS','RADEX SPINE CERVICAL 4 OR 5 VIEWS','72050','1','','1','0','','','',0, 1, 0, 0),
(6233,'RADEX SPINE CERVICAL 6 OR MORE VIEWS','RADEX SPINE CERVICAL 6 OR MORE VIEWS','72052','1','','1','0','','','',0, 1, 0, 0),
(6234,'RADEX SPINE THORACIC 2 VIEWS','RADEX SPINE THORACIC 2 VIEWS','72070','1','','1','0','','','',0, 1, 0, 0),
(6235,'RADEX SPINE THORACIC 3 VIEWS','RADEX SPINE THORACIC 3 VIEWS','72072','1','','1','0','','','',0, 1, 0, 0),
(6236,'RADEX SPINE THORACIC MINIMUM 4 VIEWS','RADEX SPINE THORACIC MINIMUM 4 VIEWS','72074','1','','1','0','','','',0, 1, 0, 0),
(6237,'RADEX SPINE THORACOLUMBAR JUNCTION MIN 2 VIEWS','RADEX SPINE THORACOLUMBAR JUNCTION MIN 2 VIEWS','72080','1','','1','0','','','',0, 1, 0, 0),
(6238,'RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 1 VW','RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 1 VW','72081','1','','1','0','','','',0, 1, 0, 0),
(6239,'RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 2/3 VW','RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 2/3 VW','72082','1','','1','0','','','',0, 1, 0, 0),
(6240,'RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 4/5 VW','RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 4/5 VW','72083','1','','1','0','','','',0, 1, 0, 0),
(6241,'RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 6/> VW','RADEX ENTIR THRC LMBR CRV SAC SPI W/SKULL 6/> VW','72084','1','','1','0','','','',0, 1, 0, 0),
(6242,'RADEX SPINE LUMBOSACRAL 2/3 VIEWS','RADEX SPINE LUMBOSACRAL 2/3 VIEWS','72100','1','','1','0','','','',0, 1, 0, 0),
(6243,'RADEX SPINE LUMBOSACRAL MINIMUM 4 VIEWS','RADEX SPINE LUMBOSACRAL MINIMUM 4 VIEWS','72110','1','','1','0','','','',0, 1, 0, 0),
(6244,'RADEX SPINE LUMBSCRL COMPL W/BENDING VIEWS MIN 6','RADEX SPINE LUMBSCRL COMPL W/BENDING VIEWS MIN 6','72114','1','','1','0','','','',0, 1, 0, 0),
(6245,'RADEX SPINE LUMBOSACRAL ONLY BENDING 2/3 VIEWS','RADEX SPINE LUMBOSACRAL ONLY BENDING 2/3 VIEWS','72120','1','','1','0','','','',0, 1, 0, 0),
(6246,'CT CERVICAL SPINE W/O CONTRAST MATERIAL','CT CERVICAL SPINE W/O CONTRAST MATERIAL','72125','1','','1','0','','','',0, 1, 0, 0),
(6247,'CT CERVICAL SPINE W/CONTRAST MATERIAL','CT CERVICAL SPINE W/CONTRAST MATERIAL','72126','1','','1','0','','','',0, 1, 0, 0),
(6248,'CT CERVICAL SPINE W/O &W/CONTRAST MATERIAL','CT CERVICAL SPINE W/O &W/CONTRAST MATERIAL','72127','1','','1','0','','','',0, 1, 0, 0),
(6249,'CT THORACIC SPINE W/O CONTRAST MATERIAL','CT THORACIC SPINE W/O CONTRAST MATERIAL','72128','1','','1','0','','','',0, 1, 0, 0),
(6250,'CT THORACIC SPINE W/CONTRAST MATERIAL','CT THORACIC SPINE W/CONTRAST MATERIAL','72129','1','','1','0','','','',0, 1, 0, 0),
(6251,'CT THORACIC SPINE W/O & W/CONTRAST MATERIAL','CT THORACIC SPINE W/O & W/CONTRAST MATERIAL','72130','1','','1','0','','','',0, 1, 0, 0),
(6252,'CT LUMBAR SPINE W/O CONTRAST MATERIAL','CT LUMBAR SPINE W/O CONTRAST MATERIAL','72131','1','','1','0','','','',0, 1, 0, 0),
(6253,'CT LUMBAR SPINE W/CONTRAST MATERIAL','CT LUMBAR SPINE W/CONTRAST MATERIAL','72132','1','','1','0','','','',0, 1, 0, 0),
(6254,'CT LUMBAR SPINE W/O & W/CONTRAST MATERIAL','CT LUMBAR SPINE W/O & W/CONTRAST MATERIAL','72133','1','','1','0','','','',0, 1, 0, 0),
(6255,'MRI SPINAL CANAL CERVICAL W/O CONTRAST MATRL','MRI SPINAL CANAL CERVICAL W/O CONTRAST MATRL','72141','1','','1','0','','','',0, 1, 0, 0),
(6256,'MRI SPINAL CANAL CERVICAL W/CONTRAST MATRL','MRI SPINAL CANAL CERVICAL W/CONTRAST MATRL','72142','1','','1','0','','','',0, 1, 0, 0),
(6257,'MRI SPINAL CANAL THORACIC W/O CONTRAST MATRL','MRI SPINAL CANAL THORACIC W/O CONTRAST MATRL','72146','1','','1','0','','','',0, 1, 0, 0),
(6258,'MRI SPINAL CANAL THORACIC W/CONTRAST MATRL','MRI SPINAL CANAL THORACIC W/CONTRAST MATRL','72147','1','','1','0','','','',0, 1, 0, 0),
(6259,'MRI SPINAL CANAL LUMBAR W/O CONTRAST MATERIAL','MRI SPINAL CANAL LUMBAR W/O CONTRAST MATERIAL','72148','1','','1','0','','','',0, 1, 0, 0),
(6260,'MRI SPINAL CANAL LUMBAR W/CONTRAST MATERIAL','MRI SPINAL CANAL LUMBAR W/CONTRAST MATERIAL','72149','1','','1','0','','','',0, 1, 0, 0),
(6261,'MRI SPINAL CANAL CERVICAL W/O & W/CONTR MATRL','MRI SPINAL CANAL CERVICAL W/O & W/CONTR MATRL','72156','1','','1','0','','','',0, 1, 0, 0),
(6262,'MRI SPINAL CANAL THORACIC W/O & W/CONTR MATRL','MRI SPINAL CANAL THORACIC W/O & W/CONTR MATRL','72157','1','','1','0','','','',0, 1, 0, 0),
(6263,'MRI SPINAL CANAL LUMBAR W/O & W/CONTR MATRL','MRI SPINAL CANAL LUMBAR W/O & W/CONTR MATRL','72158','1','','1','0','','','',0, 1, 0, 0),
(6264,'MRA SPINAL CANAL W/WO CONTRAST MATERIAL','MRA SPINAL CANAL W/WO CONTRAST MATERIAL','72159','1','','1','0','','','',0, 1, 0, 0),
(6265,'RADIOLOGIC EXAMINATION PELVIS 1/2 VIEWS','RADIOLOGIC EXAMINATION PELVIS 1/2 VIEWS','72170','1','','1','0','','','',0, 1, 0, 0),
(6266,'RADIOLOGIC EXAM PELVIS COMPL MINIMUM 3 VIEWS','RADIOLOGIC EXAM PELVIS COMPL MINIMUM 3 VIEWS','72190','1','','1','0','','','',0, 1, 0, 0),
(6267,'CT ANGIOGRAPHY PELVIS W/CONTRAST/NONCONTRAST','CT ANGIOGRAPHY PELVIS W/CONTRAST/NONCONTRAST','72191','1','','1','0','','','',0, 1, 0, 0),
(6268,'CT PELVIS W/O CONTRAST MATERIAL','CT PELVIS W/O CONTRAST MATERIAL','72192','1','','1','0','','','',0, 1, 0, 0),
(6269,'CT PELVIS W/CONTRAST MATERIAL','CT PELVIS W/CONTRAST MATERIAL','72193','1','','1','0','','','',0, 1, 0, 0),
(6270,'CT PELVIS W/O & W/CONTRAST MATERIAL','CT PELVIS W/O & W/CONTRAST MATERIAL','72194','1','','1','0','','','',0, 1, 0, 0),
(6271,'MRI PELVIS W/O CONTRAST MATERIAL','MRI PELVIS W/O CONTRAST MATERIAL','72195','1','','1','0','','','',0, 1, 0, 0),
(6272,'MRI PELVIS W/CONTRAST MATERIAL','MRI PELVIS W/CONTRAST MATERIAL','72196','1','','1','0','','','',0, 1, 0, 0),
(6273,'MRI PELVIS W/O & W/CONTRAST MATERIAL','MRI PELVIS W/O & W/CONTRAST MATERIAL','72197','1','','1','0','','','',0, 1, 0, 0),
(6274,'MRA PELVIS W/WO CONTRAST MATERIAL','MRA PELVIS W/WO CONTRAST MATERIAL','72198','1','','1','0','','','',0, 1, 0, 0),
(6275,'RADIOLOGIC EXAMINATION SACROILIAC JNTS <3 VIEWS','RADIOLOGIC EXAMINATION SACROILIAC JNTS <3 VIEWS','72200','1','','1','0','','','',0, 1, 0, 0),
(6276,'RADIOLOGIC EXAM SACROILIAC JOINTS 3/MORE VIEWS','RADIOLOGIC EXAM SACROILIAC JOINTS 3/MORE VIEWS','72202','1','','1','0','','','',0, 1, 0, 0),
(6277,'RADEX SACRUM & COCCYX MINIMUM 2 VIEWS','RADEX SACRUM & COCCYX MINIMUM 2 VIEWS','72220','1','','1','0','','','',0, 1, 0, 0),
(6278,'MYELOGRAPHY CERVICAL RS&I','MYELOGRAPHY CERVICAL RS&I','72240','1','','1','0','','','',0, 1, 0, 0),
(6279,'MYELOGRAPHY THORACIC RS&I','MYELOGRAPHY THORACIC RS&I','72255','1','','1','0','','','',0, 1, 0, 0),
(6280,'MYELOGRAPY LUMBOSACRAL RS&I','MYELOGRAPY LUMBOSACRAL RS&I','72265','1','','1','0','','','',0, 1, 0, 0),
(6281,'MYELOGRAPY 2/MORE REGIONS RS&I','MYELOGRAPY 2/MORE REGIONS RS&I','72270','1','','1','0','','','',0, 1, 0, 0),
(6282,'EPIDUROGRAPY RS&I','EPIDUROGRAPY RS&I','72275','1','','1','0','','','',0, 1, 0, 0),
(6283,'DISKOGRAPY CERVICAL/THORACIC RS&I','DISKOGRAPY CERVICAL/THORACIC RS&I','72285','1','','1','0','','','',0, 1, 0, 0),
(6284,'DISKOGRAPY LUMBAR RS&I','DISKOGRAPY LUMBAR RS&I','72295','1','','1','0','','','',0, 1, 0, 0),
(6285,'RADEX CLAVICLE COMPLETE','RADEX CLAVICLE COMPLETE','73000','1','','1','0','','','',0, 1, 0, 0),
(6286,'RADEX SCAPULA COMPLETE','RADEX SCAPULA COMPLETE','73010','1','','1','0','','','',0, 1, 0, 0),
(6287,'RADEX SHOULDER 1 VIEW','RADEX SHOULDER 1 VIEW','73020','1','','1','0','','','',0, 1, 0, 0),
(6288,'RADEX SHOULDER COMPLETE MINIMUM 2 VIEWS','RADEX SHOULDER COMPLETE MINIMUM 2 VIEWS','73030','1','','1','0','','','',0, 1, 0, 0),
(6289,'RADEX SHOULDER ARTHROGRAPHY RS&I','RADEX SHOULDER ARTHROGRAPHY RS&I','73040','1','','1','0','','','',0, 1, 0, 0),
(6290,'RADEX A-C JOINTS BI W/WO WEIGHTED DISTRCJ','RADEX A-C JOINTS BI W/WO WEIGHTED DISTRCJ','73050','1','','1','0','','','',0, 1, 0, 0),
(6291,'RADEX HUMERUS MINIMUM 2 VIEWS','RADEX HUMERUS MINIMUM 2 VIEWS','73060','1','','1','0','','','',0, 1, 0, 0),
(6292,'RADEX ELBOW 2 VIEWS','RADEX ELBOW 2 VIEWS','73070','1','','1','0','','','',0, 1, 0, 0),
(6293,'RADEX ELBOW COMPLETE MINIMUM 3 VIEWS','RADEX ELBOW COMPLETE MINIMUM 3 VIEWS','73080','1','','1','0','','','',0, 1, 0, 0),
(6294,'RADEX ELBOW ARTHROGRAPHY RS&I','RADEX ELBOW ARTHROGRAPHY RS&I','73085','1','','1','0','','','',0, 1, 0, 0),
(6295,'RADEX FOREARM 2 VIEWS','RADEX FOREARM 2 VIEWS','73090','1','','1','0','','','',0, 1, 0, 0),
(6296,'RADEX UPPER EXTREMITY INFANT MINIMUM 2 VIEWS','RADEX UPPER EXTREMITY INFANT MINIMUM 2 VIEWS','73092','1','','1','0','','','',0, 1, 0, 0),
(6297,'RADEX WRIST 2 VIEWS','RADEX WRIST 2 VIEWS','73100','1','','1','0','','','',0, 1, 0, 0),
(6298,'RADEX WRIST COMPLETE MINIMUM 3 VIEWS','RADEX WRIST COMPLETE MINIMUM 3 VIEWS','73110','1','','1','0','','','',0, 1, 0, 0),
(6299,'RADEX WRIST ARTHROGRAPHY RS&I','RADEX WRIST ARTHROGRAPHY RS&I','73115','1','','1','0','','','',0, 1, 0, 0),
(6300,'RADEX HAND 2 VIEWS','RADEX HAND 2 VIEWS','73120','1','','1','0','','','',0, 1, 0, 0),
(6301,'RADEX HAND MINIMUM 3 VIEWS','RADEX HAND MINIMUM 3 VIEWS','73130','1','','1','0','','','',0, 1, 0, 0),
(6302,'RADEX FINGR MINIMUM 2 VIEWS','RADEX FINGR MINIMUM 2 VIEWS','73140','1','','1','0','','','',0, 1, 0, 0),
(6303,'CT UPPER EXTREMITY W/O CONTRAST MATERIAL','CT UPPER EXTREMITY W/O CONTRAST MATERIAL','73200','1','','1','0','','','',0, 1, 0, 0),
(6304,'CT UPPER EXTREMITY W/CONTRAST MATERIAL','CT UPPER EXTREMITY W/CONTRAST MATERIAL','73201','1','','1','0','','','',0, 1, 0, 0),
(6305,'CT UPPER EXTREMITY W/O & W/CONTRAST MATERIAL','CT UPPER EXTREMITY W/O & W/CONTRAST MATERIAL','73202','1','','1','0','','','',0, 1, 0, 0),
(6306,'CT ANGIOGRAPHY UPPER EXTREMITY','CT ANGIOGRAPHY UPPER EXTREMITY','73206','1','','1','0','','','',0, 1, 0, 0),
(6307,'MRI UPPER EXTREMITY OTH THAN JT W/O CONTR MATRL','MRI UPPER EXTREMITY OTH THAN JT W/O CONTR MATRL','73218','1','','1','0','','','',0, 1, 0, 0),
(6308,'MRI UPPER EXTREMITY OTH THAN JT W/CONTR MATRL','MRI UPPER EXTREMITY OTH THAN JT W/CONTR MATRL','73219','1','','1','0','','','',0, 1, 0, 0),
(6309,'MRI UPPER EXTREM OTHER THAN JT W/O & W/CONTRAS','MRI UPPER EXTREM OTHER THAN JT W/O & W/CONTRAS','73220','1','','1','0','','','',0, 1, 0, 0),
(6310,'MRI ANY JT UPPER EXTREMITY W/O CONTRAST MATRL','MRI ANY JT UPPER EXTREMITY W/O CONTRAST MATRL','73221','1','','1','0','','','',0, 1, 0, 0),
(6311,'MRI ANY JT UPPER EXTREMITY W/CONTRAST MATRL','MRI ANY JT UPPER EXTREMITY W/CONTRAST MATRL','73222','1','','1','0','','','',0, 1, 0, 0),
(6312,'MRI ANY JT UPPER EXTREMITY W/O & W/CONTR MATRL','MRI ANY JT UPPER EXTREMITY W/O & W/CONTR MATRL','73223','1','','1','0','','','',0, 1, 0, 0),
(6313,'MRA UPPER EXTREMITY W/WO CONTRAST MATERIAL','MRA UPPER EXTREMITY W/WO CONTRAST MATERIAL','73225','1','','1','0','','','',0, 1, 0, 0),
(6314,'RADEX HIP UNILATERAL WITH PELVIS 1 VIEW','RADEX HIP UNILATERAL WITH PELVIS 1 VIEW','73501','1','','1','0','','','',0, 1, 0, 0),
(6315,'RADEX HIP UNILATERAL WITH PELVIS 2-3 VIEWS','RADEX HIP UNILATERAL WITH PELVIS 2-3 VIEWS','73502','1','','1','0','','','',0, 1, 0, 0),
(6316,'RADEX HIP UNILATERAL WITH PELVIS MINIMUM 4 VIEWS','RADEX HIP UNILATERAL WITH PELVIS MINIMUM 4 VIEWS','73503','1','','1','0','','','',0, 1, 0, 0),
(6317,'RADEX HIPS BILATERAL WITH PELVIS 2 VIEWS','RADEX HIPS BILATERAL WITH PELVIS 2 VIEWS','73521','1','','1','0','','','',0, 1, 0, 0),
(6318,'RADEX HIPS BILATERAL WITH PELVIS 3-4 VIEWS','RADEX HIPS BILATERAL WITH PELVIS 3-4 VIEWS','73522','1','','1','0','','','',0, 1, 0, 0),
(6319,'RADEX HIPS BILATERAL WITH PELVIS MINIMUM 5 VIEWS','RADEX HIPS BILATERAL WITH PELVIS MINIMUM 5 VIEWS','73523','1','','1','0','','','',0, 1, 0, 0),
(6320,'RADEX HIP ARTHROGRAPHY RS&I','RADEX HIP ARTHROGRAPHY RS&I','73525','1','','1','0','','','',0, 1, 0, 0),
(6321,'RADIOLOGIC EXAMINATION FEMUR 1 VIEW','RADIOLOGIC EXAMINATION FEMUR 1 VIEW','73551','1','','1','0','','','',0, 1, 0, 0),
(6322,'RADIOLOGIC EXAMINATION FEMUR MINIMUM 2 VIEWS','RADIOLOGIC EXAMINATION FEMUR MINIMUM 2 VIEWS','73552','1','','1','0','','','',0, 1, 0, 0),
(6323,'RADIOLOGIC EXAMINATION KNEE 1/2 VIEWS','RADIOLOGIC EXAMINATION KNEE 1/2 VIEWS','73560','1','','1','0','','','',0, 1, 0, 0),
(6324,'RADIOLOGIC EXAMINATION KNEE 3 VIEWS','RADIOLOGIC EXAMINATION KNEE 3 VIEWS','73562','1','','1','0','','','',0, 1, 0, 0),
(6325,'RADIOLOGIC EXAM KNEE COMPLETE 4/MORE VIEWS','RADIOLOGIC EXAM KNEE COMPLETE 4/MORE VIEWS','73564','1','','1','0','','','',0, 1, 0, 0),
(6326,'RADIOLOGIC EXAM BOTH KNEES STANDING ANTEROPOST','RADIOLOGIC EXAM BOTH KNEES STANDING ANTEROPOST','73565','1','','1','0','','','',0, 1, 0, 0),
(6327,'RADIOLOGIC EXAM KNEE ARTHROGRAPHY RS&I','RADIOLOGIC EXAM KNEE ARTHROGRAPHY RS&I','73580','1','','1','0','','','',0, 1, 0, 0),
(6328,'RADIOLOGIC EXAMINATION TIBIA & FIBULA 2 VIEWS','RADIOLOGIC EXAMINATION TIBIA & FIBULA 2 VIEWS','73590','1','','1','0','','','',0, 1, 0, 0),
(6329,'RADEX LOWER EXTREMITY INFANT MINIMUM 2 VIEWS','RADEX LOWER EXTREMITY INFANT MINIMUM 2 VIEWS','73592','1','','1','0','','','',0, 1, 0, 0),
(6330,'RADIOLOGIC EXAMINATION ANKLE 2 VIEWS','RADIOLOGIC EXAMINATION ANKLE 2 VIEWS','73600','1','','1','0','','','',0, 1, 0, 0),
(6331,'RADEX ANKLE COMPLETE MINIMUM 3 VIEWS','RADEX ANKLE COMPLETE MINIMUM 3 VIEWS','73610','1','','1','0','','','',0, 1, 0, 0),
(6332,'RADEX ANKLE ARTHROGRAPHY RS&I','RADEX ANKLE ARTHROGRAPHY RS&I','73615','1','','1','0','','','',0, 1, 0, 0),
(6333,'RADIOLOGIC EXAMINATION FOOT 2 VIEWS','RADIOLOGIC EXAMINATION FOOT 2 VIEWS','73620','1','','1','0','','','',0, 1, 0, 0),
(6334,'RADEX FOOT COMPLETE MINIMUM 3 VIEWS','RADEX FOOT COMPLETE MINIMUM 3 VIEWS','73630','1','','1','0','','','',0, 1, 0, 0),
(6335,'RADEX CALCANEUS MINIMUM 2 VIEWS','RADEX CALCANEUS MINIMUM 2 VIEWS','73650','1','','1','0','','','',0, 1, 0, 0),
(6336,'RADEX TOE MINIMUM 2 VIEWS','RADEX TOE MINIMUM 2 VIEWS','73660','1','','1','0','','','',0, 1, 0, 0),
(6337,'CT LOWER EXTREMITY W/O CONTRAST MATERIAL','CT LOWER EXTREMITY W/O CONTRAST MATERIAL','73700','1','','1','0','','','',0, 1, 0, 0),
(6338,'CT LOWER EXTREMITY W/CONTRAST MATERIAL','CT LOWER EXTREMITY W/CONTRAST MATERIAL','73701','1','','1','0','','','',0, 1, 0, 0),
(6339,'CT LOWER EXTREMITY W/O & W/CONTRAST MATRL','CT LOWER EXTREMITY W/O & W/CONTRAST MATRL','73702','1','','1','0','','','',0, 1, 0, 0),
(6340,'CT ANGIOGRAPHY LOWER EXTREMITY','CT ANGIOGRAPHY LOWER EXTREMITY','73706','1','','1','0','','','',0, 1, 0, 0),
(6341,'MRI LOWER EXTREM OTH/THN JT W/O CONTR MATRL','MRI LOWER EXTREM OTH/THN JT W/O CONTR MATRL','73718','1','','1','0','','','',0, 1, 0, 0),
(6342,'MRI LOWER EXTREM OTH/THN JT W/CONTRAST MATRL','MRI LOWER EXTREM OTH/THN JT W/CONTRAST MATRL','73719','1','','1','0','','','',0, 1, 0, 0),
(6343,'MRI LOWER EXTREM OTH/THN JT W/O & W/CONTR MATR','MRI LOWER EXTREM OTH/THN JT W/O & W/CONTR MATR','73720','1','','1','0','','','',0, 1, 0, 0),
(6344,'MRI ANY JT LOWER EXTREM W/O CONTRAST MATRL','MRI ANY JT LOWER EXTREM W/O CONTRAST MATRL','73721','1','','1','0','','','',0, 1, 0, 0),
(6345,'MRI ANY JT LOWER EXTREM W/CONTRAST MATERIAL','MRI ANY JT LOWER EXTREM W/CONTRAST MATERIAL','73722','1','','1','0','','','',0, 1, 0, 0),
(6346,'MRI ANY JT LOWER EXTREM W/O & W/CONTRAST MATRL','MRI ANY JT LOWER EXTREM W/O & W/CONTRAST MATRL','73723','1','','1','0','','','',0, 1, 0, 0),
(6347,'MRA LOWER EXTREMITY W/WO CONTRAST MATERIAL','MRA LOWER EXTREMITY W/WO CONTRAST MATERIAL','73725','1','','1','0','','','',0, 1, 0, 0),
(6348,'RADEX ABDOMEN 1 ANTEROPOSTERIOR VIEW','RADEX ABDOMEN 1 ANTEROPOSTERIOR VIEW','74000','1','','1','0','','','',0, 1, 0, 0),
(6349,'RADEX ABD ANTEROPOST&ADDL OBLQ&CONE VIEWS','RADEX ABD ANTEROPOST&ADDL OBLQ&CONE VIEWS','74010','1','','1','0','','','',0, 1, 0, 0),
(6350,'RADEX ABDOMEN COMPL W/DCBTS&/ERC VIEWS','RADEX ABDOMEN COMPL W/DCBTS&/ERC VIEWS','74020','1','','1','0','','','',0, 1, 0, 0),
(6351,'RADEX ABD COMPL AQT ABD W/S/E/D VIEWS 1 VIEW CH','RADEX ABD COMPL AQT ABD W/S/E/D VIEWS 1 VIEW CH','74022','1','','1','0','','','',0, 1, 0, 0),
(6352,'CT ABDOMEN W/O CONTRAST MATERIAL','CT ABDOMEN W/O CONTRAST MATERIAL','74150','1','','1','0','','','',0, 1, 0, 0),
(6353,'CT ABDOMEN W/CONTRAST MATERIAL','CT ABDOMEN W/CONTRAST MATERIAL','74160','1','','1','0','','','',0, 1, 0, 0),
(6354,'CT ABDOMEN W/O & W/CONTRAST MATERIAL','CT ABDOMEN W/O & W/CONTRAST MATERIAL','74170','1','','1','0','','','',0, 1, 0, 0),
(6355,'CT ANGIO ABD&PLVIS CNTRST MTRL W/WO CNTRST IMG','CT ANGIO ABD&PLVIS CNTRST MTRL W/WO CNTRST IMG','74174','1','','1','0','','','',0, 1, 0, 0),
(6356,'CT ANGIOGRAPHY ABDOMEN W/CONTRAST/NONCONTRAST','CT ANGIOGRAPHY ABDOMEN W/CONTRAST/NONCONTRAST','74175','1','','1','0','','','',0, 1, 0, 0),
(6357,'CT ABDOMEN & PELVIS W/O CONTRAST MATERIAL','CT ABDOMEN & PELVIS W/O CONTRAST MATERIAL','74176','1','','1','0','','','',0, 1, 0, 0),
(6358,'CT ABDOMEN & PELVIS W/CONTRAST MATERIAL','CT ABDOMEN & PELVIS W/CONTRAST MATERIAL','74177','1','','1','0','','','',0, 1, 0, 0),
(6359,'CT ABDOMEN & PELVIS W/O CONTRST 1/> BODY RE','CT ABDOMEN & PELVIS W/O CONTRST 1/> BODY RE','74178','1','','1','0','','','',0, 1, 0, 0),
(6360,'MRI ABDOMEN W/O CONTRAST MATERIAL','MRI ABDOMEN W/O CONTRAST MATERIAL','74181','1','','1','0','','','',0, 1, 0, 0),
(6361,'MRI ABDOMEN W/CONTRAST MATERIAL','MRI ABDOMEN W/CONTRAST MATERIAL','74182','1','','1','0','','','',0, 1, 0, 0),
(6362,'MRI ABDOMEN W/O & W/CONTRAST MATERIAL','MRI ABDOMEN W/O & W/CONTRAST MATERIAL','74183','1','','1','0','','','',0, 1, 0, 0),
(6363,'MRA ABDOMEN W/WO CONTRAST MATERIAL','MRA ABDOMEN W/WO CONTRAST MATERIAL','74185','1','','1','0','','','',0, 1, 0, 0),
(6364,'PERITONEOGRAM RS&I','PERITONEOGRAM RS&I','74190','1','','1','0','','','',0, 1, 0, 0),
(6365,'RADEX PHARYNX&/CERVICAL ESOPHAGUS','RADEX PHARYNX&/CERVICAL ESOPHAGUS','74210','1','','1','0','','','',0, 1, 0, 0),
(6366,'RADEX ESOPHAGUS','RADEX ESOPHAGUS','74220','1','','1','0','','','',0, 1, 0, 0),
(6367,'SWALLOWING FUNCJ W/CINERADIOGRAPY/VIDRADIOG','SWALLOWING FUNCJ W/CINERADIOGRAPY/VIDRADIOG','74230','1','','1','0','','','',0, 1, 0, 0),
(6368,'RMVL FB ESOPHAGEAL W/USE BALLOON CATH RS&I','RMVL FB ESOPHAGEAL W/USE BALLOON CATH RS&I','74235','1','','1','0','','','',0, 1, 0, 0),
(6369,'RADEX GI TRACT UPPER W/WO DELAYED IMAGES W/O KUB','RADEX GI TRACT UPPER W/WO DELAYED IMAGES W/O KUB','74240','1','','1','0','','','',0, 1, 0, 0),
(6370,'RADEX GI TRACT UPPER W/WO DELAYED IMAGES W/KUB','RADEX GI TRACT UPPER W/WO DELAYED IMAGES W/KUB','74241','1','','1','0','','','',0, 1, 0, 0),
(6371,'RADEX GI TRACT UPR W/SM INT W/MULT SERIAL IMAGES','RADEX GI TRACT UPR W/SM INT W/MULT SERIAL IMAGES','74245','1','','1','0','','','',0, 1, 0, 0),
(6372,'RADEX UPPER GI W/WO GLUCAGON/DELAY IMGES W/O KUB','RADEX UPPER GI W/WO GLUCAGON/DELAY IMGES W/O KUB','74246','1','','1','0','','','',0, 1, 0, 0),
(6373,'RADEX UPPER GI W/WO GLUCAGON/DELAY IMAGES W/KUB','RADEX UPPER GI W/WO GLUCAGON/DELAY IMAGES W/KUB','74247','1','','1','0','','','',0, 1, 0, 0),
(6374,'RADEX GI UPR W/WO GLUCOSE W/SM INTEST FOLLW-THRU','RADEX GI UPR W/WO GLUCOSE W/SM INTEST FOLLW-THRU','74249','1','','1','0','','','',0, 1, 0, 0),
(6375,'RADEX SMALL INTESTINE W/MULTIPLE SERIAL IMAGES','RADEX SMALL INTESTINE W/MULTIPLE SERIAL IMAGES','74250','1','','1','0','','','',0, 1, 0, 0),
(6376,'RADEX SM INT W/MLT SRL IMGES VIA ENTEROCLSS TUBE','RADEX SM INT W/MLT SRL IMGES VIA ENTEROCLSS TUBE','74251','1','','1','0','','','',0, 1, 0, 0),
(6377,'DUODENOGRAPY HYPOTONIC','DUODENOGRAPY HYPOTONIC','74260','1','','1','0','','','',0, 1, 0, 0),
(6378,'CT COLONOGRPHY DX IMAGE POSTPROCESS W/O CONTRAST','CT COLONOGRPHY DX IMAGE POSTPROCESS W/O CONTRAST','74261','1','','1','0','','','',0, 1, 0, 0),
(6379,'CT COLONOGRPHY DX IMAGE POSTPROCESS W/CONTRAST','CT COLONOGRPHY DX IMAGE POSTPROCESS W/CONTRAST','74262','1','','1','0','','','',0, 1, 0, 0),
(6380,'CT COLONOGRAPHY SCREENING IMAGE POSTPROCESSING','CT COLONOGRAPHY SCREENING IMAGE POSTPROCESSING','74263','1','','1','0','','','',0, 1, 0, 0),
(6381,'RADEX COLON BARIUM ENEMA W/WO KUB','RADEX COLON BARIUM ENEMA W/WO KUB','74270','1','','1','0','','','',0, 1, 0, 0),
(6382,'RADEX COLON W/SPEC HI DNS BARIUM W/WO GLUCAGON','RADEX COLON W/SPEC HI DNS BARIUM W/WO GLUCAGON','74280','1','','1','0','','','',0, 1, 0, 0),
(6383,'THERAPEUTIC ENEMA RDCTJ INTUSSUSCEPTION/OBSTRCJ','THERAPEUTIC ENEMA RDCTJ INTUSSUSCEPTION/OBSTRCJ','74283','1','','1','0','','','',0, 1, 0, 0),
(6384,'CHOLECYSTOGRAPHY ORAL CONTRST','CHOLECYSTOGRAPHY ORAL CONTRST','74290','1','','1','0','','','',0, 1, 0, 0),
(6385,'CHOLANGIOGRAPHY&/PANCREATOGRAPHY NTRAOP RS&I','CHOLANGIOGRAPHY&/PANCREATOGRAPHY NTRAOP RS&I','74300','1','','1','0','','','',0, 1, 0, 0),
(6386,'CHOLANGIO&/PANCREATOGRAPHY ADDL SET INTRAOP RS','CHOLANGIO&/PANCREATOGRAPHY ADDL SET INTRAOP RS','74301','1','','1','0','','','',0, 1, 0, 0),
(6387,'ENDOSCOPIC CATHJ BILIARY DUCTAL SYSTEM RS&I','ENDOSCOPIC CATHJ BILIARY DUCTAL SYSTEM RS&I','74328','1','','1','0','','','',0, 1, 0, 0),
(6388,'ENDOSCOPIC CATHJ PANCREATIC DUCTAL SYS RS&I','ENDOSCOPIC CATHJ PANCREATIC DUCTAL SYS RS&I','74329','1','','1','0','','','',0, 1, 0, 0),
(6389,'CMBN NDSC CATHJ BILIARY&PNCRTC DUCTAL SYS RS&I','CMBN NDSC CATHJ BILIARY&PNCRTC DUCTAL SYS RS&I','74330','1','','1','0','','','',0, 1, 0, 0),
(6390,'INTRO LONG GI TUBE W/MULT FLUORO & IMAGES RS&I','INTRO LONG GI TUBE W/MULT FLUORO & IMAGES RS&I','74340','1','','1','0','','','',0, 1, 0, 0),
(6391,'PERCUTANEOUS PLACEMENT ENTEROCLYSIS TUBE RS&I','PERCUTANEOUS PLACEMENT ENTEROCLYSIS TUBE RS&I','74355','1','','1','0','','','',0, 1, 0, 0),
(6392,'INTRALUMINAL DILATION STRICTURES&/OBSTRCJS RS&I','INTRALUMINAL DILATION STRICTURES&/OBSTRCJS RS&I','74360','1','','1','0','','','',0, 1, 0, 0),
(6393,'PRQ TRANSHEPATC DILAT BILIARY DUCT STRICTRE RS&I','PRQ TRANSHEPATC DILAT BILIARY DUCT STRICTRE RS&I','74363','1','','1','0','','','',0, 1, 0, 0),
(6394,'UROGRAPHY IV W/WO KUB W/WO TOMOGRAPHY','UROGRAPHY IV W/WO KUB W/WO TOMOGRAPHY','74400','1','','1','0','','','',0, 1, 0, 0),
(6395,'UROGRAPHY INFUSION DRIP &/BOLUS TECHNIQUE','UROGRAPHY INFUSION DRIP &/BOLUS TECHNIQUE','74410','1','','1','0','','','',0, 1, 0, 0),
(6396,'UROGRAPY INFUSION DRIP &/BOLUS TECHQ W/WO TOMO','UROGRAPY INFUSION DRIP &/BOLUS TECHQ W/WO TOMO','74415','1','','1','0','','','',0, 1, 0, 0),
(6397,'X-RAY URINARY TRACT EXAM WITH CONTRAST MATERIAL','X-RAY URINARY TRACT EXAM WITH CONTRAST MATERIAL','74420','1','','1','0','','','',0, 1, 0, 0),
(6398,'UROGRAPHY ANTEGRADE RS&I','UROGRAPHY ANTEGRADE RS&I','74425','1','','1','0','','','',0, 1, 0, 0),
(6399,'CYSTOGRAPHY MINIMUM 3 VIEWS RS&I','CYSTOGRAPHY MINIMUM 3 VIEWS RS&I','74430','1','','1','0','','','',0, 1, 0, 0),
(6400,'VASOGRAPY VESICULOGRAPY/EPIDIDYMOGRAPY RS&I','VASOGRAPY VESICULOGRAPY/EPIDIDYMOGRAPY RS&I','74440','1','','1','0','','','',0, 1, 0, 0),
(6401,'CORPORA CAVERNOSOGRAPY RS&I','CORPORA CAVERNOSOGRAPY RS&I','74445','1','','1','0','','','',0, 1, 0, 0),
(6402,'URETHROCYSTOGRAPHY RETROGRADE RS&I','URETHROCYSTOGRAPHY RETROGRADE RS&I','74450','1','','1','0','','','',0, 1, 0, 0),
(6403,'URETHROCYSTOGRAPHY VOIDING RS&I','URETHROCYSTOGRAPHY VOIDING RS&I','74455','1','','1','0','','','',0, 1, 0, 0),
(6404,'RADEX RENAL CYST STUDY TRANSLUMBAR RS&I','RADEX RENAL CYST STUDY TRANSLUMBAR RS&I','74470','1','','1','0','','','',0, 1, 0, 0),
(6405,'DILATION NEPHROSTOMY/URETER/URETHRA RS&I','DILATION NEPHROSTOMY/URETER/URETHRA RS&I','74485','1','','1','0','','','',0, 1, 0, 0),
(6406,'PELVIMETRY W/WOPLACENTAL LOCALIZATION','PELVIMETRY W/WOPLACENTAL LOCALIZATION','74710','1','','1','0','','','',0, 1, 0, 0),
(6407,'FETAL MRI W/PLACNTL MATRNL PLVC IMG SING/1ST GES','FETAL MRI W/PLACNTL MATRNL PLVC IMG SING/1ST GES','74712','1','','1','0','','','',0, 1, 0, 0),
(6408,'FETAL MRI W/PLACNTL MATRNL PLVC IMG EA ADDL GES','FETAL MRI W/PLACNTL MATRNL PLVC IMG EA ADDL GES','74713','1','','1','0','','','',0, 1, 0, 0),
(6409,'HYSTEROSALPINGOGRAPHY RS&I','HYSTEROSALPINGOGRAPHY RS&I','74740','1','','1','0','','','',0, 1, 0, 0),
(6410,'TRANSCERVICAL CATHJ FALLOPIAN TUBE RS&I','TRANSCERVICAL CATHJ FALLOPIAN TUBE RS&I','74742','1','','1','0','','','',0, 1, 0, 0),
(6411,'PERINEOGRAM','PERINEOGRAM','74775','1','','1','0','','','',0, 1, 0, 0),
(6412,'CARDIAC MRI MORPHOLOGY & FUNCTION W/O CONTRAST','CARDIAC MRI MORPHOLOGY & FUNCTION W/O CONTRAST','75557','1','','1','0','','','',0, 1, 0, 0),
(6413,'CARDIAC MRI W/O CONTRAST W/STRESS IMAGING','CARDIAC MRI W/O CONTRAST W/STRESS IMAGING','75559','1','','1','0','','','',0, 1, 0, 0),
(6414,'CARDIAC MRI W/WO CONTRAST & FURTHER SEQ','CARDIAC MRI W/WO CONTRAST & FURTHER SEQ','75561','1','','1','0','','','',0, 1, 0, 0),
(6415,'CARDIAC MRI W/W/O CONTRAST W/STRESS','CARDIAC MRI W/W/O CONTRAST W/STRESS','75563','1','','1','0','','','',0, 1, 0, 0),
(6416,'CARDIAC MRI FOR VELOCITY FLOW MAPPING','CARDIAC MRI FOR VELOCITY FLOW MAPPING','75565','1','','1','0','','','',0, 1, 0, 0),
(6417,'CT HEART NO CONTRAST QUANT EVAL CORONRY CALCIUM','CT HEART NO CONTRAST QUANT EVAL CORONRY CALCIUM','75571','1','','1','0','','','',0, 1, 0, 0),
(6418,'CT HEART CONTRAST EVAL CARDIAC STRUCTURE&MORPH','CT HEART CONTRAST EVAL CARDIAC STRUCTURE&MORPH','75572','1','','1','0','','','',0, 1, 0, 0),
(6419,'CT HRT CONTRST CARDIAC STRUCT&MORPH CONG HRT D','CT HRT CONTRST CARDIAC STRUCT&MORPH CONG HRT D','75573','1','','1','0','','','',0, 1, 0, 0),
(6420,'CTA HRT CORNRY ART/BYPASS GRFTS CONTRST 3D POST','CTA HRT CORNRY ART/BYPASS GRFTS CONTRST 3D POST','75574','1','','1','0','','','',0, 1, 0, 0),
(6421,'AORTOGRAPHY THORACIC W/O SERIALOGRAPHY RS&I','AORTOGRAPHY THORACIC W/O SERIALOGRAPHY RS&I','75600','1','','1','0','','','',0, 1, 0, 0),
(6422,'AORTOGRAPHY THORACIC SERIALOGRAPHY RS&I','AORTOGRAPHY THORACIC SERIALOGRAPHY RS&I','75605','1','','1','0','','','',0, 1, 0, 0),
(6423,'AORTOGRAPHY ABDOMINAL SERIALOGRAPHY RS&I','AORTOGRAPHY ABDOMINAL SERIALOGRAPHY RS&I','75625','1','','1','0','','','',0, 1, 0, 0),
(6424,'AORTOGRAPHY ABDL BI ILIOFEM LOW EXTREM CATH RS&I','AORTOGRAPHY ABDL BI ILIOFEM LOW EXTREM CATH RS&I','75630','1','','1','0','','','',0, 1, 0, 0),
(6425,'CTA ABDL AORTA&BI ILIOFEM W/CONTRAST&POSTP','CTA ABDL AORTA&BI ILIOFEM W/CONTRAST&POSTP','75635','1','','1','0','','','',0, 1, 0, 0),
(6426,'ANIOGRAPHY BRACHIAL RETROGRADE RS&I','ANIOGRAPHY BRACHIAL RETROGRADE RS&I','75658','1','','1','0','','','',0, 1, 0, 0),
(6427,'ANGIOGRAPHY SPINAL SELECTIVE RS&I','ANGIOGRAPHY SPINAL SELECTIVE RS&I','75705','1','','1','0','','','',0, 1, 0, 0),
(6428,'ANGIOGRAPHY EXTREMITY UNILATERAL RS&I','ANGIOGRAPHY EXTREMITY UNILATERAL RS&I','75710','1','','1','0','','','',0, 1, 0, 0),
(6429,'ANGIOGRAPHY EXTREMITY BILATERAL RS&I','ANGIOGRAPHY EXTREMITY BILATERAL RS&I','75716','1','','1','0','','','',0, 1, 0, 0),
(6430,'ANGIOGRAPHY VISCERAL SLCTV/SUPRASLCTV RS&I','ANGIOGRAPHY VISCERAL SLCTV/SUPRASLCTV RS&I','75726','1','','1','0','','','',0, 1, 0, 0),
(6431,'ANGIOGRAPHY ADRENAL UNILATERAL SLCTV RS&I','ANGIOGRAPHY ADRENAL UNILATERAL SLCTV RS&I','75731','1','','1','0','','','',0, 1, 0, 0),
(6432,'ANGIOGRAPHY ADRENAL BILATERAL SLCTV RS&I','ANGIOGRAPHY ADRENAL BILATERAL SLCTV RS&I','75733','1','','1','0','','','',0, 1, 0, 0),
(6433,'ANGIOGRAPHY PELVIC SLCTV/SUPRASLCTV RS&I','ANGIOGRAPHY PELVIC SLCTV/SUPRASLCTV RS&I','75736','1','','1','0','','','',0, 1, 0, 0),
(6434,'ANGIOGRAPHY PULMONARY UNILATERAL SLCTV RS&I','ANGIOGRAPHY PULMONARY UNILATERAL SLCTV RS&I','75741','1','','1','0','','','',0, 1, 0, 0),
(6435,'ANGIOGRAPHY PULMONARY BILATERAL SLCTV RS&I','ANGIOGRAPHY PULMONARY BILATERAL SLCTV RS&I','75743','1','','1','0','','','',0, 1, 0, 0),
(6436,'ANGRPH PULMONARY NONSLCTV CATH/VEN NJX RS&I','ANGRPH PULMONARY NONSLCTV CATH/VEN NJX RS&I','75746','1','','1','0','','','',0, 1, 0, 0),
(6437,'ANGIOGRAPHY INTERNAL MAMMARY RS&I','ANGIOGRAPHY INTERNAL MAMMARY RS&I','75756','1','','1','0','','','',0, 1, 0, 0),
(6438,'ANGRPH SLCTV EA VSL STUDIED AFTER BASIC XM RS&I','ANGRPH SLCTV EA VSL STUDIED AFTER BASIC XM RS&I','75774','1','','1','0','','','',0, 1, 0, 0),
(6439,'ANGIOGRPHY AV SHUNT COMPLETE EVAL FLUOR RS&I','ANGIOGRPHY AV SHUNT COMPLETE EVAL FLUOR RS&I','75791','1','','1','0','','','',0, 1, 0, 0),
(6440,'LYMPHANGIOGRAPHY EXTREMITY ONLY UNILATERAL RS&I','LYMPHANGIOGRAPHY EXTREMITY ONLY UNILATERAL RS&I','75801','1','','1','0','','','',0, 1, 0, 0),
(6441,'LYMPHANGIOGRAPHY EXTREMITY ONLY BILATERAL RS&I','LYMPHANGIOGRAPHY EXTREMITY ONLY BILATERAL RS&I','75803','1','','1','0','','','',0, 1, 0, 0),
(6442,'LYMPHANGIOGRAPHY PELVIC/ABDOMINAL UNILAT RS&I','LYMPHANGIOGRAPHY PELVIC/ABDOMINAL UNILAT RS&I','75805','1','','1','0','','','',0, 1, 0, 0),
(6443,'LYMPHANGIOGRAPHY PELVIC/ABDOMINAL BILATERAL RS&I','LYMPHANGIOGRAPHY PELVIC/ABDOMINAL BILATERAL RS&I','75807','1','','1','0','','','',0, 1, 0, 0),
(6444,'SHUNTOGRAM INDWELLING NONVASCULAR SHUNT RS&I','SHUNTOGRAM INDWELLING NONVASCULAR SHUNT RS&I','75809','1','','1','0','','','',0, 1, 0, 0),
(6445,'SPLENOPORTOGRAPY RS&I','SPLENOPORTOGRAPY RS&I','75810','1','','1','0','','','',0, 1, 0, 0),
(6446,'VENOGRAPHY EXTREMITY UNILATERAL RS&I','VENOGRAPHY EXTREMITY UNILATERAL RS&I','75820','1','','1','0','','','',0, 1, 0, 0),
(6447,'VENOGRAPHY EXTREMITY BILATERAL RS&I','VENOGRAPHY EXTREMITY BILATERAL RS&I','75822','1','','1','0','','','',0, 1, 0, 0),
(6448,'VENOGRAPHY CAVAL INFERIOR SERIALOGRAPHY RS&I','VENOGRAPHY CAVAL INFERIOR SERIALOGRAPHY RS&I','75825','1','','1','0','','','',0, 1, 0, 0),
(6449,'VENOGRAPHY CAVAL SUPERIOR SERIALOGRAPHY RS&I','VENOGRAPHY CAVAL SUPERIOR SERIALOGRAPHY RS&I','75827','1','','1','0','','','',0, 1, 0, 0),
(6450,'VENOGRAPHY RENAL UNILATERAL SELECTIVE RS&I','VENOGRAPHY RENAL UNILATERAL SELECTIVE RS&I','75831','1','','1','0','','','',0, 1, 0, 0),
(6451,'VENOGRAPHY RENAL BILATERAL SELECTIVE RS&I','VENOGRAPHY RENAL BILATERAL SELECTIVE RS&I','75833','1','','1','0','','','',0, 1, 0, 0),
(6452,'VENOGRAPHY ADRENAL UNILATERAL SELECTIVE RS&I','VENOGRAPHY ADRENAL UNILATERAL SELECTIVE RS&I','75840','1','','1','0','','','',0, 1, 0, 0),
(6453,'VENOGRAPHY ADRENAL BILATERAL SELECTIVE RS&I','VENOGRAPHY ADRENAL BILATERAL SELECTIVE RS&I','75842','1','','1','0','','','',0, 1, 0, 0),
(6454,'VENOGRAPHY VENOUS SINUS/JUGULAR CATH RS&I','VENOGRAPHY VENOUS SINUS/JUGULAR CATH RS&I','75860','1','','1','0','','','',0, 1, 0, 0),
(6455,'VENOGRAPHY SUPERIOR SAGITTAL SINUS RS&I','VENOGRAPHY SUPERIOR SAGITTAL SINUS RS&I','75870','1','','1','0','','','',0, 1, 0, 0),
(6456,'VENOGRAPHY EPIDURAL RS&I','VENOGRAPHY EPIDURAL RS&I','75872','1','','1','0','','','',0, 1, 0, 0),
(6457,'VENOGRAPHY ORBITAL RS&I','VENOGRAPHY ORBITAL RS&I','75880','1','','1','0','','','',0, 1, 0, 0),
(6458,'PRQ TRANSHEPATC PORTOGRAPY HEMODYN EVAL RS&I','PRQ TRANSHEPATC PORTOGRAPY HEMODYN EVAL RS&I','75885','1','','1','0','','','',0, 1, 0, 0),
(6459,'PRQ TRANSHEPATC PORTOGRAPY W/O HEMODYN EVL INTRP','PRQ TRANSHEPATC PORTOGRAPY W/O HEMODYN EVL INTRP','75887','1','','1','0','','','',0, 1, 0, 0),
(6460,'HEPATC VNGRPH WDG/FR HEMODYN EVAL RS&I','HEPATC VNGRPH WDG/FR HEMODYN EVAL RS&I','75889','1','','1','0','','','',0, 1, 0, 0),
(6461,'HEPATC VNGRPH WDG/FR W/O HEMODYN EVAL RS&I','HEPATC VNGRPH WDG/FR W/O HEMODYN EVAL RS&I','75891','1','','1','0','','','',0, 1, 0, 0),
(6462,'VENOUS SAMPLING THRU CATH W/WO ANGIOGRAPHY RS&','VENOUS SAMPLING THRU CATH W/WO ANGIOGRAPHY RS&','75893','1','','1','0','','','',0, 1, 0, 0),
(6463,'TRANSCATHETER EMBOLIZATION ANY METH RS&I','TRANSCATHETER EMBOLIZATION ANY METH RS&I','75894','1','','1','0','','','',0, 1, 0, 0),
(6464,'ANGRPH CATH F-UP STD TCAT OTHER THAN THROMBYLSIS','ANGRPH CATH F-UP STD TCAT OTHER THAN THROMBYLSIS','75898','1','','1','0','','','',0, 1, 0, 0),
(6465,'MECHANICAL RMVL PERICATHETER OBSTR MATRL RS&I','MECHANICAL RMVL PERICATHETER OBSTR MATRL RS&I','75901','1','','1','0','','','',0, 1, 0, 0),
(6466,'MECHANICAL RMVL INTRALUMINAL OBSTR MATRL RS&I','MECHANICAL RMVL INTRALUMINAL OBSTR MATRL RS&I','75902','1','','1','0','','','',0, 1, 0, 0),
(6467,'EVASC RPR INFRARENAL AAA/DISSECTION RS&I','EVASC RPR INFRARENAL AAA/DISSECTION RS&I','75952','1','','1','0','','','',0, 1, 0, 0),
(6468,'PLMT XTN PROSTH EVASC RPR INFRARENAL RS&I','PLMT XTN PROSTH EVASC RPR INFRARENAL RS&I','75953','1','','1','0','','','',0, 1, 0, 0),
(6469,'EVASC RPR ILIAC ART W/ILIO-ILIAC PROSTH RS&I','EVASC RPR ILIAC ART W/ILIO-ILIAC PROSTH RS&I','75954','1','','1','0','','','',0, 1, 0, 0),
(6470,'EVASC RPR DESCND THORCIC AORTA SUBCLAV ORIG RS&I','EVASC RPR DESCND THORCIC AORTA SUBCLAV ORIG RS&I','75956','1','','1','0','','','',0, 1, 0, 0),
(6471,'EVASC RPR DESCND THORCIC AORTA CELIAC ORIG RS&I','EVASC RPR DESCND THORCIC AORTA CELIAC ORIG RS&I','75957','1','','1','0','','','',0, 1, 0, 0),
(6472,'PLMT PROX XTN PRSTH EVASC DESC THORAC AORTA RS&I','PLMT PROX XTN PRSTH EVASC DESC THORAC AORTA RS&I','75958','1','','1','0','','','',0, 1, 0, 0),
(6473,'PLMT DSTL XTN PRSTH EVASC DESC THORAC AORTA RS&I','PLMT DSTL XTN PRSTH EVASC DESC THORAC AORTA RS&I','75959','1','','1','0','','','',0, 1, 0, 0),
(6474,'TRANSLUMINAL BALLOON ANGIOP PERIPHERAL ART RSI','TRANSLUMINAL BALLOON ANGIOP PERIPHERAL ART RSI','75962','1','','1','0','','','',0, 1, 0, 0),
(6475,'TRLUML BALOON ANGIOP PERIPHER EA ADDL ART RS&I','TRLUML BALOON ANGIOP PERIPHER EA ADDL ART RS&I','75964','1','','1','0','','','',0, 1, 0, 0),
(6476,'TRLUML BALO ANGIOPLASTY RENAL/OTH VISC ART RS&I','TRLUML BALO ANGIOPLASTY RENAL/OTH VISC ART RS&I','75966','1','','1','0','','','',0, 1, 0, 0),
(6477,'TRLUML BALO ANGIOPLASTY EA VISCERAL ART RS&I','TRLUML BALO ANGIOPLASTY EA VISCERAL ART RS&I','75968','1','','1','0','','','',0, 1, 0, 0),
(6478,'TRANSCATHETER BIOPSY RS&I','TRANSCATHETER BIOPSY RS&I','75970','1','','1','0','','','',0, 1, 0, 0),
(6479,'TRANSLUMINAL BALLOON ANGIOPLASTY VENOUS RS&I','TRANSLUMINAL BALLOON ANGIOPLASTY VENOUS RS&I','75978','1','','1','0','','','',0, 1, 0, 0),
(6480,'CHANGE PRQ TUBE/DRAINAGE CATH W CONTRAST RS&I','CHANGE PRQ TUBE/DRAINAGE CATH W CONTRAST RS&I','75984','1','','1','0','','','',0, 1, 0, 0),
(6481,'RADIOLOGICAL GUIDANCE PRQ DRG W/PLMT CATH RS&I','RADIOLOGICAL GUIDANCE PRQ DRG W/PLMT CATH RS&I','75989','1','','1','0','','','',0, 1, 0, 0),
(6482,'FLUOROSCOPY SPX UP TO 1 HOUR PHYS/QHP TIME','FLUOROSCOPY SPX UP TO 1 HOUR PHYS/QHP TIME','76000','1','','1','0','','','',0, 1, 0, 0),
(6483,'FLUOROSCOPY SPX >1 HOUR PHYS/QHP TIME','FLUOROSCOPY SPX >1 HOUR PHYS/QHP TIME','76001','1','','1','0','','','',0, 1, 0, 0),
(6484,'RADEX FROM NOSE RECTUM FOREIGN BODY 1 VIEW CHLD','RADEX FROM NOSE RECTUM FOREIGN BODY 1 VIEW CHLD','76010','1','','1','0','','','',0, 1, 0, 0),
(6485,'RADEX ABSCESS/FISTULA/SINUS TRACT RS&I','RADEX ABSCESS/FISTULA/SINUS TRACT RS&I','76080','1','','1','0','','','',0, 1, 0, 0),
(6486,'RADIOLOGICAL EXAMINATION SURGICAL SPECIMEN','RADIOLOGICAL EXAMINATION SURGICAL SPECIMEN','76098','1','','1','0','','','',0, 1, 0, 0),
(6487,'RADEX 1 PLNE BODY SECTION OTH/THN W/UROGRAPY','RADEX 1 PLNE BODY SECTION OTH/THN W/UROGRAPY','76100','1','','1','0','','','',0, 1, 0, 0),
(6488,'RADEX CPLX MOTION BDY SCTJ OTH/THN UROGRAPY UNI','RADEX CPLX MOTION BDY SCTJ OTH/THN UROGRAPY UNI','76101','1','','1','0','','','',0, 1, 0, 0),
(6489,'RADEX CPLX MOTION BDY SCTJ OTH/THN UROGRAPY BI','RADEX CPLX MOTION BDY SCTJ OTH/THN UROGRAPY BI','76102','1','','1','0','','','',0, 1, 0, 0),
(6490,'CINERADIOGRAPY/VIDRADIOGRAPY XCPT WHERE SPEC','CINERADIOGRAPY/VIDRADIOGRAPY XCPT WHERE SPEC','76120','1','','1','0','','','',0, 1, 0, 0),
(6491,'CINERADIOGRAPY/VIDRADIOGRAPY ROUTINE EXAMINATION','CINERADIOGRAPY/VIDRADIOGRAPY ROUTINE EXAMINATION','76125','1','','1','0','','','',0, 1, 0, 0),
(6492,'CONSLTJ X-RAY XM MADE ELSEWHERE WRTTN REPRT','CONSLTJ X-RAY XM MADE ELSEWHERE WRTTN REPRT','76140','1','','1','0','','','',0, 1, 0, 0),
(6493,'3D RENDERING W/INTERP & POSTPROCESS SUPERVISION','3D RENDERING W/INTERP & POSTPROCESS SUPERVISION','76376','1','','1','0','','','',0, 1, 0, 0),
(6494,'3D RENDERING W/INTERP&POSTPROC DIFF WORK STATION','3D RENDERING W/INTERP&POSTPROC DIFF WORK STATION','76377','1','','1','0','','','',0, 1, 0, 0),
(6495,'CT LIMITED/LOCALIZED FOLLOW UP STUDY','CT LIMITED/LOCALIZED FOLLOW UP STUDY','76380','1','','1','0','','','',0, 1, 0, 0),
(6496,'MRI SPECTROSCOPY','MRI SPECTROSCOPY','76390','1','','1','0','','','',0, 1, 0, 0),
(6497,'UNLISTED FLUOROSCOPIC PROCEDURE','UNLISTED FLUOROSCOPIC PROCEDURE','76496','1','','1','0','','','',0, 1, 0, 0),
(6498,'UNLISTED COMPUTED TOMOGRAPHY PROCEDURE','UNLISTED COMPUTED TOMOGRAPHY PROCEDURE','76497','1','','1','0','','','',0, 1, 0, 0),
(6499,'UNLISTED MAGNETIC RESONANCE PROCEDURE','UNLISTED MAGNETIC RESONANCE PROCEDURE','76498','1','','1','0','','','',0, 1, 0, 0),
(6500,'UNLISTED DIAGNOSTIC RADIOGRAPHIC PROCEDURE','UNLISTED DIAGNOSTIC RADIOGRAPHIC PROCEDURE','76499','1','','1','0','','','',0, 1, 0, 0),
(6501,'ECHOENCEPHALOGRAPHY REAL TIME IMAGING','ECHOENCEPHALOGRAPHY REAL TIME IMAGING','76506','1','','1','0','','','',0, 1, 0, 0),
(6502,'OPH US DX B-SCAN&QUAN A-SCAN SM PT ENCTR','OPH US DX B-SCAN&QUAN A-SCAN SM PT ENCTR','76510','1','','1','0','','','',0, 1, 0, 0),
(6503,'OPHTHALMIC ULTRASOUND DX QUAN A-SCAN ONLY','OPHTHALMIC ULTRASOUND DX QUAN A-SCAN ONLY','76511','1','','1','0','','','',0, 1, 0, 0),
(6504,'OPHTHALMIC ULTRASOUND DX B-SCAN W/WO A-SCAN','OPHTHALMIC ULTRASOUND DX B-SCAN W/WO A-SCAN','76512','1','','1','0','','','',0, 1, 0, 0),
(6505,'OPH US DX ANT SGM US IMMERSION B-SCAN/HR BIOM','OPH US DX ANT SGM US IMMERSION B-SCAN/HR BIOM','76513','1','','1','0','','','',0, 1, 0, 0),
(6506,'OPHTHALMIC US DX CORNEAL PACHYMETRY UNI/BI','OPHTHALMIC US DX CORNEAL PACHYMETRY UNI/BI','76514','1','','1','0','','','',0, 1, 0, 0),
(6507,'OPHTHALMIC BIOMETRY US ECHOGRAPY A-SCAN','OPHTHALMIC BIOMETRY US ECHOGRAPY A-SCAN','76516','1','','1','0','','','',0, 1, 0, 0),
(6508,'OPH BMTRY US ECHOGRAPY A-SCAN IO LENS PWR CAL','OPH BMTRY US ECHOGRAPY A-SCAN IO LENS PWR CAL','76519','1','','1','0','','','',0, 1, 0, 0),
(6509,'OPHTHALMIC ULTRASONIC FOREIGN BODY LOCALIZATION','OPHTHALMIC ULTRASONIC FOREIGN BODY LOCALIZATION','76529','1','','1','0','','','',0, 1, 0, 0),
(6510,'US SOFT TISSUE HEAD & NECK REAL TIME IMGE DOCM','US SOFT TISSUE HEAD & NECK REAL TIME IMGE DOCM','76536','1','','1','0','','','',0, 1, 0, 0),
(6511,'US CHEST REAL TIME W/IMAGE DOCUMENTATION','US CHEST REAL TIME W/IMAGE DOCUMENTATION','76604','1','','1','0','','','',0, 1, 0, 0),
(6512,'US BREAST UNI REAL TIME WITH IMAGE COMPLETE','US BREAST UNI REAL TIME WITH IMAGE COMPLETE','76641','1','','1','0','','','',0, 1, 0, 0),
(6513,'US BREAST UNI REAL TIME WITH IMAGE LIMITED','US BREAST UNI REAL TIME WITH IMAGE LIMITED','76642','1','','1','0','','','',0, 1, 0, 0),
(6514,'US ABDOMINAL REAL TIME W/IMAGE DOCUMENTATION','US ABDOMINAL REAL TIME W/IMAGE DOCUMENTATION','76700','1','','1','0','','','',0, 1, 0, 0),
(6515,'US ABDOMINAL REAL TIME W/IMAGE LIMITED','US ABDOMINAL REAL TIME W/IMAGE LIMITED','76705','1','','1','0','','','',0, 1, 0, 0),
(6516,'US RETROPERITONEAL REAL TIME W/IMAGE COMPLETE','US RETROPERITONEAL REAL TIME W/IMAGE COMPLETE','76770','1','','1','0','','','',0, 1, 0, 0),
(6517,'US RETROPERITONEAL REAL TIME W/IMAGE LIMITED','US RETROPERITONEAL REAL TIME W/IMAGE LIMITED','76775','1','','1','0','','','',0, 1, 0, 0),
(6518,'US TRNSPLNT KIDNEY REAL TIME W/IMAGE DOCMTN','US TRNSPLNT KIDNEY REAL TIME W/IMAGE DOCMTN','76776','1','','1','0','','','',0, 1, 0, 0),
(6519,'ULTRASOUND SPINAL CANAL & CONTENTS','ULTRASOUND SPINAL CANAL & CONTENTS','76800','1','','1','0','','','',0, 1, 0, 0),
(6520,'US PREGNANT UTERUS 14 WK TRANSABDL 1/1ST GESTAT','US PREGNANT UTERUS 14 WK TRANSABDL 1/1ST GESTAT','76801','1','','1','0','','','',0, 1, 0, 0),
(6521,'US PREG UTERUS 14 WK TRANSABDL EACH GESTATION','US PREG UTERUS 14 WK TRANSABDL EACH GESTATION','76802','1','','1','0','','','',0, 1, 0, 0),
(6522,'US PREG UTERUS AFTER 1ST TRIMEST 1/1ST GESTATION','US PREG UTERUS AFTER 1ST TRIMEST 1/1ST GESTATION','76805','1','','1','0','','','',0, 1, 0, 0),
(6523,'US PREG UTERUS > 1ST TRIMESTER ABDL EA GESTATIO','US PREG UTERUS > 1ST TRIMESTER ABDL EA GESTATIO','76810','1','','1','0','','','',0, 1, 0, 0),
(6524,'US PREG UTERUS W/DETAIL FETAL ANAT 1ST GESTATION','US PREG UTERUS W/DETAIL FETAL ANAT 1ST GESTATION','76811','1','','1','0','','','',0, 1, 0, 0),
(6525,'US PREG UTERUS DETAIL FETAL ANAT EXAM EA GESTAT','US PREG UTERUS DETAIL FETAL ANAT EXAM EA GESTAT','76812','1','','1','0','','','',0, 1, 0, 0),
(6526,'US FETAL NUCHAL TRANSLUCENCY 1ST GESTATION','US FETAL NUCHAL TRANSLUCENCY 1ST GESTATION','76813','1','','1','0','','','',0, 1, 0, 0),
(6527,'US FETAL NUCHAL TRANSLUCENCY EA ADDL GESTATION','US FETAL NUCHAL TRANSLUCENCY EA ADDL GESTATION','76814','1','','1','0','','','',0, 1, 0, 0),
(6528,'US PREGNANT UTERUS LIMITED 1/> FETUSES','US PREGNANT UTERUS LIMITED 1/> FETUSES','76815','1','','1','0','','','',0, 1, 0, 0),
(6529,'US PREG UTERUS REAL TIME F/U TRNSABDL PER FETUS','US PREG UTERUS REAL TIME F/U TRNSABDL PER FETUS','76816','1','','1','0','','','',0, 1, 0, 0),
(6530,'US PREG UTERUS REAL TIME W/IMAGE DCMTN TRANSVAG','US PREG UTERUS REAL TIME W/IMAGE DCMTN TRANSVAG','76817','1','','1','0','','','',0, 1, 0, 0),
(6531,'FETAL BIOPHYSICAL PROFILE NON-STRESS TESTING','FETAL BIOPHYSICAL PROFILE NON-STRESS TESTING','76818','1','','1','0','','','',0, 1, 0, 0),
(6532,'FETAL BIOPHYSICAL PROFILE W/O NON-STRESS TESTING','FETAL BIOPHYSICAL PROFILE W/O NON-STRESS TESTING','76819','1','','1','0','','','',0, 1, 0, 0),
(6533,'DOPPLER VELOCIMETRY FETAL UMBILICAL ARTERY','DOPPLER VELOCIMETRY FETAL UMBILICAL ARTERY','76820','1','','1','0','','','',0, 1, 0, 0),
(6534,'DOPPLER VELOCIMETRY FETAL MIDDLE CEREBRAL ART','DOPPLER VELOCIMETRY FETAL MIDDLE CEREBRAL ART','76821','1','','1','0','','','',0, 1, 0, 0),
(6535,'ECHO FETAL CARDIOVASC W/WO M-MODE RECORDING','ECHO FETAL CARDIOVASC W/WO M-MODE RECORDING','76825','1','','1','0','','','',0, 1, 0, 0),
(6536,'ECHO FETAL CARDIOVASC W/WO M-MODE REPEAT STD','ECHO FETAL CARDIOVASC W/WO M-MODE REPEAT STD','76826','1','','1','0','','','',0, 1, 0, 0),
(6537,'DOPPLER ECHO FETAL SPECTRAL DISPLAY COMPLETE','DOPPLER ECHO FETAL SPECTRAL DISPLAY COMPLETE','76827','1','','1','0','','','',0, 1, 0, 0),
(6538,'DOPPLER ECHO FETAL PULS SPECTRAL F/U/REPEAT','DOPPLER ECHO FETAL PULS SPECTRAL F/U/REPEAT','76828','1','','1','0','','','',0, 1, 0, 0),
(6539,'US TRANSVAGINAL','US TRANSVAGINAL','76830','1','','1','0','','','',0, 1, 0, 0),
(6540,'SALINE INFUS SONOHYSTEROGRAPHY W/COLOR DOPPLER','SALINE INFUS SONOHYSTEROGRAPHY W/COLOR DOPPLER','76831','1','','1','0','','','',0, 1, 0, 0),
(6541,'US PELVIC NONOBSTETRIC REAL-TIME IMAGE COMPLETE','US PELVIC NONOBSTETRIC REAL-TIME IMAGE COMPLETE','76856','1','','1','0','','','',0, 1, 0, 0),
(6542,'US PELVIC NONOBSTETRIC IMAGE DCMTN LIMITED/F/U','US PELVIC NONOBSTETRIC IMAGE DCMTN LIMITED/F/U','76857','1','','1','0','','','',0, 1, 0, 0),
(6543,'US SCROTUM & CONTENTS','US SCROTUM & CONTENTS','76870','1','','1','0','','','',0, 1, 0, 0),
(6544,'US TRANSRECTAL','US TRANSRECTAL','76872','1','','1','0','','','',0, 1, 0, 0),
(6545,'US TRANSRCT PRSTATE VOL BRACHYTX PLNNING SPX','US TRANSRCT PRSTATE VOL BRACHYTX PLNNING SPX','76873','1','','1','0','','','',0, 1, 0, 0),
(6546,'US EXTREMITY NON-VASC REAL-TIME IMG COMPL','US EXTREMITY NON-VASC REAL-TIME IMG COMPL','76881','1','','1','0','','','',0, 1, 0, 0),
(6547,'US EXTREMITY NON-VASC REAL-TIME IMG LMTD','US EXTREMITY NON-VASC REAL-TIME IMG LMTD','76882','1','','1','0','','','',0, 1, 0, 0),
(6548,'US INFT HIPS R-T IMG DYNAMIC REQ PHYS/QHP MANJ','US INFT HIPS R-T IMG DYNAMIC REQ PHYS/QHP MANJ','76885','1','','1','0','','','',0, 1, 0, 0),
(6549,'US INFT HIPS R-T IMG LMTD STATIC PHYS/QHP MANJ','US INFT HIPS R-T IMG LMTD STATIC PHYS/QHP MANJ','76886','1','','1','0','','','',0, 1, 0, 0),
(6550,'US GUIDANCE PERICARDIOCENTESIS RS&I','US GUIDANCE PERICARDIOCENTESIS RS&I','76930','1','','1','0','','','',0, 1, 0, 0),
(6551,'US ENDOMYOCARDIAL BIOPSY RS&I','US ENDOMYOCARDIAL BIOPSY RS&I','76932','1','','1','0','','','',0, 1, 0, 0),
(6552,'US CMPRN RPR ARTL PSEUDOARYSM/ARVEN FSTL','US CMPRN RPR ARTL PSEUDOARYSM/ARVEN FSTL','76936','1','','1','0','','','',0, 1, 0, 0),
(6553,'US VASC ACCESS SITS VSL PATENCY NDL ENTRY','US VASC ACCESS SITS VSL PATENCY NDL ENTRY','76937','1','','1','0','','','',0, 1, 0, 0),
(6554,'US &MNTR PARENCHYMAL TISSUE ABLATION','US &MNTR PARENCHYMAL TISSUE ABLATION','76940','1','','1','0','','','',0, 1, 0, 0),
(6555,'US INTRAUTERINE FTL TFUJ/CORDOCNTS IMG S&I','US INTRAUTERINE FTL TFUJ/CORDOCNTS IMG S&I','76941','1','','1','0','','','',0, 1, 0, 0),
(6556,'US GUIDANCE NEEDLE PLACEMENT IMG S&I','US GUIDANCE NEEDLE PLACEMENT IMG S&I','76942','1','','1','0','','','',0, 1, 0, 0),
(6557,'US GUIDANCE CHORIONIC VILLUS SAMPLING IMG S&I','US GUIDANCE CHORIONIC VILLUS SAMPLING IMG S&I','76945','1','','1','0','','','',0, 1, 0, 0),
(6558,'US GUIDANCE AMNIOCENTESIS IMG S&I','US GUIDANCE AMNIOCENTESIS IMG S&I','76946','1','','1','0','','','',0, 1, 0, 0),
(6559,'US GUIDANCE ASPIRATION OVA IMG S&I','US GUIDANCE ASPIRATION OVA IMG S&I','76948','1','','1','0','','','',0, 1, 0, 0),
(6560,'US GUIDANCE INTERSTITIAL RADIOELMENT APPLICATION','US GUIDANCE INTERSTITIAL RADIOELMENT APPLICATION','76965','1','','1','0','','','',0, 1, 0, 0),
(6561,'US STUDY FOLLOW UP','US STUDY FOLLOW UP','76970','1','','1','0','','','',0, 1, 0, 0),
(6562,'GI ENDOSCOPIC US S&I','GI ENDOSCOPIC US S&I','76975','1','','1','0','','','',0, 1, 0, 0),
(6563,'US BONE DENSITY MEAS & INTERP PERIPH ANY METHO','US BONE DENSITY MEAS & INTERP PERIPH ANY METHO','76977','1','','1','0','','','',0, 1, 0, 0),
(6564,'ULTRASONIC GUIDANCE INTRAOPERATIVE','ULTRASONIC GUIDANCE INTRAOPERATIVE','76998','1','','1','0','','','',0, 1, 0, 0),
(6565,'UNLISTED US PROCEDURE','UNLISTED US PROCEDURE','76999','1','','1','0','','','',0, 1, 0, 0),
(6566,'FLUORO CENTRAL VENOUS ACCESS DEV PLACEMENT','FLUORO CENTRAL VENOUS ACCESS DEV PLACEMENT','77001','1','','1','0','','','',0, 1, 0, 0),
(6567,'FLUOROSCOPIC GUIDANCE NEEDLE PLACEMENT','FLUOROSCOPIC GUIDANCE NEEDLE PLACEMENT','77002','1','','1','0','','','',0, 1, 0, 0),
(6568,'FLUORO NEEDLE/CATH SPINE/PARASPINAL DX/THER','FLUORO NEEDLE/CATH SPINE/PARASPINAL DX/THER','77003','1','','1','0','','','',0, 1, 0, 0),
(6569,'CT GUIDANCE STEREOTACTIC LOCALIZATION','CT GUIDANCE STEREOTACTIC LOCALIZATION','77011','1','','1','0','','','',0, 1, 0, 0),
(6570,'CT GUIDANCE NEEDLE PLACEMENT','CT GUIDANCE NEEDLE PLACEMENT','77012','1','','1','0','','','',0, 1, 0, 0),
(6571,'CT GUIDANCE &MONITORING VISC TISS ABLATION','CT GUIDANCE &MONITORING VISC TISS ABLATION','77013','1','','1','0','','','',0, 1, 0, 0),
(6572,'CT GUIDANCE RADIATION THERAPY FLDS PLACEMENT','CT GUIDANCE RADIATION THERAPY FLDS PLACEMENT','77014','1','','1','0','','','',0, 1, 0, 0),
(6573,'MR GUIDANCE NEEDLE PLACEMENT','MR GUIDANCE NEEDLE PLACEMENT','77021','1','','1','0','','','',0, 1, 0, 0),
(6574,'MR GUIDANCE &MONITORING TISSUE ABLATION','MR GUIDANCE &MONITORING TISSUE ABLATION','77022','1','','1','0','','','',0, 1, 0, 0),
(6575,'COMPUTER-AIDED DETECTION DX MAMMOGRAPHY','COMPUTER-AIDED DETECTION DX MAMMOGRAPHY','77051','1','','1','0','','','',0, 1, 0, 0),
(6576,'COMPUTER-AIDED DETECTION SCREENING MAMMOGRAPHY','COMPUTER-AIDED DETECTION SCREENING MAMMOGRAPHY','77052','1','','1','0','','','',0, 1, 0, 0),
(6577,'MAMMARY DUCTOGRAM OR GALACTOGRAM SINGLE','MAMMARY DUCTOGRAM OR GALACTOGRAM SINGLE','77053','1','','1','0','','','',0, 1, 0, 0),
(6578,'MAMMARY DUCTOGRAM OR GALACTOGRAM MULTIPLE','MAMMARY DUCTOGRAM OR GALACTOGRAM MULTIPLE','77054','1','','1','0','','','',0, 1, 0, 0),
(6579,'MAMMOGRAPHY UNILATERAL','MAMMOGRAPHY UNILATERAL','77055','1','','1','0','','','',0, 1, 0, 0),
(6580,'MAMMOGRAPHY BILATERAL','MAMMOGRAPHY BILATERAL','77056','1','','1','0','','','',0, 1, 0, 0),
(6581,'SCREENING MAMMOGRAPHY BILATERAL','SCREENING MAMMOGRAPHY BILATERAL','77057','1','','1','0','','','',0, 1, 0, 0),
(6582,'MRI BREAST UNILATERAL','MRI BREAST UNILATERAL','77058','1','','1','0','','','',0, 1, 0, 0),
(6583,'MRI BREAST BILATERAL','MRI BREAST BILATERAL','77059','1','','1','0','','','',0, 1, 0, 0),
(6584,'DIGITAL BREAST TOMOSYNTHESIS UNILATERAL','DIGITAL BREAST TOMOSYNTHESIS UNILATERAL','77061','1','','1','0','','','',0, 1, 0, 0),
(6585,'DIGITAL BREAST TOMOSYNTHESIS BILATERAL','DIGITAL BREAST TOMOSYNTHESIS BILATERAL','77062','1','','1','0','','','',0, 1, 0, 0),
(6586,'SCREENING DIGITAL BREAST TOMOSYNTHESIS BI','SCREENING DIGITAL BREAST TOMOSYNTHESIS BI','77063','1','','1','0','','','',0, 1, 0, 0),
(6587,'MANUAL APPL STRESS PFRMD PHYS/QHP JOINT FILMS','MANUAL APPL STRESS PFRMD PHYS/QHP JOINT FILMS','77071','1','','1','0','','','',0, 1, 0, 0),
(6588,'BONE AGE STUDIES','BONE AGE STUDIES','77072','1','','1','0','','','',0, 1, 0, 0),
(6589,'BONE LENGTH STUDIES','BONE LENGTH STUDIES','77073','1','','1','0','','','',0, 1, 0, 0),
(6590,'RADIOLOGIC EXAMINATION OSSEOUS SURVEY LIMITED','RADIOLOGIC EXAMINATION OSSEOUS SURVEY LIMITED','77074','1','','1','0','','','',0, 1, 0, 0),
(6591,'RADIOLOGIC EXAMINATION OSSEOUS SURVEY COMPL','RADIOLOGIC EXAMINATION OSSEOUS SURVEY COMPL','77075','1','','1','0','','','',0, 1, 0, 0),
(6592,'RADIOLOGIC EXAMINATION OSSEOUS SURVEY INFANT','RADIOLOGIC EXAMINATION OSSEOUS SURVEY INFANT','77076','1','','1','0','','','',0, 1, 0, 0),
(6593,'JOINT SURVEY SINGLE VIEW 2 OR MORE JOINTS','JOINT SURVEY SINGLE VIEW 2 OR MORE JOINTS','77077','1','','1','0','','','',0, 1, 0, 0),
(6594,'CT BONE MINERL DENSITY STUDY 1/> SITS AXIAL SKE','CT BONE MINERL DENSITY STUDY 1/> SITS AXIAL SKE','77078','1','','1','0','','','',0, 1, 0, 0),
(6595,'DXA BONE DENSITY STUDY 1/> SITES AXIAL SKEL','DXA BONE DENSITY STUDY 1/> SITES AXIAL SKEL','77080','1','','1','0','','','',0, 1, 0, 0),
(6596,'DXA BONE DENSITY STUDY 1/>SITES APPENDICLR SKEL','DXA BONE DENSITY STUDY 1/>SITES APPENDICLR SKEL','77081','1','','1','0','','','',0, 1, 0, 0),
(6597,'BONE MARROW BLOOD SUPPLY','BONE MARROW BLOOD SUPPLY','77084','1','','1','0','','','',0, 1, 0, 0),
(6598,'DXA BONE DENSITY STUDY AXIAL SKELETON','DXA BONE DENSITY STUDY AXIAL SKELETON','77085','1','','1','0','','','',0, 1, 0, 0),
(6599,'VERTEBRAL FRACTURE ASSESSMENT VIA DXA','VERTEBRAL FRACTURE ASSESSMENT VIA DXA','77086','1','','1','0','','','',0, 1, 0, 0),
(6600,'THERAPEUTIC RADIOLOGY TX PLANNING SIMPLE','THERAPEUTIC RADIOLOGY TX PLANNING SIMPLE','77261','1','','1','0','','','',0, 1, 0, 0),
(6601,'THERAPEUTIC RADIOLOGY TX PLANNING INTERMEDIATE','THERAPEUTIC RADIOLOGY TX PLANNING INTERMEDIATE','77262','1','','1','0','','','',0, 1, 0, 0),
(6602,'THERAPEUTIC RADIOLOGY TX PLANNING COMPLEX','THERAPEUTIC RADIOLOGY TX PLANNING COMPLEX','77263','1','','1','0','','','',0, 1, 0, 0),
(6603,'THER RAD SIMULAJ-AIDED FIELD SETTING SIMPLE','THER RAD SIMULAJ-AIDED FIELD SETTING SIMPLE','77280','1','','1','0','','','',0, 1, 0, 0),
(6604,'THER RAD SIMULAJ-AIDED FIELD SETTING INTERMED','THER RAD SIMULAJ-AIDED FIELD SETTING INTERMED','77285','1','','1','0','','','',0, 1, 0, 0),
(6605,'THER RAD SIMULAJ-AIDED FIELD SETTING COMPLEX','THER RAD SIMULAJ-AIDED FIELD SETTING COMPLEX','77290','1','','1','0','','','',0, 1, 0, 0),
(6606,'RESPIRATORY MOTION MANAGEMENT SIMULATION','RESPIRATORY MOTION MANAGEMENT SIMULATION','77293','1','','1','0','','','',0, 1, 0, 0),
(6607,'3-D RADIOTHERAPY PLAN DOSE-VOLUME HISTOGRAMS','3-D RADIOTHERAPY PLAN DOSE-VOLUME HISTOGRAMS','77295','1','','1','0','','','',0, 1, 0, 0),
(6608,'UNLIS PX THER RADIOL CLINICAL TX PLANNING','UNLIS PX THER RADIOL CLINICAL TX PLANNING','77299','1','','1','0','','','',0, 1, 0, 0),
(6609,'BASIC RADIATION DOSIMETRY CALCULATION','BASIC RADIATION DOSIMETRY CALCULATION','77300','1','','1','0','','','',0, 1, 0, 0),
(6610,'NTSTY MODUL RADTHX PLN DOSE-VOL HISTOS','NTSTY MODUL RADTHX PLN DOSE-VOL HISTOS','77301','1','','1','0','','','',0, 1, 0, 0),
(6611,'TELETHX ISODOSE PLN SMPL W/DOSIMETRY CALCULATION','TELETHX ISODOSE PLN SMPL W/DOSIMETRY CALCULATION','77306','1','','1','0','','','',0, 1, 0, 0),
(6612,'TELETHX ISODOSE PLN CPLX W/BASIC DOSIMETRY','TELETHX ISODOSE PLN CPLX W/BASIC DOSIMETRY','77307','1','','1','0','','','',0, 1, 0, 0),
(6613,'BRACHYTX ISODOSE PLN SMPL W/DOSIMETRY CAL','BRACHYTX ISODOSE PLN SMPL W/DOSIMETRY CAL','77316','1','','1','0','','','',0, 1, 0, 0),
(6614,'BRACHYTX ISODOSE PLN INTERMED W/DOSIMETRY CAL','BRACHYTX ISODOSE PLN INTERMED W/DOSIMETRY CAL','77317','1','','1','0','','','',0, 1, 0, 0),
(6615,'BRACHYTX ISODOSE PLN CPLX W/DOSIMETRY CAL','BRACHYTX ISODOSE PLN CPLX W/DOSIMETRY CAL','77318','1','','1','0','','','',0, 1, 0, 0),
(6616,'SPEC TELETHX PORT PLN PARTS HEMIBDY TOT BDY','SPEC TELETHX PORT PLN PARTS HEMIBDY TOT BDY','77321','1','','1','0','','','',0, 1, 0, 0),
(6617,'SPEC DOSIM ONLY PRESCRIBED TREATING PHYS','SPEC DOSIM ONLY PRESCRIBED TREATING PHYS','77331','1','','1','0','','','',0, 1, 0, 0),
(6618,'TX DEVICES DESIGN & CONSTRUCTION SIMPLE','TX DEVICES DESIGN & CONSTRUCTION SIMPLE','77332','1','','1','0','','','',0, 1, 0, 0),
(6619,'TX DEVICES DESIGN & CONSTRUCTION INTERMEDIATE','TX DEVICES DESIGN & CONSTRUCTION INTERMEDIATE','77333','1','','1','0','','','',0, 1, 0, 0),
(6620,'TX DEVICES DESIGN & CONSTRUCTION COMPLEX','TX DEVICES DESIGN & CONSTRUCTION COMPLEX','77334','1','','1','0','','','',0, 1, 0, 0),
(6621,'CONTINUING MEDICAL PHYSICS CONSLTJ PR WK','CONTINUING MEDICAL PHYSICS CONSLTJ PR WK','77336','1','','1','0','','','',0, 1, 0, 0),
(6622,'MLC IMRT DESIGN & CONSTRUCTION PER IMRT PLAN','MLC IMRT DESIGN & CONSTRUCTION PER IMRT PLAN','77338','1','','1','0','','','',0, 1, 0, 0),
(6623,'SPEC MEDICAL RADJ PHYSICS CONSLTJ','SPEC MEDICAL RADJ PHYSICS CONSLTJ','77370','1','','1','0','','','',0, 1, 0, 0),
(6624,'RADIATION DELIVERY STEREOTACTIC CRANIAL COBALT','RADIATION DELIVERY STEREOTACTIC CRANIAL COBALT','77371','1','','1','0','','','',0, 1, 0, 0),
(6625,'RADIATION DELIVERY STEREOTACTIC CRANIAL LINEAR','RADIATION DELIVERY STEREOTACTIC CRANIAL LINEAR','77372','1','','1','0','','','',0, 1, 0, 0),
(6626,'STEREOTACTIC BODY RADIATION DELIVERY','STEREOTACTIC BODY RADIATION DELIVERY','77373','1','','1','0','','','',0, 1, 0, 0),
(6627,'INTENSITY MODULATED RADIATION TX DLVR SIMPLE','INTENSITY MODULATED RADIATION TX DLVR SIMPLE','77385','1','','1','0','','','',0, 1, 0, 0),
(6628,'INTENSITY MODULATED RADIATION TX DLVR COMPLEX','INTENSITY MODULATED RADIATION TX DLVR COMPLEX','77386','1','','1','0','','','',0, 1, 0, 0),
(6629,'GUIDANCE FOR LOC OF TARGET VOL RADIAJ TX DLVR','GUIDANCE FOR LOC OF TARGET VOL RADIAJ TX DLVR','77387','1','','1','0','','','',0, 1, 0, 0),
(6630,'UNLIS MEDICAL RADJ DOSIM TX DEV SPEC SVCS','UNLIS MEDICAL RADJ DOSIM TX DEV SPEC SVCS','77399','1','','1','0','','','',0, 1, 0, 0),
(6631,'RADIATION TX DELIVERY SUPERFICIAL&/ORTHO VOLTA','RADIATION TX DELIVERY SUPERFICIAL&/ORTHO VOLTA','77401','1','','1','0','','','',0, 1, 0, 0),
(6632,'RADIATION TREATMENT DELIVERY 1 MEV >= SIMPLE','RADIATION TREATMENT DELIVERY 1 MEV >= SIMPLE','77402','1','','1','0','','','',0, 1, 0, 0),
(6633,'RADIATION TX DELIVERY 1 MEV >= INTERMEDIATE','RADIATION TX DELIVERY 1 MEV >= INTERMEDIATE','77407','1','','1','0','','','',0, 1, 0, 0),
(6634,'RADIATION TREATMENT DELIVERY 1 MEV >= COMPLEX','RADIATION TREATMENT DELIVERY 1 MEV >= COMPLEX','77412','1','','1','0','','','',0, 1, 0, 0),
(6635,'THERAPEUTIC RADIOLOGY PORT IMAGES(S)','THERAPEUTIC RADIOLOGY PORT IMAGES(S)','77417','1','','1','0','','','',0, 1, 0, 0),
(6636,'HIGH ENERGY NEUTRON RADJ TX DLVR 1 TX AREA','HIGH ENERGY NEUTRON RADJ TX DLVR 1 TX AREA','77422','1','','1','0','','','',0, 1, 0, 0),
(6637,'HIGH ENERGY NEUTRON RADJ TX DLVR 1/> ISOCENTER','HIGH ENERGY NEUTRON RADJ TX DLVR 1/> ISOCENTER','77423','1','','1','0','','','',0, 1, 0, 0),
(6638,'INTRAOP RADIAJ TX DELIVER XRAY SINGLE TX SESSION','INTRAOP RADIAJ TX DELIVER XRAY SINGLE TX SESSION','77424','1','','1','0','','','',0, 1, 0, 0),
(6639,'INTRAOP RADIAJ TX DELIVER ELECTRONS SNGL TX SESS','INTRAOP RADIAJ TX DELIVER ELECTRONS SNGL TX SESS','77425','1','','1','0','','','',0, 1, 0, 0),
(6640,'RADIATION TREATMENT MANAGEMENT 5 TREATMENTS','RADIATION TREATMENT MANAGEMENT 5 TREATMENTS','77427','1','','1','0','','','',0, 1, 0, 0),
(6641,'RADIATION THERAPY MGMT 1/2 FRACTIONS ONLY','RADIATION THERAPY MGMT 1/2 FRACTIONS ONLY','77431','1','','1','0','','','',0, 1, 0, 0),
(6642,'STERETCTC RADIATION TX MANAGEMENT CRANIAL LESION','STERETCTC RADIATION TX MANAGEMENT CRANIAL LESION','77432','1','','1','0','','','',0, 1, 0, 0),
(6643,'STEREOTACTIC BODY RADIATION MANAGEMENT','STEREOTACTIC BODY RADIATION MANAGEMENT','77435','1','','1','0','','','',0, 1, 0, 0),
(6644,'INTRAOPERATIVE RADIATION TREATMENT MANAGEMENT','INTRAOPERATIVE RADIATION TREATMENT MANAGEMENT','77469','1','','1','0','','','',0, 1, 0, 0),
(6645,'SPECIAL TREATMENT PROCEDURE','SPECIAL TREATMENT PROCEDURE','77470','1','','1','0','','','',0, 1, 0, 0),
(6646,'UNLISTED PROCEDURE THERAPEUTIC RADIOLOGY TX MGMT','UNLISTED PROCEDURE THERAPEUTIC RADIOLOGY TX MGMT','77499','1','','1','0','','','',0, 1, 0, 0),
(6647,'PROTON TX DELIVERY SIMPLE W/O COMPENSATION','PROTON TX DELIVERY SIMPLE W/O COMPENSATION','77520','1','','1','0','','','',0, 1, 0, 0),
(6648,'PROTON TX DELIVERY SIMPLE W/COMPENSATION','PROTON TX DELIVERY SIMPLE W/COMPENSATION','77522','1','','1','0','','','',0, 1, 0, 0),
(6649,'PROTON TX DELIVERY INTERMEDIATE','PROTON TX DELIVERY INTERMEDIATE','77523','1','','1','0','','','',0, 1, 0, 0),
(6650,'PROTON TX DELIVERY COMPLEX','PROTON TX DELIVERY COMPLEX','77525','1','','1','0','','','',0, 1, 0, 0),
(6651,'HYPERTHERMIA EXTERNAL GENERATED SUPERFICIAL','HYPERTHERMIA EXTERNAL GENERATED SUPERFICIAL','77600','1','','1','0','','','',0, 1, 0, 0),
(6652,'HYPERTHERMIA EXTERNAL GENERATED DEEP','HYPERTHERMIA EXTERNAL GENERATED DEEP','77605','1','','1','0','','','',0, 1, 0, 0),
(6653,'HYPERTHERMIA INTERSTITIAL PROBE 5/< APPLICATORS','HYPERTHERMIA INTERSTITIAL PROBE 5/< APPLICATORS','77610','1','','1','0','','','',0, 1, 0, 0),
(6654,'HYPERTHERMIA INTERSTIAL PROBE 5/> APPLICATORS','HYPERTHERMIA INTERSTIAL PROBE 5/> APPLICATORS','77615','1','','1','0','','','',0, 1, 0, 0),
(6655,'HYPERTHERMIA INTRACAVITARY PROBES','HYPERTHERMIA INTRACAVITARY PROBES','77620','1','','1','0','','','',0, 1, 0, 0),
(6656,'NFS/INSTLJ RADIOELMNT SLN 3 MO FOLLOW-UP CARE','NFS/INSTLJ RADIOELMNT SLN 3 MO FOLLOW-UP CARE','77750','1','','1','0','','','',0, 1, 0, 0),
(6657,'INTRACAVITARY RADIATION SOURCE APPLIC SIMPLE','INTRACAVITARY RADIATION SOURCE APPLIC SIMPLE','77761','1','','1','0','','','',0, 1, 0, 0),
(6658,'INTRACAVITARY RADIATION SOURCE APPLIC INTERMED','INTRACAVITARY RADIATION SOURCE APPLIC INTERMED','77762','1','','1','0','','','',0, 1, 0, 0),
(6659,'INTRACAVITARY RADIATION SOURCE APPLIC COMPLEX','INTRACAVITARY RADIATION SOURCE APPLIC COMPLEX','77763','1','','1','0','','','',0, 1, 0, 0),
(6660,'HDR RDNCL SKN SURF BRACHYTX LES </2CM/1 CHAN','HDR RDNCL SKN SURF BRACHYTX LES </2CM/1 CHAN','77767','1','','1','0','','','',0, 1, 0, 0),
(6661,'HDR RDNCL SK SRF BRCHYTX LES >2CM&2CHAN/MLT LES','HDR RDNCL SK SRF BRCHYTX LES >2CM&2CHAN/MLT LES','77768','1','','1','0','','','',0, 1, 0, 0),
(6662,'HDR RDNCL NTRSTL/INTRCAV BRACHYTX 1 CHANNEL','HDR RDNCL NTRSTL/INTRCAV BRACHYTX 1 CHANNEL','77770','1','','1','0','','','',0, 1, 0, 0),
(6663,'HDR RDNCL NTRSTL/INTRCAV BRACHYTX 2-12 CHANNEL','HDR RDNCL NTRSTL/INTRCAV BRACHYTX 2-12 CHANNEL','77771','1','','1','0','','','',0, 1, 0, 0),
(6664,'HDR RDNCL NTRSTL/INTRCAV BRACHYTX >12 CHANNELS','HDR RDNCL NTRSTL/INTRCAV BRACHYTX >12 CHANNELS','77772','1','','1','0','','','',0, 1, 0, 0),
(6665,'INTERSTITIAL RADIATION SOURCE APPLIC COMPLEX','INTERSTITIAL RADIATION SOURCE APPLIC COMPLEX','77778','1','','1','0','','','',0, 1, 0, 0),
(6666,'SURFACE APPLIC LOW DOSE RATE RADIONUCLIDE SOURCE','SURFACE APPLIC LOW DOSE RATE RADIONUCLIDE SOURCE','77789','1','','1','0','','','',0, 1, 0, 0),
(6667,'SUPERVISION HANDLING LOADING RADIATION SOURCE','SUPERVISION HANDLING LOADING RADIATION SOURCE','77790','1','','1','0','','','',0, 1, 0, 0),
(6668,'UNLISTED PROCEDURE CLINICAL BRACHYTHERAPY','UNLISTED PROCEDURE CLINICAL BRACHYTHERAPY','77799','1','','1','0','','','',0, 1, 0, 0),
(6669,'THYROID UPTAKE SINGLE/MULTIPLE QUANT MEASUREMENT','THYROID UPTAKE SINGLE/MULTIPLE QUANT MEASUREMENT','78012','1','','1','0','','','',0, 1, 0, 0),
(6670,'THYROID IMAGING WITH VASCULAR FLOW','THYROID IMAGING WITH VASCULAR FLOW','78013','1','','1','0','','','',0, 1, 0, 0),
(6671,'THYROID UPTAKE W/BLOOD FLOW SNGLE/MULT QUAN MEAS','THYROID UPTAKE W/BLOOD FLOW SNGLE/MULT QUAN MEAS','78014','1','','1','0','','','',0, 1, 0, 0),
(6672,'THYROID CARCINOMA METASTASES IMG LMTD AREA','THYROID CARCINOMA METASTASES IMG LMTD AREA','78015','1','','1','0','','','',0, 1, 0, 0),
(6673,'THYROID CARCINOMA METASTASES IMG ADDL STUDY','THYROID CARCINOMA METASTASES IMG ADDL STUDY','78016','1','','1','0','','','',0, 1, 0, 0),
(6674,'THYROID CARCINOMA METASTASES IMG WHOLE BODY','THYROID CARCINOMA METASTASES IMG WHOLE BODY','78018','1','','1','0','','','',0, 1, 0, 0),
(6675,'THYROID CARCINOMA METASTASES UPTAKE','THYROID CARCINOMA METASTASES UPTAKE','78020','1','','1','0','','','',0, 1, 0, 0),
(6676,'PARATHYROID PLANAR IMAGING','PARATHYROID PLANAR IMAGING','78070','1','','1','0','','','',0, 1, 0, 0),
(6677,'PARATHYROID PLANAR IMAGING W/WO SUBTRACTION','PARATHYROID PLANAR IMAGING W/WO SUBTRACTION','78071','1','','1','0','','','',0, 1, 0, 0),
(6678,'PARATHYROID IMAGING W/TOMOGRAPHIC SPECT & CT','PARATHYROID IMAGING W/TOMOGRAPHIC SPECT & CT','78072','1','','1','0','','','',0, 1, 0, 0),
(6679,'ADRENAL IMAGING CORTEX &/MEDULLA','ADRENAL IMAGING CORTEX &/MEDULLA','78075','1','','1','0','','','',0, 1, 0, 0),
(6680,'UNLISTED ENDOCRINE PX DX NUCLEAR MEDICINE','UNLISTED ENDOCRINE PX DX NUCLEAR MEDICINE','78099','1','','1','0','','','',0, 1, 0, 0),
(6681,'BONE MARROW IMAGING LIMITED AREA','BONE MARROW IMAGING LIMITED AREA','78102','1','','1','0','','','',0, 1, 0, 0),
(6682,'BONE MARROW IMAGING MULTIPLE AREAS','BONE MARROW IMAGING MULTIPLE AREAS','78103','1','','1','0','','','',0, 1, 0, 0),
(6683,'BONE MARROW IMAGING WHOLE BODY','BONE MARROW IMAGING WHOLE BODY','78104','1','','1','0','','','',0, 1, 0, 0),
(6684,'PLASMA VOL RADIOPHARM VOL DILUTION SPX 1 SAMPLE','PLASMA VOL RADIOPHARM VOL DILUTION SPX 1 SAMPLE','78110','1','','1','0','','','',0, 1, 0, 0),
(6685,'PLASMA VOL RADIOPHARM VOL DILUTE SPX MULT SMPLES','PLASMA VOL RADIOPHARM VOL DILUTE SPX MULT SMPLES','78111','1','','1','0','','','',0, 1, 0, 0),
(6686,'RED CELL VOLUME DETERMINATION SPX 1 SAMPLING','RED CELL VOLUME DETERMINATION SPX 1 SAMPLING','78120','1','','1','0','','','',0, 1, 0, 0),
(6687,'RED CELL VOLUME DETERMINATION SPX MULT SAMPLINGS','RED CELL VOLUME DETERMINATION SPX MULT SAMPLINGS','78121','1','','1','0','','','',0, 1, 0, 0),
(6688,'WHOLE BLOOD VOLUME DETERM PLASMA&RED CELL VOLU','WHOLE BLOOD VOLUME DETERM PLASMA&RED CELL VOLU','78122','1','','1','0','','','',0, 1, 0, 0),
(6689,'RED CELL SURVIVAL STUDY','RED CELL SURVIVAL STUDY','78130','1','','1','0','','','',0, 1, 0, 0),
(6690,'RBC SURVIVAL STUDY DIFFERNTL ORGAN/TISS KINETICS','RBC SURVIVAL STUDY DIFFERNTL ORGAN/TISS KINETICS','78135','1','','1','0','','','',0, 1, 0, 0),
(6691,'LABELED RBC SEQUESTRATION DIFFERNTL ORGAN/TISSUE','LABELED RBC SEQUESTRATION DIFFERNTL ORGAN/TISSUE','78140','1','','1','0','','','',0, 1, 0, 0),
(6692,'SPLEEN IMAGING ONLY W/WO VASCULAR FLOW','SPLEEN IMAGING ONLY W/WO VASCULAR FLOW','78185','1','','1','0','','','',0, 1, 0, 0),
(6693,'KINETICS PLATELET W/WO DIFFRNTL ORGAN/TIS LOCLZJ','KINETICS PLATELET W/WO DIFFRNTL ORGAN/TIS LOCLZJ','78190','1','','1','0','','','',0, 1, 0, 0),
(6694,'PLATELET SURVIVAL STUDY','PLATELET SURVIVAL STUDY','78191','1','','1','0','','','',0, 1, 0, 0),
(6695,'LYMPHATICS & LYMPH NODES IMAGING','LYMPHATICS & LYMPH NODES IMAGING','78195','1','','1','0','','','',0, 1, 0, 0),
(6696,'UNLIS HEMATOP RET/ENDO&LYMPHATIC DX NUC MED','UNLIS HEMATOP RET/ENDO&LYMPHATIC DX NUC MED','78199','1','','1','0','','','',0, 1, 0, 0),
(6697,'LIVER IMAGING STATIC ONLY','LIVER IMAGING STATIC ONLY','78201','1','','1','0','','','',0, 1, 0, 0),
(6698,'LIVER IMAGING W/VASCULAR FLOW','LIVER IMAGING W/VASCULAR FLOW','78202','1','','1','0','','','',0, 1, 0, 0),
(6699,'LIVER IMAGING SPECT','LIVER IMAGING SPECT','78205','1','','1','0','','','',0, 1, 0, 0),
(6700,'LIVER IMAGING SPECT W/VASCULAR FLOW','LIVER IMAGING SPECT W/VASCULAR FLOW','78206','1','','1','0','','','',0, 1, 0, 0),
(6701,'LIVER & SPLEEN IMAGING STATIC ONLY','LIVER & SPLEEN IMAGING STATIC ONLY','78215','1','','1','0','','','',0, 1, 0, 0),
(6702,'LIVER & SPLEEN IMAGING W/VASCULAR FLOW','LIVER & SPLEEN IMAGING W/VASCULAR FLOW','78216','1','','1','0','','','',0, 1, 0, 0),
(6703,'HEPATOBILIARY SYST IMAGING INCLUDING GALLBLADDER','HEPATOBILIARY SYST IMAGING INCLUDING GALLBLADDER','78226','1','','1','0','','','',0, 1, 0, 0),
(6704,'HEPATOBIL SYST IMAG INC GB W/PHARMA INTERVENJ','HEPATOBIL SYST IMAG INC GB W/PHARMA INTERVENJ','78227','1','','1','0','','','',0, 1, 0, 0),
(6705,'SALIVARY GLAND IMAGING','SALIVARY GLAND IMAGING','78230','1','','1','0','','','',0, 1, 0, 0),
(6706,'SALIVARY GLAND IMAGING SERIAL IMAGES','SALIVARY GLAND IMAGING SERIAL IMAGES','78231','1','','1','0','','','',0, 1, 0, 0),
(6707,'SALIVARY GLAND FUNCTION STUDY','SALIVARY GLAND FUNCTION STUDY','78232','1','','1','0','','','',0, 1, 0, 0),
(6708,'ESOPHAGEAL MOTILITY','ESOPHAGEAL MOTILITY','78258','1','','1','0','','','',0, 1, 0, 0),
(6709,'GASTRIC MUCOSA IMAGING','GASTRIC MUCOSA IMAGING','78261','1','','1','0','','','',0, 1, 0, 0),
(6710,'GASTROESOPHAGEAL REFLUX STUDY','GASTROESOPHAGEAL REFLUX STUDY','78262','1','','1','0','','','',0, 1, 0, 0),
(6711,'GASTRIC EMPTYING IMAGING STUDY','GASTRIC EMPTYING IMAGING STUDY','78264','1','','1','0','','','',0, 1, 0, 0),
(6712,'GASTRIC EMPTYNG IMAG STD W/SM BWL TRANSIT','GASTRIC EMPTYNG IMAG STD W/SM BWL TRANSIT','78265','1','','1','0','','','',0, 1, 0, 0),
(6713,'GSTRC EMPTNG IMAG STD W/SM BWL COL TRNST MLT DAY','GSTRC EMPTNG IMAG STD W/SM BWL COL TRNST MLT DAY','78266','1','','1','0','','','',0, 1, 0, 0),
(6714,'UREA BREATH TEST C-14 ISOTOPIC ACQUISJ ANALYSIS','UREA BREATH TEST C-14 ISOTOPIC ACQUISJ ANALYSIS','78267','1','','1','0','','','',0, 1, 0, 0),
(6715,'UREA BREATH TEST C-14 ISOTOPIC ANALYSIS','UREA BREATH TEST C-14 ISOTOPIC ANALYSIS','78268','1','','1','0','','','',0, 1, 0, 0),
(6716,'VITAMIN B-12 ABSRPJ STUDY W/O INTRINSIC FACTOR','VITAMIN B-12 ABSRPJ STUDY W/O INTRINSIC FACTOR','78270','1','','1','0','','','',0, 1, 0, 0),
(6717,'VITAMIN B-12 ABSRPJ STUDY W/INTRINSIC FACTOR','VITAMIN B-12 ABSRPJ STUDY W/INTRINSIC FACTOR','78271','1','','1','0','','','',0, 1, 0, 0),
(6718,'VITAMIN B-12 ABSRPJ STDY W/WO INTRINSIC FACT','VITAMIN B-12 ABSRPJ STDY W/WO INTRINSIC FACT','78272','1','','1','0','','','',0, 1, 0, 0),
(6719,'ACUTE GASTROINTESTINAL BLOOD LOSS IMAGING','ACUTE GASTROINTESTINAL BLOOD LOSS IMAGING','78278','1','','1','0','','','',0, 1, 0, 0),
(6720,'GASTROINTESTINAL PROTEIN LOSS','GASTROINTESTINAL PROTEIN LOSS','78282','1','','1','0','','','',0, 1, 0, 0),
(6721,'INTESTINE IMAGING','INTESTINE IMAGING','78290','1','','1','0','','','',0, 1, 0, 0),
(6722,'PERITONEAL-VENOUS SHUNT PATENCY TEST','PERITONEAL-VENOUS SHUNT PATENCY TEST','78291','1','','1','0','','','',0, 1, 0, 0),
(6723,'UNLISTED GASTROINTESTINAL PX DX NUCLEAR MEDICINE','UNLISTED GASTROINTESTINAL PX DX NUCLEAR MEDICINE','78299','1','','1','0','','','',0, 1, 0, 0),
(6724,'BONE &/JOINT IMAGING LIMITED AREA','BONE &/JOINT IMAGING LIMITED AREA','78300','1','','1','0','','','',0, 1, 0, 0),
(6725,'BONE &/JOINT IMAGING MULTIPLE AREAS','BONE &/JOINT IMAGING MULTIPLE AREAS','78305','1','','1','0','','','',0, 1, 0, 0),
(6726,'BONE &/JOINT IMAGING WHOLE BODY','BONE &/JOINT IMAGING WHOLE BODY','78306','1','','1','0','','','',0, 1, 0, 0),
(6727,'BONE &/JOINT IMAGING 3 PHASE STUDY','BONE &/JOINT IMAGING 3 PHASE STUDY','78315','1','','1','0','','','',0, 1, 0, 0),
(6728,'BONE &/JOINT IMAGING TOMOGRAPHIC SPECT','BONE &/JOINT IMAGING TOMOGRAPHIC SPECT','78320','1','','1','0','','','',0, 1, 0, 0),
(6729,'BONE DENSITY 1/> SITES 1 PHOTON ABSORPTIOMETRY','BONE DENSITY 1/> SITES 1 PHOTON ABSORPTIOMETRY','78350','1','','1','0','','','',0, 1, 0, 0),
(6730,'BONE DENSTY 1/> SITES DUAL PHOTON ABSORPTIOMETR','BONE DENSTY 1/> SITES DUAL PHOTON ABSORPTIOMETR','78351','1','','1','0','','','',0, 1, 0, 0),
(6731,'UNLISTED MUSCULOSKELETAL PX DX NUCLEAR MEDICINE','UNLISTED MUSCULOSKELETAL PX DX NUCLEAR MEDICINE','78399','1','','1','0','','','',0, 1, 0, 0),
(6732,'CARD-VASC HEMODYNAM W/WO PHARM/EXER 1/MLT DETERM','CARD-VASC HEMODYNAM W/WO PHARM/EXER 1/MLT DETERM','78414','1','','1','0','','','',0, 1, 0, 0),
(6733,'CARDIAC SHUNT DETECTION','CARDIAC SHUNT DETECTION','78428','1','','1','0','','','',0, 1, 0, 0),
(6734,'NONCARDIAC VASCULAR FLOW IMAGING','NONCARDIAC VASCULAR FLOW IMAGING','78445','1','','1','0','','','',0, 1, 0, 0),
(6735,'MYOCARDIAL SPECT SINGLE STUDY AT REST OR STRESS','MYOCARDIAL SPECT SINGLE STUDY AT REST OR STRESS','78451','1','','1','0','','','',0, 1, 0, 0),
(6736,'MYOCARDIAL SPECT MULTIPLE STUDIES','MYOCARDIAL SPECT MULTIPLE STUDIES','78452','1','','1','0','','','',0, 1, 0, 0),
(6737,'MYOCARDIAL PERFUSION PLANAR 1 STUDY REST/STRESS','MYOCARDIAL PERFUSION PLANAR 1 STUDY REST/STRESS','78453','1','','1','0','','','',0, 1, 0, 0),
(6738,'MYOCARDIAL PERFUSION PLANAR MULTIPLE STUDIES','MYOCARDIAL PERFUSION PLANAR MULTIPLE STUDIES','78454','1','','1','0','','','',0, 1, 0, 0),
(6739,'ACUTE VENOUS THROMBOSIS IMAGING PEPTIDE','ACUTE VENOUS THROMBOSIS IMAGING PEPTIDE','78456','1','','1','0','','','',0, 1, 0, 0),
(6740,'VENOUS THROMBOSIS IMAGING VENOGRAM UNILATERAL','VENOUS THROMBOSIS IMAGING VENOGRAM UNILATERAL','78457','1','','1','0','','','',0, 1, 0, 0),
(6741,'VENOUS THROMBOSIS IMAGING VENOGRAM BILATERAL','VENOUS THROMBOSIS IMAGING VENOGRAM BILATERAL','78458','1','','1','0','','','',0, 1, 0, 0),
(6742,'MYOCARDIAL IMAGING PET METABOLIC EVALUATION','MYOCARDIAL IMAGING PET METABOLIC EVALUATION','78459','1','','1','0','','','',0, 1, 0, 0),
(6743,'MYOCARDIAL IMAGING INFARCT AVID PLANAR QUAL/QUAN','MYOCARDIAL IMAGING INFARCT AVID PLANAR QUAL/QUAN','78466','1','','1','0','','','',0, 1, 0, 0),
(6744,'MYOCRD IMG INFARCT AVID PLNR EJEC FXJ 1ST PS TQ','MYOCRD IMG INFARCT AVID PLNR EJEC FXJ 1ST PS TQ','78468','1','','1','0','','','',0, 1, 0, 0),
(6745,'MYOCRD INFARCT AVID PLNR TOMOG SPECT W/WO QUANTJ','MYOCRD INFARCT AVID PLNR TOMOG SPECT W/WO QUANTJ','78469','1','','1','0','','','',0, 1, 0, 0),
(6746,'CARD BLOOD POOL GATED PLANAR 1 STUDY REST/STRESS','CARD BLOOD POOL GATED PLANAR 1 STUDY REST/STRESS','78472','1','','1','0','','','',0, 1, 0, 0),
(6747,'CARD BL POOL GATED MLT STDY WAL MOTN EJECT FRACT','CARD BL POOL GATED MLT STDY WAL MOTN EJECT FRACT','78473','1','','1','0','','','',0, 1, 0, 0),
(6748,'CARD BL POOL PLANAR 1 STDY WAL MOTN EJECT FRACT','CARD BL POOL PLANAR 1 STDY WAL MOTN EJECT FRACT','78481','1','','1','0','','','',0, 1, 0, 0),
(6749,'CARD BL POOL PLNR MLT STDY WAL MOTN EJECT FRACT','CARD BL POOL PLNR MLT STDY WAL MOTN EJECT FRACT','78483','1','','1','0','','','',0, 1, 0, 0),
(6750,'MYOCRD IMAGE PET PERFUS SINGLE STUDY REST/STRESS','MYOCRD IMAGE PET PERFUS SINGLE STUDY REST/STRESS','78491','1','','1','0','','','',0, 1, 0, 0),
(6751,'MYOCRD IMAGE PET PERFUS MULTPL STUDY REST/STRESS','MYOCRD IMAGE PET PERFUS MULTPL STUDY REST/STRESS','78492','1','','1','0','','','',0, 1, 0, 0),
(6752,'CARD BL POOL GATED SPECT REST WAL MOTN EJCT FRCT','CARD BL POOL GATED SPECT REST WAL MOTN EJCT FRCT','78494','1','','1','0','','','',0, 1, 0, 0),
(6753,'CARD BL POOL GATED 1 STDY REST RT VENT EJCT FRCT','CARD BL POOL GATED 1 STDY REST RT VENT EJCT FRCT','78496','1','','1','0','','','',0, 1, 0, 0),
(6754,'UNLISTED CARDIOVASCULAR PX DX NUCLEAR MEDICINE','UNLISTED CARDIOVASCULAR PX DX NUCLEAR MEDICINE','78499','1','','1','0','','','',0, 1, 0, 0),
(6755,'PULMONARY VENTILATION IMAGING','PULMONARY VENTILATION IMAGING','78579','1','','1','0','','','',0, 1, 0, 0),
(6756,'PULMONARY PERFUSION IMAGING PARTICULATE','PULMONARY PERFUSION IMAGING PARTICULATE','78580','1','','1','0','','','',0, 1, 0, 0),
(6757,'PULMONARY VENTILATION & PERFUSION IMAGING','PULMONARY VENTILATION & PERFUSION IMAGING','78582','1','','1','0','','','',0, 1, 0, 0),
(6758,'QUANT DIFFERENTIAL PULM PERFUSION W/WO IMAGING','QUANT DIFFERENTIAL PULM PERFUSION W/WO IMAGING','78597','1','','1','0','','','',0, 1, 0, 0),
(6759,'QUANT DIFF PULM PRFUSION & VENTLAJ W/WO IMAGIN','QUANT DIFF PULM PRFUSION & VENTLAJ W/WO IMAGIN','78598','1','','1','0','','','',0, 1, 0, 0),
(6760,'UNLISTED RESPIRATORY PX DX NUCLEAR MEDICINE','UNLISTED RESPIRATORY PX DX NUCLEAR MEDICINE','78599','1','','1','0','','','',0, 1, 0, 0),
(6761,'BRAIN IMAGING <4 STATIC VIEWS','BRAIN IMAGING <4 STATIC VIEWS','78600','1','','1','0','','','',0, 1, 0, 0),
(6762,'BRAIN IMAGING <4 STATIC VIEWS W/VASCULAR FLOW','BRAIN IMAGING <4 STATIC VIEWS W/VASCULAR FLOW','78601','1','','1','0','','','',0, 1, 0, 0),
(6763,'BRAIN IMAGING MINIMUM 4 STATIC VIEWS','BRAIN IMAGING MINIMUM 4 STATIC VIEWS','78605','1','','1','0','','','',0, 1, 0, 0),
(6764,'BRAIN IMAGING MIN 4 STATIC VIEWS W VASCULAR FLOW','BRAIN IMAGING MIN 4 STATIC VIEWS W VASCULAR FLOW','78606','1','','1','0','','','',0, 1, 0, 0),
(6765,'BRAIN IMAGING TOMOGRAPHIC SPECT','BRAIN IMAGING TOMOGRAPHIC SPECT','78607','1','','1','0','','','',0, 1, 0, 0),
(6766,'BRAIN IMAGING PET METABOLIC EVALUATION','BRAIN IMAGING PET METABOLIC EVALUATION','78608','1','','1','0','','','',0, 1, 0, 0),
(6767,'BRAIN IMAGING PET PERFUSION EVALUATION','BRAIN IMAGING PET PERFUSION EVALUATION','78609','1','','1','0','','','',0, 1, 0, 0),
(6768,'BRAIN IMAGING VASCULAR FLOW ONLY','BRAIN IMAGING VASCULAR FLOW ONLY','78610','1','','1','0','','','',0, 1, 0, 0),
(6769,'CEREBROSPINAL FLUID FLOW W/O MATL CISTERNOGRAPHY','CEREBROSPINAL FLUID FLOW W/O MATL CISTERNOGRAPHY','78630','1','','1','0','','','',0, 1, 0, 0),
(6770,'CEREBROSPINAL FLUID FLOW W/O MATL VENTRICLGRAPHY','CEREBROSPINAL FLUID FLOW W/O MATL VENTRICLGRAPHY','78635','1','','1','0','','','',0, 1, 0, 0),
(6771,'CEREBROSPINAL FLUID FLOW W/O MATL SHUNT EVALTJ','CEREBROSPINAL FLUID FLOW W/O MATL SHUNT EVALTJ','78645','1','','1','0','','','',0, 1, 0, 0),
(6772,'CEREBROSPINAL FLUID FLOW W/O MATL TOMOG SPECT','CEREBROSPINAL FLUID FLOW W/O MATL TOMOG SPECT','78647','1','','1','0','','','',0, 1, 0, 0),
(6773,'CEREBROSPINAL FLUID LEAK DETECTION&LOCALIZATIO','CEREBROSPINAL FLUID LEAK DETECTION&LOCALIZATIO','78650','1','','1','0','','','',0, 1, 0, 0),
(6774,'RADIOPHARMACEUTICAL DACRYOCYSTOGRAPHY','RADIOPHARMACEUTICAL DACRYOCYSTOGRAPHY','78660','1','','1','0','','','',0, 1, 0, 0),
(6775,'UNLISTED NERVOUS SYSTEM PX DX NUCLEAR MEDICINE','UNLISTED NERVOUS SYSTEM PX DX NUCLEAR MEDICINE','78699','1','','1','0','','','',0, 1, 0, 0),
(6776,'KIDNEY IMAGING MORPHOLOGY','KIDNEY IMAGING MORPHOLOGY','78700','1','','1','0','','','',0, 1, 0, 0),
(6777,'KIDNEY IMAGING MORPHOOGY W/VASCULAR FLOW','KIDNEY IMAGING MORPHOOGY W/VASCULAR FLOW','78701','1','','1','0','','','',0, 1, 0, 0),
(6778,'KIDNEY IMG MORPHOLOGY VASCULAR FLOW 1 W/O RX','KIDNEY IMG MORPHOLOGY VASCULAR FLOW 1 W/O RX','78707','1','','1','0','','','',0, 1, 0, 0),
(6779,'KIDNEY IMG MORPHOLOGY VASCULAR FLOW 1 W/RX','KIDNEY IMG MORPHOLOGY VASCULAR FLOW 1 W/RX','78708','1','','1','0','','','',0, 1, 0, 0),
(6780,'KIDNEY IMG MORPHOLOGY VASCULAR FLOW MULTIPLE','KIDNEY IMG MORPHOLOGY VASCULAR FLOW MULTIPLE','78709','1','','1','0','','','',0, 1, 0, 0),
(6781,'KIDNEY IMAGING MORPHOLOGY TOMOGRAPHIC','KIDNEY IMAGING MORPHOLOGY TOMOGRAPHIC','78710','1','','1','0','','','',0, 1, 0, 0),
(6782,'KIDNEY FUNCJ STUDY NON-IMG RADIOISOTOPIC STUDY','KIDNEY FUNCJ STUDY NON-IMG RADIOISOTOPIC STUDY','78725','1','','1','0','','','',0, 1, 0, 0),
(6783,'URINARY BLADDER RESIDUAL STUDY','URINARY BLADDER RESIDUAL STUDY','78730','1','','1','0','','','',0, 1, 0, 0),
(6784,'URETERAL REFLUX STUDY RP VOIDING CYSTOGRAM','URETERAL REFLUX STUDY RP VOIDING CYSTOGRAM','78740','1','','1','0','','','',0, 1, 0, 0),
(6785,'TESTICULAR IMAGING WITH VASCULAR FLOW','TESTICULAR IMAGING WITH VASCULAR FLOW','78761','1','','1','0','','','',0, 1, 0, 0),
(6786,'UNLISTED GENITOURINARY PX DX NUCLEAR MEDICINE','UNLISTED GENITOURINARY PX DX NUCLEAR MEDICINE','78799','1','','1','0','','','',0, 1, 0, 0),
(6787,'RP LOCLZJ TUMOR/DSTRBJ AGENT LIMITED AREA','RP LOCLZJ TUMOR/DSTRBJ AGENT LIMITED AREA','78800','1','','1','0','','','',0, 1, 0, 0),
(6788,'RP LOCLZJ TUMOR/DSTRBJ AGENT MULTIPLE AREAS','RP LOCLZJ TUMOR/DSTRBJ AGENT MULTIPLE AREAS','78801','1','','1','0','','','',0, 1, 0, 0),
(6789,'RP LOCLZJ TUMOR/DSTRBJ AGENT WHOLE BDY 1 DAY','RP LOCLZJ TUMOR/DSTRBJ AGENT WHOLE BDY 1 DAY','78802','1','','1','0','','','',0, 1, 0, 0),
(6790,'RP LOCLZJ TUMOR/DSTRBJ AGENT TOMOG SPECT','RP LOCLZJ TUMOR/DSTRBJ AGENT TOMOG SPECT','78803','1','','1','0','','','',0, 1, 0, 0),
(6791,'RP LOCLZJ TUMOR/DSTRBJ AGT WHOL BDY REQ 2/> DAY','RP LOCLZJ TUMOR/DSTRBJ AGT WHOL BDY REQ 2/> DAY','78804','1','','1','0','','','',0, 1, 0, 0),
(6792,'RP LOCLZJ INFLAMMATORY PROCESS LIMITED AREA','RP LOCLZJ INFLAMMATORY PROCESS LIMITED AREA','78805','1','','1','0','','','',0, 1, 0, 0),
(6793,'RP LOCLZJ INFLAMMATORY PROCESS WHOLE BODY','RP LOCLZJ INFLAMMATORY PROCESS WHOLE BODY','78806','1','','1','0','','','',0, 1, 0, 0),
(6794,'RP LOCLZJ INFLAMMATORY PROCESS TOMOG SPECT','RP LOCLZJ INFLAMMATORY PROCESS TOMOG SPECT','78807','1','','1','0','','','',0, 1, 0, 0),
(6795,'NJX RP LOCLZJ NON-IMG PROBE STUDY INTRAVENOUS','NJX RP LOCLZJ NON-IMG PROBE STUDY INTRAVENOUS','78808','1','','1','0','','','',0, 1, 0, 0),
(6796,'PET IMAGING LIMITED AREA CHEST HEAD/NECK','PET IMAGING LIMITED AREA CHEST HEAD/NECK','78811','1','','1','0','','','',0, 1, 0, 0),
(6797,'PET IMAGING SKULL BASE TO MID-THIGH','PET IMAGING SKULL BASE TO MID-THIGH','78812','1','','1','0','','','',0, 1, 0, 0),
(6798,'PET IMAGING WHOLE BODY','PET IMAGING WHOLE BODY','78813','1','','1','0','','','',0, 1, 0, 0),
(6799,'PET IMAGING CT FOR ATTENUATION LIMITED AREA','PET IMAGING CT FOR ATTENUATION LIMITED AREA','78814','1','','1','0','','','',0, 1, 0, 0),
(6800,'PET IMAGING CT ATTENUATION SKULL BASE MID-THIGH','PET IMAGING CT ATTENUATION SKULL BASE MID-THIGH','78815','1','','1','0','','','',0, 1, 0, 0),
(6801,'PET IMAGING FOR CT ATTENUATION WHOLE BODY','PET IMAGING FOR CT ATTENUATION WHOLE BODY','78816','1','','1','0','','','',0, 1, 0, 0),
(6802,'UNLISTED MISCELLANEOUS PX DX NUCLEAR MEDICINE','UNLISTED MISCELLANEOUS PX DX NUCLEAR MEDICINE','78999','1','','1','0','','','',0, 1, 0, 0),
(6803,'RP THERAPY ORAL ADMINISTRATION','RP THERAPY ORAL ADMINISTRATION','79005','1','','1','0','','','',0, 1, 0, 0),
(6804,'RP THERAPY INTRAVENOUS ADMINISTRATION','RP THERAPY INTRAVENOUS ADMINISTRATION','79101','1','','1','0','','','',0, 1, 0, 0),
(6805,'RP THERAPY INRACAVITARY ADMINISTRATION','RP THERAPY INRACAVITARY ADMINISTRATION','79200','1','','1','0','','','',0, 1, 0, 0),
(6806,'RP THERAPY INTERSTITIAL RADIOACTIVE COLLOID ADMN','RP THERAPY INTERSTITIAL RADIOACTIVE COLLOID ADMN','79300','1','','1','0','','','',0, 1, 0, 0),
(6807,'RP THER RADIOLBLD MONOCLONAL ANTIBODY IV INFUS','RP THER RADIOLBLD MONOCLONAL ANTIBODY IV INFUS','79403','1','','1','0','','','',0, 1, 0, 0),
(6808,'RP THERAPY INTRA-ARTICULAR ADMINISTRATION','RP THERAPY INTRA-ARTICULAR ADMINISTRATION','79440','1','','1','0','','','',0, 1, 0, 0),
(6809,'RP THERAPY INTRA-ARTERIAL PARTICULATE ADMN','RP THERAPY INTRA-ARTERIAL PARTICULATE ADMN','79445','1','','1','0','','','',0, 1, 0, 0),
(6810,'RP THERAPY UNLISTED PROCEDURE','RP THERAPY UNLISTED PROCEDURE','79999','1','','1','0','','','',0, 1, 0, 0),
(6811,'BASIC METABOLIC PANEL CALCIUM IONIZED','BASIC METABOLIC PANEL CALCIUM IONIZED','80047','1','','1','0','','','',0, 1, 0, 0),
(6812,'BASIC METABOLIC PANEL CALCIUM TOTAL','BASIC METABOLIC PANEL CALCIUM TOTAL','80048','1','','1','0','','','',0, 1, 0, 0),
(6813,'GENERAL HEALTH PANEL','GENERAL HEALTH PANEL','80050','1','','1','0','','','',0, 1, 0, 0),
(6814,'ELECTROLYTE PANEL','ELECTROLYTE PANEL','80051','1','','1','0','','','',0, 1, 0, 0),
(6815,'COMPREHENSIVE METABOLIC PANEL','COMPREHENSIVE METABOLIC PANEL','80053','1','','1','0','','','',0, 1, 0, 0),
(6816,'OBSTETRIC PANEL','OBSTETRIC PANEL','80055','1','','1','0','','','',0, 1, 0, 0),
(6817,'LIPID PANEL','LIPID PANEL','80061','1','','1','0','','','',0, 1, 0, 0),
(6818,'RENAL FUNCTION PANEL','RENAL FUNCTION PANEL','80069','1','','1','0','','','',0, 1, 0, 0),
(6819,'ACUTE HEPATITIS PANEL','ACUTE HEPATITIS PANEL','80074','1','','1','0','','','',0, 1, 0, 0),
(6820,'HEPATIC FUNCTION PANEL','HEPATIC FUNCTION PANEL','80076','1','','1','0','','','',0, 1, 0, 0),
(6821,'OBSTETRIC PANEL','OBSTETRIC PANEL','80081','1','','1','0','','','',0, 1, 0, 0),
(6822,'DRUG SCREEN QUANTITATIVE AMIKACIN','DRUG SCREEN QUANTITATIVE AMIKACIN','80150','1','','1','0','','','',0, 1, 0, 0),
(6823,'DRUG ASSAY CAFFEINE','DRUG ASSAY CAFFEINE','80155','1','','1','0','','','',0, 1, 0, 0),
(6824,'DRUG ASSAY CARBAMAZEPINE TOTAL','DRUG ASSAY CARBAMAZEPINE TOTAL','80156','1','','1','0','','','',0, 1, 0, 0),
(6825,'DRUG ASSAY CARBAMAZEPINE FREE','DRUG ASSAY CARBAMAZEPINE FREE','80157','1','','1','0','','','',0, 1, 0, 0),
(6826,'DRUG ASSAY CYCLOSPORINE','DRUG ASSAY CYCLOSPORINE','80158','1','','1','0','','','',0, 1, 0, 0),
(6827,'DRUG ASSAY CLOZAPINE','DRUG ASSAY CLOZAPINE','80159','1','','1','0','','','',0, 1, 0, 0),
(6828,'DRUG SCREEN QUANTITATIVE DIGOXIN TOTAL','DRUG SCREEN QUANTITATIVE DIGOXIN TOTAL','80162','1','','1','0','','','',0, 1, 0, 0),
(6829,'DRUG SCREEN QUANTITATIVE DIGOXIN FREE','DRUG SCREEN QUANTITATIVE DIGOXIN FREE','80163','1','','1','0','','','',0, 1, 0, 0),
(6830,'DRUG ASSAY VALPROIC DIPROPYLACETIC ACID TOTAL','DRUG ASSAY VALPROIC DIPROPYLACETIC ACID TOTAL','80164','1','','1','0','','','',0, 1, 0, 0),
(6831,'DRUG SCREEN QUANT DIPROPYLACETIC ACID FREE','DRUG SCREEN QUANT DIPROPYLACETIC ACID FREE','80165','1','','1','0','','','',0, 1, 0, 0),
(6832,'DRUG SCREEN QUANTITATIVE ETHOSUXIMIDE','DRUG SCREEN QUANTITATIVE ETHOSUXIMIDE','80168','1','','1','0','','','',0, 1, 0, 0),
(6833,'DRUG ASSAY EVEROLIMUS','DRUG ASSAY EVEROLIMUS','80169','1','','1','0','','','',0, 1, 0, 0),
(6834,'DRUG SCREEN QUANTITATIVE GENTAMICIN','DRUG SCREEN QUANTITATIVE GENTAMICIN','80170','1','','1','0','','','',0, 1, 0, 0),
(6835,'DRUG SCREEN QUANTITATIVE GABAPENTIN','DRUG SCREEN QUANTITATIVE GABAPENTIN','80171','1','','1','0','','','',0, 1, 0, 0),
(6836,'DRUG SCREEN QUANTITATIVE HALOPRIDOL','DRUG SCREEN QUANTITATIVE HALOPRIDOL','80173','1','','1','0','','','',0, 1, 0, 0),
(6837,'DRUG SCREEN QUANTITATIVE LAMOTRIGINE','DRUG SCREEN QUANTITATIVE LAMOTRIGINE','80175','1','','1','0','','','',0, 1, 0, 0),
(6838,'DRUG SCREEN QUANTITATIVE LIDOCAINE','DRUG SCREEN QUANTITATIVE LIDOCAINE','80176','1','','1','0','','','',0, 1, 0, 0),
(6839,'DRUG SCREEN QUANTITATIVE LEVETIRACETAM','DRUG SCREEN QUANTITATIVE LEVETIRACETAM','80177','1','','1','0','','','',0, 1, 0, 0),
(6840,'DRUG SCREEN QUANTITATIVE LITHIUM','DRUG SCREEN QUANTITATIVE LITHIUM','80178','1','','1','0','','','',0, 1, 0, 0),
(6841,'DRUG SCREEN QUANTITATIVE MYCOPHENOLATE','DRUG SCREEN QUANTITATIVE MYCOPHENOLATE','80180','1','','1','0','','','',0, 1, 0, 0),
(6842,'DRUG SCREEN QUANTITATIVE OXCARBAZEPINE','DRUG SCREEN QUANTITATIVE OXCARBAZEPINE','80183','1','','1','0','','','',0, 1, 0, 0),
(6843,'DRUG SCREEN QUANTITATIVE PHENOBARBITAL','DRUG SCREEN QUANTITATIVE PHENOBARBITAL','80184','1','','1','0','','','',0, 1, 0, 0),
(6844,'DRUG SCREEN QUANTITATIVE PHENYTOIN TOTAL','DRUG SCREEN QUANTITATIVE PHENYTOIN TOTAL','80185','1','','1','0','','','',0, 1, 0, 0),
(6845,'DRUG SCREEN QUANTITATIVE PHENYTOIN FREE','DRUG SCREEN QUANTITATIVE PHENYTOIN FREE','80186','1','','1','0','','','',0, 1, 0, 0),
(6846,'DRUG SCREEN QUANTITATIVE PRIMIDONE','DRUG SCREEN QUANTITATIVE PRIMIDONE','80188','1','','1','0','','','',0, 1, 0, 0),
(6847,'DRUG SCREEN QUANTITATIVE PROCAINAMIDE','DRUG SCREEN QUANTITATIVE PROCAINAMIDE','80190','1','','1','0','','','',0, 1, 0, 0),
(6848,'DRUG SCREEN QUANTITATIVE PROCAINAMIDE METABOLITE','DRUG SCREEN QUANTITATIVE PROCAINAMIDE METABOLITE','80192','1','','1','0','','','',0, 1, 0, 0),
(6849,'DRUG SCREEN QUANTITATIVE QUINIDINE','DRUG SCREEN QUANTITATIVE QUINIDINE','80194','1','','1','0','','','',0, 1, 0, 0),
(6850,'DRUG SCREEN QUANTITATIVE SIROLIMUS','DRUG SCREEN QUANTITATIVE SIROLIMUS','80195','1','','1','0','','','',0, 1, 0, 0),
(6851,'DRUG SCREEN QUANTITATIVE TACROLIMUS','DRUG SCREEN QUANTITATIVE TACROLIMUS','80197','1','','1','0','','','',0, 1, 0, 0),
(6852,'DRUG SCREEN QUANTITATIVE THEOPHYLLINE','DRUG SCREEN QUANTITATIVE THEOPHYLLINE','80198','1','','1','0','','','',0, 1, 0, 0),
(6853,'DRUG SCREEN QUANTITATIVE TIAGABINE','DRUG SCREEN QUANTITATIVE TIAGABINE','80199','1','','1','0','','','',0, 1, 0, 0),
(6854,'DRUG SCREEN QUANTITATIVE TOBRAMYCIN','DRUG SCREEN QUANTITATIVE TOBRAMYCIN','80200','1','','1','0','','','',0, 1, 0, 0),
(6855,'DRUG SCREEN QUANTITATIVE TOPIRAMATE','DRUG SCREEN QUANTITATIVE TOPIRAMATE','80201','1','','1','0','','','',0, 1, 0, 0),
(6856,'DRUG SCREEN QUANTITATIVE VANCOMYCIN','DRUG SCREEN QUANTITATIVE VANCOMYCIN','80202','1','','1','0','','','',0, 1, 0, 0),
(6857,'DRUG SCREEN QUANTITATIVE ZONISAMIDE','DRUG SCREEN QUANTITATIVE ZONISAMIDE','80203','1','','1','0','','','',0, 1, 0, 0),
(6858,'QUANTITATION DRUG NOT ELSEWHERE SPECIFIED','QUANTITATION DRUG NOT ELSEWHERE SPECIFIED','80299','1','','1','0','','','',0, 1, 0, 0),
(6859,'DRUG SCREEN LIST A ANY NMBR NON TLC DEVICES','DRUG SCREEN LIST A ANY NMBR NON TLC DEVICES','80300','1','','1','0','','','',0, 1, 0, 0),
(6860,'DRUG SCREEN LIST A SINGLE DRUG CLASS METHOD','DRUG SCREEN LIST A SINGLE DRUG CLASS METHOD','80301','1','','1','0','','','',0, 1, 0, 0),
(6861,'DRUG SCREEN PRESUMPTIVE 1 CLASS METHOD LIST B','DRUG SCREEN PRESUMPTIVE 1 CLASS METHOD LIST B','80302','1','','1','0','','','',0, 1, 0, 0),
(6862,'DRUG SCREEN PRSMPTV 1/MULT CLASS METHOD TLC','DRUG SCREEN PRSMPTV 1/MULT CLASS METHOD TLC','80303','1','','1','0','','','',0, 1, 0, 0),
(6863,'DRUG SCREEN PRSMPTV 1/MULT CLASS METHOD','DRUG SCREEN PRSMPTV 1/MULT CLASS METHOD','80304','1','','1','0','','','',0, 1, 0, 0),
(6864,'DRUG SCREEN QUANTITATIVE ALCOHOLS','DRUG SCREEN QUANTITATIVE ALCOHOLS','80320','1','','1','0','','','',0, 1, 0, 0),
(6865,'DRUG SCREEN QUANT ALCOHOLS BIOMARKERS 1 OR 2','DRUG SCREEN QUANT ALCOHOLS BIOMARKERS 1 OR 2','80321','1','','1','0','','','',0, 1, 0, 0),
(6866,'DRUG SCREEN QUANT ALCOHOLS BIOMARKERS 3 OR MORE','DRUG SCREEN QUANT ALCOHOLS BIOMARKERS 3 OR MORE','80322','1','','1','0','','','',0, 1, 0, 0),
(6867,'ALKALOIDS NOT OTHERWISE SPECIFIED','ALKALOIDS NOT OTHERWISE SPECIFIED','80323','1','','1','0','','','',0, 1, 0, 0),
(6868,'DRUG SCREEN QUANT AMPHETAMINES 1 OR 2','DRUG SCREEN QUANT AMPHETAMINES 1 OR 2','80324','1','','1','0','','','',0, 1, 0, 0),
(6869,'DRUG SCREEN QUANT AMPHETAMINES 3 OR 4','DRUG SCREEN QUANT AMPHETAMINES 3 OR 4','80325','1','','1','0','','','',0, 1, 0, 0),
(6870,'DRUG SCREEN QUANT AMPHETAMINES 5 OR MORE','DRUG SCREEN QUANT AMPHETAMINES 5 OR MORE','80326','1','','1','0','','','',0, 1, 0, 0),
(6871,'DRUG SCREEN QUANT ANABOLIC STEROID 1 OR 2','DRUG SCREEN QUANT ANABOLIC STEROID 1 OR 2','80327','1','','1','0','','','',0, 1, 0, 0),
(6872,'DRUG SCREEN QUANT ANABOLIC STEROID 3 OR MORE','DRUG SCREEN QUANT ANABOLIC STEROID 3 OR MORE','80328','1','','1','0','','','',0, 1, 0, 0),
(6873,'DRUG SCREEN ANALGESICS NON-OPIOID 1 OR 2','DRUG SCREEN ANALGESICS NON-OPIOID 1 OR 2','80329','1','','1','0','','','',0, 1, 0, 0),
(6874,'DRUG SCREEN ANALGESICS NON-OPIOID 3-5','DRUG SCREEN ANALGESICS NON-OPIOID 3-5','80330','1','','1','0','','','',0, 1, 0, 0),
(6875,'DRUG SCREEN ANALGESICS NON-OPIOID 6 OR MORE','DRUG SCREEN ANALGESICS NON-OPIOID 6 OR MORE','80331','1','','1','0','','','',0, 1, 0, 0),
(6876,'ANTIDEPRESSANTS SEROTONERGIC CLASS 1 OR 2','ANTIDEPRESSANTS SEROTONERGIC CLASS 1 OR 2','80332','1','','1','0','','','',0, 1, 0, 0),
(6877,'ANTIDEPRESSANTS SEROTONERGIC CLASS 3-5','ANTIDEPRESSANTS SEROTONERGIC CLASS 3-5','80333','1','','1','0','','','',0, 1, 0, 0),
(6878,'ANTIDEPRESSANTS SEROTONERGIC CLASS 6 OR MORE','ANTIDEPRESSANTS SEROTONERGIC CLASS 6 OR MORE','80334','1','','1','0','','','',0, 1, 0, 0),
(6879,'ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 1 OR 2','ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 1 OR 2','80335','1','','1','0','','','',0, 1, 0, 0),
(6880,'ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 3-5','ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 3-5','80336','1','','1','0','','','',0, 1, 0, 0),
(6881,'ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 6/MORE','ANTIDEPRESSANTS TRICYCLIC OTHER CYCLICALS 6/MORE','80337','1','','1','0','','','',0, 1, 0, 0),
(6882,'ANTIDEPRESSANTS NOT OTHERWISE SPECIFIED','ANTIDEPRESSANTS NOT OTHERWISE SPECIFIED','80338','1','','1','0','','','',0, 1, 0, 0),
(6883,'ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 1-3','ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 1-3','80339','1','','1','0','','','',0, 1, 0, 0),
(6884,'ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 4-6','ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 4-6','80340','1','','1','0','','','',0, 1, 0, 0),
(6885,'ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 7/MORE','ANTIEPILEPTICS NOT OTHERWISE SPECIFIED 7/MORE','80341','1','','1','0','','','',0, 1, 0, 0),
(6886,'ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 1-3','ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 1-3','80342','1','','1','0','','','',0, 1, 0, 0),
(6887,'ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 4-6','ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 4-6','80343','1','','1','0','','','',0, 1, 0, 0),
(6888,'ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 7/MORE','ANTIPSYCHOTICS NOT OTHERWISE SPECIFIED 7/MORE','80344','1','','1','0','','','',0, 1, 0, 0),
(6889,'DRUG SCREENING BARBITURATES','DRUG SCREENING BARBITURATES','80345','1','','1','0','','','',0, 1, 0, 0),
(6890,'DRUG SCREENING BENZODIAZEPINES 1-12','DRUG SCREENING BENZODIAZEPINES 1-12','80346','1','','1','0','','','',0, 1, 0, 0),
(6891,'DRUG SCREENING BENZODIAZEPINES 13 OR MORE','DRUG SCREENING BENZODIAZEPINES 13 OR MORE','80347','1','','1','0','','','',0, 1, 0, 0),
(6892,'DRUG SCREENING BUPRENORPHINE','DRUG SCREENING BUPRENORPHINE','80348','1','','1','0','','','',0, 1, 0, 0),
(6893,'DRUG SCREENING CANNABINOIDS NATURAL','DRUG SCREENING CANNABINOIDS NATURAL','80349','1','','1','0','','','',0, 1, 0, 0),
(6894,'DRUG SCREENING CANNABINOIDS SYNTHETIC 1-3','DRUG SCREENING CANNABINOIDS SYNTHETIC 1-3','80350','1','','1','0','','','',0, 1, 0, 0),
(6895,'DRUG SCREENING CANNABINOIDS SYNTHETIC 4-6','DRUG SCREENING CANNABINOIDS SYNTHETIC 4-6','80351','1','','1','0','','','',0, 1, 0, 0),
(6896,'DRUG SCREENING CANNABINOIDS SYNTHETIC 7/MORE','DRUG SCREENING CANNABINOIDS SYNTHETIC 7/MORE','80352','1','','1','0','','','',0, 1, 0, 0),
(6897,'DRUG SCREENING COCAINE','DRUG SCREENING COCAINE','80353','1','','1','0','','','',0, 1, 0, 0),
(6898,'DRUG SCREENING FENTANYL','DRUG SCREENING FENTANYL','80354','1','','1','0','','','',0, 1, 0, 0),
(6899,'DRUG SCREENING GABAPENTIN NON-BLOOD','DRUG SCREENING GABAPENTIN NON-BLOOD','80355','1','','1','0','','','',0, 1, 0, 0),
(6900,'DRUG SCREENING HEROIN METABOLITE','DRUG SCREENING HEROIN METABOLITE','80356','1','','1','0','','','',0, 1, 0, 0),
(6901,'DRUG SCREENING KETAMINE AND NORKETAMINE','DRUG SCREENING KETAMINE AND NORKETAMINE','80357','1','','1','0','','','',0, 1, 0, 0),
(6902,'DRUG SCREENING METHADONE','DRUG SCREENING METHADONE','80358','1','','1','0','','','',0, 1, 0, 0),
(6903,'DRUG SCREENING METHYLENEDIOXYAMPHETAMINES','DRUG SCREENING METHYLENEDIOXYAMPHETAMINES','80359','1','','1','0','','','',0, 1, 0, 0),
(6904,'DRUG SCREENING METHYLPHENIDATE','DRUG SCREENING METHYLPHENIDATE','80360','1','','1','0','','','',0, 1, 0, 0),
(6905,'DRUG SCREENING OPIATES 1 OR MORE','DRUG SCREENING OPIATES 1 OR MORE','80361','1','','1','0','','','',0, 1, 0, 0),
(6906,'DRUG SCREENING OPIOIDS AND OPIATE ANALOGS 1 OR 2','DRUG SCREENING OPIOIDS AND OPIATE ANALOGS 1 OR 2','80362','1','','1','0','','','',0, 1, 0, 0),
(6907,'DRUG SCREENING OPIOIDS AND OPIATE ANALOGS 3 OR 4','DRUG SCREENING OPIOIDS AND OPIATE ANALOGS 3 OR 4','80363','1','','1','0','','','',0, 1, 0, 0),
(6908,'DRUG SCREENING OPIOIDS & OPIATE ANALOGS 5/MORE','DRUG SCREENING OPIOIDS & OPIATE ANALOGS 5/MORE','80364','1','','1','0','','','',0, 1, 0, 0),
(6909,'DRUG SCREENING OXYCODONE','DRUG SCREENING OXYCODONE','80365','1','','1','0','','','',0, 1, 0, 0),
(6910,'DRUG SCREENING PREGABALIN','DRUG SCREENING PREGABALIN','80366','1','','1','0','','','',0, 1, 0, 0),
(6911,'DRUG SCREENING PROPOXYPHENE','DRUG SCREENING PROPOXYPHENE','80367','1','','1','0','','','',0, 1, 0, 0),
(6912,'DRUG SCREENING SEDATIVE HYPNOTICS','DRUG SCREENING SEDATIVE HYPNOTICS','80368','1','','1','0','','','',0, 1, 0, 0),
(6913,'DRUG SCREENING SKELETAL MUSCLE RELAXANTS 1 OR 2','DRUG SCREENING SKELETAL MUSCLE RELAXANTS 1 OR 2','80369','1','','1','0','','','',0, 1, 0, 0),
(6914,'DRUG SCREENING SKEL MUSCLE RELAXANTS 3 OR MORE','DRUG SCREENING SKEL MUSCLE RELAXANTS 3 OR MORE','80370','1','','1','0','','','',0, 1, 0, 0),
(6915,'DRUG SCREENING STIMULANTS SYNTHETIC','DRUG SCREENING STIMULANTS SYNTHETIC','80371','1','','1','0','','','',0, 1, 0, 0),
(6916,'DRUG SCREENING TAPENTADOL','DRUG SCREENING TAPENTADOL','80372','1','','1','0','','','',0, 1, 0, 0),
(6917,'DRUG SCREENING TRAMADOL','DRUG SCREENING TRAMADOL','80373','1','','1','0','','','',0, 1, 0, 0),
(6918,'DRUG SCREEN STEREOISOMER ANALYSIS 1 DRUG CLASS','DRUG SCREEN STEREOISOMER ANALYSIS 1 DRUG CLASS','80374','1','','1','0','','','',0, 1, 0, 0),
(6919,'DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 1-3','DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 1-3','80375','1','','1','0','','','',0, 1, 0, 0),
(6920,'DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 4-6','DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 4-6','80376','1','','1','0','','','',0, 1, 0, 0),
(6921,'DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 7/MORE','DRUG/SUBSTANCE DEFINITIVE QUAL/QUANT NOS 7/MORE','80377','1','','1','0','','','',0, 1, 0, 0),
(6922,'ACTH STIMULATION PANEL ADRENAL INSUFFICIENCY','ACTH STIMULATION PANEL ADRENAL INSUFFICIENCY','80400','1','','1','0','','','',0, 1, 0, 0),
(6923,'ACTH STIMULATION PANEL 21 HYDROXYLASE DEFICIENCY','ACTH STIMULATION PANEL 21 HYDROXYLASE DEFICIENCY','80402','1','','1','0','','','',0, 1, 0, 0),
(6924,'ACTH STIMJ PANEL 3 BETA-HYDROXYDEHYD DEFNCY','ACTH STIMJ PANEL 3 BETA-HYDROXYDEHYD DEFNCY','80406','1','','1','0','','','',0, 1, 0, 0),
(6925,'ALDOSTERONE SUPPRESSION EVALUATION PANEL','ALDOSTERONE SUPPRESSION EVALUATION PANEL','80408','1','','1','0','','','',0, 1, 0, 0),
(6926,'CALCITONIN STIMULATION PANEL','CALCITONIN STIMULATION PANEL','80410','1','','1','0','','','',0, 1, 0, 0),
(6927,'CORTICOTROPIC RELEASING HORM STIMJ PANEL','CORTICOTROPIC RELEASING HORM STIMJ PANEL','80412','1','','1','0','','','',0, 1, 0, 0),
(6928,'CHORNC GONAD STIMJ PANEL TSTOSTERONE RESPONSE','CHORNC GONAD STIMJ PANEL TSTOSTERONE RESPONSE','80414','1','','1','0','','','',0, 1, 0, 0),
(6929,'CHORNC GONAD STIMJ PANEL ESTRADIOL RESPONSE','CHORNC GONAD STIMJ PANEL ESTRADIOL RESPONSE','80415','1','','1','0','','','',0, 1, 0, 0),
(6930,'RENAL VEIN RENIN STIMULATION PANEL','RENAL VEIN RENIN STIMULATION PANEL','80416','1','','1','0','','','',0, 1, 0, 0),
(6931,'PERIPHERAL VEIN RENIN STIMULATION PANEL','PERIPHERAL VEIN RENIN STIMULATION PANEL','80417','1','','1','0','','','',0, 1, 0, 0),
(6932,'COMBINED RAPID ANT PITUITARY EVALUATION PANEL','COMBINED RAPID ANT PITUITARY EVALUATION PANEL','80418','1','','1','0','','','',0, 1, 0, 0),
(6933,'DEXMETHASONE SUPPRESSION PANEL 48 HR','DEXMETHASONE SUPPRESSION PANEL 48 HR','80420','1','','1','0','','','',0, 1, 0, 0),
(6934,'GLUCOSE TOLERANCE PANEL INSULINOMA','GLUCOSE TOLERANCE PANEL INSULINOMA','80422','1','','1','0','','','',0, 1, 0, 0),
(6935,'GLUCOSE TOLERANCE PANEL PHEOCHROMOCYTOMA','GLUCOSE TOLERANCE PANEL PHEOCHROMOCYTOMA','80424','1','','1','0','','','',0, 1, 0, 0),
(6936,'GONADOTROPIN RELEASING HORMONE STIMJ PANEL','GONADOTROPIN RELEASING HORMONE STIMJ PANEL','80426','1','','1','0','','','',0, 1, 0, 0),
(6937,'GROWTH HORMONE STIMULATION PANEL','GROWTH HORMONE STIMULATION PANEL','80428','1','','1','0','','','',0, 1, 0, 0),
(6938,'GROWTH HORMONE SUPRJ PANEL GLUCOSE ADMN','GROWTH HORMONE SUPRJ PANEL GLUCOSE ADMN','80430','1','','1','0','','','',0, 1, 0, 0),
(6939,'INSULIN-INDUCED C-PEPTIDE SUPRESSION PANEL','INSULIN-INDUCED C-PEPTIDE SUPRESSION PANEL','80432','1','','1','0','','','',0, 1, 0, 0),
(6940,'INSULIN TOLERANCE PANEL ACTH INSUFFICIENCY','INSULIN TOLERANCE PANEL ACTH INSUFFICIENCY','80434','1','','1','0','','','',0, 1, 0, 0),
(6941,'INSULIN TOLERANCE PANEL GROWTH HORM DEFNCY','INSULIN TOLERANCE PANEL GROWTH HORM DEFNCY','80435','1','','1','0','','','',0, 1, 0, 0),
(6942,'METYRAPONE PANEL','METYRAPONE PANEL','80436','1','','1','0','','','',0, 1, 0, 0),
(6943,'THYROTROPIN RELEASING HORMONE STMLJ PANEL 1 HR','THYROTROPIN RELEASING HORMONE STMLJ PANEL 1 HR','80438','1','','1','0','','','',0, 1, 0, 0),
(6944,'THYROTROPIN RELEASING HORMONE STMLJ PANEL 2 HR','THYROTROPIN RELEASING HORMONE STMLJ PANEL 2 HR','80439','1','','1','0','','','',0, 1, 0, 0),
(6945,'CLINICAL PATHOLOGY CONSULTATION LIMITED','CLINICAL PATHOLOGY CONSULTATION LIMITED','80500','1','','1','0','','','',0, 1, 0, 0),
(6946,'CLINICAL PATHOLOGY CONSULTATION COMPREHENSIVE','CLINICAL PATHOLOGY CONSULTATION COMPREHENSIVE','80502','1','','1','0','','','',0, 1, 0, 0),
(6947,'URINLS DIP STICK/TABLET REAGNT NON-AUTO MICRSCPY','URINLS DIP STICK/TABLET REAGNT NON-AUTO MICRSCPY','81000','1','','1','0','','','',0, 1, 0, 0),
(6948,'URNLS DIP STICK/TABLET REAGENT AUTO MICROSCOPY','URNLS DIP STICK/TABLET REAGENT AUTO MICROSCOPY','81001','1','','1','0','','','',0, 1, 0, 0),
(6949,'URNLS DIP STICK/TABLET RGNT NON-AUTO W/O MICRSCP','URNLS DIP STICK/TABLET RGNT NON-AUTO W/O MICRSCP','81002','1','','1','0','','','',0, 1, 0, 0),
(6950,'URNLS DIP STICK/TABLET RGNT AUTO W/O MICROSCOPY','URNLS DIP STICK/TABLET RGNT AUTO W/O MICROSCOPY','81003','1','','1','0','','','',0, 1, 0, 0),
(6951,'URINALYSIS QUAL/SEMIQUANT EXCEPT IMMUNOASSAYS','URINALYSIS QUAL/SEMIQUANT EXCEPT IMMUNOASSAYS','81005','1','','1','0','','','',0, 1, 0, 0),
(6952,'URINALYSIS BACTERIURIA SCR XCPT CULTURE/DIPSTICK','URINALYSIS BACTERIURIA SCR XCPT CULTURE/DIPSTICK','81007','1','','1','0','','','',0, 1, 0, 0),
(6953,'URINALYSIS MICROSCOPIC ONLY','URINALYSIS MICROSCOPIC ONLY','81015','1','','1','0','','','',0, 1, 0, 0),
(6954,'URINALYSIS 2/3 GLASS TEST','URINALYSIS 2/3 GLASS TEST','81020','1','','1','0','','','',0, 1, 0, 0),
(6955,'URINE PREGNANCY TEST VISUAL COLOR CMPRSN METHS','URINE PREGNANCY TEST VISUAL COLOR CMPRSN METHS','81025','1','','1','0','','','',0, 1, 0, 0),
(6956,'VOLUME MEASUREMENT TIMED COLLECTION EACH','VOLUME MEASUREMENT TIMED COLLECTION EACH','81050','1','','1','0','','','',0, 1, 0, 0),
(6957,'UNLISTED URINALYSIS PROCEDURE','UNLISTED URINALYSIS PROCEDURE','81099','1','','1','0','','','',0, 1, 0, 0),
(6958,'DMD DUPLICATION/DELETION ANALYSIS','DMD DUPLICATION/DELETION ANALYSIS','81161','1','','1','0','','','',0, 1, 0, 0),
(6959,'BRCA1&BRCA2 FULL SEQ ANALYS/FULL DUP/DEL ANALYS','BRCA1&BRCA2 FULL SEQ ANALYS/FULL DUP/DEL ANALYS','81162','1','','1','0','','','',0, 1, 0, 0),
(6960,'ABL1 GENE ANALYSIS KINASE DOMAIN VARIANTS','ABL1 GENE ANALYSIS KINASE DOMAIN VARIANTS','81170','1','','1','0','','','',0, 1, 0, 0),
(6961,'ASPA GENE ANALYSIS COMMON VARIANTS','ASPA GENE ANALYSIS COMMON VARIANTS','81200','1','','1','0','','','',0, 1, 0, 0),
(6962,'APC GENE ANALYSIS FULL GENE SEQUENCE','APC GENE ANALYSIS FULL GENE SEQUENCE','81201','1','','1','0','','','',0, 1, 0, 0),
(6963,'APC GENE ANALYSIS KNOWN FAMILIAL VARIANTS','APC GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81202','1','','1','0','','','',0, 1, 0, 0),
(6964,'APC GENE ANALYSIS DUPLICATION/DELETION VARIANTS','APC GENE ANALYSIS DUPLICATION/DELETION VARIANTS','81203','1','','1','0','','','',0, 1, 0, 0),
(6965,'BCKDHB GENE ANALYSIS COMMON VARIANTS','BCKDHB GENE ANALYSIS COMMON VARIANTS','81205','1','','1','0','','','',0, 1, 0, 0),
(6966,'BCR/ABL1 MAJOR BREAKPNT QUALITATIVE/QUANTITATIVE','BCR/ABL1 MAJOR BREAKPNT QUALITATIVE/QUANTITATIVE','81206','1','','1','0','','','',0, 1, 0, 0),
(6967,'BCR/ABL1 MINOR BREAKPNT QUALITATIVE/QUANTITATIVE','BCR/ABL1 MINOR BREAKPNT QUALITATIVE/QUANTITATIVE','81207','1','','1','0','','','',0, 1, 0, 0),
(6968,'BCR/ABL1 OTHER BREAKPNT QUALITATIVE/QUANTITATIVE','BCR/ABL1 OTHER BREAKPNT QUALITATIVE/QUANTITATIVE','81208','1','','1','0','','','',0, 1, 0, 0),
(6969,'BLM GENE ANALYSIS 2281DEL6INS7 VARIANT','BLM GENE ANALYSIS 2281DEL6INS7 VARIANT','81209','1','','1','0','','','',0, 1, 0, 0),
(6970,'BRAF GENE ANALYSIS V600 VARIANT(S)','BRAF GENE ANALYSIS V600 VARIANT(S)','81210','1','','1','0','','','',0, 1, 0, 0),
(6971,'BRCA1&BRCA2 FULL SEQ ANALYS/COMM DUP/DEL BRCA','BRCA1&BRCA2 FULL SEQ ANALYS/COMM DUP/DEL BRCA','81211','1','','1','0','','','',0, 1, 0, 0),
(6972,'BRCA1&BRCA2 ANAL 185DELAG5385INSC/6174DELT','BRCA1&BRCA2 ANAL 185DELAG5385INSC/6174DELT','81212','1','','1','0','','','',0, 1, 0, 0),
(6973,'BRCA1&BRCA2 ANAL UNCOMMON DUP/DEL VARIANTS','BRCA1&BRCA2 ANAL UNCOMMON DUP/DEL VARIANTS','81213','1','','1','0','','','',0, 1, 0, 0),
(6974,'BRCA1 FULL SEQ ANAL&COMMON DUP/DEL VARIANTS','BRCA1 FULL SEQ ANAL&COMMON DUP/DEL VARIANTS','81214','1','','1','0','','','',0, 1, 0, 0),
(6975,'BRCA1 GENE ANALYSIS KNOWN FAMILIAL VARIANT','BRCA1 GENE ANALYSIS KNOWN FAMILIAL VARIANT','81215','1','','1','0','','','',0, 1, 0, 0),
(6976,'BRCA2 GENE ANALYSIS FULL SEQUENCE ANALYSIS','BRCA2 GENE ANALYSIS FULL SEQUENCE ANALYSIS','81216','1','','1','0','','','',0, 1, 0, 0),
(6977,'BRCA2 GENE ANALYSIS KNOWN FAMILIAL VARIANT','BRCA2 GENE ANALYSIS KNOWN FAMILIAL VARIANT','81217','1','','1','0','','','',0, 1, 0, 0),
(6978,'CEBPA GENE ANALYSIS FULL GENE SEQUENCE','CEBPA GENE ANALYSIS FULL GENE SEQUENCE','81218','1','','1','0','','','',0, 1, 0, 0),
(6979,'CALR GENE ANALYSIS COMMON VARIANTS IN EXON 9','CALR GENE ANALYSIS COMMON VARIANTS IN EXON 9','81219','1','','1','0','','','',0, 1, 0, 0),
(6980,'CFTR GENE ANALYSIS COMMON VARIANTS','CFTR GENE ANALYSIS COMMON VARIANTS','81220','1','','1','0','','','',0, 1, 0, 0),
(6981,'CFTR GENE ANALYSIS KNOWN FAMILIAL VARIANTS','CFTR GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81221','1','','1','0','','','',0, 1, 0, 0),
(6982,'CFTR GENE ANALYSIS DUPLICATION/DELETION VARIANTS','CFTR GENE ANALYSIS DUPLICATION/DELETION VARIANTS','81222','1','','1','0','','','',0, 1, 0, 0),
(6983,'CFTR GENE ANALYSIS FULL GENE SEQUENCE','CFTR GENE ANALYSIS FULL GENE SEQUENCE','81223','1','','1','0','','','',0, 1, 0, 0),
(6984,'CFTR GENE ANALYSIS INTRON 8 POLY-T ANALYSIS','CFTR GENE ANALYSIS INTRON 8 POLY-T ANALYSIS','81224','1','','1','0','','','',0, 1, 0, 0),
(6985,'CYP2C19 GENE ANALYSIS COMMON VARIANTS','CYP2C19 GENE ANALYSIS COMMON VARIANTS','81225','1','','1','0','','','',0, 1, 0, 0),
(6986,'CYP2D6 GENE ANALYSIS COMMON VARIANTS','CYP2D6 GENE ANALYSIS COMMON VARIANTS','81226','1','','1','0','','','',0, 1, 0, 0),
(6987,'CYP2C9 GENE ANALYSIS COMMON VARIANTS','CYP2C9 GENE ANALYSIS COMMON VARIANTS','81227','1','','1','0','','','',0, 1, 0, 0),
(6988,'CYTOGENOM CONST MICROARRAY COPY NUMBER VARIANTS','CYTOGENOM CONST MICROARRAY COPY NUMBER VARIANTS','81228','1','','1','0','','','',0, 1, 0, 0),
(6989,'CYTOGENOM CONST MICROARRAY COPY NUMBER&SNP VAR','CYTOGENOM CONST MICROARRAY COPY NUMBER&SNP VAR','81229','1','','1','0','','','',0, 1, 0, 0),
(6990,'EGFR GENE ANALYSIS COMMON VARIANTS','EGFR GENE ANALYSIS COMMON VARIANTS','81235','1','','1','0','','','',0, 1, 0, 0),
(6991,'F2 GENE ANALYSIS 20210G >A VARIANT','F2 GENE ANALYSIS 20210G >A VARIANT','81240','1','','1','0','','','',0, 1, 0, 0),
(6992,'F5 COAGULATION FACTOR V ANAL LEIDEN VARIANT','F5 COAGULATION FACTOR V ANAL LEIDEN VARIANT','81241','1','','1','0','','','',0, 1, 0, 0),
(6993,'FANCC GENE ANALYSIS COMMON VARIANT','FANCC GENE ANALYSIS COMMON VARIANT','81242','1','','1','0','','','',0, 1, 0, 0),
(6994,'FMR1 ANALYSIS EVAL TO DETECT ABNORMAL ALLELES','FMR1 ANALYSIS EVAL TO DETECT ABNORMAL ALLELES','81243','1','','1','0','','','',0, 1, 0, 0),
(6995,'FMR1 GENE ANALYSIS CHARACTERIZATION OF ALLELES','FMR1 GENE ANALYSIS CHARACTERIZATION OF ALLELES','81244','1','','1','0','','','',0, 1, 0, 0),
(6996,'FLT3 GENE ANALYSIS INTERNAL TANDEM DUP VARIANTS','FLT3 GENE ANALYSIS INTERNAL TANDEM DUP VARIANTS','81245','1','','1','0','','','',0, 1, 0, 0),
(6997,'FLT3 GENE ANLYS TYROSINE KINASE DOMAIN VARIANTS','FLT3 GENE ANLYS TYROSINE KINASE DOMAIN VARIANTS','81246','1','','1','0','','','',0, 1, 0, 0),
(6998,'G6PC GENE ANALYSIS COMMON VARIANTS','G6PC GENE ANALYSIS COMMON VARIANTS','81250','1','','1','0','','','',0, 1, 0, 0),
(6999,'GBA GLUCOSIDASE/BETA/ACID ANAL COMM VARIANTS','GBA GLUCOSIDASE/BETA/ACID ANAL COMM VARIANTS','81251','1','','1','0','','','',0, 1, 0, 0),
(7000,'GJB2 GENE ANALYSIS FULL GENE SEQUENCE','GJB2 GENE ANALYSIS FULL GENE SEQUENCE','81252','1','','1','0','','','',0, 1, 0, 0),
(7001,'GJB2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','GJB2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81253','1','','1','0','','','',0, 1, 0, 0),
(7002,'GJB6 GENE ANALYSIS COMMON VARIANTS','GJB6 GENE ANALYSIS COMMON VARIANTS','81254','1','','1','0','','','',0, 1, 0, 0),
(7003,'HEXA GENE ANALYSIS COMMON VARIANTS','HEXA GENE ANALYSIS COMMON VARIANTS','81255','1','','1','0','','','',0, 1, 0, 0),
(7004,'HFE HEMOCHROMATOSIS GENE ANAL COMMON VARIANTS','HFE HEMOCHROMATOSIS GENE ANAL COMMON VARIANTS','81256','1','','1','0','','','',0, 1, 0, 0),
(7005,'HBA1/HBA2 ANALYSIS FOR COMMON DELETIONS/VARIANT','HBA1/HBA2 ANALYSIS FOR COMMON DELETIONS/VARIANT','81257','1','','1','0','','','',0, 1, 0, 0),
(7006,'IKBKAP GENE ANALYSIS COMMON VARIANTS','IKBKAP GENE ANALYSIS COMMON VARIANTS','81260','1','','1','0','','','',0, 1, 0, 0),
(7007,'IGH@ REARRANGE ABNORMAL CLONAL POP AMPLIFIED','IGH@ REARRANGE ABNORMAL CLONAL POP AMPLIFIED','81261','1','','1','0','','','',0, 1, 0, 0),
(7008,'IGH@ REARRANGE ABNORMAL CLONAL POP DIRECT PROBE','IGH@ REARRANGE ABNORMAL CLONAL POP DIRECT PROBE','81262','1','','1','0','','','',0, 1, 0, 0),
(7009,'IGH@ VARIABLE REGION SOMATIC MUTATION ANALYSIS','IGH@ VARIABLE REGION SOMATIC MUTATION ANALYSIS','81263','1','','1','0','','','',0, 1, 0, 0),
(7010,'IGK@ GENE REARRANGE DETECT ABNORMAL CLONAL POP','IGK@ GENE REARRANGE DETECT ABNORMAL CLONAL POP','81264','1','','1','0','','','',0, 1, 0, 0),
(7011,'COMPARATIVE ANAL STR MARKERS PATIENT&COMP SPEC','COMPARATIVE ANAL STR MARKERS PATIENT&COMP SPEC','81265','1','','1','0','','','',0, 1, 0, 0),
(7012,'COMPARATIVE ANAL STR MARKERS EA ADDL SPECIMEN','COMPARATIVE ANAL STR MARKERS EA ADDL SPECIMEN','81266','1','','1','0','','','',0, 1, 0, 0),
(7013,'CHIMERISM W/COMP TO BASELINE W/O CELL SELECTION','CHIMERISM W/COMP TO BASELINE W/O CELL SELECTION','81267','1','','1','0','','','',0, 1, 0, 0),
(7014,'CHIMERISM W/COMP TO BASELINE W/CELL SELECTION EA','CHIMERISM W/COMP TO BASELINE W/CELL SELECTION EA','81268','1','','1','0','','','',0, 1, 0, 0),
(7015,'JAK2 GENE ANALYSIS P.VAL617PHE VARIANT','JAK2 GENE ANALYSIS P.VAL617PHE VARIANT','81270','1','','1','0','','','',0, 1, 0, 0),
(7016,'KIT GENE ANALYSIS TARGETED SEQUENCE ANALYSIS','KIT GENE ANALYSIS TARGETED SEQUENCE ANALYSIS','81272','1','','1','0','','','',0, 1, 0, 0),
(7017,'KIT GENE ANALYSIS D816 VARIANT(S)','KIT GENE ANALYSIS D816 VARIANT(S)','81273','1','','1','0','','','',0, 1, 0, 0),
(7018,'KRAS GENE ANALYSIS VARIANTS IN EXON 2','KRAS GENE ANALYSIS VARIANTS IN EXON 2','81275','1','','1','0','','','',0, 1, 0, 0),
(7019,'KRAS GENE ANALYSIS ADDITIONAL VARIANT(S)','KRAS GENE ANALYSIS ADDITIONAL VARIANT(S)','81276','1','','1','0','','','',0, 1, 0, 0),
(7020,'LONG QT SYNDROME FULL SEQUENCE ANALYSIS','LONG QT SYNDROME FULL SEQUENCE ANALYSIS','81280','1','','1','0','','','',0, 1, 0, 0),
(7021,'LONG QT SYNDROME ANAL KNOWN FAMILIAL SEQUENCE','LONG QT SYNDROME ANAL KNOWN FAMILIAL SEQUENCE','81281','1','','1','0','','','',0, 1, 0, 0),
(7022,'LONG QT SYNDROME GENE ANAL DUP/DEL VARIANTS','LONG QT SYNDROME GENE ANAL DUP/DEL VARIANTS','81282','1','','1','0','','','',0, 1, 0, 0),
(7023,'MGMT METHYLATION ANALYSIS','MGMT METHYLATION ANALYSIS','81287','1','','1','0','','','',0, 1, 0, 0),
(7024,'MLH1 GENE ANALYSIS PROMOTER METHYLATION ANALYSIS','MLH1 GENE ANALYSIS PROMOTER METHYLATION ANALYSIS','81288','1','','1','0','','','',0, 1, 0, 0),
(7025,'MCOLN1 MUCOLIPIN1 GENE ANALYSIS COMMON VARIANTS','MCOLN1 MUCOLIPIN1 GENE ANALYSIS COMMON VARIANTS','81290','1','','1','0','','','',0, 1, 0, 0),
(7026,'MTHFR GENE ANALYSIS COMMON VARIANTS','MTHFR GENE ANALYSIS COMMON VARIANTS','81291','1','','1','0','','','',0, 1, 0, 0),
(7027,'MLH1 GENE ANALYSIS FULL SEQUENCE ANALYSIS','MLH1 GENE ANALYSIS FULL SEQUENCE ANALYSIS','81292','1','','1','0','','','',0, 1, 0, 0),
(7028,'MLH1 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','MLH1 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81293','1','','1','0','','','',0, 1, 0, 0),
(7029,'MLH1 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','MLH1 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','81294','1','','1','0','','','',0, 1, 0, 0),
(7030,'MSH2 GENE ANALYSIS FULL SEQUENCE ANALYSIS','MSH2 GENE ANALYSIS FULL SEQUENCE ANALYSIS','81295','1','','1','0','','','',0, 1, 0, 0),
(7031,'MSH2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','MSH2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81296','1','','1','0','','','',0, 1, 0, 0),
(7032,'MSH2 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','MSH2 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','81297','1','','1','0','','','',0, 1, 0, 0),
(7033,'MSH6 GENE ANALYSIS FULL SEQUENCE ANALYSIS','MSH6 GENE ANALYSIS FULL SEQUENCE ANALYSIS','81298','1','','1','0','','','',0, 1, 0, 0),
(7034,'MSH6 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','MSH6 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81299','1','','1','0','','','',0, 1, 0, 0),
(7035,'MSH6 GENE ANALYSIS DUPLICATION/DELETION VARIA','MSH6 GENE ANALYSIS DUPLICATION/DELETION VARIA','81300','1','','1','0','','','',0, 1, 0, 0),
(7036,'MICROSATELLITE INSTAB ANAL MISMATCH REPAIR DEF','MICROSATELLITE INSTAB ANAL MISMATCH REPAIR DEF','81301','1','','1','0','','','',0, 1, 0, 0),
(7037,'MECP2 GENE ANALYSIS FULL SEQUENCE','MECP2 GENE ANALYSIS FULL SEQUENCE','81302','1','','1','0','','','',0, 1, 0, 0),
(7038,'MECP2 GENE ANALYSIS KNOWN FAMILIAL VARIANT','MECP2 GENE ANALYSIS KNOWN FAMILIAL VARIANT','81303','1','','1','0','','','',0, 1, 0, 0),
(7039,'MECP2 GENE ANALYSIS DUPLICATION/DELETION VARIANT','MECP2 GENE ANALYSIS DUPLICATION/DELETION VARIANT','81304','1','','1','0','','','',0, 1, 0, 0),
(7040,'NPM1 NUCLEOPHOSMIN GENE ANAL EXON 12 VARIANTS','NPM1 NUCLEOPHOSMIN GENE ANAL EXON 12 VARIANTS','81310','1','','1','0','','','',0, 1, 0, 0),
(7041,'NRAS GENE ANALYSIS VARIANTS IN EXON 2&3','NRAS GENE ANALYSIS VARIANTS IN EXON 2&3','81311','1','','1','0','','','',0, 1, 0, 0),
(7042,'PCA3/KLK3 PROSTATE SPECIFIC ANTIGEN RATIO','PCA3/KLK3 PROSTATE SPECIFIC ANTIGEN RATIO','81313','1','','1','0','','','',0, 1, 0, 0),
(7043,'PDGFRA GENE ANALYS TARGETED SEQUENCE ANALYS','PDGFRA GENE ANALYS TARGETED SEQUENCE ANALYS','81314','1','','1','0','','','',0, 1, 0, 0),
(7044,'PML/RARALPHA COMMON BREAKPOINTS QUAL/QUANT','PML/RARALPHA COMMON BREAKPOINTS QUAL/QUANT','81315','1','','1','0','','','',0, 1, 0, 0),
(7045,'PML/RARALPHA SINGLE BREAKPOINT QUAL/QUAN','PML/RARALPHA SINGLE BREAKPOINT QUAL/QUAN','81316','1','','1','0','','','',0, 1, 0, 0),
(7046,'PMS2 GENE ANALYSIS FULL SEQUENCE','PMS2 GENE ANALYSIS FULL SEQUENCE','81317','1','','1','0','','','',0, 1, 0, 0),
(7047,'PMS2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','PMS2 GENE ANALYSIS KNOWN FAMILIAL VARIANTS','81318','1','','1','0','','','',0, 1, 0, 0),
(7048,'PMS2 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','PMS2 GENE ANALYSIS DUPLICATION/DELETION VARIANTS','81319','1','','1','0','','','',0, 1, 0, 0),
(7049,'PTEN GENE ANALYSIS FULL SEQUENCE ANALYSIS','PTEN GENE ANALYSIS FULL SEQUENCE ANALYSIS','81321','1','','1','0','','','',0, 1, 0, 0),
(7050,'PTEN GENE ANALYSIS KNOWN FAMILIAL VARIANT','PTEN GENE ANALYSIS KNOWN FAMILIAL VARIANT','81322','1','','1','0','','','',0, 1, 0, 0),
(7051,'PTEN GENE ANALYSIS DUPLICATION/DELETION VARIANT','PTEN GENE ANALYSIS DUPLICATION/DELETION VARIANT','81323','1','','1','0','','','',0, 1, 0, 0),
(7052,'PMP22 GENE ANAL DUPLICATION/DELETION ANALYSIS','PMP22 GENE ANAL DUPLICATION/DELETION ANALYSIS','81324','1','','1','0','','','',0, 1, 0, 0),
(7053,'PMP22 GENE ANALYSIS FULL SEQUENCE ANALYSIS','PMP22 GENE ANALYSIS FULL SEQUENCE ANALYSIS','81325','1','','1','0','','','',0, 1, 0, 0),
(7054,'PMP22 GENE ANALYSIS KNOWN FAMILIAL VARIANT','PMP22 GENE ANALYSIS KNOWN FAMILIAL VARIANT','81326','1','','1','0','','','',0, 1, 0, 0),
(7055,'SMPD1 GENE ANALYSIS COMMON VARIANTS','SMPD1 GENE ANALYSIS COMMON VARIANTS','81330','1','','1','0','','','',0, 1, 0, 0),
(7056,'SNRPN/UBE3A METHYLATION ANALYSIS','SNRPN/UBE3A METHYLATION ANALYSIS','81331','1','','1','0','','','',0, 1, 0, 0),
(7057,'SERPINA1 GENE ANALYSIS COMMON VARIANTS','SERPINA1 GENE ANALYSIS COMMON VARIANTS','81332','1','','1','0','','','',0, 1, 0, 0),
(7058,'TRB@ REARRANGEMENT ANAL AMPLIFICATION METHOD','TRB@ REARRANGEMENT ANAL AMPLIFICATION METHOD','81340','1','','1','0','','','',0, 1, 0, 0),
(7059,'TRB@ REARRANGEMENT ANAL DIRECT PROBE METHODOLOGY','TRB@ REARRANGEMENT ANAL DIRECT PROBE METHODOLOGY','81341','1','','1','0','','','',0, 1, 0, 0),
(7060,'TRG@ GENE REARRANGEMENT ANALYSIS','TRG@ GENE REARRANGEMENT ANALYSIS','81342','1','','1','0','','','',0, 1, 0, 0),
(7061,'UGT1A1 GENE ANALYSIS COMMON VARIANTS','UGT1A1 GENE ANALYSIS COMMON VARIANTS','81350','1','','1','0','','','',0, 1, 0, 0),
(7062,'VKORC1 GENE ANALYSIS COMMON VARIANT(S)','VKORC1 GENE ANALYSIS COMMON VARIANT(S)','81355','1','','1','0','','','',0, 1, 0, 0),
(7063,'HLA CLASS I&II LOW HLA-A -B -C -DRB1/3/4/5&DQB','HLA CLASS I&II LOW HLA-A -B -C -DRB1/3/4/5&DQB','81370','1','','1','0','','','',0, 1, 0, 0),
(7064,'HLA I&LI LOW RESOLUTION HLA-A -B&-DRB1','HLA I&LI LOW RESOLUTION HLA-A -B&-DRB1','81371','1','','1','0','','','',0, 1, 0, 0),
(7065,'HLA CLASS I TYPING LOW RESOLUTION COMPLETE','HLA CLASS I TYPING LOW RESOLUTION COMPLETE','81372','1','','1','0','','','',0, 1, 0, 0),
(7066,'HLA CLASS I TYPING LOW RESOLUTION ONE LOCUS EACH','HLA CLASS I TYPING LOW RESOLUTION ONE LOCUS EACH','81373','1','','1','0','','','',0, 1, 0, 0),
(7067,'HLA I LOW RESOLUTION ONE ANTIGEN EQUIVALENT EACH','HLA I LOW RESOLUTION ONE ANTIGEN EQUIVALENT EACH','81374','1','','1','0','','','',0, 1, 0, 0),
(7068,'HLA II LOW RESOLUTION HLA-DRB1/3/4/5 AND -DQB1','HLA II LOW RESOLUTION HLA-DRB1/3/4/5 AND -DQB1','81375','1','','1','0','','','',0, 1, 0, 0),
(7069,'HLA CLASS II TYPING LOW RESOLUTION ONE LOCUS EA','HLA CLASS II TYPING LOW RESOLUTION ONE LOCUS EA','81376','1','','1','0','','','',0, 1, 0, 0),
(7070,'HLA II LOW RESOLUTION ONE ANTIGEN EQUIVALENT EA','HLA II LOW RESOLUTION ONE ANTIGEN EQUIVALENT EA','81377','1','','1','0','','','',0, 1, 0, 0),
(7071,'HLA I&II HIGH RESOLUTION HLA-A -B -C AND -DRB1','HLA I&II HIGH RESOLUTION HLA-A -B -C AND -DRB1','81378','1','','1','0','','','',0, 1, 0, 0),
(7072,'HLA CLASS I TYPING HIGH RESOLUTION COMPLETE','HLA CLASS I TYPING HIGH RESOLUTION COMPLETE','81379','1','','1','0','','','',0, 1, 0, 0),
(7073,'HLA CLASS I TYPING HIGH RESOLUTION ONE LOCUS EA','HLA CLASS I TYPING HIGH RESOLUTION ONE LOCUS EA','81380','1','','1','0','','','',0, 1, 0, 0),
(7074,'HLA I TYPING HIGH RESOLUTION 1 ALLELE/ALLELE GRP','HLA I TYPING HIGH RESOLUTION 1 ALLELE/ALLELE GRP','81381','1','','1','0','','','',0, 1, 0, 0),
(7075,'HLA CLASS II TYPING HIGH RESOLUTION ONE LOCUS EA','HLA CLASS II TYPING HIGH RESOLUTION ONE LOCUS EA','81382','1','','1','0','','','',0, 1, 0, 0),
(7076,'HLA II HIGH RESOLUTION 1 ALLELE/ALLELE GROUP','HLA II HIGH RESOLUTION 1 ALLELE/ALLELE GROUP','81383','1','','1','0','','','',0, 1, 0, 0),
(7077,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 1','MOLECULAR PATHOLOGY PROCEDURE LEVEL 1','81400','1','','1','0','','','',0, 1, 0, 0),
(7078,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 2','MOLECULAR PATHOLOGY PROCEDURE LEVEL 2','81401','1','','1','0','','','',0, 1, 0, 0),
(7079,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 3','MOLECULAR PATHOLOGY PROCEDURE LEVEL 3','81402','1','','1','0','','','',0, 1, 0, 0),
(7080,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 4','MOLECULAR PATHOLOGY PROCEDURE LEVEL 4','81403','1','','1','0','','','',0, 1, 0, 0),
(7081,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 5','MOLECULAR PATHOLOGY PROCEDURE LEVEL 5','81404','1','','1','0','','','',0, 1, 0, 0),
(7082,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 6','MOLECULAR PATHOLOGY PROCEDURE LEVEL 6','81405','1','','1','0','','','',0, 1, 0, 0),
(7083,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 7','MOLECULAR PATHOLOGY PROCEDURE LEVEL 7','81406','1','','1','0','','','',0, 1, 0, 0),
(7084,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 8','MOLECULAR PATHOLOGY PROCEDURE LEVEL 8','81407','1','','1','0','','','',0, 1, 0, 0),
(7085,'MOLECULAR PATHOLOGY PROCEDURE LEVEL 9','MOLECULAR PATHOLOGY PROCEDURE LEVEL 9','81408','1','','1','0','','','',0, 1, 0, 0),
(7086,'AORTIC DYSFUNCTION/DILATION GENOMIC SEQ ANALYSIS','AORTIC DYSFUNCTION/DILATION GENOMIC SEQ ANALYSIS','81410','1','','1','0','','','',0, 1, 0, 0),
(7087,'AORTIC DYSFUNCTION/DILATION DUP/DEL ANALYSIS','AORTIC DYSFUNCTION/DILATION DUP/DEL ANALYSIS','81411','1','','1','0','','','',0, 1, 0, 0),
(7088,'ASHKENAZI JEWISH ASSOC DSRDRS GEN SEQ ANAL 9 GEN','ASHKENAZI JEWISH ASSOC DSRDRS GEN SEQ ANAL 9 GEN','81412','1','','1','0','','','',0, 1, 0, 0),
(7089,'EXOME SEQUENCE ANALYSIS','EXOME SEQUENCE ANALYSIS','81415','1','','1','0','','','',0, 1, 0, 0),
(7090,'EXOME SEQUENCE ANALYSIS EACH COMPARATOR EXOME','EXOME SEQUENCE ANALYSIS EACH COMPARATOR EXOME','81416','1','','1','0','','','',0, 1, 0, 0),
(7091,'EXOME RE-EVAL OF PREVIOUSLY OBTAINED EXOME SEQ','EXOME RE-EVAL OF PREVIOUSLY OBTAINED EXOME SEQ','81417','1','','1','0','','','',0, 1, 0, 0),
(7092,'FETAL CHROMOSOMAL ANEUPLOIDY GENOMIC SEQ ANALYS','FETAL CHROMOSOMAL ANEUPLOIDY GENOMIC SEQ ANALYS','81420','1','','1','0','','','',0, 1, 0, 0),
(7093,'GENOME SEQUENCE ANALYSIS','GENOME SEQUENCE ANALYSIS','81425','1','','1','0','','','',0, 1, 0, 0),
(7094,'GENOME SEQUENCE ANALYSIS EACH COMPARATOR GENOME','GENOME SEQUENCE ANALYSIS EACH COMPARATOR GENOME','81426','1','','1','0','','','',0, 1, 0, 0),
(7095,'GENOME RE-EVALUATION OF PREC OBTAINED GENOME SEQ','GENOME RE-EVALUATION OF PREC OBTAINED GENOME SEQ','81427','1','','1','0','','','',0, 1, 0, 0),
(7096,'HEARING LOSS GENOMIC SEQUENCE ANALYSIS 60 GENES','HEARING LOSS GENOMIC SEQUENCE ANALYSIS 60 GENES','81430','1','','1','0','','','',0, 1, 0, 0),
(7097,'HEARING LOSS DUP/DEL ANALYSIS','HEARING LOSS DUP/DEL ANALYSIS','81431','1','','1','0','','','',0, 1, 0, 0),
(7098,'HEREDITARY BRST CA-RELATED GEN SEQ ANALYS 14 GEN','HEREDITARY BRST CA-RELATED GEN SEQ ANALYS 14 GEN','81432','1','','1','0','','','',0, 1, 0, 0),
(7099,'HEREDITARY BRST CA-RELATED DUP/DEL ANALYSIS','HEREDITARY BRST CA-RELATED DUP/DEL ANALYSIS','81433','1','','1','0','','','',0, 1, 0, 0),
(7100,'HEREDITARY RETINAL DSRDRS GEN SEQ ANALYS 15 GEN','HEREDITARY RETINAL DSRDRS GEN SEQ ANALYS 15 GEN','81434','1','','1','0','','','',0, 1, 0, 0),
(7101,'HEREDITARY COLON CA DSRDRS GEN SEQ ANALYS 10 GEN','HEREDITARY COLON CA DSRDRS GEN SEQ ANALYS 10 GEN','81435','1','','1','0','','','',0, 1, 0, 0),
(7102,'HEREDITARY COLON CA DSRDRS DUP/DEL ANALYS 5 GEN','HEREDITARY COLON CA DSRDRS DUP/DEL ANALYS 5 GEN','81436','1','','1','0','','','',0, 1, 0, 0),
(7103,'HEREDTRY NURONDCRN TUM DSRDRS GEN SEQ ANAL 6 GEN','HEREDTRY NURONDCRN TUM DSRDRS GEN SEQ ANAL 6 GEN','81437','1','','1','0','','','',0, 1, 0, 0),
(7104,'HEREDTRY NURONDCRN TUM DSRDRS DUP/DEL ANALYSIS','HEREDTRY NURONDCRN TUM DSRDRS DUP/DEL ANALYSIS','81438','1','','1','0','','','',0, 1, 0, 0),
(7105,'NUCLEAR MITOCHONDRIAL 100 GENE GENOMIC SEQ','NUCLEAR MITOCHONDRIAL 100 GENE GENOMIC SEQ','81440','1','','1','0','','','',0, 1, 0, 0),
(7106,'NOONAN SPECTRUM DISORDERS GEN SEQ ANALYS 12 GEN','NOONAN SPECTRUM DISORDERS GEN SEQ ANALYS 12 GEN','81442','1','','1','0','','','',0, 1, 0, 0),
(7107,'GEN SEQ ANALYS SOLID ORGAN NEOPLASM 5-50 GENE','GEN SEQ ANALYS SOLID ORGAN NEOPLASM 5-50 GENE','81445','1','','1','0','','','',0, 1, 0, 0),
(7108,'GEN SEQ ANALYS HEMATOLYMPHOID NEO 5-50 GENE','GEN SEQ ANALYS HEMATOLYMPHOID NEO 5-50 GENE','81450','1','','1','0','','','',0, 1, 0, 0),
(7109,'GEN SEQ ANALYS SOL ORG/HEMTOLMPHOID NEO 51/> GEN','GEN SEQ ANALYS SOL ORG/HEMTOLMPHOID NEO 51/> GEN','81455','1','','1','0','','','',0, 1, 0, 0),
(7110,'WHOLE MITOCHONDRIAL GENOME','WHOLE MITOCHONDRIAL GENOME','81460','1','','1','0','','','',0, 1, 0, 0),
(7111,'WHOLE MITOCHONDRIAL GENOME ANALYSIS PANEL','WHOLE MITOCHONDRIAL GENOME ANALYSIS PANEL','81465','1','','1','0','','','',0, 1, 0, 0),
(7112,'X-LINKED INTELLECTUAL DBLT GENOMIC SEQ ANALYS','X-LINKED INTELLECTUAL DBLT GENOMIC SEQ ANALYS','81470','1','','1','0','','','',0, 1, 0, 0),
(7113,'X-LINKED INTELLECTUAL DBLT DUP/DEL GENE ANALYS','X-LINKED INTELLECTUAL DBLT DUP/DEL GENE ANALYS','81471','1','','1','0','','','',0, 1, 0, 0),
(7114,'UNLISTED MOLELCULAR PATHOLOGY PROCEDURE','UNLISTED MOLELCULAR PATHOLOGY PROCEDURE','81479','1','','1','0','','','',0, 1, 0, 0),
(7115,'AUTOIMMUNE RHEUMATOID ARTHRTS ANALYS 12 BIOMRKRS','AUTOIMMUNE RHEUMATOID ARTHRTS ANALYS 12 BIOMRKRS','81490','1','','1','0','','','',0, 1, 0, 0),
(7116,'COR ART DISEASE MRNA GENE EXPRESSION 23 GENES','COR ART DISEASE MRNA GENE EXPRESSION 23 GENES','81493','1','','1','0','','','',0, 1, 0, 0),
(7117,'ONCO (OVARIAN) BIOCHEMICAL ASSAY TWO PROTEINS','ONCO (OVARIAN) BIOCHEMICAL ASSAY TWO PROTEINS','81500','1','','1','0','','','',0, 1, 0, 0),
(7118,'ONCO (OVARIAN) BIOCHEMICAL ASSAY FIVE PROTEINS','ONCO (OVARIAN) BIOCHEMICAL ASSAY FIVE PROTEINS','81503','1','','1','0','','','',0, 1, 0, 0),
(7119,'ONCOLOGY TISSUE OF ORIGIN SIMILAR SCOR ALGORITHM','ONCOLOGY TISSUE OF ORIGIN SIMILAR SCOR ALGORITHM','81504','1','','1','0','','','',0, 1, 0, 0),
(7120,'ENDOCRINOLOGY BIOCHEMICAL ASSAY SEVEN ANAL','ENDOCRINOLOGY BIOCHEMICAL ASSAY SEVEN ANAL','81506','1','','1','0','','','',0, 1, 0, 0),
(7121,'FETAL ANEUPLOIDY 21 18 13 SEQ ANALY TRISOM RISK','FETAL ANEUPLOIDY 21 18 13 SEQ ANALY TRISOM RISK','81507','1','','1','0','','','',0, 1, 0, 0),
(7122,'FETAL CONGENITAL ABNOR ASSAY TWO PROTEINS','FETAL CONGENITAL ABNOR ASSAY TWO PROTEINS','81508','1','','1','0','','','',0, 1, 0, 0),
(7123,'FETAL CONGENITAL ABNOR ASSAY 3 PROTEINS','FETAL CONGENITAL ABNOR ASSAY 3 PROTEINS','81509','1','','1','0','','','',0, 1, 0, 0),
(7124,'FETAL CONGENITAL ABNOR ASSAY THREE ANAL','FETAL CONGENITAL ABNOR ASSAY THREE ANAL','81510','1','','1','0','','','',0, 1, 0, 0),
(7125,'FETAL CONGENITAL ABNOR ASSAY FOUR ANAL','FETAL CONGENITAL ABNOR ASSAY FOUR ANAL','81511','1','','1','0','','','',0, 1, 0, 0),
(7126,'FETAL CONGENITAL ABNOR ASSAY FIVE ANAL','FETAL CONGENITAL ABNOR ASSAY FIVE ANAL','81512','1','','1','0','','','',0, 1, 0, 0),
(7127,'ONCOLOGY BREAST MRNA GENE EXPRESSION 21 GENES','ONCOLOGY BREAST MRNA GENE EXPRESSION 21 GENES','81519','1','','1','0','','','',0, 1, 0, 0),
(7128,'ONCOLOGY COLON MRNA GENE EXPRESSION 12 GENES','ONCOLOGY COLON MRNA GENE EXPRESSION 12 GENES','81525','1','','1','0','','','',0, 1, 0, 0),
(7129,'ONCOLOGY COLORECTAL SCREENING QUAN 10 DNA MARKRS','ONCOLOGY COLORECTAL SCREENING QUAN 10 DNA MARKRS','81528','1','','1','0','','','',0, 1, 0, 0),
(7130,'ONCOLOGY GYNE LIVE TUM CELL CLTR&CHEMO RESP 1ST','ONCOLOGY GYNE LIVE TUM CELL CLTR&CHEMO RESP 1ST','81535','1','','1','0','','','',0, 1, 0, 0),
(7131,'ONCOLOGY GYNE LIVE TUM CELL CLTR&CHEMO RESP ADD','ONCOLOGY GYNE LIVE TUM CELL CLTR&CHEMO RESP ADD','81536','1','','1','0','','','',0, 1, 0, 0),
(7132,'ONCOLOGY LUNG MS 8-PROTEIN SIGNATURE','ONCOLOGY LUNG MS 8-PROTEIN SIGNATURE','81538','1','','1','0','','','',0, 1, 0, 0),
(7133,'ONCOLOGY TUM UNKNOWN ORIGIN MRNA 92 GENES','ONCOLOGY TUM UNKNOWN ORIGIN MRNA 92 GENES','81540','1','','1','0','','','',0, 1, 0, 0),
(7134,'ONCOLOGY THYROID GENE EXPRESSION 142 GENES','ONCOLOGY THYROID GENE EXPRESSION 142 GENES','81545','1','','1','0','','','',0, 1, 0, 0),
(7135,'CARDIOLOGY HRT TRNSPL MRNA GENE EXPRESS 20 GENES','CARDIOLOGY HRT TRNSPL MRNA GENE EXPRESS 20 GENES','81595','1','','1','0','','','',0, 1, 0, 0),
(7136,'UNLISTED MULTIANALYTE ASSAY ALGORITHMIC ANALYSIS','UNLISTED MULTIANALYTE ASSAY ALGORITHMIC ANALYSIS','81599','1','','1','0','','','',0, 1, 0, 0),
(7137,'KETONE BODIES SERUM QUALITATIVE','KETONE BODIES SERUM QUALITATIVE','82009','1','','1','0','','','',0, 1, 0, 0),
(7138,'KETONE BODIES SERUM QUANTITATIVE','KETONE BODIES SERUM QUANTITATIVE','82010','1','','1','0','','','',0, 1, 0, 0),
(7139,'ASSAY OF ACETYLCHOLINESTERASE','ASSAY OF ACETYLCHOLINESTERASE','82013','1','','1','0','','','',0, 1, 0, 0),
(7140,'ACYLCARNITINES QUALITATIVE EACH SPECIMEN','ACYLCARNITINES QUALITATIVE EACH SPECIMEN','82016','1','','1','0','','','',0, 1, 0, 0),
(7141,'ACYLCARNITINES QUANTIATIVE EACH SPECIMEN','ACYLCARNITINES QUANTIATIVE EACH SPECIMEN','82017','1','','1','0','','','',0, 1, 0, 0),
(7142,'ADRENOCORTICOTROPIC HORMONE ACTH','ADRENOCORTICOTROPIC HORMONE ACTH','82024','1','','1','0','','','',0, 1, 0, 0),
(7143,'ADENOSINE 5-MONOPHOSPHATE CYCLIC','ADENOSINE 5-MONOPHOSPHATE CYCLIC','82030','1','','1','0','','','',0, 1, 0, 0),
(7144,'ALBUMIN SERUM PLASMA/WHOLE BLOOD','ALBUMIN SERUM PLASMA/WHOLE BLOOD','82040','1','','1','0','','','',0, 1, 0, 0),
(7145,'ALBUMIN URINE/OTHER SOURCE QUAN EACH SPECIMEN','ALBUMIN URINE/OTHER SOURCE QUAN EACH SPECIMEN','82042','1','','1','0','','','',0, 1, 0, 0),
(7146,'ALBUMIN URINE MICROALBUMIN QUANTIATIVE','ALBUMIN URINE MICROALBUMIN QUANTIATIVE','82043','1','','1','0','','','',0, 1, 0, 0),
(7147,'ALBUMIN URINE MICROALBUMIN SEMIQUANTITATIVE','ALBUMIN URINE MICROALBUMIN SEMIQUANTITATIVE','82044','1','','1','0','','','',0, 1, 0, 0),
(7148,'ALBUMIN ISCHEMIA MODIFIED','ALBUMIN ISCHEMIA MODIFIED','82045','1','','1','0','','','',0, 1, 0, 0),
(7149,'ASSAY OF ALCOHOL BREATH','ASSAY OF ALCOHOL BREATH','82075','1','','1','0','','','',0, 1, 0, 0),
(7150,'ASSAY OF ALDOLASE','ASSAY OF ALDOLASE','82085','1','','1','0','','','',0, 1, 0, 0),
(7151,'ASSAY OF ALDOSTERONE','ASSAY OF ALDOSTERONE','82088','1','','1','0','','','',0, 1, 0, 0),
(7152,'ALPHA-1-ANTITRYPSIN TOTAL','ALPHA-1-ANTITRYPSIN TOTAL','82103','1','','1','0','','','',0, 1, 0, 0),
(7153,'ALPHA-1-ANTITRYPSIN PHENOTYPE','ALPHA-1-ANTITRYPSIN PHENOTYPE','82104','1','','1','0','','','',0, 1, 0, 0),
(7154,'ALPHA-FETOPROTEIN SERUM','ALPHA-FETOPROTEIN SERUM','82105','1','','1','0','','','',0, 1, 0, 0),
(7155,'ALPHA-FETOPROTEIN AMNIOTIC FLUID','ALPHA-FETOPROTEIN AMNIOTIC FLUID','82106','1','','1','0','','','',0, 1, 0, 0),
(7156,'AFP-L3 FRACTION ISOFORM & TOTAL AFP W/RATIO','AFP-L3 FRACTION ISOFORM & TOTAL AFP W/RATIO','82107','1','','1','0','','','',0, 1, 0, 0),
(7157,'ASSAY OF ALUMINUM','ASSAY OF ALUMINUM','82108','1','','1','0','','','',0, 1, 0, 0),
(7158,'AMINES VAGINAL FLUID QUALITATIVE','AMINES VAGINAL FLUID QUALITATIVE','82120','1','','1','0','','','',0, 1, 0, 0),
(7159,'AMINO ACIDS 1 QUALITATIVE EACH SPECIMEN','AMINO ACIDS 1 QUALITATIVE EACH SPECIMEN','82127','1','','1','0','','','',0, 1, 0, 0),
(7160,'AMINO ACIDS MULTIPLE QUALITATIVE EACH SPECIMEN','AMINO ACIDS MULTIPLE QUALITATIVE EACH SPECIMEN','82128','1','','1','0','','','',0, 1, 0, 0),
(7161,'AMINO ACIDS 1 QUANTITATIVE EACH SPECIMEN','AMINO ACIDS 1 QUANTITATIVE EACH SPECIMEN','82131','1','','1','0','','','',0, 1, 0, 0),
(7162,'AMINOLEVULINIC ACID DELTA','AMINOLEVULINIC ACID DELTA','82135','1','','1','0','','','',0, 1, 0, 0),
(7163,'AMINO ACIDS 2-5 AMINO ACIDS QUANTITATIVE EA SPEC','AMINO ACIDS 2-5 AMINO ACIDS QUANTITATIVE EA SPEC','82136','1','','1','0','','','',0, 1, 0, 0),
(7164,'AMINO ACIDS 6/> AMINO ACIDS QUANTITATIVE EA SPE','AMINO ACIDS 6/> AMINO ACIDS QUANTITATIVE EA SPE','82139','1','','1','0','','','',0, 1, 0, 0),
(7165,'ASSAY OF AMMONIA','ASSAY OF AMMONIA','82140','1','','1','0','','','',0, 1, 0, 0),
(7166,'AMNIOTIC FLU SCAN','AMNIOTIC FLU SCAN','82143','1','','1','0','','','',0, 1, 0, 0),
(7167,'ASSAY OF AMYLASE','ASSAY OF AMYLASE','82150','1','','1','0','','','',0, 1, 0, 0),
(7168,'ANDROSTANEDIOL GLUCURONIDE','ANDROSTANEDIOL GLUCURONIDE','82154','1','','1','0','','','',0, 1, 0, 0),
(7169,'ANDROSTENEDIONE','ANDROSTENEDIONE','82157','1','','1','0','','','',0, 1, 0, 0),
(7170,'ANDROSTERONE','ANDROSTERONE','82160','1','','1','0','','','',0, 1, 0, 0),
(7171,'ANGIOTENSIN II','ANGIOTENSIN II','82163','1','','1','0','','','',0, 1, 0, 0),
(7172,'ANGIOTENSIN I-CONVERTING ENZYME','ANGIOTENSIN I-CONVERTING ENZYME','82164','1','','1','0','','','',0, 1, 0, 0),
(7173,'APOLIPOPROTEIN EACH','APOLIPOPROTEIN EACH','82172','1','','1','0','','','',0, 1, 0, 0),
(7174,'ASSAY OF ARSENIC','ASSAY OF ARSENIC','82175','1','','1','0','','','',0, 1, 0, 0),
(7175,'ASSAY OF ASCORBIC ACID BLOOD','ASSAY OF ASCORBIC ACID BLOOD','82180','1','','1','0','','','',0, 1, 0, 0),
(7176,'ATOMIC ABSRPJ SPECTROSCOPY EA ANALYTE','ATOMIC ABSRPJ SPECTROSCOPY EA ANALYTE','82190','1','','1','0','','','',0, 1, 0, 0),
(7177,'BETA-2 MICROGLOBULIN','BETA-2 MICROGLOBULIN','82232','1','','1','0','','','',0, 1, 0, 0),
(7178,'BILE ACIDS TOTAL','BILE ACIDS TOTAL','82239','1','','1','0','','','',0, 1, 0, 0),
(7179,'BILE ACIDS CHOLYLGLYCINE','BILE ACIDS CHOLYLGLYCINE','82240','1','','1','0','','','',0, 1, 0, 0),
(7180,'BILIRUBIN TOTAL','BILIRUBIN TOTAL','82247','1','','1','0','','','',0, 1, 0, 0),
(7181,'BILIRUBIN DIRECT','BILIRUBIN DIRECT','82248','1','','1','0','','','',0, 1, 0, 0),
(7182,'BILIRUBIN FECES QUALITATIVE','BILIRUBIN FECES QUALITATIVE','82252','1','','1','0','','','',0, 1, 0, 0),
(7183,'BIOTINIDASE EACH SPECIMEN','BIOTINIDASE EACH SPECIMEN','82261','1','','1','0','','','',0, 1, 0, 0),
(7184,'BLOOD OCCULT PEROXIDASE ACTV QUAL FECES 1 DETER','BLOOD OCCULT PEROXIDASE ACTV QUAL FECES 1 DETER','82270','1','','1','0','','','',0, 1, 0, 0),
(7185,'BLOOD OCCULT PEROXIDASE ACTV QUAL OTHER SOURCES','BLOOD OCCULT PEROXIDASE ACTV QUAL OTHER SOURCES','82271','1','','1','0','','','',0, 1, 0, 0),
(7186,'BLOOD OCCULT PEROXIDASE ACTV QUAL FECES 1-3 SPEC','BLOOD OCCULT PEROXIDASE ACTV QUAL FECES 1-3 SPEC','82272','1','','1','0','','','',0, 1, 0, 0),
(7187,'BLOOD OCCULT FECAL HGB DETER IA QUAL FECES 1-3','BLOOD OCCULT FECAL HGB DETER IA QUAL FECES 1-3','82274','1','','1','0','','','',0, 1, 0, 0),
(7188,'BRADYKININ','BRADYKININ','82286','1','','1','0','','','',0, 1, 0, 0),
(7189,'CADMIUM','CADMIUM','82300','1','','1','0','','','',0, 1, 0, 0),
(7190,'25 HYDROXY INCLUDES FRACTIONS IF PERFORMED','25 HYDROXY INCLUDES FRACTIONS IF PERFORMED','82306','1','','1','0','','','',0, 1, 0, 0),
(7191,'CALCITONIN','CALCITONIN','82308','1','','1','0','','','',0, 1, 0, 0),
(7192,'CALCIUM TOTAL','CALCIUM TOTAL','82310','1','','1','0','','','',0, 1, 0, 0),
(7193,'CALCIUM IONIZED','CALCIUM IONIZED','82330','1','','1','0','','','',0, 1, 0, 0),
(7194,'CALCIUM AFTER CALCIUM INFUSION TEST','CALCIUM AFTER CALCIUM INFUSION TEST','82331','1','','1','0','','','',0, 1, 0, 0),
(7195,'CALCIUM URINE QUANTITATIVE TIMED SPECIMEN','CALCIUM URINE QUANTITATIVE TIMED SPECIMEN','82340','1','','1','0','','','',0, 1, 0, 0),
(7196,'CALCULUS QUALITATIVE ANALYSIS','CALCULUS QUALITATIVE ANALYSIS','82355','1','','1','0','','','',0, 1, 0, 0),
(7197,'CALCULUS QUANTITATIVE CHEMICAL','CALCULUS QUANTITATIVE CHEMICAL','82360','1','','1','0','','','',0, 1, 0, 0),
(7198,'CALCULUS INFRARED SPECTROSCOPY','CALCULUS INFRARED SPECTROSCOPY','82365','1','','1','0','','','',0, 1, 0, 0),
(7199,'CALCULUS XRAY DIFFRACTION','CALCULUS XRAY DIFFRACTION','82370','1','','1','0','','','',0, 1, 0, 0),
(7200,'CARBOHYDRATE DEFICIENT TRANSFERRIN','CARBOHYDRATE DEFICIENT TRANSFERRIN','82373','1','','1','0','','','',0, 1, 0, 0),
(7201,'CARBON DIOXIDE BICARBONATE','CARBON DIOXIDE BICARBONATE','82374','1','','1','0','','','',0, 1, 0, 0),
(7202,'CARBOXYHEMOGLOBIN QUANTITATIVE','CARBOXYHEMOGLOBIN QUANTITATIVE','82375','1','','1','0','','','',0, 1, 0, 0),
(7203,'CARBOXYHEMOGLOBIN QUALITATIVE','CARBOXYHEMOGLOBIN QUALITATIVE','82376','1','','1','0','','','',0, 1, 0, 0),
(7204,'CARCINOEMBRYONIC ANTIGEN CEA','CARCINOEMBRYONIC ANTIGEN CEA','82378','1','','1','0','','','',0, 1, 0, 0),
(7205,'CARNITINE QUANTITATIVE EACH SPECIMEN','CARNITINE QUANTITATIVE EACH SPECIMEN','82379','1','','1','0','','','',0, 1, 0, 0),
(7206,'CAROTENE','CAROTENE','82380','1','','1','0','','','',0, 1, 0, 0),
(7207,'CATECHOLAMINES TOTAL URINE','CATECHOLAMINES TOTAL URINE','82382','1','','1','0','','','',0, 1, 0, 0),
(7208,'CATECHOLAMINES BLOOD','CATECHOLAMINES BLOOD','82383','1','','1','0','','','',0, 1, 0, 0),
(7209,'CATECHOLAMINES FRACTIONATED','CATECHOLAMINES FRACTIONATED','82384','1','','1','0','','','',0, 1, 0, 0),
(7210,'CATHEPSIN-D','CATHEPSIN-D','82387','1','','1','0','','','',0, 1, 0, 0),
(7211,'CERULOPLASMIN','CERULOPLASMIN','82390','1','','1','0','','','',0, 1, 0, 0),
(7212,'CHEMILUMINESCENT ASSAY','CHEMILUMINESCENT ASSAY','82397','1','','1','0','','','',0, 1, 0, 0),
(7213,'CHLORAMPHENICOL','CHLORAMPHENICOL','82415','1','','1','0','','','',0, 1, 0, 0),
(7214,'CHLORIDE BLD','CHLORIDE BLD','82435','1','','1','0','','','',0, 1, 0, 0),
(7215,'CHLORIDE URINE','CHLORIDE URINE','82436','1','','1','0','','','',0, 1, 0, 0),
(7216,'CHLORIDE OTHER SOURCE','CHLORIDE OTHER SOURCE','82438','1','','1','0','','','',0, 1, 0, 0),
(7217,'CHLORINATED HYDROCARBONS SCREEN','CHLORINATED HYDROCARBONS SCREEN','82441','1','','1','0','','','',0, 1, 0, 0),
(7218,'CHOLESTEROL SERUM/WHOLE BLOOD TOTAL','CHOLESTEROL SERUM/WHOLE BLOOD TOTAL','82465','1','','1','0','','','',0, 1, 0, 0),
(7219,'CHOLINESTERASE SERUM','CHOLINESTERASE SERUM','82480','1','','1','0','','','',0, 1, 0, 0),
(7220,'CHOLINESTERASE RBC','CHOLINESTERASE RBC','82482','1','','1','0','','','',0, 1, 0, 0),
(7221,'CHONDROITIN B SULFATE QUANTITATIVE','CHONDROITIN B SULFATE QUANTITATIVE','82485','1','','1','0','','','',0, 1, 0, 0),
(7222,'ASSAY OF CHROMIUM','ASSAY OF CHROMIUM','82495','1','','1','0','','','',0, 1, 0, 0),
(7223,'ASSAY OF CITRATE','ASSAY OF CITRATE','82507','1','','1','0','','','',0, 1, 0, 0),
(7224,'COLLAGEN CROSS LINKS ANY METHOD','COLLAGEN CROSS LINKS ANY METHOD','82523','1','','1','0','','','',0, 1, 0, 0),
(7225,'ASSAY OF COPPER','ASSAY OF COPPER','82525','1','','1','0','','','',0, 1, 0, 0),
(7226,'CORTICOSTERONE','CORTICOSTERONE','82528','1','','1','0','','','',0, 1, 0, 0),
(7227,'CORTISOL FREE','CORTISOL FREE','82530','1','','1','0','','','',0, 1, 0, 0),
(7228,'CORTISOL TOTAL','CORTISOL TOTAL','82533','1','','1','0','','','',0, 1, 0, 0),
(7229,'ASSAY OF CREATINE','ASSAY OF CREATINE','82540','1','','1','0','','','',0, 1, 0, 0),
(7230,'COL-CHR/MS NONDRUG ANALYTE NES QUAL/QUAN EA SPEC','COL-CHR/MS NONDRUG ANALYTE NES QUAL/QUAN EA SPEC','82542','1','','1','0','','','',0, 1, 0, 0),
(7231,'CREATINE KINASE TOTAL','CREATINE KINASE TOTAL','82550','1','','1','0','','','',0, 1, 0, 0),
(7232,'CREATINE KINASE ISOENZYMES','CREATINE KINASE ISOENZYMES','82552','1','','1','0','','','',0, 1, 0, 0),
(7233,'CREATINE KINASE MB FRACTION ONLY','CREATINE KINASE MB FRACTION ONLY','82553','1','','1','0','','','',0, 1, 0, 0),
(7234,'CREATINE KINASE ISOFORMS','CREATINE KINASE ISOFORMS','82554','1','','1','0','','','',0, 1, 0, 0),
(7235,'CREATININE BLOOD','CREATININE BLOOD','82565','1','','1','0','','','',0, 1, 0, 0),
(7236,'CREATININE OTHER SOURCE','CREATININE OTHER SOURCE','82570','1','','1','0','','','',0, 1, 0, 0),
(7237,'CREATININE CLEARANCE','CREATININE CLEARANCE','82575','1','','1','0','','','',0, 1, 0, 0),
(7238,'ASSAY OF CRYOFIBRN','ASSAY OF CRYOFIBRN','82585','1','','1','0','','','',0, 1, 0, 0),
(7239,'CRYOGLOBULIN QUALITATIVE/SEMI-QUANTITATIVE','CRYOGLOBULIN QUALITATIVE/SEMI-QUANTITATIVE','82595','1','','1','0','','','',0, 1, 0, 0),
(7240,'ASSAY OF CYANIDE','ASSAY OF CYANIDE','82600','1','','1','0','','','',0, 1, 0, 0),
(7241,'CYANOCOBALAMIN VITAMIN B-12','CYANOCOBALAMIN VITAMIN B-12','82607','1','','1','0','','','',0, 1, 0, 0),
(7242,'CYANOCOBALAMIN VIT B-12 UNSAT BINDING CAPACITY','CYANOCOBALAMIN VIT B-12 UNSAT BINDING CAPACITY','82608','1','','1','0','','','',0, 1, 0, 0),
(7243,'CYSTATIN C','CYSTATIN C','82610','1','','1','0','','','',0, 1, 0, 0),
(7244,'CSTINE&HOMOCSTINE URINE QUALITATIVE','CSTINE&HOMOCSTINE URINE QUALITATIVE','82615','1','','1','0','','','',0, 1, 0, 0),
(7245,'DEHYDROEPIANDROSTERONE','DEHYDROEPIANDROSTERONE','82626','1','','1','0','','','',0, 1, 0, 0),
(7246,'DEHYDROEPIANDROSTERONE-SULFATE','DEHYDROEPIANDROSTERONE-SULFATE','82627','1','','1','0','','','',0, 1, 0, 0),
(7247,'DESOXYCORTICOSTERONE 11-','DESOXYCORTICOSTERONE 11-','82633','1','','1','0','','','',0, 1, 0, 0),
(7248,'DEOXYCORTISOL 11-','DEOXYCORTISOL 11-','82634','1','','1','0','','','',0, 1, 0, 0),
(7249,'ASSAY OF DIBUCAINE NUMBER','ASSAY OF DIBUCAINE NUMBER','82638','1','','1','0','','','',0, 1, 0, 0),
(7250,'1 25 DIHYDROXY INCLUDES FRACTIONS IF PERFORMED','1 25 DIHYDROXY INCLUDES FRACTIONS IF PERFORMED','82652','1','','1','0','','','',0, 1, 0, 0),
(7251,'ELASTASE PANCREATIC FECAL QUAL/SEMI-QUAN','ELASTASE PANCREATIC FECAL QUAL/SEMI-QUAN','82656','1','','1','0','','','',0, 1, 0, 0),
(7252,'NZYM ACTIV BLD CELLS/TISS NONRADACT SUBSTRATE EA','NZYM ACTIV BLD CELLS/TISS NONRADACT SUBSTRATE EA','82657','1','','1','0','','','',0, 1, 0, 0),
(7253,'NZYM ACTV BLOOD CELLS/TISS RADACT SUBSTRATE EA','NZYM ACTV BLOOD CELLS/TISS RADACT SUBSTRATE EA','82658','1','','1','0','','','',0, 1, 0, 0),
(7254,'ELCTROPHORETIC TECHNIQUE NOT ELSEWHERE SPECIFIED','ELCTROPHORETIC TECHNIQUE NOT ELSEWHERE SPECIFIED','82664','1','','1','0','','','',0, 1, 0, 0),
(7255,'ASSAY OF ERYTHROPOIETIN','ASSAY OF ERYTHROPOIETIN','82668','1','','1','0','','','',0, 1, 0, 0),
(7256,'ASSAY OF ESTRADIOL','ASSAY OF ESTRADIOL','82670','1','','1','0','','','',0, 1, 0, 0),
(7257,'ASSAY OF ESTROGENS FRACTIONATED','ASSAY OF ESTROGENS FRACTIONATED','82671','1','','1','0','','','',0, 1, 0, 0),
(7258,'ASSAY OF ESTROGENS TOTAL','ASSAY OF ESTROGENS TOTAL','82672','1','','1','0','','','',0, 1, 0, 0),
(7259,'ASSAY OF ESTRIOL','ASSAY OF ESTRIOL','82677','1','','1','0','','','',0, 1, 0, 0),
(7260,'ASSAY OF ESTRONE','ASSAY OF ESTRONE','82679','1','','1','0','','','',0, 1, 0, 0),
(7261,'ASSAY OF ETHYLENE GLYCOL','ASSAY OF ETHYLENE GLYCOL','82693','1','','1','0','','','',0, 1, 0, 0),
(7262,'ASSAY OF ETIOCHOLANOLONE','ASSAY OF ETIOCHOLANOLONE','82696','1','','1','0','','','',0, 1, 0, 0),
(7263,'FAT/LIPIDS FECES QUALITATIVE','FAT/LIPIDS FECES QUALITATIVE','82705','1','','1','0','','','',0, 1, 0, 0),
(7264,'FAT/LIPIDS FECES QUANTITATIVE','FAT/LIPIDS FECES QUANTITATIVE','82710','1','','1','0','','','',0, 1, 0, 0),
(7265,'FAT DIFFIAL FECES QUANTITATIVE','FAT DIFFIAL FECES QUANTITATIVE','82715','1','','1','0','','','',0, 1, 0, 0),
(7266,'FATTY ACIDS NONESTERIFIED','FATTY ACIDS NONESTERIFIED','82725','1','','1','0','','','',0, 1, 0, 0),
(7267,'VERY LONG CHAIN FATTY ACIDS','VERY LONG CHAIN FATTY ACIDS','82726','1','','1','0','','','',0, 1, 0, 0),
(7268,'ASSAY OF FERRITIN','ASSAY OF FERRITIN','82728','1','','1','0','','','',0, 1, 0, 0),
(7269,'FTL FIBRONECTIN CERVICOVAG SECRETIONS SEMI-QUAN','FTL FIBRONECTIN CERVICOVAG SECRETIONS SEMI-QUAN','82731','1','','1','0','','','',0, 1, 0, 0),
(7270,'ASSAY OF FLUORIDE','ASSAY OF FLUORIDE','82735','1','','1','0','','','',0, 1, 0, 0),
(7271,'ASSAY OF FOLIC ACID SERUM','ASSAY OF FOLIC ACID SERUM','82746','1','','1','0','','','',0, 1, 0, 0),
(7272,'ASSAY OF FOLIC ACID RBC','ASSAY OF FOLIC ACID RBC','82747','1','','1','0','','','',0, 1, 0, 0),
(7273,'ASSAY OF FRUCTOSE SEMEN','ASSAY OF FRUCTOSE SEMEN','82757','1','','1','0','','','',0, 1, 0, 0),
(7274,'ASSAY OF GALACTOKINASE RBC','ASSAY OF GALACTOKINASE RBC','82759','1','','1','0','','','',0, 1, 0, 0),
(7275,'ASSAY OF GALACTOSE','ASSAY OF GALACTOSE','82760','1','','1','0','','','',0, 1, 0, 0),
(7276,'GALACTOSE-1-PHOSPHATE URIDYL TRANSFERASE QUAN','GALACTOSE-1-PHOSPHATE URIDYL TRANSFERASE QUAN','82775','1','','1','0','','','',0, 1, 0, 0),
(7277,'GALACTOSE-1-PHOSPHATE URIDYL TRANSFERASE SCREEN','GALACTOSE-1-PHOSPHATE URIDYL TRANSFERASE SCREEN','82776','1','','1','0','','','',0, 1, 0, 0),
(7278,'GALECTIN-3','GALECTIN-3','82777','1','','1','0','','','',0, 1, 0, 0),
(7279,'ASSAY OF GAMMAGLOBULIN IGA IGD IGG IGM EACH','ASSAY OF GAMMAGLOBULIN IGA IGD IGG IGM EACH','82784','1','','1','0','','','',0, 1, 0, 0),
(7280,'ASSAY OF GAMMAGLOBULIN IGE','ASSAY OF GAMMAGLOBULIN IGE','82785','1','','1','0','','','',0, 1, 0, 0),
(7281,'GAMMAGLOBULIN IMMUNOGLOBULIN SUBCLASSES','GAMMAGLOBULIN IMMUNOGLOBULIN SUBCLASSES','82787','1','','1','0','','','',0, 1, 0, 0),
(7282,'GASES BLOOD PH ONLY','GASES BLOOD PH ONLY','82800','1','','1','0','','','',0, 1, 0, 0),
(7283,'BLOOD GASES ANY COMBINATION PH PCO2 PO2 CO2 HCO3','BLOOD GASES ANY COMBINATION PH PCO2 PO2 CO2 HCO3','82803','1','','1','0','','','',0, 1, 0, 0),
(7284,'GASES BLOOD PH DIRECT MEAS XCPT PULSE OXIMITRY','GASES BLOOD PH DIRECT MEAS XCPT PULSE OXIMITRY','82805','1','','1','0','','','',0, 1, 0, 0),
(7285,'GASES BLOOD O2 SATURATION ONLY DIRECT MEAS','GASES BLOOD O2 SATURATION ONLY DIRECT MEAS','82810','1','','1','0','','','',0, 1, 0, 0),
(7286,'HGB-O2 AFFINITY PO2 50% SATURATION OXYGEN','HGB-O2 AFFINITY PO2 50% SATURATION OXYGEN','82820','1','','1','0','','','',0, 1, 0, 0),
(7287,'GASTRIC ACID ANALYIS W/PH EACH SPECIMEN','GASTRIC ACID ANALYIS W/PH EACH SPECIMEN','82930','1','','1','0','','','',0, 1, 0, 0),
(7288,'GASTRIN AFTER SECRETIN STIMULATION','GASTRIN AFTER SECRETIN STIMULATION','82938','1','','1','0','','','',0, 1, 0, 0),
(7289,'ASSAY OF GASTRIN','ASSAY OF GASTRIN','82941','1','','1','0','','','',0, 1, 0, 0),
(7290,'ASSAY OF GLUCAGON','ASSAY OF GLUCAGON','82943','1','','1','0','','','',0, 1, 0, 0),
(7291,'GLUCOSE BODY FLUID OTHER THAN BLOOD','GLUCOSE BODY FLUID OTHER THAN BLOOD','82945','1','','1','0','','','',0, 1, 0, 0),
(7292,'GLUCOSE TOLERANCE TEST','GLUCOSE TOLERANCE TEST','82946','1','','1','0','','','',0, 1, 0, 0),
(7293,'GLUCOSE QUANTITATIVE BLOOD XCPT REAGENT STRIP','GLUCOSE QUANTITATIVE BLOOD XCPT REAGENT STRIP','82947','1','','1','0','','','',0, 1, 0, 0),
(7294,'GLUCOSE BLOOD REAGENT STRIP','GLUCOSE BLOOD REAGENT STRIP','82948','1','','1','0','','','',0, 1, 0, 0),
(7295,'GLUCOSE POST GLUCOSE DOSE','GLUCOSE POST GLUCOSE DOSE','82950','1','','1','0','','','',0, 1, 0, 0),
(7296,'GLUCOSE TOLERANCE TEST GTT 3 SPECIMENS','GLUCOSE TOLERANCE TEST GTT 3 SPECIMENS','82951','1','','1','0','','','',0, 1, 0, 0),
(7297,'GLUCOSE TOLERANCE EA ADDL BEYOND 3 SPECIMENS','GLUCOSE TOLERANCE EA ADDL BEYOND 3 SPECIMENS','82952','1','','1','0','','','',0, 1, 0, 0),
(7298,'GLUC-6-PHOSPHATE DEHYDROGENASE QUANTITATIVE','GLUC-6-PHOSPHATE DEHYDROGENASE QUANTITATIVE','82955','1','','1','0','','','',0, 1, 0, 0),
(7299,'GLUC-6-PHOSPHATE DEHYDROGENASE SCREEN','GLUC-6-PHOSPHATE DEHYDROGENASE SCREEN','82960','1','','1','0','','','',0, 1, 0, 0),
(7300,'GLUC BLD GLUC MNTR DEV CLEARED FDA SPEC HOME USE','GLUC BLD GLUC MNTR DEV CLEARED FDA SPEC HOME USE','82962','1','','1','0','','','',0, 1, 0, 0),
(7301,'ASSAY OF GLUCOSIDASE BETA','ASSAY OF GLUCOSIDASE BETA','82963','1','','1','0','','','',0, 1, 0, 0),
(7302,'ASSAY OF GLUTAMATE DEHYDROGENASE','ASSAY OF GLUTAMATE DEHYDROGENASE','82965','1','','1','0','','','',0, 1, 0, 0),
(7303,'ASSAY OF GLUTAMYLTRASE GAMMA','ASSAY OF GLUTAMYLTRASE GAMMA','82977','1','','1','0','','','',0, 1, 0, 0),
(7304,'ASSAY OF GLUTATHIONE','ASSAY OF GLUTATHIONE','82978','1','','1','0','','','',0, 1, 0, 0),
(7305,'ASSAY OF GLUTATHIONE REDUCTASE RBC','ASSAY OF GLUTATHIONE REDUCTASE RBC','82979','1','','1','0','','','',0, 1, 0, 0),
(7306,'ASSAY OF GLYCATED PROTEIN','ASSAY OF GLYCATED PROTEIN','82985','1','','1','0','','','',0, 1, 0, 0),
(7307,'GONADOTROPIN FOLLICLE STIMULATING HORMONE','GONADOTROPIN FOLLICLE STIMULATING HORMONE','83001','1','','1','0','','','',0, 1, 0, 0),
(7308,'GONADOTROPIN LUTEINIZING HORMONE','GONADOTROPIN LUTEINIZING HORMONE','83002','1','','1','0','','','',0, 1, 0, 0),
(7309,'ASSAY OF GROWTH HORMONE HUMAN','ASSAY OF GROWTH HORMONE HUMAN','83003','1','','1','0','','','',0, 1, 0, 0),
(7310,'GROWTH STIMULATION EXPRESSED GENE 2','GROWTH STIMULATION EXPRESSED GENE 2','83006','1','','1','0','','','',0, 1, 0, 0),
(7311,'HPYLORI BLOOD ANAL UREASE ACT NON-RADACT ISOTOPE','HPYLORI BLOOD ANAL UREASE ACT NON-RADACT ISOTOPE','83009','1','','1','0','','','',0, 1, 0, 0),
(7312,'ASSAY OF HAPTOGLOBIN QUANTITATIVE','ASSAY OF HAPTOGLOBIN QUANTITATIVE','83010','1','','1','0','','','',0, 1, 0, 0),
(7313,'ASSAY OF HAPTOGLOBIN PHENOTYPES','ASSAY OF HAPTOGLOBIN PHENOTYPES','83012','1','','1','0','','','',0, 1, 0, 0),
(7314,'HPYLORI BREATH ANAL UREASE ACT NON-RADACT ISTOPE','HPYLORI BREATH ANAL UREASE ACT NON-RADACT ISTOPE','83013','1','','1','0','','','',0, 1, 0, 0),
(7315,'HPYLORI DRUG ADMINISTRATION','HPYLORI DRUG ADMINISTRATION','83014','1','','1','0','','','',0, 1, 0, 0),
(7316,'HEAVY METAL SCREEN','HEAVY METAL SCREEN','83015','1','','1','0','','','',0, 1, 0, 0),
(7317,'HEAVY METAL QUANTIATIVE EACH','HEAVY METAL QUANTIATIVE EACH','83018','1','','1','0','','','',0, 1, 0, 0),
(7318,'HEMOGLOBIN FRACTJ/QUANTJ ELECTROPHORESIS','HEMOGLOBIN FRACTJ/QUANTJ ELECTROPHORESIS','83020','1','','1','0','','','',0, 1, 0, 0),
(7319,'HEMOGLOBIN FRACTJ/QUANTJ CHROMOTOGRAPHY','HEMOGLOBIN FRACTJ/QUANTJ CHROMOTOGRAPHY','83021','1','','1','0','','','',0, 1, 0, 0),
(7320,'HEMOGLOBIN COPPER SULFATE METHOD NON-AUTOMATED','HEMOGLOBIN COPPER SULFATE METHOD NON-AUTOMATED','83026','1','','1','0','','','',0, 1, 0, 0),
(7321,'HEMOGLOBIN F FETAL CHEMICAL','HEMOGLOBIN F FETAL CHEMICAL','83030','1','','1','0','','','',0, 1, 0, 0),
(7322,'HEMOGLOBIN F FETAL QUALITATIVE','HEMOGLOBIN F FETAL QUALITATIVE','83033','1','','1','0','','','',0, 1, 0, 0),
(7323,'HEMOGLOBIN GLYCOSYLATED A1C','HEMOGLOBIN GLYCOSYLATED A1C','83036','1','','1','0','','','',0, 1, 0, 0),
(7324,'HGB GLYCOSYLATED DEVICE CLEARED FDA HOME USE','HGB GLYCOSYLATED DEVICE CLEARED FDA HOME USE','83037','1','','1','0','','','',0, 1, 0, 0),
(7325,'HEMOGLOBIN METHEMOGLOBIN QUALITATIVE','HEMOGLOBIN METHEMOGLOBIN QUALITATIVE','83045','1','','1','0','','','',0, 1, 0, 0),
(7326,'HEMOGLOBIN METHEMOGLOBIN QUANTITATIVE','HEMOGLOBIN METHEMOGLOBIN QUANTITATIVE','83050','1','','1','0','','','',0, 1, 0, 0),
(7327,'ASSAY OF HEMOGLOBIN PLASMA','ASSAY OF HEMOGLOBIN PLASMA','83051','1','','1','0','','','',0, 1, 0, 0),
(7328,'HEMOGLOBIN SULFHEMOGLOBIN QUANTITATIVE','HEMOGLOBIN SULFHEMOGLOBIN QUANTITATIVE','83060','1','','1','0','','','',0, 1, 0, 0),
(7329,'HEMOGLOBIN THERMOLABILE','HEMOGLOBIN THERMOLABILE','83065','1','','1','0','','','',0, 1, 0, 0),
(7330,'HEMOGLOBIN UNSTABLE SCREEN','HEMOGLOBIN UNSTABLE SCREEN','83068','1','','1','0','','','',0, 1, 0, 0),
(7331,'ASSAY OF HEMOGLOBIN URINE','ASSAY OF HEMOGLOBIN URINE','83069','1','','1','0','','','',0, 1, 0, 0),
(7332,'ASSAY OF HEMOSIDERIN QUALITATIVE','ASSAY OF HEMOSIDERIN QUALITATIVE','83070','1','','1','0','','','',0, 1, 0, 0),
(7333,'ASSAY OF B-HEXOSAMINIDASE EACH ASSAY','ASSAY OF B-HEXOSAMINIDASE EACH ASSAY','83080','1','','1','0','','','',0, 1, 0, 0),
(7334,'ASSAY OF HISTAMINE','ASSAY OF HISTAMINE','83088','1','','1','0','','','',0, 1, 0, 0),
(7335,'ASSAY OF HOMOCYSTEINE','ASSAY OF HOMOCYSTEINE','83090','1','','1','0','','','',0, 1, 0, 0),
(7336,'ASSAY OF HOMOVANILLIC ACID','ASSAY OF HOMOVANILLIC ACID','83150','1','','1','0','','','',0, 1, 0, 0),
(7337,'HYDROXYCORTICOSTEROIDS 17','HYDROXYCORTICOSTEROIDS 17','83491','1','','1','0','','','',0, 1, 0, 0),
(7338,'ASSAY OF HYDROXYINDOLACETIC ACID 5-HIAA','ASSAY OF HYDROXYINDOLACETIC ACID 5-HIAA','83497','1','','1','0','','','',0, 1, 0, 0),
(7339,'ASSAY OF HYDROXYPROGESTERONE 17-D','ASSAY OF HYDROXYPROGESTERONE 17-D','83498','1','','1','0','','','',0, 1, 0, 0),
(7340,'ASSAY OF HYDROXYPROGESTERONE 20-','ASSAY OF HYDROXYPROGESTERONE 20-','83499','1','','1','0','','','',0, 1, 0, 0),
(7341,'ASSAY OF HYDROXYPROLINE FREE','ASSAY OF HYDROXYPROLINE FREE','83500','1','','1','0','','','',0, 1, 0, 0),
(7342,'ASSAY OF HYDROXYPROLINE TOTAL','ASSAY OF HYDROXYPROLINE TOTAL','83505','1','','1','0','','','',0, 1, 0, 0),
(7343,'IMMUNOASSAY ANALYTE QUAL/SEMIQUAL MULTIPLE STEP','IMMUNOASSAY ANALYTE QUAL/SEMIQUAL MULTIPLE STEP','83516','1','','1','0','','','',0, 1, 0, 0),
(7344,'IMMUNOASSAY ANALYTE QUAL/SEMIQUAL SINGLE STEP','IMMUNOASSAY ANALYTE QUAL/SEMIQUAL SINGLE STEP','83518','1','','1','0','','','',0, 1, 0, 0),
(7345,'IMMUNOASSAY ANALYTE QUANT RADIOIMMUNOASSAY','IMMUNOASSAY ANALYTE QUANT RADIOIMMUNOASSAY','83519','1','','1','0','','','',0, 1, 0, 0),
(7346,'IMMUNOASSAY ANALYTE QUANTITATIVE NOS','IMMUNOASSAY ANALYTE QUANTITATIVE NOS','83520','1','','1','0','','','',0, 1, 0, 0),
(7347,'ASSAY OF INSULIN TOTAL','ASSAY OF INSULIN TOTAL','83525','1','','1','0','','','',0, 1, 0, 0),
(7348,'ASSAY OF INSULIN FREE','ASSAY OF INSULIN FREE','83527','1','','1','0','','','',0, 1, 0, 0),
(7349,'ASSAY OF INTRINSIC FACTOR','ASSAY OF INTRINSIC FACTOR','83528','1','','1','0','','','',0, 1, 0, 0),
(7350,'ASSAY OF IRON','ASSAY OF IRON','83540','1','','1','0','','','',0, 1, 0, 0),
(7351,'IRON BINDING CAPACITY','IRON BINDING CAPACITY','83550','1','','1','0','','','',0, 1, 0, 0),
(7352,'ISOCITRIC DEHYDROGENASE','ISOCITRIC DEHYDROGENASE','83570','1','','1','0','','','',0, 1, 0, 0),
(7353,'ASSAY OF KETOGENIC STEROIDS FRACTIONATION','ASSAY OF KETOGENIC STEROIDS FRACTIONATION','83582','1','','1','0','','','',0, 1, 0, 0),
(7354,'ASSAY OF KETOSTEROIDS 17- TOTAL','ASSAY OF KETOSTEROIDS 17- TOTAL','83586','1','','1','0','','','',0, 1, 0, 0),
(7355,'KETOSTEROIDS 17- FRACTIONATION','KETOSTEROIDS 17- FRACTIONATION','83593','1','','1','0','','','',0, 1, 0, 0),
(7356,'ASSAY OF LACTATE','ASSAY OF LACTATE','83605','1','','1','0','','','',0, 1, 0, 0),
(7357,'LACTATE DEHYDROGENASE LDH','LACTATE DEHYDROGENASE LDH','83615','1','','1','0','','','',0, 1, 0, 0),
(7358,'LACTATE DEHYDROGENASE ISOENZYMES SEP&QUAN','LACTATE DEHYDROGENASE ISOENZYMES SEP&QUAN','83625','1','','1','0','','','',0, 1, 0, 0),
(7359,'LACTOFERRIN FECAL QUALITATIVE','LACTOFERRIN FECAL QUALITATIVE','83630','1','','1','0','','','',0, 1, 0, 0),
(7360,'LACTOFERRIN FECAL QUANTITATIVE','LACTOFERRIN FECAL QUANTITATIVE','83631','1','','1','0','','','',0, 1, 0, 0),
(7361,'LACTOGEN HPL HUMAN CHORIONIC SOMATOMAMMOTROPIN','LACTOGEN HPL HUMAN CHORIONIC SOMATOMAMMOTROPIN','83632','1','','1','0','','','',0, 1, 0, 0),
(7362,'LACTOSE URINE QUALITATIVE','LACTOSE URINE QUALITATIVE','83633','1','','1','0','','','',0, 1, 0, 0),
(7363,'ASSAY OF LEAD','ASSAY OF LEAD','83655','1','','1','0','','','',0, 1, 0, 0),
(7364,'FETAL LUNG MATURITY LECITHIN SPHINGOMYELIN RATIO','FETAL LUNG MATURITY LECITHIN SPHINGOMYELIN RATIO','83661','1','','1','0','','','',0, 1, 0, 0),
(7365,'FETAL LUNG MATURITY FOAM STABILITY TEST','FETAL LUNG MATURITY FOAM STABILITY TEST','83662','1','','1','0','','','',0, 1, 0, 0),
(7366,'FETAL LUNG MATURITY FLUORESCENCE POLARIZATION','FETAL LUNG MATURITY FLUORESCENCE POLARIZATION','83663','1','','1','0','','','',0, 1, 0, 0),
(7367,'FETAL LUNG MATURITY LAMELLAR BODY DENSITY','FETAL LUNG MATURITY LAMELLAR BODY DENSITY','83664','1','','1','0','','','',0, 1, 0, 0),
(7368,'LEUCINE AMINOPEPTIDASE LAP','LEUCINE AMINOPEPTIDASE LAP','83670','1','','1','0','','','',0, 1, 0, 0),
(7369,'ASSAY OF LIPASE','ASSAY OF LIPASE','83690','1','','1','0','','','',0, 1, 0, 0),
(7370,'LIPOPROTEIN (A)','LIPOPROTEIN (A)','83695','1','','1','0','','','',0, 1, 0, 0),
(7371,'LIPOPROTEIN-ASSOCIATED PHOSPHOLIPASE A2','LIPOPROTEIN-ASSOCIATED PHOSPHOLIPASE A2','83698','1','','1','0','','','',0, 1, 0, 0),
(7372,'LIPOPROTEIN BLOOD ELECTROPHORECTIC SEP&QUAN','LIPOPROTEIN BLOOD ELECTROPHORECTIC SEP&QUAN','83700','1','','1','0','','','',0, 1, 0, 0),
(7373,'LIPOPROTEIN BLOOD HIGH RESOLTJ&QUANTJ SUBCLASS','LIPOPROTEIN BLOOD HIGH RESOLTJ&QUANTJ SUBCLASS','83701','1','','1','0','','','',0, 1, 0, 0),
(7374,'LIPOPROTEIN BLOOD QUAN NUMBERS&SUBCLASSES','LIPOPROTEIN BLOOD QUAN NUMBERS&SUBCLASSES','83704','1','','1','0','','','',0, 1, 0, 0),
(7375,'LIPOPROTEIN DIR MEAS HIGH DENSITY CHOLESTEROL','LIPOPROTEIN DIR MEAS HIGH DENSITY CHOLESTEROL','83718','1','','1','0','','','',0, 1, 0, 0),
(7376,'LIPOPROTEIN DIRECT MEASUREMENT VLDL CHOLESTEROL','LIPOPROTEIN DIRECT MEASUREMENT VLDL CHOLESTEROL','83719','1','','1','0','','','',0, 1, 0, 0),
(7377,'LIPOPROTEIN DIRECT MEASUREMENT LDL CHOLESTEROL','LIPOPROTEIN DIRECT MEASUREMENT LDL CHOLESTEROL','83721','1','','1','0','','','',0, 1, 0, 0),
(7378,'LUTEINIZING RELEASING FACTOR','LUTEINIZING RELEASING FACTOR','83727','1','','1','0','','','',0, 1, 0, 0),
(7379,'ASSAY OF MAGNESIUM','ASSAY OF MAGNESIUM','83735','1','','1','0','','','',0, 1, 0, 0),
(7380,'ASSAY OF MALATE DEHYDROGENASE','ASSAY OF MALATE DEHYDROGENASE','83775','1','','1','0','','','',0, 1, 0, 0),
(7381,'ASSAY OF MANGANESE','ASSAY OF MANGANESE','83785','1','','1','0','','','',0, 1, 0, 0),
(7382,'MASS SPECT&TANDEM MASS SPECT NONDRG ANAL NES EA','MASS SPECT&TANDEM MASS SPECT NONDRG ANAL NES EA','83789','1','','1','0','','','',0, 1, 0, 0),
(7383,'ASSAY OF MERCURY QUANTITATIVE','ASSAY OF MERCURY QUANTITATIVE','83825','1','','1','0','','','',0, 1, 0, 0),
(7384,'METANEPHRINES','METANEPHRINES','83835','1','','1','0','','','',0, 1, 0, 0),
(7385,'METHEMALBUMIN','METHEMALBUMIN','83857','1','','1','0','','','',0, 1, 0, 0),
(7386,'MICROFLUIDIC ANALYSIS TEAR OSMOLARITY','MICROFLUIDIC ANALYSIS TEAR OSMOLARITY','83861','1','','1','0','','','',0, 1, 0, 0),
(7387,'MUCOPOLYSACCHARIDES ACID QUANTITATIVE','MUCOPOLYSACCHARIDES ACID QUANTITATIVE','83864','1','','1','0','','','',0, 1, 0, 0),
(7388,'MUCIN SYNOVIAL FLUID ROPES TEST','MUCIN SYNOVIAL FLUID ROPES TEST','83872','1','','1','0','','','',0, 1, 0, 0),
(7389,'MYELIN BASIC PROTEIN CEREBROSPINAL FLUID','MYELIN BASIC PROTEIN CEREBROSPINAL FLUID','83873','1','','1','0','','','',0, 1, 0, 0),
(7390,'MYOGLOBIN','MYOGLOBIN','83874','1','','1','0','','','',0, 1, 0, 0),
(7391,'MYELOPEROXIDASE MPO','MYELOPEROXIDASE MPO','83876','1','','1','0','','','',0, 1, 0, 0),
(7392,'NATRIURETIC PEPTIDE','NATRIURETIC PEPTIDE','83880','1','','1','0','','','',0, 1, 0, 0),
(7393,'ASSAY OF NEPHELOMETRY EACH ANALYTE NES','ASSAY OF NEPHELOMETRY EACH ANALYTE NES','83883','1','','1','0','','','',0, 1, 0, 0),
(7394,'ASSAY OF NICKEL','ASSAY OF NICKEL','83885','1','','1','0','','','',0, 1, 0, 0),
(7395,'ASSAY OF NUCLEOTIDASE 5''-','ASSAY OF NUCLEOTIDASE 5''-','83915','1','','1','0','','','',0, 1, 0, 0),
(7396,'OLIGOCLONAL IMMUNE','OLIGOCLONAL IMMUNE','83916','1','','1','0','','','',0, 1, 0, 0),
(7397,'ORGANIC ACIDS TOTAL QUANTITATIVE EACH SPECIMEN','ORGANIC ACIDS TOTAL QUANTITATIVE EACH SPECIMEN','83918','1','','1','0','','','',0, 1, 0, 0),
(7398,'ORGANIC ACIDS QUALITATIVE EACH SPECIMEN','ORGANIC ACIDS QUALITATIVE EACH SPECIMEN','83919','1','','1','0','','','',0, 1, 0, 0),
(7399,'ORGANIC ACID 1 QUANTITATIVE','ORGANIC ACID 1 QUANTITATIVE','83921','1','','1','0','','','',0, 1, 0, 0),
(7400,'ASSAY OF OSMOLALITY BLOOD','ASSAY OF OSMOLALITY BLOOD','83930','1','','1','0','','','',0, 1, 0, 0),
(7401,'ASSAY OF OSMOLALITY URINE','ASSAY OF OSMOLALITY URINE','83935','1','','1','0','','','',0, 1, 0, 0),
(7402,'ASSAY OF OSTEOCALCIN','ASSAY OF OSTEOCALCIN','83937','1','','1','0','','','',0, 1, 0, 0),
(7403,'ASSAY OF OXALATE','ASSAY OF OXALATE','83945','1','','1','0','','','',0, 1, 0, 0),
(7404,'ONCOPROTEIN HER-2/NEU','ONCOPROTEIN HER-2/NEU','83950','1','','1','0','','','',0, 1, 0, 0),
(7405,'ONCOPROTEIN DES-GAMMA-CARBOXY-PROTHROMBIN DCP','ONCOPROTEIN DES-GAMMA-CARBOXY-PROTHROMBIN DCP','83951','1','','1','0','','','',0, 1, 0, 0),
(7406,'ASSAY OF PARATHORMONE','ASSAY OF PARATHORMONE','83970','1','','1','0','','','',0, 1, 0, 0),
(7407,'PH BODY FLUID NOT ELSEWHERE SPECIFIED','PH BODY FLUID NOT ELSEWHERE SPECIFIED','83986','1','','1','0','','','',0, 1, 0, 0),
(7408,'PH EXHALED BREATH CONDENSATE','PH EXHALED BREATH CONDENSATE','83987','1','','1','0','','','',0, 1, 0, 0),
(7409,'ASSAY OF PHENCYCLIDINE','ASSAY OF PHENCYCLIDINE','83992','1','','1','0','','','',0, 1, 0, 0),
(7410,'ASSAY OF CALPROTECTIN FECAL','ASSAY OF CALPROTECTIN FECAL','83993','1','','1','0','','','',0, 1, 0, 0),
(7411,'ASSAY OF PHENYLALANINE BLOOD','ASSAY OF PHENYLALANINE BLOOD','84030','1','','1','0','','','',0, 1, 0, 0),
(7412,'ASSAY OF PHENYLKETONES QUALITATIVE','ASSAY OF PHENYLKETONES QUALITATIVE','84035','1','','1','0','','','',0, 1, 0, 0),
(7413,'ASSAY OF PHOSPHATASE ACID TOTAL','ASSAY OF PHOSPHATASE ACID TOTAL','84060','1','','1','0','','','',0, 1, 0, 0),
(7414,'PHOSPHATASE ACID FORENSIC EXAMINATION','PHOSPHATASE ACID FORENSIC EXAMINATION','84061','1','','1','0','','','',0, 1, 0, 0),
(7415,'ASSAY OF PHOSPHATASE ACID PROSTATIC','ASSAY OF PHOSPHATASE ACID PROSTATIC','84066','1','','1','0','','','',0, 1, 0, 0),
(7416,'ASSAY OF PHOSPHATASE ALKALINE','ASSAY OF PHOSPHATASE ALKALINE','84075','1','','1','0','','','',0, 1, 0, 0),
(7417,'ASSAY OF PHOSPHATASE ALKALINE HEAT STABLE','ASSAY OF PHOSPHATASE ALKALINE HEAT STABLE','84078','1','','1','0','','','',0, 1, 0, 0),
(7418,'ASSAY OF PHOSPHATASE ALKALINE ISOENZYMES','ASSAY OF PHOSPHATASE ALKALINE ISOENZYMES','84080','1','','1','0','','','',0, 1, 0, 0),
(7419,'PHOSPHATIDYLGLYCEROL','PHOSPHATIDYLGLYCEROL','84081','1','','1','0','','','',0, 1, 0, 0),
(7420,'PHOSPHOGLUCONATE 6-DEHYD RBC','PHOSPHOGLUCONATE 6-DEHYD RBC','84085','1','','1','0','','','',0, 1, 0, 0),
(7421,'ASSAY OF PHOSPHOHEXOSE ISOMERASE','ASSAY OF PHOSPHOHEXOSE ISOMERASE','84087','1','','1','0','','','',0, 1, 0, 0),
(7422,'ASSAY OF PHOSPHORUS INORGANIC','ASSAY OF PHOSPHORUS INORGANIC','84100','1','','1','0','','','',0, 1, 0, 0),
(7423,'ASSAY OF PHOSPHORUS INORGANIC URINE','ASSAY OF PHOSPHORUS INORGANIC URINE','84105','1','','1','0','','','',0, 1, 0, 0),
(7424,'PORPHOBILINOGEN URINE QUALITATIVE','PORPHOBILINOGEN URINE QUALITATIVE','84106','1','','1','0','','','',0, 1, 0, 0),
(7425,'ASSAY OF PORPHOBILINOGEN URINE QUANTITATIVE','ASSAY OF PORPHOBILINOGEN URINE QUANTITATIVE','84110','1','','1','0','','','',0, 1, 0, 0),
(7426,'EVAL C/V AMNIOTIC FLUID PROTEIN QUAL EA SPECIMEN','EVAL C/V AMNIOTIC FLUID PROTEIN QUAL EA SPECIMEN','84112','1','','1','0','','','',0, 1, 0, 0),
(7427,'PORPHYRINS URINE QUALITATAIVE','PORPHYRINS URINE QUALITATAIVE','84119','1','','1','0','','','',0, 1, 0, 0),
(7428,'PORPHYRINS URINE QUANTITATION & FRACTIONATION','PORPHYRINS URINE QUANTITATION & FRACTIONATION','84120','1','','1','0','','','',0, 1, 0, 0),
(7429,'PORPHYRINS FECES QUANTITATIVE','PORPHYRINS FECES QUANTITATIVE','84126','1','','1','0','','','',0, 1, 0, 0),
(7430,'POTASSIUM SERUM PLASMA/WHOLE BLOOD','POTASSIUM SERUM PLASMA/WHOLE BLOOD','84132','1','','1','0','','','',0, 1, 0, 0),
(7431,'POTASSIUM URINE','POTASSIUM URINE','84133','1','','1','0','','','',0, 1, 0, 0),
(7432,'PREALBUMIN','PREALBUMIN','84134','1','','1','0','','','',0, 1, 0, 0),
(7433,'PREGNANEDIOL','PREGNANEDIOL','84135','1','','1','0','','','',0, 1, 0, 0),
(7434,'PREGNANETRIOL','PREGNANETRIOL','84138','1','','1','0','','','',0, 1, 0, 0),
(7435,'PREGNENOLONE','PREGNENOLONE','84140','1','','1','0','','','',0, 1, 0, 0),
(7436,'17-HYDROXYPREGNENOLONE','17-HYDROXYPREGNENOLONE','84143','1','','1','0','','','',0, 1, 0, 0),
(7437,'ASSAY OF PROGESTERONE','ASSAY OF PROGESTERONE','84144','1','','1','0','','','',0, 1, 0, 0),
(7438,'PROCALCITONIN (PCT)','PROCALCITONIN (PCT)','84145','1','','1','0','','','',0, 1, 0, 0),
(7439,'ASSAY OF PROLACTIN','ASSAY OF PROLACTIN','84146','1','','1','0','','','',0, 1, 0, 0),
(7440,'ASSAY OF PROSTAGLNDIN EACH','ASSAY OF PROSTAGLNDIN EACH','84150','1','','1','0','','','',0, 1, 0, 0),
(7441,'ASSAY OF PROSTATE SPECIFIC ANTIGEN COMPLEXED','ASSAY OF PROSTATE SPECIFIC ANTIGEN COMPLEXED','84152','1','','1','0','','','',0, 1, 0, 0),
(7442,'ASSAY OF PROSTATE SPECIFIC ANTIGEN TOTAL','ASSAY OF PROSTATE SPECIFIC ANTIGEN TOTAL','84153','1','','1','0','','','',0, 1, 0, 0),
(7443,'ASSAY OF PROSTATE SPECIFIC ANTIGEN FREE','ASSAY OF PROSTATE SPECIFIC ANTIGEN FREE','84154','1','','1','0','','','',0, 1, 0, 0),
(7444,'PROTEIN XCPT REFRACTOMETRY SERUM PLASMA/WHL BLD','PROTEIN XCPT REFRACTOMETRY SERUM PLASMA/WHL BLD','84155','1','','1','0','','','',0, 1, 0, 0),
(7445,'PROTEIN TOTAL XCPT REFRACTOMETRY URINE','PROTEIN TOTAL XCPT REFRACTOMETRY URINE','84156','1','','1','0','','','',0, 1, 0, 0),
(7446,'PROTEIN TOTAL XCPT REFRACTOMETRY OTH SRC','PROTEIN TOTAL XCPT REFRACTOMETRY OTH SRC','84157','1','','1','0','','','',0, 1, 0, 0),
(7447,'PROTEIN TOTAL REFRACTOMETRY ANY SRC','PROTEIN TOTAL REFRACTOMETRY ANY SRC','84160','1','','1','0','','','',0, 1, 0, 0),
(7448,'PREGNANCY-ASSOCIATED PLASMA PROTEIN-A','PREGNANCY-ASSOCIATED PLASMA PROTEIN-A','84163','1','','1','0','','','',0, 1, 0, 0),
(7449,'PROTEIN ELECTROPHORETIC FRACTJ&QUANTJ SERUM','PROTEIN ELECTROPHORETIC FRACTJ&QUANTJ SERUM','84165','1','','1','0','','','',0, 1, 0, 0),
(7450,'PROTEIN ELECTROP FXJ&QUAN OTH FLUS CONCENTRATI','PROTEIN ELECTROP FXJ&QUAN OTH FLUS CONCENTRATI','84166','1','','1','0','','','',0, 1, 0, 0),
(7451,'PROTEIN WESTRN BLOT I&R BLOOD/OTHER FLUID','PROTEIN WESTRN BLOT I&R BLOOD/OTHER FLUID','84181','1','','1','0','','','',0, 1, 0, 0),
(7452,'PROTEIN WESTRN BLOT BLOOD/OTH FLU IMMUNOLOGICAL','PROTEIN WESTRN BLOT BLOOD/OTH FLU IMMUNOLOGICAL','84182','1','','1','0','','','',0, 1, 0, 0),
(7453,'PROTOPORPHYRIN RBC QUANTITATIVE','PROTOPORPHYRIN RBC QUANTITATIVE','84202','1','','1','0','','','',0, 1, 0, 0),
(7454,'PROTOPORPHYRIN RBC SCREEN','PROTOPORPHYRIN RBC SCREEN','84203','1','','1','0','','','',0, 1, 0, 0),
(7455,'ASSAY OF PROINSULIN','ASSAY OF PROINSULIN','84206','1','','1','0','','','',0, 1, 0, 0),
(7456,'ASSAY OF PYRIDOXAL PHOSPHATE','ASSAY OF PYRIDOXAL PHOSPHATE','84207','1','','1','0','','','',0, 1, 0, 0),
(7457,'ASSAY OF PYRUVATE','ASSAY OF PYRUVATE','84210','1','','1','0','','','',0, 1, 0, 0),
(7458,'ASSAY OF PYRUVATE KINASE','ASSAY OF PYRUVATE KINASE','84220','1','','1','0','','','',0, 1, 0, 0),
(7459,'ASSAY OF QUININE','ASSAY OF QUININE','84228','1','','1','0','','','',0, 1, 0, 0),
(7460,'ASSAY OF RECEPTOR ASSAY ESTROGEN','ASSAY OF RECEPTOR ASSAY ESTROGEN','84233','1','','1','0','','','',0, 1, 0, 0),
(7461,'ASSAY OF RECEPTOR ASSAY PROGESTERONE','ASSAY OF RECEPTOR ASSAY PROGESTERONE','84234','1','','1','0','','','',0, 1, 0, 0),
(7462,'RECEPTOR ASSAY ENDOCRINE OTH/THN ESTRGN/PROGST','RECEPTOR ASSAY ENDOCRINE OTH/THN ESTRGN/PROGST','84235','1','','1','0','','','',0, 1, 0, 0),
(7463,'RECEPTOR ASSAY NON-ENDOCRINE SPECIFY RECEPTOR','RECEPTOR ASSAY NON-ENDOCRINE SPECIFY RECEPTOR','84238','1','','1','0','','','',0, 1, 0, 0),
(7464,'ASSAY OF RENIN','ASSAY OF RENIN','84244','1','','1','0','','','',0, 1, 0, 0),
(7465,'ASSAY OF RIBOFLAVIN-VITAMIN B-2','ASSAY OF RIBOFLAVIN-VITAMIN B-2','84252','1','','1','0','','','',0, 1, 0, 0),
(7466,'ASSAY OF SELENIUM','ASSAY OF SELENIUM','84255','1','','1','0','','','',0, 1, 0, 0),
(7467,'ASSAY OF SEROTONIN','ASSAY OF SEROTONIN','84260','1','','1','0','','','',0, 1, 0, 0),
(7468,'ASSAY OF SEX HORMONE BINDING GLOBULIN','ASSAY OF SEX HORMONE BINDING GLOBULIN','84270','1','','1','0','','','',0, 1, 0, 0),
(7469,'ASSAY OF SIALIC ACID','ASSAY OF SIALIC ACID','84275','1','','1','0','','','',0, 1, 0, 0),
(7470,'ASSAY OF SILICA','ASSAY OF SILICA','84285','1','','1','0','','','',0, 1, 0, 0),
(7471,'SODIUM SERUM PLASMA OR WHOLE BLOOD','SODIUM SERUM PLASMA OR WHOLE BLOOD','84295','1','','1','0','','','',0, 1, 0, 0),
(7472,'ASSAY OF URINE SODIUM','ASSAY OF URINE SODIUM','84300','1','','1','0','','','',0, 1, 0, 0),
(7473,'ASSAY OF SODIUM OTHER SOURCE','ASSAY OF SODIUM OTHER SOURCE','84302','1','','1','0','','','',0, 1, 0, 0),
(7474,'ASSAY OF SOMATOMEDIN','ASSAY OF SOMATOMEDIN','84305','1','','1','0','','','',0, 1, 0, 0),
(7475,'ASSAY OF SOMATOSTATIN','ASSAY OF SOMATOSTATIN','84307','1','','1','0','','','',0, 1, 0, 0),
(7476,'SPECTROPHOTOMETRY ANALYT NOT ELSEWHERE SPECIFIED','SPECTROPHOTOMETRY ANALYT NOT ELSEWHERE SPECIFIED','84311','1','','1','0','','','',0, 1, 0, 0),
(7477,'SPECIFIC GRAVITY EXCEPT URINE','SPECIFIC GRAVITY EXCEPT URINE','84315','1','','1','0','','','',0, 1, 0, 0),
(7478,'SUGARS CHROMATOGRAPHIC TLC/PAPER CHROMATOGRAPHY','SUGARS CHROMATOGRAPHIC TLC/PAPER CHROMATOGRAPHY','84375','1','','1','0','','','',0, 1, 0, 0),
(7479,'SUGARS MONO DI&OLIGOS 1 QUALITATAIVE EACH SPEC','SUGARS MONO DI&OLIGOS 1 QUALITATAIVE EACH SPEC','84376','1','','1','0','','','',0, 1, 0, 0),
(7480,'SUGARS MONO DI&OLIGOS MLT QUALITATIVE EACH SPE','SUGARS MONO DI&OLIGOS MLT QUALITATIVE EACH SPE','84377','1','','1','0','','','',0, 1, 0, 0),
(7481,'SUGARS MONO DI&OLIGOS 1 QUANTITATIVE EACH SPEC','SUGARS MONO DI&OLIGOS 1 QUANTITATIVE EACH SPEC','84378','1','','1','0','','','',0, 1, 0, 0),
(7482,'SUGARS MONO DI&OLIGOS MLT QUANTITATIVE EA SPEC','SUGARS MONO DI&OLIGOS MLT QUANTITATIVE EA SPEC','84379','1','','1','0','','','',0, 1, 0, 0),
(7483,'ASSAY OF SULFATE URINE','ASSAY OF SULFATE URINE','84392','1','','1','0','','','',0, 1, 0, 0),
(7484,'ASSAY OF TESTOSTERONE FREE','ASSAY OF TESTOSTERONE FREE','84402','1','','1','0','','','',0, 1, 0, 0),
(7485,'ASSAY OF TESTOSTERONE TOTAL','ASSAY OF TESTOSTERONE TOTAL','84403','1','','1','0','','','',0, 1, 0, 0),
(7486,'ASSAY OF THIAMINE-VITAMIN B-1','ASSAY OF THIAMINE-VITAMIN B-1','84425','1','','1','0','','','',0, 1, 0, 0),
(7487,'ASSAY OF THIOCYANATE','ASSAY OF THIOCYANATE','84430','1','','1','0','','','',0, 1, 0, 0),
(7488,'THROMBOXANE METABOLITE W/WO THROMBOXANE URINE','THROMBOXANE METABOLITE W/WO THROMBOXANE URINE','84431','1','','1','0','','','',0, 1, 0, 0),
(7489,'ASSAY OF THYROGLOBULIN','ASSAY OF THYROGLOBULIN','84432','1','','1','0','','','',0, 1, 0, 0),
(7490,'ASSAY OF THYROXINE TOTAL','ASSAY OF THYROXINE TOTAL','84436','1','','1','0','','','',0, 1, 0, 0),
(7491,'ASSAY OF THYROXINE REQUIRING ELUTION','ASSAY OF THYROXINE REQUIRING ELUTION','84437','1','','1','0','','','',0, 1, 0, 0),
(7492,'ASSAY OF FREE THYROXINE','ASSAY OF FREE THYROXINE','84439','1','','1','0','','','',0, 1, 0, 0),
(7493,'ASSAY OF THYROXINE BINDING GLOBULIN','ASSAY OF THYROXINE BINDING GLOBULIN','84442','1','','1','0','','','',0, 1, 0, 0),
(7494,'ASSAY OF THYROID STIMULATING HORMONE TSH','ASSAY OF THYROID STIMULATING HORMONE TSH','84443','1','','1','0','','','',0, 1, 0, 0),
(7495,'THYROID STIMULATING IMMUNE GLOBULINS TSI','THYROID STIMULATING IMMUNE GLOBULINS TSI','84445','1','','1','0','','','',0, 1, 0, 0),
(7496,'ASSAY OF TOCOPHEROL ALPHA VITAMIN E','ASSAY OF TOCOPHEROL ALPHA VITAMIN E','84446','1','','1','0','','','',0, 1, 0, 0),
(7497,'ASSAY OF TRANSCORTIN CORTISOL BINDING GLOBULIN','ASSAY OF TRANSCORTIN CORTISOL BINDING GLOBULIN','84449','1','','1','0','','','',0, 1, 0, 0),
(7498,'TRANSFERASE ASPARTATE AMINO AST SGOT','TRANSFERASE ASPARTATE AMINO AST SGOT','84450','1','','1','0','','','',0, 1, 0, 0),
(7499,'TRANSFERASE ALANINE AMINO ALT SGPT','TRANSFERASE ALANINE AMINO ALT SGPT','84460','1','','1','0','','','',0, 1, 0, 0),
(7500,'ASSAY OF L7383TRANSFERRIN','ASSAY OF L7383TRANSFERRIN','84466','1','','1','0','','','',0, 1, 0, 0),
(7501,'ASSAY OF TRIGLYCERIDES','ASSAY OF TRIGLYCERIDES','84478','1','','1','0','','','',0, 1, 0, 0),
(7502,'THYROID HORM UPTK/THYROID HORMONE BINDING RATIO','THYROID HORM UPTK/THYROID HORMONE BINDING RATIO','84479','1','','1','0','','','',0, 1, 0, 0),
(7503,'ASSAY OF TRIIODOTHYRONINE T3 TOTAL TT3','ASSAY OF TRIIODOTHYRONINE T3 TOTAL TT3','84480','1','','1','0','','','',0, 1, 0, 0),
(7504,'ASSAY OF TRIIODOTHYRONINE T3 FREE','ASSAY OF TRIIODOTHYRONINE T3 FREE','84481','1','','1','0','','','',0, 1, 0, 0),
(7505,'TRIIODOTHYRONINE T3 REVERSE','TRIIODOTHYRONINE T3 REVERSE','84482','1','','1','0','','','',0, 1, 0, 0),
(7506,'ASSAY OF TROPONIN QUANTITATIVE','ASSAY OF TROPONIN QUANTITATIVE','84484','1','','1','0','','','',0, 1, 0, 0),
(7507,'ASSAY OF TRYPSIN DUODENAL FLUID','ASSAY OF TRYPSIN DUODENAL FLUID','84485','1','','1','0','','','',0, 1, 0, 0),
(7508,'ASSAY OF TRYPSIN FECES QUALITATIVE','ASSAY OF TRYPSIN FECES QUALITATIVE','84488','1','','1','0','','','',0, 1, 0, 0),
(7509,'TRYPSIN FECES QUANTITATIVE 24-HR COLLECTION','TRYPSIN FECES QUANTITATIVE 24-HR COLLECTION','84490','1','','1','0','','','',0, 1, 0, 0),
(7510,'ASSAY OF TYROSINE','ASSAY OF TYROSINE','84510','1','','1','0','','','',0, 1, 0, 0),
(7511,'ASSAY OF TROPONIN QUALITATIVE','ASSAY OF TROPONIN QUALITATIVE','84512','1','','1','0','','','',0, 1, 0, 0),
(7512,'ASSAY OF UREA NITROGEN QUANTITATIVE','ASSAY OF UREA NITROGEN QUANTITATIVE','84520','1','','1','0','','','',0, 1, 0, 0),
(7513,'ASSAY OF UREA NITROGEN SEMIQUANTITATIVE','ASSAY OF UREA NITROGEN SEMIQUANTITATIVE','84525','1','','1','0','','','',0, 1, 0, 0),
(7514,'ASSAY OF UREA NITROGEN URINE','ASSAY OF UREA NITROGEN URINE','84540','1','','1','0','','','',0, 1, 0, 0),
(7515,'UREA NITROGEN CLEARANCE','UREA NITROGEN CLEARANCE','84545','1','','1','0','','','',0, 1, 0, 0),
(7516,'ASSAY OF BLOOD/URIC ACID','ASSAY OF BLOOD/URIC ACID','84550','1','','1','0','','','',0, 1, 0, 0),
(7517,'ASSAY OF URIC ACID OTHER SOURCE','ASSAY OF URIC ACID OTHER SOURCE','84560','1','','1','0','','','',0, 1, 0, 0),
(7518,'ASSAY OF UROBILINOGEN FECES QUANTITATIVE','ASSAY OF UROBILINOGEN FECES QUANTITATIVE','84577','1','','1','0','','','',0, 1, 0, 0),
(7519,'ASSAY OF UROBILINOGEN URINE QUALITATIVE','ASSAY OF UROBILINOGEN URINE QUALITATIVE','84578','1','','1','0','','','',0, 1, 0, 0),
(7520,'UROBILINOGEN URINE QUANTITATIVE TIMED SPECIMEN','UROBILINOGEN URINE QUANTITATIVE TIMED SPECIMEN','84580','1','','1','0','','','',0, 1, 0, 0),
(7521,'ASSAY OF UROBILINOGEN URINE SEMIQUANTITATIVE','ASSAY OF UROBILINOGEN URINE SEMIQUANTITATIVE','84583','1','','1','0','','','',0, 1, 0, 0),
(7522,'ASSAY OF VANILLYLMANDELIC ACID URINE','ASSAY OF VANILLYLMANDELIC ACID URINE','84585','1','','1','0','','','',0, 1, 0, 0),
(7523,'ASSAY OF VASOACTIVE INTESTINAL PEPTIDE','ASSAY OF VASOACTIVE INTESTINAL PEPTIDE','84586','1','','1','0','','','',0, 1, 0, 0),
(7524,'ASSAY OF VASOPRESSIN ANTI-DIURETIC HORMONE','ASSAY OF VASOPRESSIN ANTI-DIURETIC HORMONE','84588','1','','1','0','','','',0, 1, 0, 0),
(7525,'ASSAY OF VITAMIN A','ASSAY OF VITAMIN A','84590','1','','1','0','','','',0, 1, 0, 0),
(7526,'ASSAY OF VITAMIN NOT OTHERWISE SPECIFIED','ASSAY OF VITAMIN NOT OTHERWISE SPECIFIED','84591','1','','1','0','','','',0, 1, 0, 0),
(7527,'ASSAY OF VITAMIN K','ASSAY OF VITAMIN K','84597','1','','1','0','','','',0, 1, 0, 0),
(7528,'ASSAY OF VOLATILES','ASSAY OF VOLATILES','84600','1','','1','0','','','',0, 1, 0, 0),
(7529,'XYLOSE ABSORPTION TEST BLOOD &/URINE','XYLOSE ABSORPTION TEST BLOOD &/URINE','84620','1','','1','0','','','',0, 1, 0, 0),
(7530,'ASSAY OF ZINC','ASSAY OF ZINC','84630','1','','1','0','','','',0, 1, 0, 0),
(7531,'ASSAY OF C-PEPTIDE','ASSAY OF C-PEPTIDE','84681','1','','1','0','','','',0, 1, 0, 0),
(7532,'GONADOTROPIN CHORIONIC QUANTITATIVE','GONADOTROPIN CHORIONIC QUANTITATIVE','84702','1','','1','0','','','',0, 1, 0, 0),
(7533,'GONADOTROPIN CHORIONIC QUALITATIVE','GONADOTROPIN CHORIONIC QUALITATIVE','84703','1','','1','0','','','',0, 1, 0, 0),
(7534,'GONADOTROPIN CHORIONIC HCG FREE BETA CHAIN','GONADOTROPIN CHORIONIC HCG FREE BETA CHAIN','84704','1','','1','0','','','',0, 1, 0, 0),
(7535,'OVULATION TEST VISUAL COLOR COMPARISON HLH','OVULATION TEST VISUAL COLOR COMPARISON HLH','84830','1','','1','0','','','',0, 1, 0, 0),
(7536,'UNLISTED CHEMISTRY PROCEDURE','UNLISTED CHEMISTRY PROCEDURE','84999','1','','1','0','','','',0, 1, 0, 0),
(7537,'BLEEDING TIME TEST','BLEEDING TIME TEST','85002','1','','1','0','','','',0, 1, 0, 0),
(7538,'BLOOD COUNT AUTOMATED DIFFERENTIAL WBC COUNT','BLOOD COUNT AUTOMATED DIFFERENTIAL WBC COUNT','85004','1','','1','0','','','',0, 1, 0, 0),
(7539,'BLOOD COUNT SMEAR MCRSCP W/MNL DIFRNTL WBC COUNT','BLOOD COUNT SMEAR MCRSCP W/MNL DIFRNTL WBC COUNT','85007','1','','1','0','','','',0, 1, 0, 0),
(7540,'BLD COUNT SMEAR MCRSCP W/O MNL DIFRNTL WBC COUNT','BLD COUNT SMEAR MCRSCP W/O MNL DIFRNTL WBC COUNT','85008','1','','1','0','','','',0, 1, 0, 0),
(7541,'BLOOD COUNT MANUAL DIFRNTL WBC COUNT BUFFY COAT','BLOOD COUNT MANUAL DIFRNTL WBC COUNT BUFFY COAT','85009','1','','1','0','','','',0, 1, 0, 0),
(7542,'BLOOD COUNT SPUN MICROHEMATOCRIT','BLOOD COUNT SPUN MICROHEMATOCRIT','85013','1','','1','0','','','',0, 1, 0, 0),
(7543,'BLOOD COUNT HEMATOCRIT','BLOOD COUNT HEMATOCRIT','85014','1','','1','0','','','',0, 1, 0, 0),
(7544,'BLOOD COUNT HEMOGLOBIN','BLOOD COUNT HEMOGLOBIN','85018','1','','1','0','','','',0, 1, 0, 0),
(7545,'BLOOD COUNT COMPLETE AUTO&AUTO DIFRNTL WBC','BLOOD COUNT COMPLETE AUTO&AUTO DIFRNTL WBC','85025','1','','1','0','','','',0, 1, 0, 0),
(7546,'BLOOD COUNT COMPLETE AUTOMATED','BLOOD COUNT COMPLETE AUTOMATED','85027','1','','1','0','','','',0, 1, 0, 0),
(7547,'BLOOD COUNT MANUAL CELL COUNT EACH','BLOOD COUNT MANUAL CELL COUNT EACH','85032','1','','1','0','','','',0, 1, 0, 0),
(7548,'BLOOD COUNT RED BLOOD CELL AUTOMATED','BLOOD COUNT RED BLOOD CELL AUTOMATED','85041','1','','1','0','','','',0, 1, 0, 0),
(7549,'BLOOD COUNT RETICULOCYTE AUTOMATED','BLOOD COUNT RETICULOCYTE AUTOMATED','85044','1','','1','0','','','',0, 1, 0, 0),
(7550,'BLOOD COUNT RETICULOCYTE AUTOMATED','BLOOD COUNT RETICULOCYTE AUTOMATED','85045','1','','1','0','','','',0, 1, 0, 0),
(7551,'BLOOD COUNT RETICULOCYTES AUTO 1/> CELL MEAS','BLOOD COUNT RETICULOCYTES AUTO 1/> CELL MEAS','85046','1','','1','0','','','',0, 1, 0, 0),
(7552,'BLOOD COUNT LEUKOCYTE WBC AUTOMATED','BLOOD COUNT LEUKOCYTE WBC AUTOMATED','85048','1','','1','0','','','',0, 1, 0, 0),
(7553,'BLOOD COUNT PLATELET AUTOMATED','BLOOD COUNT PLATELET AUTOMATED','85049','1','','1','0','','','',0, 1, 0, 0),
(7554,'RETICULATED PLATELET ASSAY','RETICULATED PLATELET ASSAY','85055','1','','1','0','','','',0, 1, 0, 0),
(7555,'BLOOD SMEAR PERIPHERAL INTERP PHYS W/WRIT REPORT','BLOOD SMEAR PERIPHERAL INTERP PHYS W/WRIT REPORT','85060','1','','1','0','','','',0, 1, 0, 0),
(7556,'BONE MARROW SMEAR INTERPRETATION','BONE MARROW SMEAR INTERPRETATION','85097','1','','1','0','','','',0, 1, 0, 0),
(7557,'CHROMOGENIC SUBSTRATE ASSAY','CHROMOGENIC SUBSTRATE ASSAY','85130','1','','1','0','','','',0, 1, 0, 0),
(7558,'BLOOD CLOT RETRACTION','BLOOD CLOT RETRACTION','85170','1','','1','0','','','',0, 1, 0, 0),
(7559,'CLOT LYSIS TIME WHOLE BLOOD DILUTION','CLOT LYSIS TIME WHOLE BLOOD DILUTION','85175','1','','1','0','','','',0, 1, 0, 0),
(7560,'CLOTTING FACTOR II PROTHROMBIN SPECIFIC','CLOTTING FACTOR II PROTHROMBIN SPECIFIC','85210','1','','1','0','','','',0, 1, 0, 0),
(7561,'CLOTTING FACTOR V ACG/PROACCELERIN LABILE FACTOR','CLOTTING FACTOR V ACG/PROACCELERIN LABILE FACTOR','85220','1','','1','0','','','',0, 1, 0, 0),
(7562,'CLOTTING FACTOR VII PROCONVERTIN STABLE FACTOR','CLOTTING FACTOR VII PROCONVERTIN STABLE FACTOR','85230','1','','1','0','','','',0, 1, 0, 0),
(7563,'CLOTTING FACTOR VIII AHG 1 STAGE','CLOTTING FACTOR VIII AHG 1 STAGE','85240','1','','1','0','','','',0, 1, 0, 0),
(7564,'CLOTTING FACTOR VIII RELATED ANTIGEN','CLOTTING FACTOR VIII RELATED ANTIGEN','85244','1','','1','0','','','',0, 1, 0, 0),
(7565,'CLOTTING FACTOR VIII VW FACTOR RISTOCETIN COFACT','CLOTTING FACTOR VIII VW FACTOR RISTOCETIN COFACT','85245','1','','1','0','','','',0, 1, 0, 0),
(7566,'CLOTTING FACTOR VIII VW FACTOR ANTIGEN','CLOTTING FACTOR VIII VW FACTOR ANTIGEN','85246','1','','1','0','','','',0, 1, 0, 0),
(7567,'CLOTTING FACTOR VIII MULTIMETRIC ANALYSIS','CLOTTING FACTOR VIII MULTIMETRIC ANALYSIS','85247','1','','1','0','','','',0, 1, 0, 0),
(7568,'CLOTTING FACTOR IX PTC/CHRISTMAS','CLOTTING FACTOR IX PTC/CHRISTMAS','85250','1','','1','0','','','',0, 1, 0, 0),
(7569,'CLOTTING FACTOR X STUART-PROWER','CLOTTING FACTOR X STUART-PROWER','85260','1','','1','0','','','',0, 1, 0, 0),
(7570,'CLOTTING FACTOR XI PTA','CLOTTING FACTOR XI PTA','85270','1','','1','0','','','',0, 1, 0, 0),
(7571,'CLOTTING FACTOR XII HAGEMAN','CLOTTING FACTOR XII HAGEMAN','85280','1','','1','0','','','',0, 1, 0, 0),
(7572,'CLOTTING FACTOR XIII FIBRIN STABILIZING','CLOTTING FACTOR XIII FIBRIN STABILIZING','85290','1','','1','0','','','',0, 1, 0, 0),
(7573,'CLOTTING FACTOR XIII FIBRN STABILIZ SCREEN SOLUB','CLOTTING FACTOR XIII FIBRN STABILIZ SCREEN SOLUB','85291','1','','1','0','','','',0, 1, 0, 0),
(7574,'CLOTTING PREKALLIKREIN ASSAY FLETCHER FACT ASSAY','CLOTTING PREKALLIKREIN ASSAY FLETCHER FACT ASSAY','85292','1','','1','0','','','',0, 1, 0, 0),
(7575,'CLOTTING HI MOLEC WEIGHT KININOGEN ASSAY','CLOTTING HI MOLEC WEIGHT KININOGEN ASSAY','85293','1','','1','0','','','',0, 1, 0, 0),
(7576,'CLOTTING INHIBITORS ANTITHROMBIN III ACTIVITY','CLOTTING INHIBITORS ANTITHROMBIN III ACTIVITY','85300','1','','1','0','','','',0, 1, 0, 0),
(7577,'CLOTTING INHIBITRS ANTITHROMBN III ANTIGEN ASSAY','CLOTTING INHIBITRS ANTITHROMBN III ANTIGEN ASSAY','85301','1','','1','0','','','',0, 1, 0, 0),
(7578,'CLOTTING INHIBITORS PROTEIN C ANTIGEN','CLOTTING INHIBITORS PROTEIN C ANTIGEN','85302','1','','1','0','','','',0, 1, 0, 0),
(7579,'CLOTTING INHIBITORS PROTEIN C ACTIVITY','CLOTTING INHIBITORS PROTEIN C ACTIVITY','85303','1','','1','0','','','',0, 1, 0, 0),
(7580,'CLOTTING INHIBITORS PROTEIN S TOTAL','CLOTTING INHIBITORS PROTEIN S TOTAL','85305','1','','1','0','','','',0, 1, 0, 0),
(7581,'CLOTTING INHIBITORS PROTEIN S FREE','CLOTTING INHIBITORS PROTEIN S FREE','85306','1','','1','0','','','',0, 1, 0, 0),
(7582,'ACTIVATED PROTEIN C APC RESISTANCE ASSAY','ACTIVATED PROTEIN C APC RESISTANCE ASSAY','85307','1','','1','0','','','',0, 1, 0, 0),
(7583,'FACTOR INHIBITOR TEST','FACTOR INHIBITOR TEST','85335','1','','1','0','','','',0, 1, 0, 0),
(7584,'THROMBOMODULIN','THROMBOMODULIN','85337','1','','1','0','','','',0, 1, 0, 0),
(7585,'COAGULATION TIME LEE AND WHITE','COAGULATION TIME LEE AND WHITE','85345','1','','1','0','','','',0, 1, 0, 0),
(7586,'COAGULATION TIME ACTIVATED','COAGULATION TIME ACTIVATED','85347','1','','1','0','','','',0, 1, 0, 0),
(7587,'COAGULATION TIME OTHER METHODS','COAGULATION TIME OTHER METHODS','85348','1','','1','0','','','',0, 1, 0, 0),
(7588,'EUGLOBULIN LYSIS','EUGLOBULIN LYSIS','85360','1','','1','0','','','',0, 1, 0, 0),
(7589,'FIBRIN DGRADJ SPLT PRODUXS AGGLUJ SLIDE SEMIQUAN','FIBRIN DGRADJ SPLT PRODUXS AGGLUJ SLIDE SEMIQUAN','85362','1','','1','0','','','',0, 1, 0, 0),
(7590,'FIBRIN DGRADJ SPLT PRODUXS PARACOAGJ','FIBRIN DGRADJ SPLT PRODUXS PARACOAGJ','85366','1','','1','0','','','',0, 1, 0, 0),
(7591,'FIBRIN DGRADJ SPLT PRODUCTS QUANTITATIVE','FIBRIN DGRADJ SPLT PRODUCTS QUANTITATIVE','85370','1','','1','0','','','',0, 1, 0, 0),
(7592,'FIBRIN DGRADJ PRODUCTS D-DIMER QUAL/SEMIQUAN','FIBRIN DGRADJ PRODUCTS D-DIMER QUAL/SEMIQUAN','85378','1','','1','0','','','',0, 1, 0, 0),
(7593,'FIBRIN DGRADJ PRODUCTS D-DIMER QUANTITATIVE','FIBRIN DGRADJ PRODUCTS D-DIMER QUANTITATIVE','85379','1','','1','0','','','',0, 1, 0, 0),
(7594,'FIBRIN DGRADJ PRODUCTS D-DIMER ULTRASENSITIVE','FIBRIN DGRADJ PRODUCTS D-DIMER ULTRASENSITIVE','85380','1','','1','0','','','',0, 1, 0, 0),
(7595,'FIBRINOGEN ACTIVITY','FIBRINOGEN ACTIVITY','85384','1','','1','0','','','',0, 1, 0, 0),
(7596,'FIBRINOGEN ANTIGEN','FIBRINOGEN ANTIGEN','85385','1','','1','0','','','',0, 1, 0, 0),
(7597,'FIBRINOLYSINS/COAGULOPATHY SCREEN INTERP&REPOR','FIBRINOLYSINS/COAGULOPATHY SCREEN INTERP&REPOR','85390','1','','1','0','','','',0, 1, 0, 0),
(7598,'COAGJ/FBRNLYS ASSAY WHOLE BLOOD ADDITIVE PER DAY','COAGJ/FBRNLYS ASSAY WHOLE BLOOD ADDITIVE PER DAY','85396','1','','1','0','','','',0, 1, 0, 0),
(7599,'COAGJ&FIBRINOLYSIS FUNCTIONAL ACTV NOS EA ANAL','COAGJ&FIBRINOLYSIS FUNCTIONAL ACTV NOS EA ANAL','85397','1','','1','0','','','',0, 1, 0, 0),
(7600,'FIBRINOLYTIC FACTORS & INHIBITORS PLASMIN','FIBRINOLYTIC FACTORS & INHIBITORS PLASMIN','85400','1','','1','0','','','',0, 1, 0, 0),
(7601,'FBRNLYC FACTORS&INHIBITORS ALPHA-2 ANTIPLASMIN','FBRNLYC FACTORS&INHIBITORS ALPHA-2 ANTIPLASMIN','85410','1','','1','0','','','',0, 1, 0, 0),
(7602,'FBRNLYC FACTORS&INHIBITORS PLSMNG ACTIVATOR','FBRNLYC FACTORS&INHIBITORS PLSMNG ACTIVATOR','85415','1','','1','0','','','',0, 1, 0, 0),
(7603,'FBRNLYC FACTORS&INHIBITRS PLSMNG XCPT AGIC ASS','FBRNLYC FACTORS&INHIBITRS PLSMNG XCPT AGIC ASS','85420','1','','1','0','','','',0, 1, 0, 0),
(7604,'FBRNLYC FACTORS&INHIBITORS PLSMNG AGIC ASSAY','FBRNLYC FACTORS&INHIBITORS PLSMNG AGIC ASSAY','85421','1','','1','0','','','',0, 1, 0, 0),
(7605,'HEINZ BODIES DIRECT','HEINZ BODIES DIRECT','85441','1','','1','0','','','',0, 1, 0, 0),
(7606,'HEINZ BODIES INDUCED ACETYL PHENYLHYDRAZINE','HEINZ BODIES INDUCED ACETYL PHENYLHYDRAZINE','85445','1','','1','0','','','',0, 1, 0, 0),
(7607,'HGB/RBCS FETAL FETOMATERNAL HEMRRG DIFRNTL LYSIS','HGB/RBCS FETAL FETOMATERNAL HEMRRG DIFRNTL LYSIS','85460','1','','1','0','','','',0, 1, 0, 0),
(7608,'HGB/RBCS FETAL FETOMATERNAL HEMRRG ROSETTE','HGB/RBCS FETAL FETOMATERNAL HEMRRG ROSETTE','85461','1','','1','0','','','',0, 1, 0, 0),
(7609,'HEMOLYSIN ACID','HEMOLYSIN ACID','85475','1','','1','0','','','',0, 1, 0, 0),
(7610,'HEPARIN ASSAY','HEPARIN ASSAY','85520','1','','1','0','','','',0, 1, 0, 0),
(7611,'HEPARIN NEUTRALIZATION','HEPARIN NEUTRALIZATION','85525','1','','1','0','','','',0, 1, 0, 0),
(7612,'HEPARIN-PROTAMINE TOLERANCE TST','HEPARIN-PROTAMINE TOLERANCE TST','85530','1','','1','0','','','',0, 1, 0, 0),
(7613,'IRON STAIN PERIPHERAL BLOOD','IRON STAIN PERIPHERAL BLOOD','85536','1','','1','0','','','',0, 1, 0, 0),
(7614,'WBC ALKALINE PHOSPHATASE COUNT','WBC ALKALINE PHOSPHATASE COUNT','85540','1','','1','0','','','',0, 1, 0, 0),
(7615,'MECHANICAL FRAGILITY RBC','MECHANICAL FRAGILITY RBC','85547','1','','1','0','','','',0, 1, 0, 0),
(7616,'MURAMIDASE','MURAMIDASE','85549','1','','1','0','','','',0, 1, 0, 0),
(7617,'OSMOTIC FRAGILITY RBC UNINCUBATED','OSMOTIC FRAGILITY RBC UNINCUBATED','85555','1','','1','0','','','',0, 1, 0, 0),
(7618,'OSMOTIC FRAGILITY RBC INCUBATED','OSMOTIC FRAGILITY RBC INCUBATED','85557','1','','1','0','','','',0, 1, 0, 0),
(7619,'PLATELET AGGREGATION IN VITRO EACH AGENT','PLATELET AGGREGATION IN VITRO EACH AGENT','85576','1','','1','0','','','',0, 1, 0, 0),
(7620,'PHOSPHOLIPID NEUTRALIZATION PLATELET','PHOSPHOLIPID NEUTRALIZATION PLATELET','85597','1','','1','0','','','',0, 1, 0, 0),
(7621,'PHOSPHOLIPID NEUTRALIZATION HEXAGONAL','PHOSPHOLIPID NEUTRALIZATION HEXAGONAL','85598','1','','1','0','','','',0, 1, 0, 0),
(7622,'PROTHROMBIN TIME','PROTHROMBIN TIME','85610','1','','1','0','','','',0, 1, 0, 0),
(7623,'PROTHROMBIN TIME SUBSTITUTION PLASMA FRCTJ EACH','PROTHROMBIN TIME SUBSTITUTION PLASMA FRCTJ EACH','85611','1','','1','0','','','',0, 1, 0, 0),
(7624,'RUSSELL VIPER VENON TIME UNDILUTED','RUSSELL VIPER VENON TIME UNDILUTED','85612','1','','1','0','','','',0, 1, 0, 0),
(7625,'RUSSELL VIPER VENOM TIME DILUTED','RUSSELL VIPER VENOM TIME DILUTED','85613','1','','1','0','','','',0, 1, 0, 0),
(7626,'REPTILASE TEST','REPTILASE TEST','85635','1','','1','0','','','',0, 1, 0, 0),
(7627,'SEDIMENTATION RATE RBC NON-AUTOMATED','SEDIMENTATION RATE RBC NON-AUTOMATED','85651','1','','1','0','','','',0, 1, 0, 0),
(7628,'SEDIMENTATION RATE RBC AUTOMATED','SEDIMENTATION RATE RBC AUTOMATED','85652','1','','1','0','','','',0, 1, 0, 0),
(7629,'SICKLING RBC REDUCTION','SICKLING RBC REDUCTION','85660','1','','1','0','','','',0, 1, 0, 0),
(7630,'THROMBIN TIME PLASMA','THROMBIN TIME PLASMA','85670','1','','1','0','','','',0, 1, 0, 0),
(7631,'THROMBIN TIME TITER','THROMBIN TIME TITER','85675','1','','1','0','','','',0, 1, 0, 0),
(7632,'THROMBOPLASTIN INHIBITION TISSUE','THROMBOPLASTIN INHIBITION TISSUE','85705','1','','1','0','','','',0, 1, 0, 0),
(7633,'THROMBOPLASTIN TIME PARTIAL PLASMA/WHOLE BLOOD','THROMBOPLASTIN TIME PARTIAL PLASMA/WHOLE BLOOD','85730','1','','1','0','','','',0, 1, 0, 0),
(7634,'THROMBOPLASTIN TIME PRTL SUBSTIT PLASMA FRCTJ EA','THROMBOPLASTIN TIME PRTL SUBSTIT PLASMA FRCTJ EA','85732','1','','1','0','','','',0, 1, 0, 0),
(7635,'VISCOSITY','VISCOSITY','85810','1','','1','0','','','',0, 1, 0, 0),
(7636,'UNLISTED HEMATOLOGY & COAGULATION PROCEDURE','UNLISTED HEMATOLOGY & COAGULATION PROCEDURE','85999','1','','1','0','','','',0, 1, 0, 0),
(7637,'AGGLUTININS FEBRILE EACH ANTIGEN','AGGLUTININS FEBRILE EACH ANTIGEN','86000','1','','1','0','','','',0, 1, 0, 0),
(7638,'ALLERGEN SPECIFIC IGG QUAN/SEMIQUAN EA ALLERGEN','ALLERGEN SPECIFIC IGG QUAN/SEMIQUAN EA ALLERGEN','86001','1','','1','0','','','',0, 1, 0, 0),
(7639,'ALLERGEN SPECIFIC IGE QUAN/SEMIQUAN EA ALLERGEN','ALLERGEN SPECIFIC IGE QUAN/SEMIQUAN EA ALLERGEN','86003','1','','1','0','','','',0, 1, 0, 0),
(7640,'ALLERGEN SPECIFIC IGE QUAL MULTIALLERGEN SCREEN','ALLERGEN SPECIFIC IGE QUAL MULTIALLERGEN SCREEN','86005','1','','1','0','','','',0, 1, 0, 0),
(7641,'ANTIBODY IDENTIFICATION LEUKOCYTE ANTIBODIES','ANTIBODY IDENTIFICATION LEUKOCYTE ANTIBODIES','86021','1','','1','0','','','',0, 1, 0, 0),
(7642,'ANTIBODY IDENTIFICATION PLATELET ANTIBODIES','ANTIBODY IDENTIFICATION PLATELET ANTIBODIES','86022','1','','1','0','','','',0, 1, 0, 0),
(7643,'ANTIBODY IDENTIFICATION PLATELET IMMUNOGL ASSAY','ANTIBODY IDENTIFICATION PLATELET IMMUNOGL ASSAY','86023','1','','1','0','','','',0, 1, 0, 0),
(7644,'ANTINUCLEAR ANTIBODIES ANA','ANTINUCLEAR ANTIBODIES ANA','86038','1','','1','0','','','',0, 1, 0, 0),
(7645,'ANTINUCLEAR ANTIBODIES ANA TITER','ANTINUCLEAR ANTIBODIES ANA TITER','86039','1','','1','0','','','',0, 1, 0, 0),
(7646,'ANTISTREPTOLYSIN O TITER','ANTISTREPTOLYSIN O TITER','86060','1','','1','0','','','',0, 1, 0, 0),
(7647,'ANTISTREPTOLYSIN O SCREEN','ANTISTREPTOLYSIN O SCREEN','86063','1','','1','0','','','',0, 1, 0, 0),
(7648,'BLD BANK PHYS SVCS DIFFC CROSS MATCH&/EVAL REP','BLD BANK PHYS SVCS DIFFC CROSS MATCH&/EVAL REP','86077','1','','1','0','','','',0, 1, 0, 0),
(7649,'BLD BANK PHYS SVCS INVSTGJ TFUJ RXN REPRT','BLD BANK PHYS SVCS INVSTGJ TFUJ RXN REPRT','86078','1','','1','0','','','',0, 1, 0, 0),
(7650,'BLD BANK PHYS SVCS AUTHJ DEVIJ STANDARD REPRT','BLD BANK PHYS SVCS AUTHJ DEVIJ STANDARD REPRT','86079','1','','1','0','','','',0, 1, 0, 0),
(7651,'C-REACTIVE PROTEIN','C-REACTIVE PROTEIN','86140','1','','1','0','','','',0, 1, 0, 0),
(7652,'C-REACTIVE PROTEIN HIGH SENSITIVITY','C-REACTIVE PROTEIN HIGH SENSITIVITY','86141','1','','1','0','','','',0, 1, 0, 0),
(7653,'BETA 2 GLYCOPROTEIN I ANTIBODY EACH','BETA 2 GLYCOPROTEIN I ANTIBODY EACH','86146','1','','1','0','','','',0, 1, 0, 0),
(7654,'CARDIOLIPIN ANTIBODY EACH IG CLASS','CARDIOLIPIN ANTIBODY EACH IG CLASS','86147','1','','1','0','','','',0, 1, 0, 0),
(7655,'ANTI-PHOSPHATIDYLSERINE ANTIBODY','ANTI-PHOSPHATIDYLSERINE ANTIBODY','86148','1','','1','0','','','',0, 1, 0, 0),
(7656,'CELL ENUMERATION IMMUNE SELECTJ & ID FLUID SPEC','CELL ENUMERATION IMMUNE SELECTJ & ID FLUID SPEC','86152','1','','1','0','','','',0, 1, 0, 0),
(7657,'CELL ENUMERATION IMMUNE SELECTJ & ID PHYS INTERP','CELL ENUMERATION IMMUNE SELECTJ & ID PHYS INTERP','86153','1','','1','0','','','',0, 1, 0, 0),
(7658,'CHEMOTAXIS ASSAY SPECIFY METHOD','CHEMOTAXIS ASSAY SPECIFY METHOD','86155','1','','1','0','','','',0, 1, 0, 0),
(7659,'COLD AGGLUTININ SCREEN','COLD AGGLUTININ SCREEN','86156','1','','1','0','','','',0, 1, 0, 0),
(7660,'COLD AGGLUTININ TITER','COLD AGGLUTININ TITER','86157','1','','1','0','','','',0, 1, 0, 0),
(7661,'COMPLEMENT ANTIGEN EACH COMPONENT','COMPLEMENT ANTIGEN EACH COMPONENT','86160','1','','1','0','','','',0, 1, 0, 0),
(7662,'COMPLEMENT FUNCTIONAL ACTIVITY EACH COMPONENT','COMPLEMENT FUNCTIONAL ACTIVITY EACH COMPONENT','86161','1','','1','0','','','',0, 1, 0, 0),
(7663,'COMPLEMENT TOTAL HEMOLYTIC','COMPLEMENT TOTAL HEMOLYTIC','86162','1','','1','0','','','',0, 1, 0, 0),
(7664,'COMPLEMENT FIXATION TESTS EACH ANTIGEN','COMPLEMENT FIXATION TESTS EACH ANTIGEN','86171','1','','1','0','','','',0, 1, 0, 0),
(7665,'CNTERIMMUNOELECTROPHORESIS EACH ANTIGEN','CNTERIMMUNOELECTROPHORESIS EACH ANTIGEN','86185','1','','1','0','','','',0, 1, 0, 0),
(7666,'CYCLIC CITRULLINATED PEPTIDE ANTIBODY','CYCLIC CITRULLINATED PEPTIDE ANTIBODY','86200','1','','1','0','','','',0, 1, 0, 0),
(7667,'DEOXYRIBONUCLEASE ANTIBODY','DEOXYRIBONUCLEASE ANTIBODY','86215','1','','1','0','','','',0, 1, 0, 0),
(7668,'DNA ANTIBODY NATIVE/DOUBLE STRANDED','DNA ANTIBODY NATIVE/DOUBLE STRANDED','86225','1','','1','0','','','',0, 1, 0, 0),
(7669,'DNA ANTIBODY SINGLE STRANDED','DNA ANTIBODY SINGLE STRANDED','86226','1','','1','0','','','',0, 1, 0, 0),
(7670,'EXTRACTABLE NUCLEAR ANTIGEN ANTIBODY ANY METHOD','EXTRACTABLE NUCLEAR ANTIGEN ANTIBODY ANY METHOD','86235','1','','1','0','','','',0, 1, 0, 0),
(7671,'FC RECEPTOR','FC RECEPTOR','86243','1','','1','0','','','',0, 1, 0, 0),
(7672,'FLUORESCENT NONNFCT AGT ANTB SCREEN EA ANTIBODY','FLUORESCENT NONNFCT AGT ANTB SCREEN EA ANTIBODY','86255','1','','1','0','','','',0, 1, 0, 0),
(7673,'FLUORESCENT NONNFCT AGT ANTB TITER EA ANTIBODY','FLUORESCENT NONNFCT AGT ANTB TITER EA ANTIBODY','86256','1','','1','0','','','',0, 1, 0, 0),
(7674,'GROWTH HORMONE HUMAN ANTIBODY','GROWTH HORMONE HUMAN ANTIBODY','86277','1','','1','0','','','',0, 1, 0, 0),
(7675,'HEMAGGLUTINATION INHIBITION TEST HAI','HEMAGGLUTINATION INHIBITION TEST HAI','86280','1','','1','0','','','',0, 1, 0, 0),
(7676,'IMMUNOASSAY TUMOR ANTIGEN QUAL/SEMIQUANTITATIVE','IMMUNOASSAY TUMOR ANTIGEN QUAL/SEMIQUANTITATIVE','86294','1','','1','0','','','',0, 1, 0, 0),
(7677,'IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 15-3','IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 15-3','86300','1','','1','0','','','',0, 1, 0, 0),
(7678,'IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 19-9','IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 19-9','86301','1','','1','0','','','',0, 1, 0, 0),
(7679,'IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 125','IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE CA 125','86304','1','','1','0','','','',0, 1, 0, 0),
(7680,'HUMAN EPIDIDYMIS PROTEIN 4 (HE4)','HUMAN EPIDIDYMIS PROTEIN 4 (HE4)','86305','1','','1','0','','','',0, 1, 0, 0),
(7681,'HETEROPHILE ANTIBODIES SCREEN','HETEROPHILE ANTIBODIES SCREEN','86308','1','','1','0','','','',0, 1, 0, 0),
(7682,'HETEROPHILE ANTIBODIES TITER','HETEROPHILE ANTIBODIES TITER','86309','1','','1','0','','','',0, 1, 0, 0),
(7683,'HETEROPHILE ANTIBODIES TITER AFTER ABSORPTION','HETEROPHILE ANTIBODIES TITER AFTER ABSORPTION','86310','1','','1','0','','','',0, 1, 0, 0),
(7684,'IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE','IMMUNOASSAY TUMOR ANTIGEN QUANTITATIVE','86316','1','','1','0','','','',0, 1, 0, 0),
(7685,'IMMUNOASSAY INFECTIOUS AGENT ANTIBODY QUAN NOS','IMMUNOASSAY INFECTIOUS AGENT ANTIBODY QUAN NOS','86317','1','','1','0','','','',0, 1, 0, 0),
(7686,'IMMUNOASSAY NFCT AGT ANTB QUAL/SEMIQUAN 1 STEP','IMMUNOASSAY NFCT AGT ANTB QUAL/SEMIQUAN 1 STEP','86318','1','','1','0','','','',0, 1, 0, 0),
(7687,'IMMUNOELECTROPHORESIS SERUM','IMMUNOELECTROPHORESIS SERUM','86320','1','','1','0','','','',0, 1, 0, 0),
(7688,'IMMUNOELECTROPHORESIS OTHER FLUIDS CONCENTRATION','IMMUNOELECTROPHORESIS OTHER FLUIDS CONCENTRATION','86325','1','','1','0','','','',0, 1, 0, 0),
(7689,'IMMUNOELECTROPHORESIS CROSSED','IMMUNOELECTROPHORESIS CROSSED','86327','1','','1','0','','','',0, 1, 0, 0),
(7690,'IMMUNODIFFUSION NOT ELSEWHERE SPECIFIED','IMMUNODIFFUSION NOT ELSEWHERE SPECIFIED','86329','1','','1','0','','','',0, 1, 0, 0),
(7691,'IMMUNODIFFUSION GEL DIFFUSION QUAL EA AG/ANTBDY','IMMUNODIFFUSION GEL DIFFUSION QUAL EA AG/ANTBDY','86331','1','','1','0','','','',0, 1, 0, 0),
(7692,'IMMUNE COMPLEX ASSAY','IMMUNE COMPLEX ASSAY','86332','1','','1','0','','','',0, 1, 0, 0),
(7693,'IMMUNOFIXJ ELECTROPHORESIS SERUM','IMMUNOFIXJ ELECTROPHORESIS SERUM','86334','1','','1','0','','','',0, 1, 0, 0),
(7694,'IMMUNOFIXJ ELECTROPHORESIS OTHER FLUIDS','IMMUNOFIXJ ELECTROPHORESIS OTHER FLUIDS','86335','1','','1','0','','','',0, 1, 0, 0),
(7695,'INHIBIN A','INHIBIN A','86336','1','','1','0','','','',0, 1, 0, 0),
(7696,'INSULIN ANTIBODIES','INSULIN ANTIBODIES','86337','1','','1','0','','','',0, 1, 0, 0),
(7697,'INTRINSIC FACTOR ANTIBODIES','INTRINSIC FACTOR ANTIBODIES','86340','1','','1','0','','','',0, 1, 0, 0),
(7698,'ISLET CELL ANTIBODY','ISLET CELL ANTIBODY','86341','1','','1','0','','','',0, 1, 0, 0),
(7699,'LEUKOCYTE HISTAMINE RELEASE TEST LHR','LEUKOCYTE HISTAMINE RELEASE TEST LHR','86343','1','','1','0','','','',0, 1, 0, 0),
(7700,'LEUKOCYTE PHAGOCYTOSIS','LEUKOCYTE PHAGOCYTOSIS','86344','1','','1','0','','','',0, 1, 0, 0),
(7701,'CELLULAR FUNCTION ASSAY STIMUL&DETECT BIOMARKE','CELLULAR FUNCTION ASSAY STIMUL&DETECT BIOMARKE','86352','1','','1','0','','','',0, 1, 0, 0),
(7702,'LYMPHOCYTE TR MITOGEN/AG INDUCED BLASTOGENESIS','LYMPHOCYTE TR MITOGEN/AG INDUCED BLASTOGENESIS','86353','1','','1','0','','','',0, 1, 0, 0),
(7703,'B CELLS TOTAL COUNT','B CELLS TOTAL COUNT','86355','1','','1','0','','','',0, 1, 0, 0),
(7704,'MONONUCLEAR CELL ANTIGEN QUANTITATIVE NOS EA','MONONUCLEAR CELL ANTIGEN QUANTITATIVE NOS EA','86356','1','','1','0','','','',0, 1, 0, 0),
(7705,'NATURAL KILLER CELLS TOTAL COUNT','NATURAL KILLER CELLS TOTAL COUNT','86357','1','','1','0','','','',0, 1, 0, 0),
(7706,'T CELLS TOTAL COUNT','T CELLS TOTAL COUNT','86359','1','','1','0','','','',0, 1, 0, 0),
(7707,'T CELLS ABSOLUTE CD4&CD8 COUNT RATIO','T CELLS ABSOLUTE CD4&CD8 COUNT RATIO','86360','1','','1','0','','','',0, 1, 0, 0),
(7708,'T CELLS ABSOLUTE CD4 COUNT','T CELLS ABSOLUTE CD4 COUNT','86361','1','','1','0','','','',0, 1, 0, 0),
(7709,'STEM CELLS TOTAL COUNT','STEM CELLS TOTAL COUNT','86367','1','','1','0','','','',0, 1, 0, 0),
(7710,'MICROSOMAL ANTIBODIES EACH','MICROSOMAL ANTIBODIES EACH','86376','1','','1','0','','','',0, 1, 0, 0),
(7711,'MIGRATION INHIBITORY FACTOR TEST MIF','MIGRATION INHIBITORY FACTOR TEST MIF','86378','1','','1','0','','','',0, 1, 0, 0),
(7712,'NEUTRALIZATION TEST VIRAL','NEUTRALIZATION TEST VIRAL','86382','1','','1','0','','','',0, 1, 0, 0),
(7713,'NITROBLUE TETRAZOLIUM DYE TEST NTD','NITROBLUE TETRAZOLIUM DYE TEST NTD','86384','1','','1','0','','','',0, 1, 0, 0),
(7714,'NUCLEAR MATRIX PROTEIN 22 NMP22 QUALITATIVE','NUCLEAR MATRIX PROTEIN 22 NMP22 QUALITATIVE','86386','1','','1','0','','','',0, 1, 0, 0),
(7715,'PARTICLE AGGLUTINATION SCREEN EACH ANTIBODY','PARTICLE AGGLUTINATION SCREEN EACH ANTIBODY','86403','1','','1','0','','','',0, 1, 0, 0),
(7716,'PARTICLE AGGLUTINATION TITER EACH ANTIBODY','PARTICLE AGGLUTINATION TITER EACH ANTIBODY','86406','1','','1','0','','','',0, 1, 0, 0),
(7717,'RHEUMATOID FACTOR QUALITATIVE','RHEUMATOID FACTOR QUALITATIVE','86430','1','','1','0','','','',0, 1, 0, 0),
(7718,'RHEUMATOID FACTOR QUANTITATIVE','RHEUMATOID FACTOR QUANTITATIVE','86431','1','','1','0','','','',0, 1, 0, 0),
(7719,'TB CELL MEDIATED ANTIGN RESPNSE GAMMA INTERFERON','TB CELL MEDIATED ANTIGN RESPNSE GAMMA INTERFERON','86480','1','','1','0','','','',0, 1, 0, 0),
(7720,'TB ANTIGEN RESPONSE GAMMA INTERFERON T-CELL SUSP','TB ANTIGEN RESPONSE GAMMA INTERFERON T-CELL SUSP','86481','1','','1','0','','','',0, 1, 0, 0),
(7721,'SKIN TEST CANDIDA','SKIN TEST CANDIDA','86485','1','','1','0','','','',0, 1, 0, 0),
(7722,'SKIN TEST UNLISTED ANTIGEN EACH','SKIN TEST UNLISTED ANTIGEN EACH','86486','1','','1','0','','','',0, 1, 0, 0),
(7723,'SKIN TEST COCCIDIOIDOMYCOSIS','SKIN TEST COCCIDIOIDOMYCOSIS','86490','1','','1','0','','','',0, 1, 0, 0),
(7724,'SKIN TEST HISTOPLASMOSIS','SKIN TEST HISTOPLASMOSIS','86510','1','','1','0','','','',0, 1, 0, 0),
(7725,'SKIN TEST TUBERCULOSIS INTRADERMAL','SKIN TEST TUBERCULOSIS INTRADERMAL','86580','1','','1','0','','','',0, 1, 0, 0),
(7726,'STREPTOKINASE ANTIBODY','STREPTOKINASE ANTIBODY','86590','1','','1','0','','','',0, 1, 0, 0),
(7727,'SYPHILIS TEST NON-TREPONEMAL ANTIBODY QUAL','SYPHILIS TEST NON-TREPONEMAL ANTIBODY QUAL','86592','1','','1','0','','','',0, 1, 0, 0),
(7728,'SYPHILIS TEST QUANTITATIVE','SYPHILIS TEST QUANTITATIVE','86593','1','','1','0','','','',0, 1, 0, 0),
(7729,'ANTIBODY ACTINOMYCES','ANTIBODY ACTINOMYCES','86602','1','','1','0','','','',0, 1, 0, 0),
(7730,'ANTIBODY ADENOVIRUS','ANTIBODY ADENOVIRUS','86603','1','','1','0','','','',0, 1, 0, 0),
(7731,'ANTIBODY ASPERGILLUS','ANTIBODY ASPERGILLUS','86606','1','','1','0','','','',0, 1, 0, 0),
(7732,'ANTIBODY BACTERIUM NOT ELSEWHERE SPECIFIED','ANTIBODY BACTERIUM NOT ELSEWHERE SPECIFIED','86609','1','','1','0','','','',0, 1, 0, 0),
(7733,'ANTIBODY BARTONELLA','ANTIBODY BARTONELLA','86611','1','','1','0','','','',0, 1, 0, 0),
(7734,'ANTIBODY BLASTOMYCES','ANTIBODY BLASTOMYCES','86612','1','','1','0','','','',0, 1, 0, 0),
(7735,'ANTIBODY BORDETELLA','ANTIBODY BORDETELLA','86615','1','','1','0','','','',0, 1, 0, 0),
(7736,'ANTIBODY BORRELIA BURGDORFERI CONFIRMATORY TST','ANTIBODY BORRELIA BURGDORFERI CONFIRMATORY TST','86617','1','','1','0','','','',0, 1, 0, 0),
(7737,'ANTIBODY BORRELIA BURGDORFERI LYME DISEASE','ANTIBODY BORRELIA BURGDORFERI LYME DISEASE','86618','1','','1','0','','','',0, 1, 0, 0),
(7738,'ANTIBODY BORRELIA RELAPSING FEVER','ANTIBODY BORRELIA RELAPSING FEVER','86619','1','','1','0','','','',0, 1, 0, 0),
(7739,'ANTIBODY BRUCELLA','ANTIBODY BRUCELLA','86622','1','','1','0','','','',0, 1, 0, 0),
(7740,'ANTIBODY CAMPYLOBACTER','ANTIBODY CAMPYLOBACTER','86625','1','','1','0','','','',0, 1, 0, 0),
(7741,'ANTIBODY CANDIDA','ANTIBODY CANDIDA','86628','1','','1','0','','','',0, 1, 0, 0),
(7742,'ANTIBODY CHLAMYDIA','ANTIBODY CHLAMYDIA','86631','1','','1','0','','','',0, 1, 0, 0),
(7743,'ANTIBODY CHLAMYDIA IGM','ANTIBODY CHLAMYDIA IGM','86632','1','','1','0','','','',0, 1, 0, 0),
(7744,'ANTIBODY COCCIDIOIDES','ANTIBODY COCCIDIOIDES','86635','1','','1','0','','','',0, 1, 0, 0),
(7745,'ANTIBODY COXIELLA BURNETII Q FEVER','ANTIBODY COXIELLA BURNETII Q FEVER','86638','1','','1','0','','','',0, 1, 0, 0),
(7746,'ANTIBODY CRYPTOCOCCUS','ANTIBODY CRYPTOCOCCUS','86641','1','','1','0','','','',0, 1, 0, 0),
(7747,'ANTIBODY CYTOMEGALOVIRUS CMV','ANTIBODY CYTOMEGALOVIRUS CMV','86644','1','','1','0','','','',0, 1, 0, 0),
(7748,'ANTIBODY CYTOMEGALOVIRUS CMV IGM','ANTIBODY CYTOMEGALOVIRUS CMV IGM','86645','1','','1','0','','','',0, 1, 0, 0),
(7749,'ANTIBODY DIPHTHERIA','ANTIBODY DIPHTHERIA','86648','1','','1','0','','','',0, 1, 0, 0),
(7750,'ANTIBODY ENCEPHALITIS CALIFORNIA LA CROSSE','ANTIBODY ENCEPHALITIS CALIFORNIA LA CROSSE','86651','1','','1','0','','','',0, 1, 0, 0),
(7751,'ANTIBODY ENCEPHALITIS EASTERN EQUINE','ANTIBODY ENCEPHALITIS EASTERN EQUINE','86652','1','','1','0','','','',0, 1, 0, 0),
(7752,'ANTIBODY ENCEPHALITIS ST. LOUIS','ANTIBODY ENCEPHALITIS ST. LOUIS','86653','1','','1','0','','','',0, 1, 0, 0),
(7753,'ANTIBODY ENCEPHALITIS WESTRN EQUINE','ANTIBODY ENCEPHALITIS WESTRN EQUINE','86654','1','','1','0','','','',0, 1, 0, 0),
(7754,'ANTIBODY ENTEROVIRUS','ANTIBODY ENTEROVIRUS','86658','1','','1','0','','','',0, 1, 0, 0),
(7755,'ANTIBODY EPSTEIN-BARR EB VIRUS EARLY ANTIGEN EA','ANTIBODY EPSTEIN-BARR EB VIRUS EARLY ANTIGEN EA','86663','1','','1','0','','','',0, 1, 0, 0),
(7756,'ANTIBODY EPSTEIN-BARR EB VIRUS NUCLEAR AG EBNA','ANTIBODY EPSTEIN-BARR EB VIRUS NUCLEAR AG EBNA','86664','1','','1','0','','','',0, 1, 0, 0),
(7757,'ANTIBODY EPSTEIN-BARR EB VIRUS VIRAL CAPSID VCA','ANTIBODY EPSTEIN-BARR EB VIRUS VIRAL CAPSID VCA','86665','1','','1','0','','','',0, 1, 0, 0),
(7758,'ANTIBODY EHRLICHIA','ANTIBODY EHRLICHIA','86666','1','','1','0','','','',0, 1, 0, 0),
(7759,'ANTIBODY FRANCISELLA TULARENSIS','ANTIBODY FRANCISELLA TULARENSIS','86668','1','','1','0','','','',0, 1, 0, 0),
(7760,'ANTIBODY FUNGUS NOT ELSEWHERE SPECIFIED','ANTIBODY FUNGUS NOT ELSEWHERE SPECIFIED','86671','1','','1','0','','','',0, 1, 0, 0),
(7761,'ANTIBODY GIARDIA LAMBLIA','ANTIBODY GIARDIA LAMBLIA','86674','1','','1','0','','','',0, 1, 0, 0),
(7762,'ANTIBODY HELICOBACTER PYLORI','ANTIBODY HELICOBACTER PYLORI','86677','1','','1','0','','','',0, 1, 0, 0),
(7763,'ANTIBODY HELMINTH NOT ELSEWHERE SPECIFIED','ANTIBODY HELMINTH NOT ELSEWHERE SPECIFIED','86682','1','','1','0','','','',0, 1, 0, 0),
(7764,'ANTIBODY HAEMOPHILUS INFLUENZA','ANTIBODY HAEMOPHILUS INFLUENZA','86684','1','','1','0','','','',0, 1, 0, 0),
(7765,'ANTIBODY HTLV-I','ANTIBODY HTLV-I','86687','1','','1','0','','','',0, 1, 0, 0),
(7766,'ANTIBODY HTLV-II','ANTIBODY HTLV-II','86688','1','','1','0','','','',0, 1, 0, 0),
(7767,'ANTIBODY HTLV/HIV ANTIBODY CONFIRMATORY TEST','ANTIBODY HTLV/HIV ANTIBODY CONFIRMATORY TEST','86689','1','','1','0','','','',0, 1, 0, 0),
(7768,'ANTIBODY HEP DELTA AGENT','ANTIBODY HEP DELTA AGENT','86692','1','','1','0','','','',0, 1, 0, 0),
(7769,'ANTIBODY HERPES SMPLX NON-SPECIFIC TYPE TEST','ANTIBODY HERPES SMPLX NON-SPECIFIC TYPE TEST','86694','1','','1','0','','','',0, 1, 0, 0),
(7770,'ANTIBODY HERPES SMPLX TYPE 1','ANTIBODY HERPES SMPLX TYPE 1','86695','1','','1','0','','','',0, 1, 0, 0),
(7771,'ANTIBODY HERPES SMPLX TYPE 2','ANTIBODY HERPES SMPLX TYPE 2','86696','1','','1','0','','','',0, 1, 0, 0),
(7772,'ANTIBODY HISTOPLASMA','ANTIBODY HISTOPLASMA','86698','1','','1','0','','','',0, 1, 0, 0),
(7773,'ANTIBODY HIV-1','ANTIBODY HIV-1','86701','1','','1','0','','','',0, 1, 0, 0),
(7774,'ANTIBODY HIV-2','ANTIBODY HIV-2','86702','1','','1','0','','','',0, 1, 0, 0),
(7775,'ANTIBODY HIV-1&HIV-2 SINGLE RESULT','ANTIBODY HIV-1&HIV-2 SINGLE RESULT','86703','1','','1','0','','','',0, 1, 0, 0),
(7776,'HEPATITIS B CORE ANTIBODY HBCAB TOTAL','HEPATITIS B CORE ANTIBODY HBCAB TOTAL','86704','1','','1','0','','','',0, 1, 0, 0),
(7777,'HEPATITIS B CORE ANTIBODY HBCAB IGM ANTIBODY','HEPATITIS B CORE ANTIBODY HBCAB IGM ANTIBODY','86705','1','','1','0','','','',0, 1, 0, 0),
(7778,'HEPATITIS B SURF ANTIBODY HBSAB','HEPATITIS B SURF ANTIBODY HBSAB','86706','1','','1','0','','','',0, 1, 0, 0),
(7779,'HEPATITIS BE ANTIBODY HBEAB','HEPATITIS BE ANTIBODY HBEAB','86707','1','','1','0','','','',0, 1, 0, 0),
(7780,'HEPATITIS A ANTIBODY HAAB','HEPATITIS A ANTIBODY HAAB','86708','1','','1','0','','','',0, 1, 0, 0),
(7781,'HEPATITIS ANTIBODY HAAB IGM ANTIBODY','HEPATITIS ANTIBODY HAAB IGM ANTIBODY','86709','1','','1','0','','','',0, 1, 0, 0),
(7782,'ANTIBODY INFLUENZA VIRUS','ANTIBODY INFLUENZA VIRUS','86710','1','','1','0','','','',0, 1, 0, 0),
(7783,'ANTIBODY JOHN CUNNINGHAM VIRUS','ANTIBODY JOHN CUNNINGHAM VIRUS','86711','1','','1','0','','','',0, 1, 0, 0),
(7784,'ANTIBODY LEGIONELLA','ANTIBODY LEGIONELLA','86713','1','','1','0','','','',0, 1, 0, 0),
(7785,'ANTIBODY LEISHMANIA','ANTIBODY LEISHMANIA','86717','1','','1','0','','','',0, 1, 0, 0),
(7786,'ANTIBODY LEPTOSPIRA','ANTIBODY LEPTOSPIRA','86720','1','','1','0','','','',0, 1, 0, 0),
(7787,'ANTIBODY LISTERIA MONOCYTOGENES','ANTIBODY LISTERIA MONOCYTOGENES','86723','1','','1','0','','','',0, 1, 0, 0),
(7788,'ANTIBODY LYMPHOCYTIC CHORIOMENINGITIS','ANTIBODY LYMPHOCYTIC CHORIOMENINGITIS','86727','1','','1','0','','','',0, 1, 0, 0),
(7789,'ANTIBODY LYMPHOGRANULOMA VENEREUM','ANTIBODY LYMPHOGRANULOMA VENEREUM','86729','1','','1','0','','','',0, 1, 0, 0),
(7790,'ANTIBODY MUCORMYCOSIS','ANTIBODY MUCORMYCOSIS','86732','1','','1','0','','','',0, 1, 0, 0),
(7791,'ANTIBODY MUMPS','ANTIBODY MUMPS','86735','1','','1','0','','','',0, 1, 0, 0),
(7792,'ANTIBODY MYCOPLSM','ANTIBODY MYCOPLSM','86738','1','','1','0','','','',0, 1, 0, 0),
(7793,'ANTIBODY NEISSERIA MENINGITIDIS','ANTIBODY NEISSERIA MENINGITIDIS','86741','1','','1','0','','','',0, 1, 0, 0),
(7794,'ANTIBODY NOCARDIA','ANTIBODY NOCARDIA','86744','1','','1','0','','','',0, 1, 0, 0),
(7795,'ANTIBODY PARVOVIRUS','ANTIBODY PARVOVIRUS','86747','1','','1','0','','','',0, 1, 0, 0),
(7796,'ANTIBODY PLASMODIUM MALARIA','ANTIBODY PLASMODIUM MALARIA','86750','1','','1','0','','','',0, 1, 0, 0),
(7797,'ANTIBODY PROTOZOA NES','ANTIBODY PROTOZOA NES','86753','1','','1','0','','','',0, 1, 0, 0),
(7798,'ANTIBODY RESPIRATORY SYNCTIAL VIRUS','ANTIBODY RESPIRATORY SYNCTIAL VIRUS','86756','1','','1','0','','','',0, 1, 0, 0),
(7799,'ANTIBODY RICKETTSIA','ANTIBODY RICKETTSIA','86757','1','','1','0','','','',0, 1, 0, 0),
(7800,'ANTIBODY ROTAVIRUS','ANTIBODY ROTAVIRUS','86759','1','','1','0','','','',0, 1, 0, 0),
(7801,'ANTIBODY RUBELLA','ANTIBODY RUBELLA','86762','1','','1','0','','','',0, 1, 0, 0),
(7802,'ANTIBODY RUBEOLA','ANTIBODY RUBEOLA','86765','1','','1','0','','','',0, 1, 0, 0),
(7803,'ANTIBODY SALMONELLA','ANTIBODY SALMONELLA','86768','1','','1','0','','','',0, 1, 0, 0),
(7804,'ANTIBODY SHIGELLA','ANTIBODY SHIGELLA','86771','1','','1','0','','','',0, 1, 0, 0),
(7805,'ANTIBODY TETANUS','ANTIBODY TETANUS','86774','1','','1','0','','','',0, 1, 0, 0),
(7806,'ANTIBODY TOXOPLASMA','ANTIBODY TOXOPLASMA','86777','1','','1','0','','','',0, 1, 0, 0),
(7807,'ANTIBODY TOXOPLASMA IGM','ANTIBODY TOXOPLASMA IGM','86778','1','','1','0','','','',0, 1, 0, 0),
(7808,'ANTIBODY TREPONEMA PALLIDUM','ANTIBODY TREPONEMA PALLIDUM','86780','1','','1','0','','','',0, 1, 0, 0),
(7809,'ANTIBODY TRICHINELLA','ANTIBODY TRICHINELLA','86784','1','','1','0','','','',0, 1, 0, 0),
(7810,'ANTIBODY VARICELLA-ZOSTER','ANTIBODY VARICELLA-ZOSTER','86787','1','','1','0','','','',0, 1, 0, 0),
(7811,'ANTIBODY WEST NILE VIRUS IGM','ANTIBODY WEST NILE VIRUS IGM','86788','1','','1','0','','','',0, 1, 0, 0),
(7812,'ANTIBODY WEST NILE VIRUS','ANTIBODY WEST NILE VIRUS','86789','1','','1','0','','','',0, 1, 0, 0),
(7813,'ANTIBODY VIRUS NOT ELSEWHERE SPECIFIFED','ANTIBODY VIRUS NOT ELSEWHERE SPECIFIFED','86790','1','','1','0','','','',0, 1, 0, 0),
(7814,'ANTIBODY YERSINIA','ANTIBODY YERSINIA','86793','1','','1','0','','','',0, 1, 0, 0),
(7815,'THYROGLOBULIN ANTIBODY','THYROGLOBULIN ANTIBODY','86800','1','','1','0','','','',0, 1, 0, 0),
(7816,'HEPATITIS C ANTIBODY','HEPATITIS C ANTIBODY','86803','1','','1','0','','','',0, 1, 0, 0),
(7817,'HEPATITIS C ANTIBODY CONFIRMATORY TEST','HEPATITIS C ANTIBODY CONFIRMATORY TEST','86804','1','','1','0','','','',0, 1, 0, 0),
(7818,'LYMPHOCYTOTOXICITY ASSAY VIS CROSSMATCH TITRATJ','LYMPHOCYTOTOXICITY ASSAY VIS CROSSMATCH TITRATJ','86805','1','','1','0','','','',0, 1, 0, 0),
(7819,'LMPHOCYTOTOXICITY ASSAY VIS CROSSMTCH W/O TITRAT','LMPHOCYTOTOXICITY ASSAY VIS CROSSMTCH W/O TITRAT','86806','1','','1','0','','','',0, 1, 0, 0),
(7820,'SERUM SCREENING % REACTIVE ANTIBODY STANDRD METH','SERUM SCREENING % REACTIVE ANTIBODY STANDRD METH','86807','1','','1','0','','','',0, 1, 0, 0),
(7821,'SERUM SCREENING % REACTIVE ANTIBODY QUICK METH','SERUM SCREENING % REACTIVE ANTIBODY QUICK METH','86808','1','','1','0','','','',0, 1, 0, 0),
(7822,'HLA TYPING A/B/C SINGLE ANTIGEN','HLA TYPING A/B/C SINGLE ANTIGEN','86812','1','','1','0','','','',0, 1, 0, 0),
(7823,'HLA TYPING A/B/C MULTIPLE ANTIGENS','HLA TYPING A/B/C MULTIPLE ANTIGENS','86813','1','','1','0','','','',0, 1, 0, 0),
(7824,'HLA TYPING DR/DQ SINGLE ANTIGEN','HLA TYPING DR/DQ SINGLE ANTIGEN','86816','1','','1','0','','','',0, 1, 0, 0),
(7825,'HLA TYPING DR/DQ MULTIPLE ANTIGENS','HLA TYPING DR/DQ MULTIPLE ANTIGENS','86817','1','','1','0','','','',0, 1, 0, 0),
(7826,'HLA TYPING LYMPHOCYTE CULTURE MIXED','HLA TYPING LYMPHOCYTE CULTURE MIXED','86821','1','','1','0','','','',0, 1, 0, 0),
(7827,'HLA TYPING LYMPHOCYTE CULTURE PRIMED','HLA TYPING LYMPHOCYTE CULTURE PRIMED','86822','1','','1','0','','','',0, 1, 0, 0),
(7828,'HLA CROSSMATCH NONCYTOTOXIC 1ST SERUM/DILUTION','HLA CROSSMATCH NONCYTOTOXIC 1ST SERUM/DILUTION','86825','1','','1','0','','','',0, 1, 0, 0),
(7829,'HLA CROSSMATCH NONCYTOTOXIC ADDL SERUM/DILUTION','HLA CROSSMATCH NONCYTOTOXIC ADDL SERUM/DILUTION','86826','1','','1','0','','','',0, 1, 0, 0),
(7830,'ANTIBODY HLA CLASS I & CLASS II ANTIGENS QUAL','ANTIBODY HLA CLASS I & CLASS II ANTIGENS QUAL','86828','1','','1','0','','','',0, 1, 0, 0),
(7831,'ANTIBODY HLA CLASS I OR CLASS II ANTIGENS QUAL','ANTIBODY HLA CLASS I OR CLASS II ANTIGENS QUAL','86829','1','','1','0','','','',0, 1, 0, 0),
(7832,'ANTIBODY HLA CLASS I PHENOTYPE PANEL QUALITATIVE','ANTIBODY HLA CLASS I PHENOTYPE PANEL QUALITATIVE','86830','1','','1','0','','','',0, 1, 0, 0),
(7833,'ANTIBODY HLA CLASS II PHENOTYPE PANEL QUAL','ANTIBODY HLA CLASS II PHENOTYPE PANEL QUAL','86831','1','','1','0','','','',0, 1, 0, 0),
(7834,'ANTIBODY HLA CLASS I HIGH DEFINITION PANEL QUAL','ANTIBODY HLA CLASS I HIGH DEFINITION PANEL QUAL','86832','1','','1','0','','','',0, 1, 0, 0),
(7835,'ANTIBODY HLA CLASS II HIGH DEFINITION PANEL QUAL','ANTIBODY HLA CLASS II HIGH DEFINITION PANEL QUAL','86833','1','','1','0','','','',0, 1, 0, 0),
(7836,'ANTIBODY HLA CLASS I SEMIQUANTITATIVE PANEL','ANTIBODY HLA CLASS I SEMIQUANTITATIVE PANEL','86834','1','','1','0','','','',0, 1, 0, 0),
(7837,'ANTIBODY HLA CLASS II SEMIQUANTITATIVE PANEL','ANTIBODY HLA CLASS II SEMIQUANTITATIVE PANEL','86835','1','','1','0','','','',0, 1, 0, 0),
(7838,'UNLISTED IMMUNOLOGY','UNLISTED IMMUNOLOGY','86849','1','','1','0','','','',0, 1, 0, 0),
(7839,'ANTIBODY SCREEN RBC EACH SERUM TECHNIQUE','ANTIBODY SCREEN RBC EACH SERUM TECHNIQUE','86850','1','','1','0','','','',0, 1, 0, 0),
(7840,'ANTIBODY ELUTION RBC EACH ELUTION','ANTIBODY ELUTION RBC EACH ELUTION','86860','1','','1','0','','','',0, 1, 0, 0),
(7841,'ANTIBODY ID RBC ANTIBODIES EA PANEL EA SERUM TQ','ANTIBODY ID RBC ANTIBODIES EA PANEL EA SERUM TQ','86870','1','','1','0','','','',0, 1, 0, 0),
(7842,'ANTIHUMAN GLOBULIN DIRECT EACH ANTISERUM','ANTIHUMAN GLOBULIN DIRECT EACH ANTISERUM','86880','1','','1','0','','','',0, 1, 0, 0),
(7843,'ANTIHUMAN GLOBULIN INDIR QUAL EA REAGENT CELL','ANTIHUMAN GLOBULIN INDIR QUAL EA REAGENT CELL','86885','1','','1','0','','','',0, 1, 0, 0),
(7844,'ANTIHUMAN GLOBULIN INDIRECT EACH ANTIBODY TITER','ANTIHUMAN GLOBULIN INDIRECT EACH ANTIBODY TITER','86886','1','','1','0','','','',0, 1, 0, 0),
(7845,'AUTOL BLD/COMPONENT COLLJ STORAGE PREDEPOSITED','AUTOL BLD/COMPONENT COLLJ STORAGE PREDEPOSITED','86890','1','','1','0','','','',0, 1, 0, 0),
(7846,'AUTOL BLD/COMPONENT COLLJ STORAGE SALVAGE','AUTOL BLD/COMPONENT COLLJ STORAGE SALVAGE','86891','1','','1','0','','','',0, 1, 0, 0),
(7847,'BLOOD TYPING SEROLOGIC ABO','BLOOD TYPING SEROLOGIC ABO','86900','1','','1','0','','','',0, 1, 0, 0),
(7848,'BLOOD TYPING SEROLOGIC RH (D)','BLOOD TYPING SEROLOGIC RH (D)','86901','1','','1','0','','','',0, 1, 0, 0),
(7849,'BLOOD TYPE ANTIGEN DONOR REAGENT SERUM EACH','BLOOD TYPE ANTIGEN DONOR REAGENT SERUM EACH','86902','1','','1','0','','','',0, 1, 0, 0),
(7850,'BLOOD TYPING ANTIGEN SCREEN PATIENT SERUM/UNIT','BLOOD TYPING ANTIGEN SCREEN PATIENT SERUM/UNIT','86904','1','','1','0','','','',0, 1, 0, 0),
(7851,'BLOOD TYPING RBC ANTIGENS OTH/THN ABO/RH D EACH','BLOOD TYPING RBC ANTIGENS OTH/THN ABO/RH D EACH','86905','1','','1','0','','','',0, 1, 0, 0),
(7852,'BLOOD TYPING SEROLOGIC RH PHENOTYPING COMPLETE','BLOOD TYPING SEROLOGIC RH PHENOTYPING COMPLETE','86906','1','','1','0','','','',0, 1, 0, 0),
(7853,'BLOOD TYPING PATERNITY PR INDIV ABO RH&MN','BLOOD TYPING PATERNITY PR INDIV ABO RH&MN','86910','1','','1','0','','','',0, 1, 0, 0),
(7854,'BLOOD TYPING PATERNITY INDIV ADDL ANTIGEN SYS','BLOOD TYPING PATERNITY INDIV ADDL ANTIGEN SYS','86911','1','','1','0','','','',0, 1, 0, 0),
(7855,'COMPATIBILITY EACH UNIT IMMEDIATE SPIN TECHNIQUE','COMPATIBILITY EACH UNIT IMMEDIATE SPIN TECHNIQUE','86920','1','','1','0','','','',0, 1, 0, 0),
(7856,'COMPATIBILITY EACH UNIT INCUBATION','COMPATIBILITY EACH UNIT INCUBATION','86921','1','','1','0','','','',0, 1, 0, 0),
(7857,'COMPATIBILITY EACH UNIT ANTIGLOBULIN','COMPATIBILITY EACH UNIT ANTIGLOBULIN','86922','1','','1','0','','','',0, 1, 0, 0),
(7858,'COMPATIBILITY EACH UNIT ELECTRONIC','COMPATIBILITY EACH UNIT ELECTRONIC','86923','1','','1','0','','','',0, 1, 0, 0),
(7859,'FRESH FROZEN PLASMA THAWING EACH UNIT','FRESH FROZEN PLASMA THAWING EACH UNIT','86927','1','','1','0','','','',0, 1, 0, 0),
(7860,'FROZEN BLOOD EACH UNIT FREEZING','FROZEN BLOOD EACH UNIT FREEZING','86930','1','','1','0','','','',0, 1, 0, 0),
(7861,'FROZEN BLOOD EACH UNIT THAWING','FROZEN BLOOD EACH UNIT THAWING','86931','1','','1','0','','','',0, 1, 0, 0),
(7862,'FROZEN BLOOD EACH UNIT FREEZING & THAWING','FROZEN BLOOD EACH UNIT FREEZING & THAWING','86932','1','','1','0','','','',0, 1, 0, 0),
(7863,'HEMOLYSINS&AGGLUTININS AUTO SCREEN EACH','HEMOLYSINS&AGGLUTININS AUTO SCREEN EACH','86940','1','','1','0','','','',0, 1, 0, 0),
(7864,'HEMOLYSINS&AGGLUTININS INCUBATED','HEMOLYSINS&AGGLUTININS INCUBATED','86941','1','','1','0','','','',0, 1, 0, 0),
(7865,'IRRADIATION BLOOD PRODUCT EACH UNIT','IRRADIATION BLOOD PRODUCT EACH UNIT','86945','1','','1','0','','','',0, 1, 0, 0),
(7866,'LEUKOCYTE TRANSFUSION','LEUKOCYTE TRANSFUSION','86950','1','','1','0','','','',0, 1, 0, 0),
(7867,'VOLUME REDUCTION BLOOD/BLOOD PRODUCT EACH UNIT','VOLUME REDUCTION BLOOD/BLOOD PRODUCT EACH UNIT','86960','1','','1','0','','','',0, 1, 0, 0),
(7868,'POOLING PLATELETS/OTHER BLOOD PRODUCTS','POOLING PLATELETS/OTHER BLOOD PRODUCTS','86965','1','','1','0','','','',0, 1, 0, 0),
(7869,'PRETX RBC ANTIBODY INCUBAT W/CHEM AGNTS/DRUGS EA','PRETX RBC ANTIBODY INCUBAT W/CHEM AGNTS/DRUGS EA','86970','1','','1','0','','','',0, 1, 0, 0),
(7870,'PRETX RBC ANTIBODY INCUBAT W/ENZYMES EACH','PRETX RBC ANTIBODY INCUBAT W/ENZYMES EACH','86971','1','','1','0','','','',0, 1, 0, 0),
(7871,'PRETX RBC ANTIBODY INCUBAT W/DENSITY GRAD SEP','PRETX RBC ANTIBODY INCUBAT W/DENSITY GRAD SEP','86972','1','','1','0','','','',0, 1, 0, 0),
(7872,'PRETX SERUM RBC ANTIBODY INCUBATION DRUGS EACH','PRETX SERUM RBC ANTIBODY INCUBATION DRUGS EACH','86975','1','','1','0','','','',0, 1, 0, 0),
(7873,'PRETX SERUM RBC ANTIBODY IDENTIFICATION DILUTION','PRETX SERUM RBC ANTIBODY IDENTIFICATION DILUTION','86976','1','','1','0','','','',0, 1, 0, 0),
(7874,'PRETX SERUM RBC ANTB ID INCUBATION INHIBITORS EA','PRETX SERUM RBC ANTB ID INCUBATION INHIBITORS EA','86977','1','','1','0','','','',0, 1, 0, 0),
(7875,'PRETX SERUM RBC ANTIBODY ID DIFFIAL EACH ABSRPJ','PRETX SERUM RBC ANTIBODY ID DIFFIAL EACH ABSRPJ','86978','1','','1','0','','','',0, 1, 0, 0),
(7876,'SPLITTING BLOOD/BLOOD PRODUCTS EACH UNIT','SPLITTING BLOOD/BLOOD PRODUCTS EACH UNIT','86985','1','','1','0','','','',0, 1, 0, 0),
(7877,'UNLISTED TRANSFUSION MEDICINE PROCEDURE','UNLISTED TRANSFUSION MEDICINE PROCEDURE','86999','1','','1','0','','','',0, 1, 0, 0),
(7878,'ANIMAL INOCULATION SMALL ANIMAL W/OBS&DSJ','ANIMAL INOCULATION SMALL ANIMAL W/OBS&DSJ','87003','1','','1','0','','','',0, 1, 0, 0),
(7879,'CONCENTRATION INFECTIOUS AGENTS','CONCENTRATION INFECTIOUS AGENTS','87015','1','','1','0','','','',0, 1, 0, 0),
(7880,'CULTURE BACTERIAL BLOOD AEROBIC W/ID ISOLATES','CULTURE BACTERIAL BLOOD AEROBIC W/ID ISOLATES','87040','1','','1','0','','','',0, 1, 0, 0),
(7881,'CUL BACT STOOL AEROBIC ISOL SALMONELLA&SHIGELL','CUL BACT STOOL AEROBIC ISOL SALMONELLA&SHIGELL','87045','1','','1','0','','','',0, 1, 0, 0),
(7882,'CUL BACT STOOL AEROBIC ADDL PATHOGENS&ID EA','CUL BACT STOOL AEROBIC ADDL PATHOGENS&ID EA','87046','1','','1','0','','','',0, 1, 0, 0),
(7883,'CUL BACT XCPT URINE BLOOD/STOOL AEROBIC ISOL','CUL BACT XCPT URINE BLOOD/STOOL AEROBIC ISOL','87070','1','','1','0','','','',0, 1, 0, 0),
(7884,'CUL BACT QUAN AEROBIC ISOL XCPT UR BLOOD/STOOL','CUL BACT QUAN AEROBIC ISOL XCPT UR BLOOD/STOOL','87071','1','','1','0','','','',0, 1, 0, 0),
(7885,'CUL BACT QUAN ANAERC ISOL XCPT UR BLOOD/STOOL','CUL BACT QUAN ANAERC ISOL XCPT UR BLOOD/STOOL','87073','1','','1','0','','','',0, 1, 0, 0),
(7886,'CULTURE BACTERIAL ANY SOURCE ANAEROBIC ISO&ID','CULTURE BACTERIAL ANY SOURCE ANAEROBIC ISO&ID','87075','1','','1','0','','','',0, 1, 0, 0),
(7887,'CUL BACT ANAEROBIC ADDL METHS DEFINITIVE EA ISOL','CUL BACT ANAEROBIC ADDL METHS DEFINITIVE EA ISOL','87076','1','','1','0','','','',0, 1, 0, 0),
(7888,'CUL BACT AEROBIC ADDL METHS DEFINITIVE EA ISOL','CUL BACT AEROBIC ADDL METHS DEFINITIVE EA ISOL','87077','1','','1','0','','','',0, 1, 0, 0),
(7889,'CUL PRSMPTV PTHGNC ORGANISM SCRN W/COLONY ESTIMJ','CUL PRSMPTV PTHGNC ORGANISM SCRN W/COLONY ESTIMJ','87081','1','','1','0','','','',0, 1, 0, 0),
(7890,'CUL PRSMPTV PTHGNC ORGANISMS SCR DNS CHART','CUL PRSMPTV PTHGNC ORGANISMS SCR DNS CHART','87084','1','','1','0','','','',0, 1, 0, 0),
(7891,'CULTURE BACTERIAL QUANTTATIVE COLONY COUNT URINE','CULTURE BACTERIAL QUANTTATIVE COLONY COUNT URINE','87086','1','','1','0','','','',0, 1, 0, 0),
(7892,'CULTURE BCT ISOL&PRSMPTV ID ISOLATE EA URINE','CULTURE BCT ISOL&PRSMPTV ID ISOLATE EA URINE','87088','1','','1','0','','','',0, 1, 0, 0),
(7893,'CUL FNGI MOLD/YEAST PRSMPTV ID SKN HAIR/NAIL','CUL FNGI MOLD/YEAST PRSMPTV ID SKN HAIR/NAIL','87101','1','','1','0','','','',0, 1, 0, 0),
(7894,'CULTURE FNGI MOLD/YEAST PRSMPTV OTH XCPT BLOOD','CULTURE FNGI MOLD/YEAST PRSMPTV OTH XCPT BLOOD','87102','1','','1','0','','','',0, 1, 0, 0),
(7895,'CULTURE FNGI MOLD/YEAST ISOL PRSMPTV ISOL BLOOD','CULTURE FNGI MOLD/YEAST ISOL PRSMPTV ISOL BLOOD','87103','1','','1','0','','','',0, 1, 0, 0),
(7896,'CULTURE FUNGI DEFINITIVE ID EACH ORGANISM YEAST','CULTURE FUNGI DEFINITIVE ID EACH ORGANISM YEAST','87106','1','','1','0','','','',0, 1, 0, 0),
(7897,'CULTURE FUNGI DEFINITIVE ID EACH ORGANISM MOLD','CULTURE FUNGI DEFINITIVE ID EACH ORGANISM MOLD','87107','1','','1','0','','','',0, 1, 0, 0),
(7898,'CULTURE MYCOPLASMA ANY SOURCE','CULTURE MYCOPLASMA ANY SOURCE','87109','1','','1','0','','','',0, 1, 0, 0),
(7899,'CULTURE CHLAMYDIA ANY SOURCE','CULTURE CHLAMYDIA ANY SOURCE','87110','1','','1','0','','','',0, 1, 0, 0),
(7900,'CULTURE TUBERCLE/OTH ACID-FAST BACILLI ANY ISOL','CULTURE TUBERCLE/OTH ACID-FAST BACILLI ANY ISOL','87116','1','','1','0','','','',0, 1, 0, 0),
(7901,'CULTURE MYCOBACTERIAL DEFINITIVE ID EA ISOL','CULTURE MYCOBACTERIAL DEFINITIVE ID EA ISOL','87118','1','','1','0','','','',0, 1, 0, 0),
(7902,'CULTURE TYPING IMMUNOFLUORESCENT EACH ANTISERUM','CULTURE TYPING IMMUNOFLUORESCENT EACH ANTISERUM','87140','1','','1','0','','','',0, 1, 0, 0),
(7903,'CULTURE TYPING GAS/HIGH PRES LIQ CHROMATOGRAPHY','CULTURE TYPING GAS/HIGH PRES LIQ CHROMATOGRAPHY','87143','1','','1','0','','','',0, 1, 0, 0),
(7904,'CULTURE TYPING IMMUNOLOGIC OTH/THN IMMUNOFLUORES','CULTURE TYPING IMMUNOLOGIC OTH/THN IMMUNOFLUORES','87147','1','','1','0','','','',0, 1, 0, 0),
(7905,'CULTURE TYPING NUCLEIC ACID PROBE DIR EA ORGANSM','CULTURE TYPING NUCLEIC ACID PROBE DIR EA ORGANSM','87149','1','','1','0','','','',0, 1, 0, 0),
(7906,'CULTYP NUC ACID AMP PRB CULT/ISOLATE EA ORGNISM','CULTYP NUC ACID AMP PRB CULT/ISOLATE EA ORGNISM','87150','1','','1','0','','','',0, 1, 0, 0),
(7907,'CULTURE TYPING IDENTIFJ PULSE FIELD GEL TYPING','CULTURE TYPING IDENTIFJ PULSE FIELD GEL TYPING','87152','1','','1','0','','','',0, 1, 0, 0),
(7908,'CULTYP NUCLEIC ACID SEQUENCING METH EA ISOLATE','CULTYP NUCLEIC ACID SEQUENCING METH EA ISOLATE','87153','1','','1','0','','','',0, 1, 0, 0),
(7909,'CULTURE TYPING OTHER METHODS','CULTURE TYPING OTHER METHODS','87158','1','','1','0','','','',0, 1, 0, 0),
(7910,'DARK FIELD EXAM ANY SOURCE W/SPECIMEN COLLECTION','DARK FIELD EXAM ANY SOURCE W/SPECIMEN COLLECTION','87164','1','','1','0','','','',0, 1, 0, 0),
(7911,'DARK FIELD EXAM ANY SOURCE W/O SPECIMEN COLLECT','DARK FIELD EXAM ANY SOURCE W/O SPECIMEN COLLECT','87166','1','','1','0','','','',0, 1, 0, 0),
(7912,'MACROSCOPIC EXAMINATION ARTHROPOD','MACROSCOPIC EXAMINATION ARTHROPOD','87168','1','','1','0','','','',0, 1, 0, 0),
(7913,'MACROSCOPIC EXAMINATION PARASITE','MACROSCOPIC EXAMINATION PARASITE','87169','1','','1','0','','','',0, 1, 0, 0),
(7914,'PINWORM EXAMINATION','PINWORM EXAMINATION','87172','1','','1','0','','','',0, 1, 0, 0),
(7915,'HOMOGENIZATION TISSUE CULTURE','HOMOGENIZATION TISSUE CULTURE','87176','1','','1','0','','','',0, 1, 0, 0),
(7916,'OVA&PARASITES DIRECT SMEARS CONCENTRATION & ID','OVA&PARASITES DIRECT SMEARS CONCENTRATION & ID','87177','1','','1','0','','','',0, 1, 0, 0),
(7917,'SUSCEPTBILTY STDY ANTIMICRBIAL AGNT AGAR DILUTJ','SUSCEPTBILTY STDY ANTIMICRBIAL AGNT AGAR DILUTJ','87181','1','','1','0','','','',0, 1, 0, 0),
(7918,'SUSCEPTIBILITY STUDY ANTIMICROBIAL DISK METHOD','SUSCEPTIBILITY STUDY ANTIMICROBIAL DISK METHOD','87184','1','','1','0','','','',0, 1, 0, 0),
(7919,'SUSCEPTIBILITY STUDY ANTIMICROBIAL ENZYME DETCJ','SUSCEPTIBILITY STUDY ANTIMICROBIAL ENZYME DETCJ','87185','1','','1','0','','','',0, 1, 0, 0),
(7920,'SUSCEPTIBLTY STDY ANTIMICRBIAL MICRO/AGAR DILUTJ','SUSCEPTIBLTY STDY ANTIMICRBIAL MICRO/AGAR DILUTJ','87186','1','','1','0','','','',0, 1, 0, 0),
(7921,'SUSCEPTIBLTY STDY ANTMCRB MICRO/AGAR DILUTJ EA','SUSCEPTIBLTY STDY ANTMCRB MICRO/AGAR DILUTJ EA','87187','1','','1','0','','','',0, 1, 0, 0),
(7922,'SC STD ANTMCRB AGT MACROBROTH DIL METH EA AGT','SC STD ANTMCRB AGT MACROBROTH DIL METH EA AGT','87188','1','','1','0','','','',0, 1, 0, 0),
(7923,'SUSCEPTIBLTY STDY ANTMCRB MYCOBACT PROPORJ MTHD','SUSCEPTIBLTY STDY ANTMCRB MYCOBACT PROPORJ MTHD','87190','1','','1','0','','','',0, 1, 0, 0),
(7924,'SERUM BACTERICIDAL TITER','SERUM BACTERICIDAL TITER','87197','1','','1','0','','','',0, 1, 0, 0),
(7925,'SMR PRIM SRC GRAM/GIEMSA STAIN BCT FUNGI/CELL','SMR PRIM SRC GRAM/GIEMSA STAIN BCT FUNGI/CELL','87205','1','','1','0','','','',0, 1, 0, 0),
(7926,'SMR PRIM SRC FLUORESCENT&/AFS BCT FNGI PARASIT','SMR PRIM SRC FLUORESCENT&/AFS BCT FNGI PARASIT','87206','1','','1','0','','','',0, 1, 0, 0),
(7927,'SMR PRIM SRC SPEC STAIN BODIES/PARASITS','SMR PRIM SRC SPEC STAIN BODIES/PARASITS','87207','1','','1','0','','','',0, 1, 0, 0),
(7928,'SMR PRIM SRC CPLX SPEC STAIN OVA&PARASITS','SMR PRIM SRC CPLX SPEC STAIN OVA&PARASITS','87209','1','','1','0','','','',0, 1, 0, 0),
(7929,'SMR PRIM SRC WET MOUNT NFCT AGT','SMR PRIM SRC WET MOUNT NFCT AGT','87210','1','','1','0','','','',0, 1, 0, 0),
(7930,'TISS KOH SLIDE SAMPS SKN/HR/NLS FNGI/ECTOPARASIT','TISS KOH SLIDE SAMPS SKN/HR/NLS FNGI/ECTOPARASIT','87220','1','','1','0','','','',0, 1, 0, 0),
(7931,'TOXIN/ANTITOXIN ASSAY TISSUE CULTURE','TOXIN/ANTITOXIN ASSAY TISSUE CULTURE','87230','1','','1','0','','','',0, 1, 0, 0),
(7932,'VIRUS INOCULATION EGGS/SM ANIMAL OBS&DSJ','VIRUS INOCULATION EGGS/SM ANIMAL OBS&DSJ','87250','1','','1','0','','','',0, 1, 0, 0),
(7933,'VIRUS TISS CUL INOCULATION CYTOPATHIC EFFECT','VIRUS TISS CUL INOCULATION CYTOPATHIC EFFECT','87252','1','','1','0','','','',0, 1, 0, 0),
(7934,'VIRUS TISSUE CULTURE ADDL STDY/ID EACH ISOLATE','VIRUS TISSUE CULTURE ADDL STDY/ID EACH ISOLATE','87253','1','','1','0','','','',0, 1, 0, 0),
(7935,'VIRUS CENTRIFUGE ENHNCD ID IMFLUOR STAIN EA','VIRUS CENTRIFUGE ENHNCD ID IMFLUOR STAIN EA','87254','1','','1','0','','','',0, 1, 0, 0),
(7936,'VIRUS ID NON-IMMUNOLOGIC OTH/THN CYTOPATHIC','VIRUS ID NON-IMMUNOLOGIC OTH/THN CYTOPATHIC','87255','1','','1','0','','','',0, 1, 0, 0),
(7937,'IAADI ADENOVIRUS','IAADI ADENOVIRUS','87260','1','','1','0','','','',0, 1, 0, 0),
(7938,'IAADI BORDETELLA PRTUSSIS/PARAPRTUSSIS','IAADI BORDETELLA PRTUSSIS/PARAPRTUSSIS','87265','1','','1','0','','','',0, 1, 0, 0),
(7939,'IAADI ENTEROVIRUS DIRECT FLUORESCENT ANTIBODY','IAADI ENTEROVIRUS DIRECT FLUORESCENT ANTIBODY','87267','1','','1','0','','','',0, 1, 0, 0),
(7940,'IAADI GIARDIA','IAADI GIARDIA','87269','1','','1','0','','','',0, 1, 0, 0),
(7941,'IAADI CHLAMYDIA TRACHOMATIS','IAADI CHLAMYDIA TRACHOMATIS','87270','1','','1','0','','','',0, 1, 0, 0),
(7942,'IAADI CYTOMEGALOVIRUS DIR FLUORESCENT ANTIBODY','IAADI CYTOMEGALOVIRUS DIR FLUORESCENT ANTIBODY','87271','1','','1','0','','','',0, 1, 0, 0),
(7943,'IAADI CRYPTOSPORIDIUM','IAADI CRYPTOSPORIDIUM','87272','1','','1','0','','','',0, 1, 0, 0),
(7944,'IAADI HERPES SMPLX VIRUS TYPE 2','IAADI HERPES SMPLX VIRUS TYPE 2','87273','1','','1','0','','','',0, 1, 0, 0),
(7945,'IAADI HERPES SMPLX VIRUS TYPE 1','IAADI HERPES SMPLX VIRUS TYPE 1','87274','1','','1','0','','','',0, 1, 0, 0),
(7946,'IAADI INFLUENZA B VIRUS','IAADI INFLUENZA B VIRUS','87275','1','','1','0','','','',0, 1, 0, 0),
(7947,'IAADI INFFLUENZA A VIRUS','IAADI INFFLUENZA A VIRUS','87276','1','','1','0','','','',0, 1, 0, 0),
(7948,'IAADI LEGIONELLA MICDADEI','IAADI LEGIONELLA MICDADEI','87277','1','','1','0','','','',0, 1, 0, 0),
(7949,'IAADI LEGIONELLA PNEUMOPHILA','IAADI LEGIONELLA PNEUMOPHILA','87278','1','','1','0','','','',0, 1, 0, 0),
(7950,'IAADI PARAINFLUENZA VIRUS EACH TYPE','IAADI PARAINFLUENZA VIRUS EACH TYPE','87279','1','','1','0','','','',0, 1, 0, 0),
(7951,'IAADI RESPIRATORY SYNCTIAL VIRUS','IAADI RESPIRATORY SYNCTIAL VIRUS','87280','1','','1','0','','','',0, 1, 0, 0),
(7952,'IAADI PNEUMOCUSTIS CARINII','IAADI PNEUMOCUSTIS CARINII','87281','1','','1','0','','','',0, 1, 0, 0),
(7953,'IAADI RUBEOLA','IAADI RUBEOLA','87283','1','','1','0','','','',0, 1, 0, 0),
(7954,'IAADI TREPONEMA PALLIDUM','IAADI TREPONEMA PALLIDUM','87285','1','','1','0','','','',0, 1, 0, 0),
(7955,'IAADI VARICELLA ZOSTER VIRUS','IAADI VARICELLA ZOSTER VIRUS','87290','1','','1','0','','','',0, 1, 0, 0),
(7956,'IAADI NOT OTHERWISE SPECIFIED EACH ORGANISM','IAADI NOT OTHERWISE SPECIFIED EACH ORGANISM','87299','1','','1','0','','','',0, 1, 0, 0),
(7957,'IAADI POLYV MLT ORGANISMS EA POLYV ANTISERUM','IAADI POLYV MLT ORGANISMS EA POLYV ANTISERUM','87300','1','','1','0','','','',0, 1, 0, 0),
(7958,'IAAD IA ADENOVIRUS ENTERIC TYP 40/41','IAAD IA ADENOVIRUS ENTERIC TYP 40/41','87301','1','','1','0','','','',0, 1, 0, 0),
(7959,'IAAD IA QUAL/SEMIQUAN MULTIPLE STEP ASPERGILLUS','IAAD IA QUAL/SEMIQUAN MULTIPLE STEP ASPERGILLUS','87305','1','','1','0','','','',0, 1, 0, 0),
(7960,'IAAD IA CHLAMYDIA TRACHOMATIS','IAAD IA CHLAMYDIA TRACHOMATIS','87320','1','','1','0','','','',0, 1, 0, 0),
(7961,'IAAD IA CLOSTRIDIUM DIFFICILE TOXIN','IAAD IA CLOSTRIDIUM DIFFICILE TOXIN','87324','1','','1','0','','','',0, 1, 0, 0),
(7962,'IAAD IA CRYPTOCOCCUS NEOFORMANS','IAAD IA CRYPTOCOCCUS NEOFORMANS','87327','1','','1','0','','','',0, 1, 0, 0),
(7963,'IAAD IA CRYPTOSPORIDIUM','IAAD IA CRYPTOSPORIDIUM','87328','1','','1','0','','','',0, 1, 0, 0),
(7964,'IAAD IA GIARDIA','IAAD IA GIARDIA','87329','1','','1','0','','','',0, 1, 0, 0),
(7965,'IAAD IA CYTOMEGALOVIRUS','IAAD IA CYTOMEGALOVIRUS','87332','1','','1','0','','','',0, 1, 0, 0),
(7966,'IAAD IA ESCHERICHIA COLI 0157','IAAD IA ESCHERICHIA COLI 0157','87335','1','','1','0','','','',0, 1, 0, 0),
(7967,'IAAD IA ENTAMOEBA HISTOLYTICA DISPAR GRP','IAAD IA ENTAMOEBA HISTOLYTICA DISPAR GRP','87336','1','','1','0','','','',0, 1, 0, 0),
(7968,'IAAD IA ENTAMOEBA HISTOLYTICA GRP','IAAD IA ENTAMOEBA HISTOLYTICA GRP','87337','1','','1','0','','','',0, 1, 0, 0),
(7969,'IAAD IA HPYLORI STOOL','IAAD IA HPYLORI STOOL','87338','1','','1','0','','','',0, 1, 0, 0),
(7970,'IAAD IA HPYLORI','IAAD IA HPYLORI','87339','1','','1','0','','','',0, 1, 0, 0),
(7971,'IAAD IA HEPATITIS B SURFACE ANTIGEN','IAAD IA HEPATITIS B SURFACE ANTIGEN','87340','1','','1','0','','','',0, 1, 0, 0),
(7972,'IAAD IA HEPATITIS B SURFACE AG NEUTRALIZATION','IAAD IA HEPATITIS B SURFACE AG NEUTRALIZATION','87341','1','','1','0','','','',0, 1, 0, 0),
(7973,'IAAD IA HEPATITIS BE ANTIGEN','IAAD IA HEPATITIS BE ANTIGEN','87350','1','','1','0','','','',0, 1, 0, 0),
(7974,'IAAD IA HEPATITIS DELTA ANTIGEN','IAAD IA HEPATITIS DELTA ANTIGEN','87380','1','','1','0','','','',0, 1, 0, 0),
(7975,'IAAD IA HISTOPLASM CAPSULATUM','IAAD IA HISTOPLASM CAPSULATUM','87385','1','','1','0','','','',0, 1, 0, 0),
(7976,'IAAD IA HIV-1 AG W/HIV-1 & HIV-2 ANTBDY SINGLE','IAAD IA HIV-1 AG W/HIV-1 & HIV-2 ANTBDY SINGLE','87389','1','','1','0','','','',0, 1, 0, 0),
(7977,'IAAD IA HIV-1','IAAD IA HIV-1','87390','1','','1','0','','','',0, 1, 0, 0),
(7978,'IAAD IA HIV-2','IAAD IA HIV-2','87391','1','','1','0','','','',0, 1, 0, 0),
(7979,'IAAD IA INFLUENZA A/B EACH','IAAD IA INFLUENZA A/B EACH','87400','1','','1','0','','','',0, 1, 0, 0),
(7980,'IAAD IA RESPIRATORY SYNCTIAL VIRUS','IAAD IA RESPIRATORY SYNCTIAL VIRUS','87420','1','','1','0','','','',0, 1, 0, 0),
(7981,'IAAD IA ROTAVIRUS','IAAD IA ROTAVIRUS','87425','1','','1','0','','','',0, 1, 0, 0),
(7982,'IAAD IA SHIGA-LIKE TOXIN','IAAD IA SHIGA-LIKE TOXIN','87427','1','','1','0','','','',0, 1, 0, 0),
(7983,'IAAD IA STREPTOCOCCUS GROUP A','IAAD IA STREPTOCOCCUS GROUP A','87430','1','','1','0','','','',0, 1, 0, 0),
(7984,'IAAD IA MULT STEP METHOD NOS EACH ORGANISM','IAAD IA MULT STEP METHOD NOS EACH ORGANISM','87449','1','','1','0','','','',0, 1, 0, 0),
(7985,'IAAD IA SINGLE STEP METHOD NOS EA ORGANISM','IAAD IA SINGLE STEP METHOD NOS EA ORGANISM','87450','1','','1','0','','','',0, 1, 0, 0),
(7986,'IAAD IA POLYV MLT ORGANISMS EA POLYV ANTISERUM','IAAD IA POLYV MLT ORGANISMS EA POLYV ANTISERUM','87451','1','','1','0','','','',0, 1, 0, 0),
(7987,'IADNA BARTONELLA DIRECT PROBE TECHNIQUE','IADNA BARTONELLA DIRECT PROBE TECHNIQUE','87470','1','','1','0','','','',0, 1, 0, 0),
(7988,'IADNA BARTONELLA AMPLIFIED PROBE TECHNIQUE','IADNA BARTONELLA AMPLIFIED PROBE TECHNIQUE','87471','1','','1','0','','','',0, 1, 0, 0),
(7989,'IADNA BARTONELLA HENSELAE&QUINTANA QUANTJ','IADNA BARTONELLA HENSELAE&QUINTANA QUANTJ','87472','1','','1','0','','','',0, 1, 0, 0),
(7990,'IADNA BORRELIA BURGDORFERI DIRECT PROBE TQ','IADNA BORRELIA BURGDORFERI DIRECT PROBE TQ','87475','1','','1','0','','','',0, 1, 0, 0),
(7991,'IADNA BORRELIA BURGDORFERI AMPLIFIED PROBE TQ','IADNA BORRELIA BURGDORFERI AMPLIFIED PROBE TQ','87476','1','','1','0','','','',0, 1, 0, 0),
(7992,'IADNA BORRELIA BURGDORFERI QUANTIFICATION','IADNA BORRELIA BURGDORFERI QUANTIFICATION','87477','1','','1','0','','','',0, 1, 0, 0),
(7993,'IADNA CANDIDA SPECIES DIRECT PROBE TQ','IADNA CANDIDA SPECIES DIRECT PROBE TQ','87480','1','','1','0','','','',0, 1, 0, 0),
(7994,'IADNA CANDIDA SPECIES AMPLIFIED PROBE TQ','IADNA CANDIDA SPECIES AMPLIFIED PROBE TQ','87481','1','','1','0','','','',0, 1, 0, 0),
(7995,'IADNA CANDIDA SPECIES QUANTIFICATION','IADNA CANDIDA SPECIES QUANTIFICATION','87482','1','','1','0','','','',0, 1, 0, 0),
(7996,'IADNA CHLAMYDIA PNEUMONIAE DIRECT PROBE TQ','IADNA CHLAMYDIA PNEUMONIAE DIRECT PROBE TQ','87485','1','','1','0','','','',0, 1, 0, 0),
(7997,'IADNA CHLAMYDIA PNEUMONIAE AMPLIFIED PROBE TQ','IADNA CHLAMYDIA PNEUMONIAE AMPLIFIED PROBE TQ','87486','1','','1','0','','','',0, 1, 0, 0),
(7998,'IADNA CHLAMYDIA PNEUMONIAE QUANTIFICATION','IADNA CHLAMYDIA PNEUMONIAE QUANTIFICATION','87487','1','','1','0','','','',0, 1, 0, 0),
(7999,'IADNA CHLAMYDIA TRACHOMATIS DIRECT PROBE TQ','IADNA CHLAMYDIA TRACHOMATIS DIRECT PROBE TQ','87490','1','','1','0','','','',0, 1, 0, 0),
(8000,'IADNA CHLAMYDIA TRACHOMATIS AMPLIFIED PROBE TQ','IADNA CHLAMYDIA TRACHOMATIS AMPLIFIED PROBE TQ','87491','1','','1','0','','','',0, 1, 0, 0),
(8001,'IADNA CHLAMYDIA TRACHOMATIS QUANTIFICATION','IADNA CHLAMYDIA TRACHOMATIS QUANTIFICATION','87492','1','','1','0','','','',0, 1, 0, 0),
(8002,'INF AGENT DET NUCLEIC ACID CLOSTRIDIUM AMP PROBE','INF AGENT DET NUCLEIC ACID CLOSTRIDIUM AMP PROBE','87493','1','','1','0','','','',0, 1, 0, 0),
(8003,'IADNA CYTOMEGALOVIRUS DIRECT PROBE TQ','IADNA CYTOMEGALOVIRUS DIRECT PROBE TQ','87495','1','','1','0','','','',0, 1, 0, 0),
(8004,'IADNA CYTOMEGALOVIRUS AMPLIFIED PROBE TQ','IADNA CYTOMEGALOVIRUS AMPLIFIED PROBE TQ','87496','1','','1','0','','','',0, 1, 0, 0),
(8005,'IADNA CYTOMEGALOVIRUS QUANTIFICATION','IADNA CYTOMEGALOVIRUS QUANTIFICATION','87497','1','','1','0','','','',0, 1, 0, 0),
(8006,'IADNA ENTEROVIRUS AMPLIF PROBE & REVRSE TRNSCRIP','IADNA ENTEROVIRUS AMPLIF PROBE & REVRSE TRNSCRIP','87498','1','','1','0','','','',0, 1, 0, 0),
(8007,'INFECTIOUS AGENT DNA/RNA VANCOMYCIN RESISTANCE','INFECTIOUS AGENT DNA/RNA VANCOMYCIN RESISTANCE','87500','1','','1','0','','','',0, 1, 0, 0),
(8008,'INFECTIOUS AGENT DNA/RNA INFLUENZA EA TYPE','INFECTIOUS AGENT DNA/RNA INFLUENZA EA TYPE','87501','1','','1','0','','','',0, 1, 0, 0),
(8009,'INFECTIOUS AGENT DNA/RNA INFLUENZA 1ST 2 TYPES','INFECTIOUS AGENT DNA/RNA INFLUENZA 1ST 2 TYPES','87502','1','','1','0','','','',0, 1, 0, 0),
(8010,'NFCT AGENT DNA/RNA INFLUENZA >2 TYPES EA ADDL','NFCT AGENT DNA/RNA INFLUENZA >2 TYPES EA ADDL','87503','1','','1','0','','','',0, 1, 0, 0),
(8011,'NFCT AGENT DNA/RNA GASTROINTESTINAL PATHOGEN','NFCT AGENT DNA/RNA GASTROINTESTINAL PATHOGEN','87505','1','','1','0','','','',0, 1, 0, 0),
(8012,'IADNA-DNA/RNA GI PTHGN MULTIPLEX PROBE TQ 6-11','IADNA-DNA/RNA GI PTHGN MULTIPLEX PROBE TQ 6-11','87506','1','','1','0','','','',0, 1, 0, 0),
(8013,'IADNA-DNA/RNA GI PTHGN MULTIPLEX PROBE TQ 12-25','IADNA-DNA/RNA GI PTHGN MULTIPLEX PROBE TQ 12-25','87507','1','','1','0','','','',0, 1, 0, 0),
(8014,'IADNA GARDNERELLA VAGINALIS DIRECT PROBE TQ','IADNA GARDNERELLA VAGINALIS DIRECT PROBE TQ','87510','1','','1','0','','','',0, 1, 0, 0),
(8015,'IADNA GARDNERELLA VAGINALIS AMPLIFIED PROBE TQ','IADNA GARDNERELLA VAGINALIS AMPLIFIED PROBE TQ','87511','1','','1','0','','','',0, 1, 0, 0),
(8016,'IADNA GARDNERELLA VAGINALIS QUANTIFICATION','IADNA GARDNERELLA VAGINALIS QUANTIFICATION','87512','1','','1','0','','','',0, 1, 0, 0),
(8017,'IADNA HEPATITIS B VIRUS DIRECT PROBE TECHNIQUE','IADNA HEPATITIS B VIRUS DIRECT PROBE TECHNIQUE','87515','1','','1','0','','','',0, 1, 0, 0),
(8018,'IADNA HEPATITIS B VIRUS AMPLIFIED PROBE TQ','IADNA HEPATITIS B VIRUS AMPLIFIED PROBE TQ','87516','1','','1','0','','','',0, 1, 0, 0),
(8019,'IADNA HEPATITIS B VIRUS QUANTIFICATION','IADNA HEPATITIS B VIRUS QUANTIFICATION','87517','1','','1','0','','','',0, 1, 0, 0),
(8020,'IADNA HEPATITIS C DIRECT PROBE TECHNIQUE','IADNA HEPATITIS C DIRECT PROBE TECHNIQUE','87520','1','','1','0','','','',0, 1, 0, 0),
(8021,'IADNA HEPATITIS C AMPLIFIED PROBE&REVRSE TRANSCR','IADNA HEPATITIS C AMPLIFIED PROBE&REVRSE TRANSCR','87521','1','','1','0','','','',0, 1, 0, 0),
(8022,'IADNA HEPATITIS C QUANT & REVERSE TRANSCRIPTION','IADNA HEPATITIS C QUANT & REVERSE TRANSCRIPTION','87522','1','','1','0','','','',0, 1, 0, 0),
(8023,'IADNA HEPATITIS G DIRECT PROBE TECHNIQUE','IADNA HEPATITIS G DIRECT PROBE TECHNIQUE','87525','1','','1','0','','','',0, 1, 0, 0),
(8024,'IADNA HEPATITIS G AMPLIFIED PROBE TECHNIQUE','IADNA HEPATITIS G AMPLIFIED PROBE TECHNIQUE','87526','1','','1','0','','','',0, 1, 0, 0),
(8025,'IADNA HEPATITIS G QUANTIFICATION','IADNA HEPATITIS G QUANTIFICATION','87527','1','','1','0','','','',0, 1, 0, 0),
(8026,'IADNA HERPES SIMPLX VIRUS DIRECT PROBE TQ','IADNA HERPES SIMPLX VIRUS DIRECT PROBE TQ','87528','1','','1','0','','','',0, 1, 0, 0),
(8027,'IADNA HERPES SOMPLX VIRUS AMPLIFIED PROBE TQ','IADNA HERPES SOMPLX VIRUS AMPLIFIED PROBE TQ','87529','1','','1','0','','','',0, 1, 0, 0),
(8028,'IADNA HERPES SOMPLX VIRUS QUANTIFICATION','IADNA HERPES SOMPLX VIRUS QUANTIFICATION','87530','1','','1','0','','','',0, 1, 0, 0),
(8029,'IADNA HERPES VIRUS-6 DIRECT PROBE TQ','IADNA HERPES VIRUS-6 DIRECT PROBE TQ','87531','1','','1','0','','','',0, 1, 0, 0),
(8030,'IADNA HERPES VIRUS-6 AMPLIFIED PROBE TQ','IADNA HERPES VIRUS-6 AMPLIFIED PROBE TQ','87532','1','','1','0','','','',0, 1, 0, 0),
(8031,'IADNA HERPES VIRUS-6 QUANTIFICATION','IADNA HERPES VIRUS-6 QUANTIFICATION','87533','1','','1','0','','','',0, 1, 0, 0),
(8032,'IADNA HIV-1 DIRECT PROBE TECHNIQUE','IADNA HIV-1 DIRECT PROBE TECHNIQUE','87534','1','','1','0','','','',0, 1, 0, 0),
(8033,'IADNA HIV-1 AMPLIFIED PROBE & REVERSE TRANSCRPJ','IADNA HIV-1 AMPLIFIED PROBE & REVERSE TRANSCRPJ','87535','1','','1','0','','','',0, 1, 0, 0),
(8034,'IADNA HIV-1 QUANT & REVERSE TRANSCRIPTION','IADNA HIV-1 QUANT & REVERSE TRANSCRIPTION','87536','1','','1','0','','','',0, 1, 0, 0),
(8035,'IADNA HIV-2 DIRECT PROBE TECHNIQUE','IADNA HIV-2 DIRECT PROBE TECHNIQUE','87537','1','','1','0','','','',0, 1, 0, 0),
(8036,'IADNA HIV-2 AMPLIFIED PROBE & REVERSE TRANSCRIPJ','IADNA HIV-2 AMPLIFIED PROBE & REVERSE TRANSCRIPJ','87538','1','','1','0','','','',0, 1, 0, 0),
(8037,'IADNA HIV-2 QUANT & REVERSE TRANSCRIPTION','IADNA HIV-2 QUANT & REVERSE TRANSCRIPTION','87539','1','','1','0','','','',0, 1, 0, 0),
(8038,'IADNA LEGIONELLA PNEUMOPHILA DIRECT PROBE TQ','IADNA LEGIONELLA PNEUMOPHILA DIRECT PROBE TQ','87540','1','','1','0','','','',0, 1, 0, 0),
(8039,'IADNA LEGIONELLA PNEUMOPHILA AMPLIFIED PROBE TQ','IADNA LEGIONELLA PNEUMOPHILA AMPLIFIED PROBE TQ','87541','1','','1','0','','','',0, 1, 0, 0),
(8040,'IADNA LEGIONELLA PNEUMOPHILA QUANTIFICATION','IADNA LEGIONELLA PNEUMOPHILA QUANTIFICATION','87542','1','','1','0','','','',0, 1, 0, 0),
(8041,'IADNA MYCOBACTERIA SPECIES DIRECT PROBE TQ','IADNA MYCOBACTERIA SPECIES DIRECT PROBE TQ','87550','1','','1','0','','','',0, 1, 0, 0),
(8042,'IADNA MYCOBACTERIA SPECIES AMPLIFIED PROBE TQ','IADNA MYCOBACTERIA SPECIES AMPLIFIED PROBE TQ','87551','1','','1','0','','','',0, 1, 0, 0),
(8043,'IADNA MYCOBACTERIA SPECIES QUANTIFICATION','IADNA MYCOBACTERIA SPECIES QUANTIFICATION','87552','1','','1','0','','','',0, 1, 0, 0),
(8044,'IADNA MYCOBACTERIA TUBERCULOSIS DIR PRB','IADNA MYCOBACTERIA TUBERCULOSIS DIR PRB','87555','1','','1','0','','','',0, 1, 0, 0),
(8045,'IADNA MYCOBACTERIA TUBERCULOSIS AMP PRB','IADNA MYCOBACTERIA TUBERCULOSIS AMP PRB','87556','1','','1','0','','','',0, 1, 0, 0),
(8046,'IADNA MYCOBACTERIA TUBERCULOSIS QUANTIFICATION','IADNA MYCOBACTERIA TUBERCULOSIS QUANTIFICATION','87557','1','','1','0','','','',0, 1, 0, 0),
(8047,'IADNA MYCOBACTERIA AVIUM-INTRACLRE DIR PRB','IADNA MYCOBACTERIA AVIUM-INTRACLRE DIR PRB','87560','1','','1','0','','','',0, 1, 0, 0),
(8048,'IADNA MYCOBACTERIA AVIUM-INTRACLRE AMP PRB','IADNA MYCOBACTERIA AVIUM-INTRACLRE AMP PRB','87561','1','','1','0','','','',0, 1, 0, 0),
(8049,'IADNA MYCOBACTERIA AVIUM-INTRACELLULARE QUANT','IADNA MYCOBACTERIA AVIUM-INTRACELLULARE QUANT','87562','1','','1','0','','','',0, 1, 0, 0),
(8050,'IADNA MYCOPLSM PNEUMONIAE DIRECT PROBE TQ','IADNA MYCOPLSM PNEUMONIAE DIRECT PROBE TQ','87580','1','','1','0','','','',0, 1, 0, 0),
(8051,'IADNA MYCOPLSM PNEUMONIAE AMPLIFIED PROBE TQ','IADNA MYCOPLSM PNEUMONIAE AMPLIFIED PROBE TQ','87581','1','','1','0','','','',0, 1, 0, 0),
(8052,'IADNA MYCOPLSM PNEUMONIAE QUANTIFICATION','IADNA MYCOPLSM PNEUMONIAE QUANTIFICATION','87582','1','','1','0','','','',0, 1, 0, 0),
(8053,'IADNA NEISSERIA GONORRHOEAE DIRECT PROBE TQ','IADNA NEISSERIA GONORRHOEAE DIRECT PROBE TQ','87590','1','','1','0','','','',0, 1, 0, 0),
(8054,'IADNA NEISSERIA GONORRHOEAE AMPLIFIED PROBE TQ','IADNA NEISSERIA GONORRHOEAE AMPLIFIED PROBE TQ','87591','1','','1','0','','','',0, 1, 0, 0),
(8055,'IADNA NEISSERIA GONORRHOEAE QUANTIFICATION','IADNA NEISSERIA GONORRHOEAE QUANTIFICATION','87592','1','','1','0','','','',0, 1, 0, 0),
(8056,'IADNA HUMAN PAPILLOMAVIRUS LOW-RISK TYPES','IADNA HUMAN PAPILLOMAVIRUS LOW-RISK TYPES','87623','1','','1','0','','','',0, 1, 0, 0),
(8057,'IADNA HUMAN PAPILLOMAVIRUS HIGH-RISK TYPES','IADNA HUMAN PAPILLOMAVIRUS HIGH-RISK TYPES','87624','1','','1','0','','','',0, 1, 0, 0),
(8058,'IADNA HUMAN PAPILLOMAVIRUS TYPES 16 & 18 ONLY','IADNA HUMAN PAPILLOMAVIRUS TYPES 16 & 18 ONLY','87625','1','','1','0','','','',0, 1, 0, 0),
(8059,'IADNA RESPIRATRY PROBE & REV TRNSCR 3-5 TARGETS','IADNA RESPIRATRY PROBE & REV TRNSCR 3-5 TARGETS','87631','1','','1','0','','','',0, 1, 0, 0),
(8060,'IADNA RESPIRATRY PROBE & REV TRNSCR 6-11 TARGETS','IADNA RESPIRATRY PROBE & REV TRNSCR 6-11 TARGETS','87632','1','','1','0','','','',0, 1, 0, 0),
(8061,'IADNA RESPIRATRY PROBE & REV TRNSCR 12-25 TARGET','IADNA RESPIRATRY PROBE & REV TRNSCR 12-25 TARGET','87633','1','','1','0','','','',0, 1, 0, 0),
(8062,'IADNA S AUREUS AMPLIFIED PROBE TQ','IADNA S AUREUS AMPLIFIED PROBE TQ','87640','1','','1','0','','','',0, 1, 0, 0),
(8063,'IADNA S AUREUS METHICILLIN RESIST AMP PROBE TQ','IADNA S AUREUS METHICILLIN RESIST AMP PROBE TQ','87641','1','','1','0','','','',0, 1, 0, 0),
(8064,'IADNA STREPTOCOCCUS GROUP A DIRECT PROBE TQ','IADNA STREPTOCOCCUS GROUP A DIRECT PROBE TQ','87650','1','','1','0','','','',0, 1, 0, 0),
(8065,'IADNA STREPTOCOCCUS GROUP A AMPLIFIED PROBE TQ','IADNA STREPTOCOCCUS GROUP A AMPLIFIED PROBE TQ','87651','1','','1','0','','','',0, 1, 0, 0),
(8066,'IADNA STREPTOCOCCUS GROUP A QUANTIFICATION','IADNA STREPTOCOCCUS GROUP A QUANTIFICATION','87652','1','','1','0','','','',0, 1, 0, 0),
(8067,'IADNA STREPTOCOCCUS GROUP B AMPLIFIED PROBE TQ','IADNA STREPTOCOCCUS GROUP B AMPLIFIED PROBE TQ','87653','1','','1','0','','','',0, 1, 0, 0),
(8068,'IADNA TRICHOMONAS VAGINALIS DIRECT PROBE TQ','IADNA TRICHOMONAS VAGINALIS DIRECT PROBE TQ','87660','1','','1','0','','','',0, 1, 0, 0),
(8069,'IADNA TRICHOMONAS VAGINALIS AMPLIFIED PROBE TECH','IADNA TRICHOMONAS VAGINALIS AMPLIFIED PROBE TECH','87661','1','','1','0','','','',0, 1, 0, 0),
(8070,'IADNA NOS DIRECT PROBE TQ EACH ORGANISM','IADNA NOS DIRECT PROBE TQ EACH ORGANISM','87797','1','','1','0','','','',0, 1, 0, 0),
(8071,'IADNA NOS AMPLIFIED PROBE TQ EACH ORGANISM','IADNA NOS AMPLIFIED PROBE TQ EACH ORGANISM','87798','1','','1','0','','','',0, 1, 0, 0),
(8072,'IADNA NOS QUANTIFICATION EACH ORGANISM','IADNA NOS QUANTIFICATION EACH ORGANISM','87799','1','','1','0','','','',0, 1, 0, 0),
(8073,'IADNA MULTIPLE ORGANISMS DIRECT PROBE TQ','IADNA MULTIPLE ORGANISMS DIRECT PROBE TQ','87800','1','','1','0','','','',0, 1, 0, 0),
(8074,'IADNA MULTIPLE ORGANISMS AMPLIFIED PROBE TQ','IADNA MULTIPLE ORGANISMS AMPLIFIED PROBE TQ','87801','1','','1','0','','','',0, 1, 0, 0),
(8075,'IAADIADOO STREPTOCOCCUS GROUP B','IAADIADOO STREPTOCOCCUS GROUP B','87802','1','','1','0','','','',0, 1, 0, 0),
(8076,'IAADIADOO CLOSTRIDIUM DIFFICILE TOXIN','IAADIADOO CLOSTRIDIUM DIFFICILE TOXIN','87803','1','','1','0','','','',0, 1, 0, 0),
(8077,'IAADIADOO INFLUENZA','IAADIADOO INFLUENZA','87804','1','','1','0','','','',0, 1, 0, 0),
(8078,'IAADIADOO HIV1 ANTIGEN W/HIV1 & HIV2 ANTIBODIES','IAADIADOO HIV1 ANTIGEN W/HIV1 & HIV2 ANTIBODIES','87806','1','','1','0','','','',0, 1, 0, 0),
(8079,'IAADIADOO RESPIRATORY SYNCTIAL VIRUS','IAADIADOO RESPIRATORY SYNCTIAL VIRUS','87807','1','','1','0','','','',0, 1, 0, 0),
(8080,'IAADIADOO TRICHOMONAS VAGINALIS','IAADIADOO TRICHOMONAS VAGINALIS','87808','1','','1','0','','','',0, 1, 0, 0),
(8081,'INFECTIOUS AGENT IMMUNOASSAY OPTICAL ADENOVIRUS','INFECTIOUS AGENT IMMUNOASSAY OPTICAL ADENOVIRUS','87809','1','','1','0','','','',0, 1, 0, 0),
(8082,'CHLAMYDIA TRACHOMATIS','CHLAMYDIA TRACHOMATIS','87810','1','','1','0','','','',0, 1, 0, 0),
(8083,'IAADIADOO NEISSERIA GONORRHOEAE','IAADIADOO NEISSERIA GONORRHOEAE','87850','1','','1','0','','','',0, 1, 0, 0),
(8084,'IAADIADOO STREPTOCOCCUS GROUP A','IAADIADOO STREPTOCOCCUS GROUP A','87880','1','','1','0','','','',0, 1, 0, 0),
(8085,'IAADIADOO NOT OTHERWISE SPECIFIED','IAADIADOO NOT OTHERWISE SPECIFIED','87899','1','','1','0','','','',0, 1, 0, 0),
(8086,'NFCT AGT DRUG SUSCEPT PHENOTYPE PREDICTION','NFCT AGT DRUG SUSCEPT PHENOTYPE PREDICTION','87900','1','','1','0','','','',0, 1, 0, 0),
(8087,'NFCT GEXYP NUCLEIC ACID HIV REV TRNSCR&PROTEAS','NFCT GEXYP NUCLEIC ACID HIV REV TRNSCR&PROTEAS','87901','1','','1','0','','','',0, 1, 0, 0),
(8088,'NFCT AGNT GENOTYP NUCLEIC ACID HEPATITIS C VIRUS','NFCT AGNT GENOTYP NUCLEIC ACID HEPATITIS C VIRUS','87902','1','','1','0','','','',0, 1, 0, 0),
(8089,'NFCT PHEXYP RESIST TISS CUL HIV FIRST 1-10 DRUGS','NFCT PHEXYP RESIST TISS CUL HIV FIRST 1-10 DRUGS','87903','1','','1','0','','','',0, 1, 0, 0),
(8090,'NFCT PHEXYP RESIST TISS CUL HIV EA ADDL DRUG','NFCT PHEXYP RESIST TISS CUL HIV EA ADDL DRUG','87904','1','','1','0','','','',0, 1, 0, 0),
(8091,'INFECTIOUS AGENT ENZYMATIC ACTV OTH/THN VIRUS','INFECTIOUS AGENT ENZYMATIC ACTV OTH/THN VIRUS','87905','1','','1','0','','','',0, 1, 0, 0),
(8092,'NFCT GEXYP DNA/RNA HIV 1 OTHER REGION','NFCT GEXYP DNA/RNA HIV 1 OTHER REGION','87906','1','','1','0','','','',0, 1, 0, 0),
(8093,'NFCT AGT GENOTYPE NUCLEIC ACID CYTOMEGALOVIRUS','NFCT AGT GENOTYPE NUCLEIC ACID CYTOMEGALOVIRUS','87910','1','','1','0','','','',0, 1, 0, 0),
(8094,'NFCT AGENT GENOTYPE HEPATITIS B VIRUS','NFCT AGENT GENOTYPE HEPATITIS B VIRUS','87912','1','','1','0','','','',0, 1, 0, 0),
(8095,'UNLISTED MICROBIOLOGY','UNLISTED MICROBIOLOGY','87999','1','','1','0','','','',0, 1, 0, 0),
(8096,'NECROPSY GROSS EXAMINATION ONLY W/O CNS','NECROPSY GROSS EXAMINATION ONLY W/O CNS','88000','1','','1','0','','','',0, 1, 0, 0),
(8097,'NECROPSY GROSS EXAMINATION W/BRAIN','NECROPSY GROSS EXAMINATION W/BRAIN','88005','1','','1','0','','','',0, 1, 0, 0),
(8098,'NECROPSY GROSS EXAMINATION W/BRAIN&SPINAL CORD','NECROPSY GROSS EXAMINATION W/BRAIN&SPINAL CORD','88007','1','','1','0','','','',0, 1, 0, 0),
(8099,'NECROPSY GROSS EXAMINATION INFANT W/BRAIN','NECROPSY GROSS EXAMINATION INFANT W/BRAIN','88012','1','','1','0','','','',0, 1, 0, 0),
(8100,'NECROPSY GROSS EXAM STILLBORN/NEWBORN W/BRAIN','NECROPSY GROSS EXAM STILLBORN/NEWBORN W/BRAIN','88014','1','','1','0','','','',0, 1, 0, 0),
(8101,'NECROPSY GROSS EXAM MACERATED STILLBORN','NECROPSY GROSS EXAM MACERATED STILLBORN','88016','1','','1','0','','','',0, 1, 0, 0),
(8102,'NECROPSY GROSS & MICROSCOPIC W/O CNS','NECROPSY GROSS & MICROSCOPIC W/O CNS','88020','1','','1','0','','','',0, 1, 0, 0),
(8103,'NECROPSY GROSS & MICROSCOPIC W/BRAIN','NECROPSY GROSS & MICROSCOPIC W/BRAIN','88025','1','','1','0','','','',0, 1, 0, 0),
(8104,'NECROPSY GROSS&MCRSCP BRAIN & SPINAL CORD','NECROPSY GROSS&MCRSCP BRAIN & SPINAL CORD','88027','1','','1','0','','','',0, 1, 0, 0),
(8105,'NECROPSY GROSS & MICROSCOPIC INFANT W/BRAIN','NECROPSY GROSS & MICROSCOPIC INFANT W/BRAIN','88028','1','','1','0','','','',0, 1, 0, 0),
(8106,'NECROPSY GROSS&MCRSCP STILLBORN/NEWBORN BRAIN','NECROPSY GROSS&MCRSCP STILLBORN/NEWBORN BRAIN','88029','1','','1','0','','','',0, 1, 0, 0),
(8107,'NECROPSY LIMITED GROSS&/MCRSCP REGIONAL','NECROPSY LIMITED GROSS&/MCRSCP REGIONAL','88036','1','','1','0','','','',0, 1, 0, 0),
(8108,'NECROPSY LIMITD GROSS&/MCRSCP SINGLE ORGAN','NECROPSY LIMITD GROSS&/MCRSCP SINGLE ORGAN','88037','1','','1','0','','','',0, 1, 0, 0),
(8109,'NECROPSY FORENSIC EXAMINATION','NECROPSY FORENSIC EXAMINATION','88040','1','','1','0','','','',0, 1, 0, 0),
(8110,'NECROPSY CORONER CALL','NECROPSY CORONER CALL','88045','1','','1','0','','','',0, 1, 0, 0),
(8111,'UNLISTED NECROPSY PROCEDURE','UNLISTED NECROPSY PROCEDURE','88099','1','','1','0','','','',0, 1, 0, 0),
(8112,'CYTP FLU WASHGS/BRUSHINGS XCPT C/V SMRS INTERPJ','CYTP FLU WASHGS/BRUSHINGS XCPT C/V SMRS INTERPJ','88104','1','','1','0','','','',0, 1, 0, 0),
(8113,'CYTP FLU BR/WA XCPT C/V FILTER METH ONLY INTERPJ','CYTP FLU BR/WA XCPT C/V FILTER METH ONLY INTERPJ','88106','1','','1','0','','','',0, 1, 0, 0),
(8114,'CYTP CONCENTRATION SMEARS & INTERPRETATION','CYTP CONCENTRATION SMEARS & INTERPRETATION','88108','1','','1','0','','','',0, 1, 0, 0),
(8115,'CYTP SLCTV CELL ENHANCEMENT INTERPJ XCPT C/V','CYTP SLCTV CELL ENHANCEMENT INTERPJ XCPT C/V','88112','1','','1','0','','','',0, 1, 0, 0),
(8116,'CYTP INSITU HYBRID URINE SPEC 3-5 PROBES EA MNL','CYTP INSITU HYBRID URINE SPEC 3-5 PROBES EA MNL','88120','1','','1','0','','','',0, 1, 0, 0),
(8117,'CYTP INSITU HYBRID URNE SPEC 3-5 PROBES CPTR EA','CYTP INSITU HYBRID URNE SPEC 3-5 PROBES CPTR EA','88121','1','','1','0','','','',0, 1, 0, 0),
(8118,'CYTOPATHOLOGY FORENSIC','CYTOPATHOLOGY FORENSIC','88125','1','','1','0','','','',0, 1, 0, 0),
(8119,'SEX CHROMATIN IDENTIFICATION BARR BODIES','SEX CHROMATIN IDENTIFICATION BARR BODIES','88130','1','','1','0','','','',0, 1, 0, 0),
(8120,'SEX CHROMATIN IDENTJ PERIPHERAL BLOOD SMEAR','SEX CHROMATIN IDENTJ PERIPHERAL BLOOD SMEAR','88140','1','','1','0','','','',0, 1, 0, 0),
(8121,'CYTP CERVICAL/VAGINAL REQ INTERP PHYSICIAN','CYTP CERVICAL/VAGINAL REQ INTERP PHYSICIAN','88141','1','','1','0','','','',0, 1, 0, 0),
(8122,'CYTP CERV/VAG AUTO THIN LAYER PREP MNL SCREEN','CYTP CERV/VAG AUTO THIN LAYER PREP MNL SCREEN','88142','1','','1','0','','','',0, 1, 0, 0),
(8123,'CYTP C/V FLU AUTO THIN MNL SCR&RESCR PHYS','CYTP C/V FLU AUTO THIN MNL SCR&RESCR PHYS','88143','1','','1','0','','','',0, 1, 0, 0),
(8124,'CYTP SMRS C/V SCR AUTOMATED SYSTEM PHYS SUPV','CYTP SMRS C/V SCR AUTOMATED SYSTEM PHYS SUPV','88147','1','','1','0','','','',0, 1, 0, 0),
(8125,'CYTP SMRS C/V SCR AUTO SYS MNL RESCR PHYS','CYTP SMRS C/V SCR AUTO SYS MNL RESCR PHYS','88148','1','','1','0','','','',0, 1, 0, 0),
(8126,'CYTP SLIDES C/V MNL SCR UNDER PHYS','CYTP SLIDES C/V MNL SCR UNDER PHYS','88150','1','','1','0','','','',0, 1, 0, 0),
(8127,'CYTP SLIDES C/V MNL SCR&CPTR RESCR PHYS','CYTP SLIDES C/V MNL SCR&CPTR RESCR PHYS','88152','1','','1','0','','','',0, 1, 0, 0),
(8128,'CYTP SLIDES C/V MNL SCR&RESCR PHYS','CYTP SLIDES C/V MNL SCR&RESCR PHYS','88153','1','','1','0','','','',0, 1, 0, 0),
(8129,'CYTP SLIDES C/V MNL SCR&CPTR-RESCR CELL S&I','CYTP SLIDES C/V MNL SCR&CPTR-RESCR CELL S&I','88154','1','','1','0','','','',0, 1, 0, 0),
(8130,'CYTP SLIDES C/V DEFINITIVE HORMONAL EVAL','CYTP SLIDES C/V DEFINITIVE HORMONAL EVAL','88155','1','','1','0','','','',0, 1, 0, 0),
(8131,'CYTP SMRS ANY OTH SRC SCR&INTERPJ','CYTP SMRS ANY OTH SRC SCR&INTERPJ','88160','1','','1','0','','','',0, 1, 0, 0),
(8132,'CYTP SMRS ANY OTH SRC PREPJ SCR&INTERPJ','CYTP SMRS ANY OTH SRC PREPJ SCR&INTERPJ','88161','1','','1','0','','','',0, 1, 0, 0),
(8133,'CYTP SMRS ANY OTH SRC EXTND STD > 5 SLIDES','CYTP SMRS ANY OTH SRC EXTND STD > 5 SLIDES','88162','1','','1','0','','','',0, 1, 0, 0),
(8134,'CYTP SLIDES CERV/VAG MNL SCRN PHYSICIAN SUPV','CYTP SLIDES CERV/VAG MNL SCRN PHYSICIAN SUPV','88164','1','','1','0','','','',0, 1, 0, 0),
(8135,'CYTP SLIDES C/V MNL SCR&RESCR PHYS SUPV','CYTP SLIDES C/V MNL SCR&RESCR PHYS SUPV','88165','1','','1','0','','','',0, 1, 0, 0),
(8136,'CYTP SLIDES C/V MNL SCR&CPTR RESCR PHYS SUPV','CYTP SLIDES C/V MNL SCR&CPTR RESCR PHYS SUPV','88166','1','','1','0','','','',0, 1, 0, 0),
(8137,'CYTP SLIDES C/V MNL SCR&CPTR RESCR CELL S&I','CYTP SLIDES C/V MNL SCR&CPTR RESCR CELL S&I','88167','1','','1','0','','','',0, 1, 0, 0),
(8138,'CYTP FINE NDL ASPIRATE IMMT CYTOHIST STD DX 1ST','CYTP FINE NDL ASPIRATE IMMT CYTOHIST STD DX 1ST','88172','1','','1','0','','','',0, 1, 0, 0),
(8139,'CYTP EVAL FINE NEEDLE ASPIRATE INTERP & REPORT','CYTP EVAL FINE NEEDLE ASPIRATE INTERP & REPORT','88173','1','','1','0','','','',0, 1, 0, 0),
(8140,'CYTP C/V AUTO THIN LYR PREPJ SCR SYS PHYS','CYTP C/V AUTO THIN LYR PREPJ SCR SYS PHYS','88174','1','','1','0','','','',0, 1, 0, 0),
(8141,'CYTP C/V AUTO THIN LYR PREPJ SCR MNL RESCR PHYS','CYTP C/V AUTO THIN LYR PREPJ SCR MNL RESCR PHYS','88175','1','','1','0','','','',0, 1, 0, 0),
(8142,'CYTP FINE NDL ASPIRATE IMMT CYTOHIST STD EA EVAL','CYTP FINE NDL ASPIRATE IMMT CYTOHIST STD EA EVAL','88177','1','','1','0','','','',0, 1, 0, 0),
(8143,'FLOW CYTOMETRY CELL CYCLE/DNA ANALYSIS','FLOW CYTOMETRY CELL CYCLE/DNA ANALYSIS','88182','1','','1','0','','','',0, 1, 0, 0),
(8144,'FLOW CYTOMETRY CELL SURF MARKER TECHL ONLY 1ST','FLOW CYTOMETRY CELL SURF MARKER TECHL ONLY 1ST','88184','1','','1','0','','','',0, 1, 0, 0),
(8145,'FLOW CYTOMETRY CELL SURF MARKER TECHL ONLY EA','FLOW CYTOMETRY CELL SURF MARKER TECHL ONLY EA','88185','1','','1','0','','','',0, 1, 0, 0),
(8146,'FLOW CYTOMETRY INTERPJ 2-8 MARKERS','FLOW CYTOMETRY INTERPJ 2-8 MARKERS','88187','1','','1','0','','','',0, 1, 0, 0),
(8147,'FLOW CYTOMETRY INTERPJ 9-15 MARKERS','FLOW CYTOMETRY INTERPJ 9-15 MARKERS','88188','1','','1','0','','','',0, 1, 0, 0),
(8148,'FLOW CYTOMETRY INTERPRETATION 16/> MARKERS','FLOW CYTOMETRY INTERPRETATION 16/> MARKERS','88189','1','','1','0','','','',0, 1, 0, 0),
(8149,'UNLISTED CYTOPATHOLOGY PROCEDURE','UNLISTED CYTOPATHOLOGY PROCEDURE','88199','1','','1','0','','','',0, 1, 0, 0),
(8150,'TISS CUL NON-NEO DISORDERS LYMPHOCYTE','TISS CUL NON-NEO DISORDERS LYMPHOCYTE','88230','1','','1','0','','','',0, 1, 0, 0),
(8151,'TISS CUL NON-NEO DISORDERS SKN/OTH SOLID TISS BX','TISS CUL NON-NEO DISORDERS SKN/OTH SOLID TISS BX','88233','1','','1','0','','','',0, 1, 0, 0),
(8152,'TISS CUL NON-NEO DISORDERS AMNIOTIC/CHORNC CELLS','TISS CUL NON-NEO DISORDERS AMNIOTIC/CHORNC CELLS','88235','1','','1','0','','','',0, 1, 0, 0),
(8153,'TISS CUL NEO DISORDERS BONE MARROW BLOOD CELLS','TISS CUL NEO DISORDERS BONE MARROW BLOOD CELLS','88237','1','','1','0','','','',0, 1, 0, 0),
(8154,'TISS CUL NEO DISORDERS SOLID TUMOR','TISS CUL NEO DISORDERS SOLID TUMOR','88239','1','','1','0','','','',0, 1, 0, 0),
(8155,'CRYOPRSRV FRZING&STORAGE CELLS EA CELL LINE','CRYOPRSRV FRZING&STORAGE CELLS EA CELL LINE','88240','1','','1','0','','','',0, 1, 0, 0),
(8156,'THAWING&EXPANSION FROZEN CELLS EACH ALIQUOT','THAWING&EXPANSION FROZEN CELLS EACH ALIQUOT','88241','1','','1','0','','','',0, 1, 0, 0),
(8157,'CHRMSM BREAKAGE BASELINE SISTER 20-25 CLL','CHRMSM BREAKAGE BASELINE SISTER 20-25 CLL','88245','1','','1','0','','','',0, 1, 0, 0),
(8158,'CHRMSM BREAKAGE BASELINE BREAKAGE 50-100 CLL','CHRMSM BREAKAGE BASELINE BREAKAGE 50-100 CLL','88248','1','','1','0','','','',0, 1, 0, 0),
(8159,'CHRMSM BREAKAGE SYNDS SCORE 100 CLL','CHRMSM BREAKAGE SYNDS SCORE 100 CLL','88249','1','','1','0','','','',0, 1, 0, 0),
(8160,'CHRMSM COUNT 5 CELL 1KARYOTYPE BANDING','CHRMSM COUNT 5 CELL 1KARYOTYPE BANDING','88261','1','','1','0','','','',0, 1, 0, 0),
(8161,'CHRMSM COUNT 15-20 CLL 2KARYOTYP BANDING','CHRMSM COUNT 15-20 CLL 2KARYOTYP BANDING','88262','1','','1','0','','','',0, 1, 0, 0),
(8162,'CHRMSM COUNT 45 CELL MOSAICISM 2KARYOTYPE','CHRMSM COUNT 45 CELL MOSAICISM 2KARYOTYPE','88263','1','','1','0','','','',0, 1, 0, 0),
(8163,'CHRMSM ANALYZE 20-25 CELLS','CHRMSM ANALYZE 20-25 CELLS','88264','1','','1','0','','','',0, 1, 0, 0),
(8164,'CHRMSM ALYS AMNIOTIC/VILLUS 15 CELL 1KARYOTYPE','CHRMSM ALYS AMNIOTIC/VILLUS 15 CELL 1KARYOTYPE','88267','1','','1','0','','','',0, 1, 0, 0),
(8165,'CHRMSM SITU AMNIOTIC CLL 6-12 COLONIES 1KARYOTYP','CHRMSM SITU AMNIOTIC CLL 6-12 COLONIES 1KARYOTYP','88269','1','','1','0','','','',0, 1, 0, 0),
(8166,'MOLECULAR CYTOGENETICS DNA PROBE EACH','MOLECULAR CYTOGENETICS DNA PROBE EACH','88271','1','','1','0','','','',0, 1, 0, 0),
(8167,'MOLECULAR CYTOGENETICS CHRMOML ISH 3-5 CELLS','MOLECULAR CYTOGENETICS CHRMOML ISH 3-5 CELLS','88272','1','','1','0','','','',0, 1, 0, 0),
(8168,'MOLECULAR CYTOGENETICS CHRMOML ISH 10-30 CLL','MOLECULAR CYTOGENETICS CHRMOML ISH 10-30 CLL','88273','1','','1','0','','','',0, 1, 0, 0),
(8169,'MOLECULAR CYTOGENETICS INTERPHASE ISH 25-99 CLL','MOLECULAR CYTOGENETICS INTERPHASE ISH 25-99 CLL','88274','1','','1','0','','','',0, 1, 0, 0),
(8170,'MOLEC CYTG INTERPHASE ISH ANALYZE 100-300 CLL','MOLEC CYTG INTERPHASE ISH ANALYZE 100-300 CLL','88275','1','','1','0','','','',0, 1, 0, 0),
(8171,'CHRMSM ANALYSIS ADDL KARYOTYP EACH STUDY','CHRMSM ANALYSIS ADDL KARYOTYP EACH STUDY','88280','1','','1','0','','','',0, 1, 0, 0),
(8172,'CHRMSM ANALYSIS ADDL SPECIALIZED BANDING','CHRMSM ANALYSIS ADDL SPECIALIZED BANDING','88283','1','','1','0','','','',0, 1, 0, 0),
(8173,'CHRMSM ANALYSIS ADDL CELLS COUNTED EACH STUDY','CHRMSM ANALYSIS ADDL CELLS COUNTED EACH STUDY','88285','1','','1','0','','','',0, 1, 0, 0),
(8174,'CHRMSM ANALYSIS ADDL HIGH RESOLUTION STUDY','CHRMSM ANALYSIS ADDL HIGH RESOLUTION STUDY','88289','1','','1','0','','','',0, 1, 0, 0),
(8175,'CYTOGENETICS&MOLEC CYTOGENETICS INTERP&REP','CYTOGENETICS&MOLEC CYTOGENETICS INTERP&REP','88291','1','','1','0','','','',0, 1, 0, 0),
(8176,'UNLISTED CYTOGENETIC STUDY','UNLISTED CYTOGENETIC STUDY','88299','1','','1','0','','','',0, 1, 0, 0),
(8177,'LEVEL I SURG PATHOLOGY GROSS EXAMINATION ONLY','LEVEL I SURG PATHOLOGY GROSS EXAMINATION ONLY','88300','1','','1','0','','','',0, 1, 0, 0),
(8178,'LEVEL II SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','LEVEL II SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','88302','1','','1','0','','','',0, 1, 0, 0),
(8179,'LEVEL III SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','LEVEL III SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','88304','1','','1','0','','','',0, 1, 0, 0),
(8180,'LEVEL IV SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','LEVEL IV SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','88305','1','','1','0','','','',0, 1, 0, 0),
(8181,'LEVEL V SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','LEVEL V SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','88307','1','','1','0','','','',0, 1, 0, 0),
(8182,'LEVEL VI SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','LEVEL VI SURG PATHOLOGY GROSS&MICROSCOPIC EXAM','88309','1','','1','0','','','',0, 1, 0, 0),
(8183,'DECALCIFICATION PROCEDURE','DECALCIFICATION PROCEDURE','88311','1','','1','0','','','',0, 1, 0, 0),
(8184,'SPECIAL STAIN GROUP 1 MICROORGANISMS I&R','SPECIAL STAIN GROUP 1 MICROORGANISMS I&R','88312','1','','1','0','','','',0, 1, 0, 0),
(8185,'SPCL STN 2 I&R EXCPT MICROORG/ENZYME/IMCYT','SPCL STN 2 I&R EXCPT MICROORG/ENZYME/IMCYT','88313','1','','1','0','','','',0, 1, 0, 0),
(8186,'SPECIAL STAIN I&R HISTOCHEMICAL W/FROZEN TISSU','SPECIAL STAIN I&R HISTOCHEMICAL W/FROZEN TISSU','88314','1','','1','0','','','',0, 1, 0, 0),
(8187,'SPECIAL STAIN I&R GROUP III ENZYME CONSITUENTS','SPECIAL STAIN I&R GROUP III ENZYME CONSITUENTS','88319','1','','1','0','','','',0, 1, 0, 0),
(8188,'CONSLTJ&REPRT SLIDES PREPARED ELSEWHERE','CONSLTJ&REPRT SLIDES PREPARED ELSEWHERE','88321','1','','1','0','','','',0, 1, 0, 0),
(8189,'CONSLTJ&REPRT MATERIAL REQUIRING PREPJ SLIDES','CONSLTJ&REPRT MATERIAL REQUIRING PREPJ SLIDES','88323','1','','1','0','','','',0, 1, 0, 0),
(8190,'CONSLTJ COMPRE REVIEW REPRT REFERRED MATRL','CONSLTJ COMPRE REVIEW REPRT REFERRED MATRL','88325','1','','1','0','','','',0, 1, 0, 0),
(8191,'PATHOLOGY CONSULTATION DURING SURGERY','PATHOLOGY CONSULTATION DURING SURGERY','88329','1','','1','0','','','',0, 1, 0, 0),
(8192,'PATH CONSLTJ SURG 1ST BLK FROZEN SCTJ 1 SPEC','PATH CONSLTJ SURG 1ST BLK FROZEN SCTJ 1 SPEC','88331','1','','1','0','','','',0, 1, 0, 0),
(8193,'PATH CONSLTJ SURG EA ADDL BLK FROZEN SECTION','PATH CONSLTJ SURG EA ADDL BLK FROZEN SECTION','88332','1','','1','0','','','',0, 1, 0, 0),
(8194,'PATH CONSLTJ SURG CYTOLOGIC EXAM INITIAL SITE','PATH CONSLTJ SURG CYTOLOGIC EXAM INITIAL SITE','88333','1','','1','0','','','',0, 1, 0, 0),
(8195,'PATH CONSLTJ SURG CYTOLOGIC EXAM ADDL SITE','PATH CONSLTJ SURG CYTOLOGIC EXAM ADDL SITE','88334','1','','1','0','','','',0, 1, 0, 0),
(8196,'IMHISTOCHEM/CYTCHM EA ADDL ANTIBODY SLIDE','IMHISTOCHEM/CYTCHM EA ADDL ANTIBODY SLIDE','88341','1','','1','0','','','',0, 1, 0, 0),
(8197,'IMHISTOCHEM/CYTCHM 1ST ANTIBODY STAIN PROCEDURE','IMHISTOCHEM/CYTCHM 1ST ANTIBODY STAIN PROCEDURE','88342','1','','1','0','','','',0, 1, 0, 0),
(8198,'IMHISTOCHEM/CYTCHM EA MULTIPLEX ANTIBODY SLIDE','IMHISTOCHEM/CYTCHM EA MULTIPLEX ANTIBODY SLIDE','88344','1','','1','0','','','',0, 1, 0, 0),
(8199,'IMMUNOFLUORESCENCE PER SPEC 1ST SINGL ANTB STAIN','IMMUNOFLUORESCENCE PER SPEC 1ST SINGL ANTB STAIN','88346','1','','1','0','','','',0, 1, 0, 0),
(8200,'ELECTRON MICROSCOPY DIAGNOSTIC','ELECTRON MICROSCOPY DIAGNOSTIC','88348','1','','1','0','','','',0, 1, 0, 0),
(8201,'IMMUNOFLUORESCENCE PER SPEC ADD SINGL ANTB STAIN','IMMUNOFLUORESCENCE PER SPEC ADD SINGL ANTB STAIN','88350','1','','1','0','','','',0, 1, 0, 0),
(8202,'MORPHOMETRIC ANALYSIS SKELETAL MUSCLE','MORPHOMETRIC ANALYSIS SKELETAL MUSCLE','88355','1','','1','0','','','',0, 1, 0, 0),
(8203,'MORPHOMETRIC ANALYSIS NERVE','MORPHOMETRIC ANALYSIS NERVE','88356','1','','1','0','','','',0, 1, 0, 0),
(8204,'MORPHOMETRIC ANALYSIS TUMOR','MORPHOMETRIC ANALYSIS TUMOR','88358','1','','1','0','','','',0, 1, 0, 0),
(8205,'M/PHMTRC ALYS TUMOR IMHCHEM EA ANTIBODY MANUAL','M/PHMTRC ALYS TUMOR IMHCHEM EA ANTIBODY MANUAL','88360','1','','1','0','','','',0, 1, 0, 0),
(8206,'M/PHMTRC ALYS TUMOR IMHCHEM EA ANTBDY CMPTR ASST','M/PHMTRC ALYS TUMOR IMHCHEM EA ANTBDY CMPTR ASST','88361','1','','1','0','','','',0, 1, 0, 0),
(8207,'NERVE TEASING PREPARATIONS','NERVE TEASING PREPARATIONS','88362','1','','1','0','','','',0, 1, 0, 0),
(8208,'EXAM & SELECT ARCHIVE TISSUE MOLECULAR ANALYSI','EXAM & SELECT ARCHIVE TISSUE MOLECULAR ANALYSI','88363','1','','1','0','','','',0, 1, 0, 0),
(8209,'IN SITU HYBRIDIZATION EA ADDL PROBE STAIN','IN SITU HYBRIDIZATION EA ADDL PROBE STAIN','88364','1','','1','0','','','',0, 1, 0, 0),
(8210,'IN SITU HYBRIDIZATION 1ST PROBE STAIN','IN SITU HYBRIDIZATION 1ST PROBE STAIN','88365','1','','1','0','','','',0, 1, 0, 0),
(8211,'IN SITU HYBRIDIZATION EA MULTIPLEX PROBE STAIN','IN SITU HYBRIDIZATION EA MULTIPLEX PROBE STAIN','88366','1','','1','0','','','',0, 1, 0, 0),
(8212,'M/PHMTRC ALYS ISH CPTR-ASST TECH 1ST PROBE STAIN','M/PHMTRC ALYS ISH CPTR-ASST TECH 1ST PROBE STAIN','88367','1','','1','0','','','',0, 1, 0, 0),
(8213,'M/PHMTRC ALYS IN SITU HYBRIDIZATION EA PROBE MNL','M/PHMTRC ALYS IN SITU HYBRIDIZATION EA PROBE MNL','88368','1','','1','0','','','',0, 1, 0, 0),
(8214,'M/PHMTRC ALYS ISH QUANT/SEMIQ MNL PER SPEC EACH','M/PHMTRC ALYS ISH QUANT/SEMIQ MNL PER SPEC EACH','88369','1','','1','0','','','',0, 1, 0, 0),
(8215,'PROTEIN ANAL TISSUE WESTERN BLOT W/INTERP&REPO','PROTEIN ANAL TISSUE WESTERN BLOT W/INTERP&REPO','88371','1','','1','0','','','',0, 1, 0, 0),
(8216,'PROTEIN ALYS WSTRN BLOT I&R IMMUNOLOGICAL EA','PROTEIN ALYS WSTRN BLOT I&R IMMUNOLOGICAL EA','88372','1','','1','0','','','',0, 1, 0, 0),
(8217,'M/PHMTRC ALYS ISH QUANT/SEMIQ CPTR PER SPEC EACH','M/PHMTRC ALYS ISH QUANT/SEMIQ CPTR PER SPEC EACH','88373','1','','1','0','','','',0, 1, 0, 0),
(8218,'M/PHMTRC ALYS ISH QUANT/SEMIQ CPTR EACH MULTIPRB','M/PHMTRC ALYS ISH QUANT/SEMIQ CPTR EACH MULTIPRB','88374','1','','1','0','','','',0, 1, 0, 0),
(8219,'OPTICAL ENDOMICROSCOPIC IMAGE INTERP & REPORT','OPTICAL ENDOMICROSCOPIC IMAGE INTERP & REPORT','88375','1','','1','0','','','',0, 1, 0, 0),
(8220,'M/PHMTRC ALYS ISH QUANT/SEMIQ MNL EACH MULTIPRB','M/PHMTRC ALYS ISH QUANT/SEMIQ MNL EACH MULTIPRB','88377','1','','1','0','','','',0, 1, 0, 0),
(8221,'MICRODISSECTION PREP IDENTIFIED TARGET LASER','MICRODISSECTION PREP IDENTIFIED TARGET LASER','88380','1','','1','0','','','',0, 1, 0, 0),
(8222,'MICRODISSECTION PREP IDENTIFIED TARGET MANUAL','MICRODISSECTION PREP IDENTIFIED TARGET MANUAL','88381','1','','1','0','','','',0, 1, 0, 0),
(8223,'MACRO EXAM DISSECT&PREP TISS NONMICRO STD EA','MACRO EXAM DISSECT&PREP TISS NONMICRO STD EA','88387','1','','1','0','','','',0, 1, 0, 0),
(8224,'MACR EXM DISS&PRP NONMICR IMPRNT/CONSLT/FRZ SE','MACR EXM DISS&PRP NONMICR IMPRNT/CONSLT/FRZ SE','88388','1','','1','0','','','',0, 1, 0, 0),
(8225,'UNLISTED SURGICAL PATHOLOGY PROCEDURE','UNLISTED SURGICAL PATHOLOGY PROCEDURE','88399','1','','1','0','','','',0, 1, 0, 0),
(8226,'BILIRUBIN TOTAL TRANSCUTANEOUS','BILIRUBIN TOTAL TRANSCUTANEOUS','88720','1','','1','0','','','',0, 1, 0, 0),
(8227,'HGB QUANTITATIVE TRANSCUTANEOUS','HGB QUANTITATIVE TRANSCUTANEOUS','88738','1','','1','0','','','',0, 1, 0, 0),
(8228,'HEMOGLOBIN QUAN TC PER DAY CARBOXYHEMOGLOBIN','HEMOGLOBIN QUAN TC PER DAY CARBOXYHEMOGLOBIN','88740','1','','1','0','','','',0, 1, 0, 0),
(8229,'HEMOGLOBIN QUANTITATIVE TC PER DAY METHEMOGLOBIN','HEMOGLOBIN QUANTITATIVE TC PER DAY METHEMOGLOBIN','88741','1','','1','0','','','',0, 1, 0, 0),
(8230,'UNLISTED IN VIVO LABORTORY SERVICE','UNLISTED IN VIVO LABORTORY SERVICE','88749','1','','1','0','','','',0, 1, 0, 0),
(8231,'CAFFEINE HALOTHANE CONTRACTURE TEST','CAFFEINE HALOTHANE CONTRACTURE TEST','89049','1','','1','0','','','',0, 1, 0, 0),
(8232,'CELL COUNT MISCELLANEOUS BODY FLUIDS','CELL COUNT MISCELLANEOUS BODY FLUIDS','89050','1','','1','0','','','',0, 1, 0, 0),
(8233,'CELL COUNT MISC BODY FLUIDS W/DIFFERENTIAL COUNT','CELL COUNT MISC BODY FLUIDS W/DIFFERENTIAL COUNT','89051','1','','1','0','','','',0, 1, 0, 0),
(8234,'LEUKOCYTE ASSMT FECAL QUAL/SEMIQUANTITATIVE','LEUKOCYTE ASSMT FECAL QUAL/SEMIQUANTITATIVE','89055','1','','1','0','','','',0, 1, 0, 0),
(8235,'CRYSTAL ID LIGHT MICROSCOPY ALYS TISS/ANY FLUID','CRYSTAL ID LIGHT MICROSCOPY ALYS TISS/ANY FLUID','89060','1','','1','0','','','',0, 1, 0, 0),
(8236,'FAT STAIN FECES URINE/RESPIR SECRETIONS','FAT STAIN FECES URINE/RESPIR SECRETIONS','89125','1','','1','0','','','',0, 1, 0, 0),
(8237,'MEAT FIBERS FECES','MEAT FIBERS FECES','89160','1','','1','0','','','',0, 1, 0, 0),
(8238,'NASAL SMEAR EOSINOPHILS','NASAL SMEAR EOSINOPHILS','89190','1','','1','0','','','',0, 1, 0, 0),
(8239,'SPUTUM OBTAINING SPEC AEROSOL INDUCED TX SPX','SPUTUM OBTAINING SPEC AEROSOL INDUCED TX SPX','89220','1','','1','0','','','',0, 1, 0, 0),
(8240,'SWEAT COLLECTION IONTOPHORESIS','SWEAT COLLECTION IONTOPHORESIS','89230','1','','1','0','','','',0, 1, 0, 0),
(8241,'UNLIS MISC PATH','UNLIS MISC PATH','89240','1','','1','0','','','',0, 1, 0, 0),
(8242,'CUL OOCYTE/EMBRYO <4 DAYS','CUL OOCYTE/EMBRYO <4 DAYS','89250','1','','1','0','','','',0, 1, 0, 0),
(8243,'CUL OOCYTE/EMBRYO < 4 D CO-CULT OCYTE/EMBRY','CUL OOCYTE/EMBRYO < 4 D CO-CULT OCYTE/EMBRY','89251','1','','1','0','','','',0, 1, 0, 0),
(8244,'ASSTD EMBRYO HATCHING MICROTQS ANY METH','ASSTD EMBRYO HATCHING MICROTQS ANY METH','89253','1','','1','0','','','',0, 1, 0, 0),
(8245,'OOCYTE ID FROM FOLLICULAR FLU','OOCYTE ID FROM FOLLICULAR FLU','89254','1','','1','0','','','',0, 1, 0, 0),
(8246,'PREPJ EMBRYO TR','PREPJ EMBRYO TR','89255','1','','1','0','','','',0, 1, 0, 0),
(8247,'SPRM ID FROM ASPIR OTH/THN SEMINAL','SPRM ID FROM ASPIR OTH/THN SEMINAL','89257','1','','1','0','','','',0, 1, 0, 0),
(8248,'CRYOPRSRV EMBRYO','CRYOPRSRV EMBRYO','89258','1','','1','0','','','',0, 1, 0, 0),
(8249,'CRYOPRSRV SPRM','CRYOPRSRV SPRM','89259','1','','1','0','','','',0, 1, 0, 0),
(8250,'SPRM ISOL SMPL PREP INSEMINATION/DX SEMEN ALYS','SPRM ISOL SMPL PREP INSEMINATION/DX SEMEN ALYS','89260','1','','1','0','','','',0, 1, 0, 0),
(8251,'SPRM ISOL CPLX PREP INSEMINATION/DX SEMEN ALYS','SPRM ISOL CPLX PREP INSEMINATION/DX SEMEN ALYS','89261','1','','1','0','','','',0, 1, 0, 0),
(8252,'SPRM ID FROM TSTIS TISS FRSH/CRYOPRSRVD','SPRM ID FROM TSTIS TISS FRSH/CRYOPRSRVD','89264','1','','1','0','','','',0, 1, 0, 0),
(8253,'INSEMINATION OOCYTES','INSEMINATION OOCYTES','89268','1','','1','0','','','',0, 1, 0, 0),
(8254,'EXTND CUL OOCYTE/EMBRYO 4-7 DAYS','EXTND CUL OOCYTE/EMBRYO 4-7 DAYS','89272','1','','1','0','','','',0, 1, 0, 0),
(8255,'ASSTD FERTILIZATION MICROTQ </EQUAL 10 OOCYTES','ASSTD FERTILIZATION MICROTQ </EQUAL 10 OOCYTES','89280','1','','1','0','','','',0, 1, 0, 0),
(8256,'ASSTD FERTILIZATION MICROTQ > 10 OOCYTES','ASSTD FERTILIZATION MICROTQ > 10 OOCYTES','89281','1','','1','0','','','',0, 1, 0, 0),
(8257,'BX OOCYTE MICROTQ </= 5 EMBRY','BX OOCYTE MICROTQ </= 5 EMBRY','89290','1','','1','0','','','',0, 1, 0, 0),
(8258,'BX OOCYTE MICROTQ >5 EMBRY','BX OOCYTE MICROTQ >5 EMBRY','89291','1','','1','0','','','',0, 1, 0, 0),
(8259,'SEMEN ALYS PRESENCE&/MOTILITY SPRM HUHNER','SEMEN ALYS PRESENCE&/MOTILITY SPRM HUHNER','89300','1','','1','0','','','',0, 1, 0, 0),
(8260,'SEMEN ALYS MOTILITY&CNT X W/HUHNER TST','SEMEN ALYS MOTILITY&CNT X W/HUHNER TST','89310','1','','1','0','','','',0, 1, 0, 0),
(8261,'SEMEN ANALYSIS VOLUME COUNT MOTILITY DIFFERENT','SEMEN ANALYSIS VOLUME COUNT MOTILITY DIFFERENT','89320','1','','1','0','','','',0, 1, 0, 0),
(8262,'SEMEN ANALYSIS SPERM PRESENCE&/MOTILITY SPRM','SEMEN ANALYSIS SPERM PRESENCE&/MOTILITY SPRM','89321','1','','1','0','','','',0, 1, 0, 0),
(8263,'SEMEN ANALYSIS STRICT MORPHOLOGIC CRITERIA','SEMEN ANALYSIS STRICT MORPHOLOGIC CRITERIA','89322','1','','1','0','','','',0, 1, 0, 0),
(8264,'SPERM ANTIBODIES','SPERM ANTIBODIES','89325','1','','1','0','','','',0, 1, 0, 0),
(8265,'SPERM EVALUATION HAMSTER PENETRATION TEST','SPERM EVALUATION HAMSTER PENETRATION TEST','89329','1','','1','0','','','',0, 1, 0, 0),
(8266,'SPERM EVALUATION CERVICAL MUCOUS PENETRATION','SPERM EVALUATION CERVICAL MUCOUS PENETRATION','89330','1','','1','0','','','',0, 1, 0, 0),
(8267,'SPERM EVALUATION RETROGRADE EJACULATION URINE','SPERM EVALUATION RETROGRADE EJACULATION URINE','89331','1','','1','0','','','',0, 1, 0, 0),
(8268,'CRYOPRSRV REPRODUCTIVE TISSUE TESTICULAR','CRYOPRSRV REPRODUCTIVE TISSUE TESTICULAR','89335','1','','1','0','','','',0, 1, 0, 0),
(8269,'CRYOPRESERVATION MATURE OOCYTE(S)','CRYOPRESERVATION MATURE OOCYTE(S)','89337','1','','1','0','','','',0, 1, 0, 0),
(8270,'STORAGE PER YEAR EMBRYO','STORAGE PER YEAR EMBRYO','89342','1','','1','0','','','',0, 1, 0, 0),
(8271,'STORAGE PER YEAR SPERM/SEMEN','STORAGE PER YEAR SPERM/SEMEN','89343','1','','1','0','','','',0, 1, 0, 0),
(8272,'STORAGE PER YR REPRDTVE TISS TSTICULAR/OVARIAN','STORAGE PER YR REPRDTVE TISS TSTICULAR/OVARIAN','89344','1','','1','0','','','',0, 1, 0, 0),
(8273,'STORAGE PER YEAR OOCYTE','STORAGE PER YEAR OOCYTE','89346','1','','1','0','','','',0, 1, 0, 0),
(8274,'THAWING CRYOPRESERVED EMBRYO','THAWING CRYOPRESERVED EMBRYO','89352','1','','1','0','','','',0, 1, 0, 0),
(8275,'THAWING CRYOPRESERVED SPERM/SEMEN EACH ALIQUOT','THAWING CRYOPRESERVED SPERM/SEMEN EACH ALIQUOT','89353','1','','1','0','','','',0, 1, 0, 0),
(8276,'THAWING CRYOPRESERVED TESTICULAR/OVARIAN','THAWING CRYOPRESERVED TESTICULAR/OVARIAN','89354','1','','1','0','','','',0, 1, 0, 0),
(8277,'THAWING CRYOPRESERVED OOCYTES EACH ALIQUOT','THAWING CRYOPRESERVED OOCYTES EACH ALIQUOT','89356','1','','1','0','','','',0, 1, 0, 0),
(8278,'UNLISTED REPRODUCTIVE MEDICINE LAB PROCEDURE','UNLISTED REPRODUCTIVE MEDICINE LAB PROCEDURE','89398','1','','1','0','','','',0, 1, 0, 0),
(8279,'IMMUNE GLOBULIN IG HUMAN IM USE','IMMUNE GLOBULIN IG HUMAN IM USE','90281','1','','1','0','','','',0, 1, 0, 0),
(8280,'IMMUNE GLOBULIN IGIV HUMAN IV USE','IMMUNE GLOBULIN IGIV HUMAN IV USE','90283','1','','1','0','','','',0, 1, 0, 0),
(8281,'IMMUNE GLOBULIN HUMAN SUBQ INFUSION 100 MG EA','IMMUNE GLOBULIN HUMAN SUBQ INFUSION 100 MG EA','90284','1','','1','0','','','',0, 1, 0, 0),
(8282,'BOTULINUM ANTITOXIN EQUINE ANY ROUTE','BOTULINUM ANTITOXIN EQUINE ANY ROUTE','90287','1','','1','0','','','',0, 1, 0, 0),
(8283,'BOTULISM IMMUNE GLOBULIN HUMAN INTRAVENOUS USE','BOTULISM IMMUNE GLOBULIN HUMAN INTRAVENOUS USE','90288','1','','1','0','','','',0, 1, 0, 0),
(8284,'CYTOMEGALOVIRUS IMMUNE GLOBULIN HUMAN IV','CYTOMEGALOVIRUS IMMUNE GLOBULIN HUMAN IV','90291','1','','1','0','','','',0, 1, 0, 0),
(8285,'DIPHTHERIA ANTITOXIN EQUINE ANY ROUTE','DIPHTHERIA ANTITOXIN EQUINE ANY ROUTE','90296','1','','1','0','','','',0, 1, 0, 0),
(8286,'HEPATITIS B IMMUNE GLOBULIN HBIG HUMAN IM','HEPATITIS B IMMUNE GLOBULIN HBIG HUMAN IM','90371','1','','1','0','','','',0, 1, 0, 0),
(8287,'RABIES IMMUNE GLOBULIN RIG HUMAN IM/SUBQ','RABIES IMMUNE GLOBULIN RIG HUMAN IM/SUBQ','90375','1','','1','0','','','',0, 1, 0, 0),
(8288,'RABIES IG HEAT-TREATED HUMAN IM/SUBQ','RABIES IG HEAT-TREATED HUMAN IM/SUBQ','90376','1','','1','0','','','',0, 1, 0, 0),
(8289,'RESPIRATORY SYNCYTIAL VIRUS IG IM 50 MG E','RESPIRATORY SYNCYTIAL VIRUS IG IM 50 MG E','90378','1','','1','0','','','',0, 1, 0, 0),
(8290,'RHO(D) IMMUNE GLOBULIN HUMAN FULL-DOSE IM','RHO(D) IMMUNE GLOBULIN HUMAN FULL-DOSE IM','90384','1','','1','0','','','',0, 1, 0, 0),
(8291,'RHO(D) IMMUNE GLOBULIN HUMAN MINI-DOSE IM','RHO(D) IMMUNE GLOBULIN HUMAN MINI-DOSE IM','90385','1','','1','0','','','',0, 1, 0, 0),
(8292,'RHO(D) IMMUNE GLOBULIN HUMAN IV','RHO(D) IMMUNE GLOBULIN HUMAN IV','90386','1','','1','0','','','',0, 1, 0, 0),
(8293,'TETANUS IMMUNE GLOBULIN TIG HUMAN IM','TETANUS IMMUNE GLOBULIN TIG HUMAN IM','90389','1','','1','0','','','',0, 1, 0, 0),
(8294,'VACCINIA IMMUNE GLOBULIN HUMAN IM','VACCINIA IMMUNE GLOBULIN HUMAN IM','90393','1','','1','0','','','',0, 1, 0, 0),
(8295,'VARICELLA-ZOSTER IMMUNE GLOBULIN HUMAN IM','VARICELLA-ZOSTER IMMUNE GLOBULIN HUMAN IM','90396','1','','1','0','','','',0, 1, 0, 0),
(8296,'UNLISTED IMMUNE GLOBULIN','UNLISTED IMMUNE GLOBULIN','90399','1','','1','0','','','',0, 1, 0, 0),
(8297,'IM ADM THRU 18YR ANY RTE 1ST/ONLY COMPT VAC/TOX','IM ADM THRU 18YR ANY RTE 1ST/ONLY COMPT VAC/TOX','90460','1','','1','0','','','',0, 1, 0, 0),
(8298,'IM ADM THRU 18YR ANY RTE ADDL VAC/TOX COMPT','IM ADM THRU 18YR ANY RTE ADDL VAC/TOX COMPT','90461','1','','1','0','','','',0, 1, 0, 0),
(8299,'IM ADM PRQ ID SUBQ/IM NJXS 1 VACCINE','IM ADM PRQ ID SUBQ/IM NJXS 1 VACCINE','90471','1','','1','0','','','',0, 1, 0, 0),
(8300,'IM ADM PRQ ID SUBQ/IM NJXS EA VACCINE','IM ADM PRQ ID SUBQ/IM NJXS EA VACCINE','90472','1','','1','0','','','',0, 1, 0, 0),
(8301,'IM ADM INTRANSL/ORAL 1 VACCINE','IM ADM INTRANSL/ORAL 1 VACCINE','90473','1','','1','0','','','',0, 1, 0, 0),
(8302,'IM ADM INTRANSL/ORAL EA VACCINE','IM ADM INTRANSL/ORAL EA VACCINE','90474','1','','1','0','','','',0, 1, 0, 0),
(8303,'ADENOVIRUS VACCINE TYPE 4 LIVE ORAL','ADENOVIRUS VACCINE TYPE 4 LIVE ORAL','90476','1','','1','0','','','',0, 1, 0, 0),
(8304,'ADENOVIRUS VACCINE TYPE 7 LIVE FOR ORAL','ADENOVIRUS VACCINE TYPE 7 LIVE FOR ORAL','90477','1','','1','0','','','',0, 1, 0, 0),
(8305,'ANTHRAX VACCINE SUBCUTANEOUS/IM USE','ANTHRAX VACCINE SUBCUTANEOUS/IM USE','90581','1','','1','0','','','',0, 1, 0, 0),
(8306,'BACILLUS CALMETTE-GUERIN VACC FOR TB LIVE PERQ','BACILLUS CALMETTE-GUERIN VACC FOR TB LIVE PERQ','90585','1','','1','0','','','',0, 1, 0, 0),
(8307,'BACILLUS CALMETTE-GUERIN VACCINE INTRAVESICAL','BACILLUS CALMETTE-GUERIN VACCINE INTRAVESICAL','90586','1','','1','0','','','',0, 1, 0, 0),
(8308,'MENB RECOMBINANT PROT W/OUT MEMBR VESIC VACC IM','MENB RECOMBINANT PROT W/OUT MEMBR VESIC VACC IM','90620','1','','1','0','','','',0, 1, 0, 0),
(8309,'MENB RECOMBINANT LIPOPROTEIN VACCINE IM','MENB RECOMBINANT LIPOPROTEIN VACCINE IM','90621','1','','1','0','','','',0, 1, 0, 0),
(8310,'CHOLERA VACCINE ADULT 1 DOSE LIVE FOR ORAL USE','CHOLERA VACCINE ADULT 1 DOSE LIVE FOR ORAL USE','90625','1','','1','0','','','',0, 1, 0, 0),
(8311,'INFLUENZA VACC IIV4 SPLIT VIRUS PRSRV FREE ID','INFLUENZA VACC IIV4 SPLIT VIRUS PRSRV FREE ID','90630','1','','1','0','','','',0, 1, 0, 0),
(8312,'HEPA VACCINE ADULT DOSE FOR INTRAMUSCULAR USE','HEPA VACCINE ADULT DOSE FOR INTRAMUSCULAR USE','90632','1','','1','0','','','',0, 1, 0, 0),
(8313,'HEPA VACCINE 2 DOSE SCHEDULE PED/ADOLESC IM USE','HEPA VACCINE 2 DOSE SCHEDULE PED/ADOLESC IM USE','90633','1','','1','0','','','',0, 1, 0, 0),
(8314,'HEPA VACCINE 3 DOSE SCHEDULE PED/ADOLESC IM USE','HEPA VACCINE 3 DOSE SCHEDULE PED/ADOLESC IM USE','90634','1','','1','0','','','',0, 1, 0, 0),
(8315,'HEPATITIS A & B VACCINE HEPA-HEPB ADULT IM','HEPATITIS A & B VACCINE HEPA-HEPB ADULT IM','90636','1','','1','0','','','',0, 1, 0, 0),
(8316,'HIB-MENCY VACC 4 DOSE SCHEDULE 2-18 MONTHS IM','HIB-MENCY VACC 4 DOSE SCHEDULE 2-18 MONTHS IM','90644','1','','1','0','','','',0, 1, 0, 0),
(8317,'HIB PRP-OMP VACCINE 3 DOSE SCHEDULE IM USE','HIB PRP-OMP VACCINE 3 DOSE SCHEDULE IM USE','90647','1','','1','0','','','',0, 1, 0, 0),
(8318,'HIB PRP-T VACCINE 4 DOSE SCHEDULE IM USE','HIB PRP-T VACCINE 4 DOSE SCHEDULE IM USE','90648','1','','1','0','','','',0, 1, 0, 0),
(8319,'4VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','4VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','90649','1','','1','0','','','',0, 1, 0, 0),
(8320,'2VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','2VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','90650','1','','1','0','','','',0, 1, 0, 0),
(8321,'9VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','9VHPV VACCINE 3 DOSE SCHEDULE FOR IM USE','90651','1','','1','0','','','',0, 1, 0, 0),
(8322,'IIV ADJUVANTED VACCINE FOR INTRAMUSCULAR USE','IIV ADJUVANTED VACCINE FOR INTRAMUSCULAR USE','90653','1','','1','0','','','',0, 1, 0, 0),
(8323,'INFLUENZA VACC IIV3 SPLIT VIRUS PRSRV FREE ID','INFLUENZA VACC IIV3 SPLIT VIRUS PRSRV FREE ID','90654','1','','1','0','','','',0, 1, 0, 0),
(8324,'IIV3 VACC PRESRV FREE CHILD 6-35 MONTHS IM USE','IIV3 VACC PRESRV FREE CHILD 6-35 MONTHS IM USE','90655','1','','1','0','','','',0, 1, 0, 0),
(8325,'IIV3 VACC PRESERVATIVE FREE 3 YRS & OLDER IM USE','IIV3 VACC PRESERVATIVE FREE 3 YRS & OLDER IM USE','90656','1','','1','0','','','',0, 1, 0, 0),
(8326,'IIV3 VACCINE TO CHILD 6-35 MONTHS FOR IM USE','IIV3 VACCINE TO CHILD 6-35 MONTHS FOR IM USE','90657','1','','1','0','','','',0, 1, 0, 0),
(8327,'IIV3 VACCINE 3 YRS & OLDER FOR IM USE','IIV3 VACCINE 3 YRS & OLDER FOR IM USE','90658','1','','1','0','','','',0, 1, 0, 0),
(8328,'LAIV3 VACCINE LIVE FOR INTRANASAL USE','LAIV3 VACCINE LIVE FOR INTRANASAL USE','90660','1','','1','0','','','',0, 1, 0, 0),
(8329,'CCIIV3 VACCINE PRESERVATIVE FREE FOR IM USE','CCIIV3 VACCINE PRESERVATIVE FREE FOR IM USE','90661','1','','1','0','','','',0, 1, 0, 0),
(8330,'IIV VACCINE PRESERV FREE INCREASED AG COUNT IM','IIV VACCINE PRESERV FREE INCREASED AG COUNT IM','90662','1','','1','0','','','',0, 1, 0, 0),
(8331,'LAIV VACCINE PANDEMIC FORMULA FOR INTRANASAL USE','LAIV VACCINE PANDEMIC FORMULA FOR INTRANASAL USE','90664','1','','1','0','','','',0, 1, 0, 0),
(8332,'INFLUENZA VACCINE PANDEMIC SPLT PRSRV FREE IM','INFLUENZA VACCINE PANDEMIC SPLT PRSRV FREE IM','90666','1','','1','0','','','',0, 1, 0, 0),
(8333,'IIV VACCINE PANDEMIC ADJUVANT FOR IM USE','IIV VACCINE PANDEMIC ADJUVANT FOR IM USE','90667','1','','1','0','','','',0, 1, 0, 0),
(8334,'IIV VACCINE PANDEMIC FOR INTRAMUSCULAR USE','IIV VACCINE PANDEMIC FOR INTRAMUSCULAR USE','90668','1','','1','0','','','',0, 1, 0, 0),
(8335,'PCV13 VACCINE FOR INTRAMUSCULAR USE','PCV13 VACCINE FOR INTRAMUSCULAR USE','90670','1','','1','0','','','',0, 1, 0, 0),
(8336,'LAIV4 VACCINE FOR INTRANASAL USE','LAIV4 VACCINE FOR INTRANASAL USE','90672','1','','1','0','','','',0, 1, 0, 0),
(8337,'RIV3 VACCINE PRESERVATIVE FREE FOR IM USE','RIV3 VACCINE PRESERVATIVE FREE FOR IM USE','90673','1','','1','0','','','',0, 1, 0, 0),
(8338,'RABIES VACCINE INTRAMUSCULAR','RABIES VACCINE INTRAMUSCULAR','90675','1','','1','0','','','',0, 1, 0, 0),
(8339,'RABIES VACCINE INTRADERMAL','RABIES VACCINE INTRADERMAL','90676','1','','1','0','','','',0, 1, 0, 0),
(8340,'RV5 VACCINE 3 DOSE SCHEDULE LIVE FOR ORAL USE','RV5 VACCINE 3 DOSE SCHEDULE LIVE FOR ORAL USE','90680','1','','1','0','','','',0, 1, 0, 0),
(8341,'RV1 VACCINE 2 DOSE SCHEDULE LIVE FOR ORAL USE','RV1 VACCINE 2 DOSE SCHEDULE LIVE FOR ORAL USE','90681','1','','1','0','','','',0, 1, 0, 0),
(8342,'IIV4 PRESRV FREE VACC CHILD 6-35 MO FOR IM USE','IIV4 PRESRV FREE VACC CHILD 6-35 MO FOR IM USE','90685','1','','1','0','','','',0, 1, 0, 0),
(8343,'IIV4 VACC PRESRV FREE 3 YRS & OLDER IM USE','IIV4 VACC PRESRV FREE 3 YRS & OLDER IM USE','90686','1','','1','0','','','',0, 1, 0, 0),
(8344,'IIV4 VACCINE CHILD 6-35 MO FOR IM USE','IIV4 VACCINE CHILD 6-35 MO FOR IM USE','90687','1','','1','0','','','',0, 1, 0, 0),
(8345,'IIV4 VACCINE 3 YRS & OLDER FOR IM USE','IIV4 VACCINE 3 YRS & OLDER FOR IM USE','90688','1','','1','0','','','',0, 1, 0, 0),
(8346,'TYPHOID VACCINE LIVE ORAL','TYPHOID VACCINE LIVE ORAL','90690','1','','1','0','','','',0, 1, 0, 0),
(8347,'TYPHOID VACCINE VI CAPSULAR POLYSACCHARIDE IM','TYPHOID VACCINE VI CAPSULAR POLYSACCHARIDE IM','90691','1','','1','0','','','',0, 1, 0, 0),
(8348,'DTAP-IPV VACCINE CHILD 4-6 YRS FOR IM USE','DTAP-IPV VACCINE CHILD 4-6 YRS FOR IM USE','90696','1','','1','0','','','',0, 1, 0, 0),
(8349,'DTAP-IPV-HIB-HEPB VACCINE INTRAMUSCULAR','DTAP-IPV-HIB-HEPB VACCINE INTRAMUSCULAR','90697','1','','1','0','','','',0, 1, 0, 0),
(8350,'DTAP-IPV/HIB VACCINE FOR INTRAMUSCULAR USE','DTAP-IPV/HIB VACCINE FOR INTRAMUSCULAR USE','90698','1','','1','0','','','',0, 1, 0, 0),
(8351,'DIPHTH TETANUS TOX ACELL PERTUSSIS VACC<7 YR IM','DIPHTH TETANUS TOX ACELL PERTUSSIS VACC<7 YR IM','90700','1','','1','0','','','',0, 1, 0, 0),
(8352,'T VACCINE YOUNGER THAN 7 YRS FOR IM USE','T VACCINE YOUNGER THAN 7 YRS FOR IM USE','90702','1','','1','0','','','',0, 1, 0, 0),
(8353,'MEASLES MUMPS RUBELLA VIRUS VACCINE LIVE SUBQ','MEASLES MUMPS RUBELLA VIRUS VACCINE LIVE SUBQ','90707','1','','1','0','','','',0, 1, 0, 0),
(8354,'MEASLES MUMPS RUBELLA VARICELLA VACC LIVE SUBQ','MEASLES MUMPS RUBELLA VARICELLA VACC LIVE SUBQ','90710','1','','1','0','','','',0, 1, 0, 0),
(8355,'POLIOVIRUS VACCINE INACTIVATED SUBQ/IM','POLIOVIRUS VACCINE INACTIVATED SUBQ/IM','90713','1','','1','0','','','',0, 1, 0, 0),
(8356,'TD VACCINE PRSRV FREE 7 YRS OR OLDER FOR IM USE','TD VACCINE PRSRV FREE 7 YRS OR OLDER FOR IM USE','90714','1','','1','0','','','',0, 1, 0, 0),
(8357,'TDAP VACCINE 7 YRS/> IM','TDAP VACCINE 7 YRS/> IM','90715','1','','1','0','','','',0, 1, 0, 0),
(8358,'VAR VACCINE LIVE FOR SUBCUTANEOUS USE','VAR VACCINE LIVE FOR SUBCUTANEOUS USE','90716','1','','1','0','','','',0, 1, 0, 0),
(8359,'YELLOW FEVER VACCINE LIVE SUBQ','YELLOW FEVER VACCINE LIVE SUBQ','90717','1','','1','0','','','',0, 1, 0, 0),
(8360,'DTAP-HEPB-IPV VACCINE INTRAMUSCULAR','DTAP-HEPB-IPV VACCINE INTRAMUSCULAR','90723','1','','1','0','','','',0, 1, 0, 0),
(8361,'PPSV23 VACCINE 2 YRS OR OLDER FOR SUBQ/IM USE','PPSV23 VACCINE 2 YRS OR OLDER FOR SUBQ/IM USE','90732','1','','1','0','','','',0, 1, 0, 0),
(8362,'MPSV4 VACCINE GROUPS ACYW-135 SUBQ USE','MPSV4 VACCINE GROUPS ACYW-135 SUBQ USE','90733','1','','1','0','','','',0, 1, 0, 0),
(8363,'MENACWY CONJUGATE VACCINE GROUPS ACYW-135 IM USE','MENACWY CONJUGATE VACCINE GROUPS ACYW-135 IM USE','90734','1','','1','0','','','',0, 1, 0, 0),
(8364,'ZOSTER VACCINE HZV LIVE FOR SUBCUTANEOUS USE','ZOSTER VACCINE HZV LIVE FOR SUBCUTANEOUS USE','90736','1','','1','0','','','',0, 1, 0, 0),
(8365,'JAPANESE ENCEPHALITIS VACCINE INACTIVATED IM','JAPANESE ENCEPHALITIS VACCINE INACTIVATED IM','90738','1','','1','0','','','',0, 1, 0, 0),
(8366,'HEPB VACCINE ADULT 2 DOSE SCHEDULE FOR IM USE','HEPB VACCINE ADULT 2 DOSE SCHEDULE FOR IM USE','90739','1','','1','0','','','',0, 1, 0, 0),
(8367,'HEPB VACCINE DIALYSIS/IMMUNSUP PAT 3 DOSE IM','HEPB VACCINE DIALYSIS/IMMUNSUP PAT 3 DOSE IM','90740','1','','1','0','','','',0, 1, 0, 0),
(8368,'HEPB VACCINE ADOLESCENT 2 DOSE SCHEDULE IM','HEPB VACCINE ADOLESCENT 2 DOSE SCHEDULE IM','90743','1','','1','0','','','',0, 1, 0, 0),
(8369,'HEPB VACCINE PED/ADOLESC 3 DOSE SCHEDULE IM','HEPB VACCINE PED/ADOLESC 3 DOSE SCHEDULE IM','90744','1','','1','0','','','',0, 1, 0, 0),
(8370,'HEPB VACCINE ADULT 3 DOSE SCHEDULE FOR IM USE','HEPB VACCINE ADULT 3 DOSE SCHEDULE FOR IM USE','90746','1','','1','0','','','',0, 1, 0, 0),
(8371,'HEPB VACCINE DIALYSIS/IMMUNSUP PAT 4 DOSE IM','HEPB VACCINE DIALYSIS/IMMUNSUP PAT 4 DOSE IM','90747','1','','1','0','','','',0, 1, 0, 0),
(8372,'HIB-HEPB VACCINE FOR INTRAMUSCULAR USE','HIB-HEPB VACCINE FOR INTRAMUSCULAR USE','90748','1','','1','0','','','',0, 1, 0, 0),
(8373,'UNLISTED VACCINE/TOXOID','UNLISTED VACCINE/TOXOID','90749','1','','1','0','','','',0, 1, 0, 0),
(8374,'PSYCHOTHERAPY COMPLEX INTERACTIVE','PSYCHOTHERAPY COMPLEX INTERACTIVE','90785','1','','1','0','','','',0, 1, 0, 0),
(8375,'PSYCHIATRIC DIAGNOSTIC EVALUATION','PSYCHIATRIC DIAGNOSTIC EVALUATION','90791','1','','1','0','','','',0, 1, 0, 0),
(8376,'PSYCHIATRIC DIAGNOSTIC EVAL W/MEDICAL SERVICES','PSYCHIATRIC DIAGNOSTIC EVAL W/MEDICAL SERVICES','90792','1','','1','0','','','',0, 1, 0, 0),
(8377,'PSYCHOTHERAPY PATIENT &/ FAMILY 30 MINUTES','PSYCHOTHERAPY PATIENT &/ FAMILY 30 MINUTES','90832','1','','1','0','','','',0, 1, 0, 0),
(8378,'PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 30 MIN','PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 30 MIN','90833','1','','1','0','','','',0, 1, 0, 0),
(8379,'PSYCHOTHERAPY PATIENT &/ FAMILY 45 MINUTES','PSYCHOTHERAPY PATIENT &/ FAMILY 45 MINUTES','90834','1','','1','0','','','',0, 1, 0, 0),
(8380,'PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 45 MIN','PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 45 MIN','90836','1','','1','0','','','',0, 1, 0, 0),
(8381,'PSYCHOTHERAPY PATIENT &/ FAMILY 60 MINUTES','PSYCHOTHERAPY PATIENT &/ FAMILY 60 MINUTES','90837','1','','1','0','','','',0, 1, 0, 0),
(8382,'PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 60 MIN','PSYCHOTHERAPY PT&/FAMILY W/E&M SRVCS 60 MIN','90838','1','','1','0','','','',0, 1, 0, 0),
(8383,'PSYCHOTHERAPY FOR CRISIS INITIAL 60 MINUTES','PSYCHOTHERAPY FOR CRISIS INITIAL 60 MINUTES','90839','1','','1','0','','','',0, 1, 0, 0),
(8384,'PSYCHOTHERAPY FOR CRISIS EACH ADDL 30 MINUTES','PSYCHOTHERAPY FOR CRISIS EACH ADDL 30 MINUTES','90840','1','','1','0','','','',0, 1, 0, 0),
(8385,'PSYCHOANALYSIS','PSYCHOANALYSIS','90845','1','','1','0','','','',0, 1, 0, 0),
(8386,'FAMILY PSYCHOTHERAPY W/O PATIENT PRESENT','FAMILY PSYCHOTHERAPY W/O PATIENT PRESENT','90846','1','','1','0','','','',0, 1, 0, 0),
(8387,'FAMILY PSYCHOTHERAPY W/PATIENT PRESENT','FAMILY PSYCHOTHERAPY W/PATIENT PRESENT','90847','1','','1','0','','','',0, 1, 0, 0),
(8388,'MULTIPLE FAMILY GROUP PSYCHOTHERAPY','MULTIPLE FAMILY GROUP PSYCHOTHERAPY','90849','1','','1','0','','','',0, 1, 0, 0),
(8389,'GROUP PSYCHOTHERAPY','GROUP PSYCHOTHERAPY','90853','1','','1','0','','','',0, 1, 0, 0),
(8390,'PHARMACOLOGIC MANAGEMENT W/PSYCHOTHERAPY','PHARMACOLOGIC MANAGEMENT W/PSYCHOTHERAPY','90863','1','','1','0','','','',0, 1, 0, 0),
(8391,'NARCOSYNTHESIS PSYC DX&THER PURPOSES','NARCOSYNTHESIS PSYC DX&THER PURPOSES','90865','1','','1','0','','','',0, 1, 0, 0),
(8392,'REPET TMS TX INITIAL W/MAP/MOTR THRESHLD/DEL&M','REPET TMS TX INITIAL W/MAP/MOTR THRESHLD/DEL&M','90867','1','','1','0','','','',0, 1, 0, 0),
(8393,'THERAP REPETITIVE TMS TX SUBSEQ DELIVERY & MNG','THERAP REPETITIVE TMS TX SUBSEQ DELIVERY & MNG','90868','1','','1','0','','','',0, 1, 0, 0),
(8394,'REPET TMS TX SUBSEQ MOTR THRESHLD W/DELIV & MN','REPET TMS TX SUBSEQ MOTR THRESHLD W/DELIV & MN','90869','1','','1','0','','','',0, 1, 0, 0),
(8395,'ELECTROCONVULSIVE THERAPY','ELECTROCONVULSIVE THERAPY','90870','1','','1','0','','','',0, 1, 0, 0),
(8396,'INDIV PSYCHOPHYS BIOFEED TRAIN W/PSYTX 30 MIN','INDIV PSYCHOPHYS BIOFEED TRAIN W/PSYTX 30 MIN','90875','1','','1','0','','','',0, 1, 0, 0),
(8397,'INDIV PSYCHOPHYS BIOFEED TRAIN W/PSYTX 45 MIN','INDIV PSYCHOPHYS BIOFEED TRAIN W/PSYTX 45 MIN','90876','1','','1','0','','','',0, 1, 0, 0),
(8398,'HYPNOTHERAPY','HYPNOTHERAPY','90880','1','','1','0','','','',0, 1, 0, 0),
(8399,'ENVIRONMENTAL IVNTJ MGMT PURPOSES PSYC PT','ENVIRONMENTAL IVNTJ MGMT PURPOSES PSYC PT','90882','1','','1','0','','','',0, 1, 0, 0),
(8400,'PSYCHIATRIC EVAL HOSPITAL RECORDS DX PURPOSES','PSYCHIATRIC EVAL HOSPITAL RECORDS DX PURPOSES','90885','1','','1','0','','','',0, 1, 0, 0),
(8401,'INTERPJ/EXPLNAJ RESULTS PSYCHIATRIC EXAM FAMILY','INTERPJ/EXPLNAJ RESULTS PSYCHIATRIC EXAM FAMILY','90887','1','','1','0','','','',0, 1, 0, 0),
(8402,'PREP REPORT PT PSYCH STATUS AGENCY/PAYER','PREP REPORT PT PSYCH STATUS AGENCY/PAYER','90889','1','','1','0','','','',0, 1, 0, 0),
(8403,'UNLISTED PSYCHIATRIC SERVICE/PROCEDURE','UNLISTED PSYCHIATRIC SERVICE/PROCEDURE','90899','1','','1','0','','','',0, 1, 0, 0),
(8404,'BIOFEEDBACK TRAINING ANY MODALITY','BIOFEEDBACK TRAINING ANY MODALITY','90901','1','','1','0','','','',0, 1, 0, 0),
(8405,'BIOFDBK TRNG PERINL MUSC ANORECT/URO SPHX W/EMG','BIOFDBK TRNG PERINL MUSC ANORECT/URO SPHX W/EMG','90911','1','','1','0','','','',0, 1, 0, 0),
(8406,'HEMODIALYSIS PROCEDURE W/ PHYS/QHP EVALUATION','HEMODIALYSIS PROCEDURE W/ PHYS/QHP EVALUATION','90935','1','','1','0','','','',0, 1, 0, 0),
(8407,'HEMODIALYSIS PX REPEAT EVAL W/WO REVJ DIALYS RX','HEMODIALYSIS PX REPEAT EVAL W/WO REVJ DIALYS RX','90937','1','','1','0','','','',0, 1, 0, 0),
(8408,'HEMODIALYSIS ACCESS FLOW STUDY','HEMODIALYSIS ACCESS FLOW STUDY','90940','1','','1','0','','','',0, 1, 0, 0),
(8409,'DIALYSIS OTHER/THAN HEMODIALYSIS 1 PHYS/QHP EVAL','DIALYSIS OTHER/THAN HEMODIALYSIS 1 PHYS/QHP EVAL','90945','1','','1','0','','','',0, 1, 0, 0),
(8410,'DIALYSIS OTH/THN HEMODIALY REPEAT PHYS/QHP EVALS','DIALYSIS OTH/THN HEMODIALY REPEAT PHYS/QHP EVALS','90947','1','','1','0','','','',0, 1, 0, 0),
(8411,'ESRD RELATED SVC MONTHLY & <2 YR OLD 4/> VISITS','ESRD RELATED SVC MONTHLY & <2 YR OLD 4/> VISITS','90951','1','','1','0','','','',0, 1, 0, 0),
(8412,'ESRD RELATED SVC MONTHLY <2 YR OLD 2/3 VISITS','ESRD RELATED SVC MONTHLY <2 YR OLD 2/3 VISITS','90952','1','','1','0','','','',0, 1, 0, 0),
(8413,'ESRD RELATED SVC MONTHLY <2 YR OLD 1 VISIT','ESRD RELATED SVC MONTHLY <2 YR OLD 1 VISIT','90953','1','','1','0','','','',0, 1, 0, 0),
(8414,'ESRD RELATED SVC MONTHLY 2-11 YR OLD 4/> VISITS','ESRD RELATED SVC MONTHLY 2-11 YR OLD 4/> VISITS','90954','1','','1','0','','','',0, 1, 0, 0),
(8415,'ESRD RELATED SVC MONTHLY 2-11 YR OLD 2/3 VISITS','ESRD RELATED SVC MONTHLY 2-11 YR OLD 2/3 VISITS','90955','1','','1','0','','','',0, 1, 0, 0),
(8416,'ESRD RELATED SVC MONTHLY 2-11 YR OLD 1 VISIT','ESRD RELATED SVC MONTHLY 2-11 YR OLD 1 VISIT','90956','1','','1','0','','','',0, 1, 0, 0),
(8417,'ESRD RELATED SVC MONTHLY 12-19 YR OLD 4/> VISITS','ESRD RELATED SVC MONTHLY 12-19 YR OLD 4/> VISITS','90957','1','','1','0','','','',0, 1, 0, 0),
(8418,'ESRD RELATED SVC MONTHLY 12-19 YR OLD 2/3 VISITS','ESRD RELATED SVC MONTHLY 12-19 YR OLD 2/3 VISITS','90958','1','','1','0','','','',0, 1, 0, 0),
(8419,'ESRD RELATED SVC MONTHLY 12-19 YR OLD 1 VISIT','ESRD RELATED SVC MONTHLY 12-19 YR OLD 1 VISIT','90959','1','','1','0','','','',0, 1, 0, 0),
(8420,'ESRD RELATED SVC MONTHLY 20&/> YR OLD 4/> VISITS','ESRD RELATED SVC MONTHLY 20&/> YR OLD 4/> VISITS','90960','1','','1','0','','','',0, 1, 0, 0),
(8421,'ESRD RELATED SVC MONTHLY 20/>YR OLD 2/3 VISITS','ESRD RELATED SVC MONTHLY 20/>YR OLD 2/3 VISITS','90961','1','','1','0','','','',0, 1, 0, 0),
(8422,'ESRD RELATED SVC MONTHLY 20&/>YR OLD 1 VISIT','ESRD RELATED SVC MONTHLY 20&/>YR OLD 1 VISIT','90962','1','','1','0','','','',0, 1, 0, 0),
(8423,'ESRD SVC HOME DIALYSIS FULL MONTH <2YR OLD','ESRD SVC HOME DIALYSIS FULL MONTH <2YR OLD','90963','1','','1','0','','','',0, 1, 0, 0),
(8424,'ESRD SVC HOME DIALYSIS FULL MONTH 2-11 YR OLD','ESRD SVC HOME DIALYSIS FULL MONTH 2-11 YR OLD','90964','1','','1','0','','','',0, 1, 0, 0),
(8425,'ESRD SVC HOME DIALYSIS FULL MONTH 12-19 YR OLD','ESRD SVC HOME DIALYSIS FULL MONTH 12-19 YR OLD','90965','1','','1','0','','','',0, 1, 0, 0),
(8426,'ESRD SVC HOME DIALYSIS FULL MONTH 20 YR OLD','ESRD SVC HOME DIALYSIS FULL MONTH 20 YR OLD','90966','1','','1','0','','','',0, 1, 0, 0),
(8427,'ESRD RELATED SVC <FULL MONTH <2 YR OLD','ESRD RELATED SVC <FULL MONTH <2 YR OLD','90967','1','','1','0','','','',0, 1, 0, 0),
(8428,'ESRD RELATED SVC <FULL MONTH 2-11 YR OLD','ESRD RELATED SVC <FULL MONTH 2-11 YR OLD','90968','1','','1','0','','','',0, 1, 0, 0),
(8429,'ESRD RELATED SVC <FULL MONTH 12-19 YR OLD','ESRD RELATED SVC <FULL MONTH 12-19 YR OLD','90969','1','','1','0','','','',0, 1, 0, 0),
(8430,'ESRD RELATED SVC <FULL MONTH 20/>YR OLD','ESRD RELATED SVC <FULL MONTH 20/>YR OLD','90970','1','','1','0','','','',0, 1, 0, 0),
(8431,'DIALYSIS TRAINING PATIENT COMPLETED COURSE','DIALYSIS TRAINING PATIENT COMPLETED COURSE','90989','1','','1','0','','','',0, 1, 0, 0),
(8432,'DIALYSIS TRAINING PATIENT PER TRAINING SESSION','DIALYSIS TRAINING PATIENT PER TRAINING SESSION','90993','1','','1','0','','','',0, 1, 0, 0),
(8433,'HEMOPERFUSION','HEMOPERFUSION','90997','1','','1','0','','','',0, 1, 0, 0),
(8434,'UNLISTED DIALYSIS PROCEDURE INPATIENT/OUTPATIENT','UNLISTED DIALYSIS PROCEDURE INPATIENT/OUTPATIENT','90999','1','','1','0','','','',0, 1, 0, 0),
(8435,'ESOPHAGEAL MOTILITY STUDY W/INTERP&RPT','ESOPHAGEAL MOTILITY STUDY W/INTERP&RPT','91010','1','','1','0','','','',0, 1, 0, 0),
(8436,'ESOPHAGEAL MOTILITY STD W/I&R STIM/PERFUSION','ESOPHAGEAL MOTILITY STD W/I&R STIM/PERFUSION','91013','1','','1','0','','','',0, 1, 0, 0),
(8437,'GASTRIC MOTILITY MANOMETRIC STUDIES','GASTRIC MOTILITY MANOMETRIC STUDIES','91020','1','','1','0','','','',0, 1, 0, 0),
(8438,'DUODENAL MOTILITY MANOMETRIC STUDY','DUODENAL MOTILITY MANOMETRIC STUDY','91022','1','','1','0','','','',0, 1, 0, 0),
(8439,'ESOPHAGUS ACID PERFUSION TEST ESOPHAGITIS','ESOPHAGUS ACID PERFUSION TEST ESOPHAGITIS','91030','1','','1','0','','','',0, 1, 0, 0),
(8440,'GASTROESOPHAG REFLX TEST W/CATH PH ELTRD PLCMT','GASTROESOPHAG REFLX TEST W/CATH PH ELTRD PLCMT','91034','1','','1','0','','','',0, 1, 0, 0),
(8441,'GASTROESOPHAG REFLX TEST W/TELEMTRY PH ELTRD','GASTROESOPHAG REFLX TEST W/TELEMTRY PH ELTRD','91035','1','','1','0','','','',0, 1, 0, 0),
(8442,'GASTROESOPHAG REFLX TEST W/INTRLUML IMPED ELTRD','GASTROESOPHAG REFLX TEST W/INTRLUML IMPED ELTRD','91037','1','','1','0','','','',0, 1, 0, 0),
(8443,'ESOPHGL FUNCJ G-ESOP RFLX IMPD ELTRD PROLNG','ESOPHGL FUNCJ G-ESOP RFLX IMPD ELTRD PROLNG','91038','1','','1','0','','','',0, 1, 0, 0),
(8444,'ESOPHGL BALO DISTENSION DX STD W/PROVOCATION','ESOPHGL BALO DISTENSION DX STD W/PROVOCATION','91040','1','','1','0','','','',0, 1, 0, 0),
(8445,'BREATH HYDROGEN/METHANE TEST','BREATH HYDROGEN/METHANE TEST','91065','1','','1','0','','','',0, 1, 0, 0),
(8446,'GI IMAG INTRALUMINAL ESOPHAGUS-ILEUM W/I&R','GI IMAG INTRALUMINAL ESOPHAGUS-ILEUM W/I&R','91110','1','','1','0','','','',0, 1, 0, 0),
(8447,'GASTROINTESTINAL TRACT IMAGING ESOPHAGUS W/I&R','GASTROINTESTINAL TRACT IMAGING ESOPHAGUS W/I&R','91111','1','','1','0','','','',0, 1, 0, 0),
(8448,'GI TRANSIT & PRES MEAS WIRELESS CAPSULE W/INTERP','GI TRANSIT & PRES MEAS WIRELESS CAPSULE W/INTERP','91112','1','','1','0','','','',0, 1, 0, 0),
(8449,'COLON MOTILITY STDY MIN 6 HR CONT RECORD W/I&R','COLON MOTILITY STDY MIN 6 HR CONT RECORD W/I&R','91117','1','','1','0','','','',0, 1, 0, 0),
(8450,'RECTAL SESATION TONE & COMPLIANCE TEST','RECTAL SESATION TONE & COMPLIANCE TEST','91120','1','','1','0','','','',0, 1, 0, 0),
(8451,'ANORECTAL MANOMETRY','ANORECTAL MANOMETRY','91122','1','','1','0','','','',0, 1, 0, 0),
(8452,'ELECTROGASTROGRAPHY DX TRANSCUTANEOUS','ELECTROGASTROGRAPHY DX TRANSCUTANEOUS','91132','1','','1','0','','','',0, 1, 0, 0),
(8453,'ELECTROGASTROGRAPHY DX TRANSCUT W/PROVOCTVE TSTG','ELECTROGASTROGRAPHY DX TRANSCUT W/PROVOCTVE TSTG','91133','1','','1','0','','','',0, 1, 0, 0),
(8454,'LIVER ELASTOGRAPHY W/O IMAG W/I&R','LIVER ELASTOGRAPHY W/O IMAG W/I&R','91200','1','','1','0','','','',0, 1, 0, 0),
(8455,'UNLISTED DIAGNOSTIC GASTROENTEROLOGY PROCEDURE','UNLISTED DIAGNOSTIC GASTROENTEROLOGY PROCEDURE','91299','1','','1','0','','','',0, 1, 0, 0),
(8456,'OPHTH MEDICAL XM&EVAL INTERMEDIATE NEW PT','OPHTH MEDICAL XM&EVAL INTERMEDIATE NEW PT','92002','1','','1','0','','','',0, 1, 0, 0),
(8457,'OPHTH MEDICAL XM&EVAL COMPRE NEW PT 1/> VST','OPHTH MEDICAL XM&EVAL COMPRE NEW PT 1/> VST','92004','1','','1','0','','','',0, 1, 0, 0),
(8458,'OPHTH MEDICAL XM&EVAL INTERMEDIATE ESTAB PT','OPHTH MEDICAL XM&EVAL INTERMEDIATE ESTAB PT','92012','1','','1','0','','','',0, 1, 0, 0),
(8459,'OPHTH MEDICAL XM&EVAL COMPRHNSV ESTAB PT 1/>','OPHTH MEDICAL XM&EVAL COMPRHNSV ESTAB PT 1/>','92014','1','','1','0','','','',0, 1, 0, 0),
(8460,'DETERMINATION REFRACTIVE STATE','DETERMINATION REFRACTIVE STATE','92015','1','','1','0','','','',0, 1, 0, 0),
(8461,'OPHTH XM&EVAL ANES W/WO MANJ GLOBE COMPL','OPHTH XM&EVAL ANES W/WO MANJ GLOBE COMPL','92018','1','','1','0','','','',0, 1, 0, 0),
(8462,'OPHTH XM&EVAL ANES W/WO MANJ GLOBE LMTD','OPHTH XM&EVAL ANES W/WO MANJ GLOBE LMTD','92019','1','','1','0','','','',0, 1, 0, 0),
(8463,'GONIOSCOPY SEPARATE PROCEDURE','GONIOSCOPY SEPARATE PROCEDURE','92020','1','','1','0','','','',0, 1, 0, 0),
(8464,'COMPUTERIZED CORNEAL TOPOGRAPHY UNI/BI','COMPUTERIZED CORNEAL TOPOGRAPHY UNI/BI','92025','1','','1','0','','','',0, 1, 0, 0),
(8465,'SENSORMOTOR XM W/MLT MEAS OCULAR DEVIJ W/I&R SPX','SENSORMOTOR XM W/MLT MEAS OCULAR DEVIJ W/I&R SPX','92060','1','','1','0','','','',0, 1, 0, 0),
(8466,'ORTHOPTIC &/PLEOPTIC TRAINING W/MEDICAL DIRECTJ','ORTHOPTIC &/PLEOPTIC TRAINING W/MEDICAL DIRECTJ','92065','1','','1','0','','','',0, 1, 0, 0),
(8467,'FIT CONTACT LENS TX OCULAR SURFACE DISEASE','FIT CONTACT LENS TX OCULAR SURFACE DISEASE','92071','1','','1','0','','','',0, 1, 0, 0),
(8468,'FITTING CONTACT LENS FOR MNGT OF KERATOCONUS','FITTING CONTACT LENS FOR MNGT OF KERATOCONUS','92072','1','','1','0','','','',0, 1, 0, 0),
(8469,'VISUAL FIELD XM UNI/BI W/INTERPRETJ LIMITED EXAM','VISUAL FIELD XM UNI/BI W/INTERPRETJ LIMITED EXAM','92081','1','','1','0','','','',0, 1, 0, 0),
(8470,'VISUAL FIELD XM UNI/BI W/INTERP INTERMED EXAM','VISUAL FIELD XM UNI/BI W/INTERP INTERMED EXAM','92082','1','','1','0','','','',0, 1, 0, 0),
(8471,'VISUAL FIELD XM UNI/BI W/INTERP EXTENDED EXAM','VISUAL FIELD XM UNI/BI W/INTERP EXTENDED EXAM','92083','1','','1','0','','','',0, 1, 0, 0),
(8472,'SERIAL TONOMETRY SPX W/MLT MEAS INTRAOCULAR PRES','SERIAL TONOMETRY SPX W/MLT MEAS INTRAOCULAR PRES','92100','1','','1','0','','','',0, 1, 0, 0),
(8473,'CMPTR OPHTHALMIC DX IMG ANT SEGMT W/I&R UNI/BI','CMPTR OPHTHALMIC DX IMG ANT SEGMT W/I&R UNI/BI','92132','1','','1','0','','','',0, 1, 0, 0),
(8474,'COMPUTERIZED OPHTHALMIC IMAGING OPTIC NERVE','COMPUTERIZED OPHTHALMIC IMAGING OPTIC NERVE','92133','1','','1','0','','','',0, 1, 0, 0),
(8475,'COMPUTERIZED OPHTHALMIC IMAGING RETINA','COMPUTERIZED OPHTHALMIC IMAGING RETINA','92134','1','','1','0','','','',0, 1, 0, 0),
(8476,'OPH BMTRY PRTL COHER INTRFRMTRY IO LENS PWR CAL','OPH BMTRY PRTL COHER INTRFRMTRY IO LENS PWR CAL','92136','1','','1','0','','','',0, 1, 0, 0),
(8477,'PROVOCATIVE TESTS GLAUCOMA I&R W/O TONOGRAPHY','PROVOCATIVE TESTS GLAUCOMA I&R W/O TONOGRAPHY','92140','1','','1','0','','','',0, 1, 0, 0),
(8478,'CORNEA HYSTERESIS DETERMIN IMPULSE STIMJ UNI/BI','CORNEA HYSTERESIS DETERMIN IMPULSE STIMJ UNI/BI','92145','1','','1','0','','','',0, 1, 0, 0),
(8479,'OPHTHALMOSCPY EXTENDED RETINAL DRAWING I&R 1ST','OPHTHALMOSCPY EXTENDED RETINAL DRAWING I&R 1ST','92225','1','','1','0','','','',0, 1, 0, 0),
(8480,'OPHTHALMOSCPY EXTENDED RETINAL DRAWING I&R SBS','OPHTHALMOSCPY EXTENDED RETINAL DRAWING I&R SBS','92226','1','','1','0','','','',0, 1, 0, 0),
(8481,'REMOTE IMG DX RETINL DIS W/ALYS & REPORT UNI/B','REMOTE IMG DX RETINL DIS W/ALYS & REPORT UNI/B','92227','1','','1','0','','','',0, 1, 0, 0),
(8482,'REMOTE IMAGING MGT RETINAL DISEASE W/I&R UNI/B','REMOTE IMAGING MGT RETINAL DISEASE W/I&R UNI/B','92228','1','','1','0','','','',0, 1, 0, 0),
(8483,'FLUORESCEIN ANGIOSCOPY INTERPRETATION & REPORT','FLUORESCEIN ANGIOSCOPY INTERPRETATION & REPORT','92230','1','','1','0','','','',0, 1, 0, 0),
(8484,'FLUORESCEIN ANGIOSCOPY INTERPRETATION & REPORT','FLUORESCEIN ANGIOSCOPY INTERPRETATION & REPORT','92235','1','','1','0','','','',0, 1, 0, 0),
(8485,'INDOCYANINE GREEN ANGIOGRAPHY W/INTERP & REPOR','INDOCYANINE GREEN ANGIOGRAPHY W/INTERP & REPOR','92240','1','','1','0','','','',0, 1, 0, 0),
(8486,'FUNDUS PHOTOGRAPHY W/INTERPRETATION & REPORT','FUNDUS PHOTOGRAPHY W/INTERPRETATION & REPORT','92250','1','','1','0','','','',0, 1, 0, 0),
(8487,'OPHTHALMODYNAMOMETRY','OPHTHALMODYNAMOMETRY','92260','1','','1','0','','','',0, 1, 0, 0),
(8488,'NEEDLE OCULOGRAPHY 1/ XOC MUSC 1/BOTH EYE W/I&R','NEEDLE OCULOGRAPHY 1/ XOC MUSC 1/BOTH EYE W/I&R','92265','1','','1','0','','','',0, 1, 0, 0),
(8489,'ELECTRO-OCULOGRAPY W/INTERPRETATION & REPORT','ELECTRO-OCULOGRAPY W/INTERPRETATION & REPORT','92270','1','','1','0','','','',0, 1, 0, 0),
(8490,'ELECTRORETINOGRAPY W/INTERPRETATION & REPORT','ELECTRORETINOGRAPY W/INTERPRETATION & REPORT','92275','1','','1','0','','','',0, 1, 0, 0),
(8491,'COLOR VISION XM EXTENDED ANOMALOSCOPE/EQUIV','COLOR VISION XM EXTENDED ANOMALOSCOPE/EQUIV','92283','1','','1','0','','','',0, 1, 0, 0),
(8492,'DARK ADAPTATION XM W/INTERPRETATION & REPORT','DARK ADAPTATION XM W/INTERPRETATION & REPORT','92284','1','','1','0','','','',0, 1, 0, 0),
(8493,'XTRNL OCULAR PHOTOG W/I&R DOCMT MEDICAL PROGRE','XTRNL OCULAR PHOTOG W/I&R DOCMT MEDICAL PROGRE','92285','1','','1','0','','','',0, 1, 0, 0),
(8494,'ANT SGM IMAGING W/MICROSCOPY ENDOTHELIAL ANALY','ANT SGM IMAGING W/MICROSCOPY ENDOTHELIAL ANALY','92286','1','','1','0','','','',0, 1, 0, 0),
(8495,'ANT SGM IMAGING W/FLUOROSCEIN ANGIO & I&R','ANT SGM IMAGING W/FLUOROSCEIN ANGIO & I&R','92287','1','','1','0','','','',0, 1, 0, 0),
(8496,'RX&FITG C-LENS SUPVJ CRNL LENS OU XCPT APHK','RX&FITG C-LENS SUPVJ CRNL LENS OU XCPT APHK','92310','1','','1','0','','','',0, 1, 0, 0),
(8497,'RX&FITG CONTACT CORNEAL LENS APHAKIA 1 EYE','RX&FITG CONTACT CORNEAL LENS APHAKIA 1 EYE','92311','1','','1','0','','','',0, 1, 0, 0),
(8498,'RX&FITG CONTACT CORNEAL LENS APHAKIA BOTH EYES','RX&FITG CONTACT CORNEAL LENS APHAKIA BOTH EYES','92312','1','','1','0','','','',0, 1, 0, 0),
(8499,'RX&FITG CORNEOSCLERAL LENS','RX&FITG CORNEOSCLERAL LENS','92313','1','','1','0','','','',0, 1, 0, 0),
(8500,'RX&FTG CONTACT CORNEAL LENS EYES XCPT APHAKIA','RX&FTG CONTACT CORNEAL LENS EYES XCPT APHAKIA','92314','1','','1','0','','','',0, 1, 0, 0),
(8501,'RX CONTACT CORNEAL LENS APHAKIA 1 EYE','RX CONTACT CORNEAL LENS APHAKIA 1 EYE','92315','1','','1','0','','','',0, 1, 0, 0),
(8502,'RX CONTACT CORNEAL LENS APHAKIA BOTH EYES','RX CONTACT CORNEAL LENS APHAKIA BOTH EYES','92316','1','','1','0','','','',0, 1, 0, 0),
(8503,'RX CONTACT CORNEOSCLERAL LENS','RX CONTACT CORNEOSCLERAL LENS','92317','1','','1','0','','','',0, 1, 0, 0),
(8504,'MODIFICAJ CONTACT LENX SPX SUPVJ ADAPTATION','MODIFICAJ CONTACT LENX SPX SUPVJ ADAPTATION','92325','1','','1','0','','','',0, 1, 0, 0),
(8505,'REPLACEMENT CONTACT LENS','REPLACEMENT CONTACT LENS','92326','1','','1','0','','','',0, 1, 0, 0),
(8506,'FITTING SPECTACLES XCPT APHAKIA MONOFOCAL','FITTING SPECTACLES XCPT APHAKIA MONOFOCAL','92340','1','','1','0','','','',0, 1, 0, 0),
(8507,'FITTING SPECTACLES XCPT APHAKIA BIFOCAL','FITTING SPECTACLES XCPT APHAKIA BIFOCAL','92341','1','','1','0','','','',0, 1, 0, 0),
(8508,'FITTING SPECTACLES XCPT APHAKIA MULTIFOCAL','FITTING SPECTACLES XCPT APHAKIA MULTIFOCAL','92342','1','','1','0','','','',0, 1, 0, 0),
(8509,'FITTING SPECTACLE PROSTH APHAKIA MONOFOCAL','FITTING SPECTACLE PROSTH APHAKIA MONOFOCAL','92352','1','','1','0','','','',0, 1, 0, 0),
(8510,'FITTING SPECTACLE PROSTH APHAKIA MULTIFOCAL','FITTING SPECTACLE PROSTH APHAKIA MULTIFOCAL','92353','1','','1','0','','','',0, 1, 0, 0),
(8511,'FITTING SPECTACLE MOUNTED LW VIS AID 1 ELMNT','FITTING SPECTACLE MOUNTED LW VIS AID 1 ELMNT','92354','1','','1','0','','','',0, 1, 0, 0),
(8512,'FITTING SPECTACLE MOUNTED LW VIS AID TLSCP','FITTING SPECTACLE MOUNTED LW VIS AID TLSCP','92355','1','','1','0','','','',0, 1, 0, 0),
(8513,'PROSTHESIS SERVICE APHAKIA TEMPORARY','PROSTHESIS SERVICE APHAKIA TEMPORARY','92358','1','','1','0','','','',0, 1, 0, 0),
(8514,'RPR&REFITG SPECTACLES EXCEPT APHAKIA','RPR&REFITG SPECTACLES EXCEPT APHAKIA','92370','1','','1','0','','','',0, 1, 0, 0),
(8515,'RPR&REFITG SPECTACLE PROSTHESIS APHAKIA','RPR&REFITG SPECTACLE PROSTHESIS APHAKIA','92371','1','','1','0','','','',0, 1, 0, 0),
(8516,'UNLIVSTED OPHTHALMOLOGICAL SERVICE/PROCEDURE','UNLIVSTED OPHTHALMOLOGICAL SERVICE/PROCEDURE','92499','1','','1','0','','','',0, 1, 0, 0),
(8517,'OTOLARYNGOLOGIC EXAM UNDER GENERAL ANESTHESIA','OTOLARYNGOLOGIC EXAM UNDER GENERAL ANESTHESIA','92502','1','','1','0','','','',0, 1, 0, 0),
(8518,'BINOCULAR MICROSCOPY SEPARATE DX PROCEDURE','BINOCULAR MICROSCOPY SEPARATE DX PROCEDURE','92504','1','','1','0','','','',0, 1, 0, 0),
(8519,'TX SPEECH LANG VOICE COMMJ &/AUDITORY PROC IND','TX SPEECH LANG VOICE COMMJ &/AUDITORY PROC IND','92507','1','','1','0','','','',0, 1, 0, 0),
(8520,'TX SPEECH LANGUAGE VOICE COMMJ AUDITRY 2/>INDIV','TX SPEECH LANGUAGE VOICE COMMJ AUDITRY 2/>INDIV','92508','1','','1','0','','','',0, 1, 0, 0),
(8521,'NASOPHARYNGOSCOPY W/ENDOSCOPE SPX','NASOPHARYNGOSCOPY W/ENDOSCOPE SPX','92511','1','','1','0','','','',0, 1, 0, 0),
(8522,'NASAL FUNCTION STUDIES','NASAL FUNCTION STUDIES','92512','1','','1','0','','','',0, 1, 0, 0),
(8523,'FACIAL NERVE FUNCTION STUDIES','FACIAL NERVE FUNCTION STUDIES','92516','1','','1','0','','','',0, 1, 0, 0),
(8524,'LARYNGEAL FUNCTION STUDIES','LARYNGEAL FUNCTION STUDIES','92520','1','','1','0','','','',0, 1, 0, 0),
(8525,'EVALUATION OF SPEECH FLUENCY (STUTTER CLUTTER)','EVALUATION OF SPEECH FLUENCY (STUTTER CLUTTER)','92521','1','','1','0','','','',0, 1, 0, 0),
(8526,'EVALUATION OF SPEECH SOUND PRODUCTION ARTICULATE','EVALUATION OF SPEECH SOUND PRODUCTION ARTICULATE','92522','1','','1','0','','','',0, 1, 0, 0),
(8527,'EVAL SPEECH SOUND PRODUCT LANGUAGE COMPREHENSION','EVAL SPEECH SOUND PRODUCT LANGUAGE COMPREHENSION','92523','1','','1','0','','','',0, 1, 0, 0),
(8528,'BEHAVIORAL & QUALIT ANALYSIS VOICE AND RESONANCE','BEHAVIORAL & QUALIT ANALYSIS VOICE AND RESONANCE','92524','1','','1','0','','','',0, 1, 0, 0),
(8529,'TX SWALLOWING DYSFUNCTION&/ORAL FUNCJ FEEDING','TX SWALLOWING DYSFUNCTION&/ORAL FUNCJ FEEDING','92526','1','','1','0','','','',0, 1, 0, 0),
(8530,'SPONTANEOUS NYSTAGMUS W/GAZE','SPONTANEOUS NYSTAGMUS W/GAZE','92531','1','','1','0','','','',0, 1, 0, 0),
(8531,'POSITIONAL NYSTAGMUS TEST','POSITIONAL NYSTAGMUS TEST','92532','1','','1','0','','','',0, 1, 0, 0),
(8532,'CALORIC VESTIBULAR TEST EACH IRRIGATION','CALORIC VESTIBULAR TEST EACH IRRIGATION','92533','1','','1','0','','','',0, 1, 0, 0),
(8533,'OPTOKINETIC NYSTAGMUS TEST','OPTOKINETIC NYSTAGMUS TEST','92534','1','','1','0','','','',0, 1, 0, 0),
(8534,'CALORIC VESTIBULAR TEST W/REC BI BITHERMAL','CALORIC VESTIBULAR TEST W/REC BI BITHERMAL','92537','1','','1','0','','','',0, 1, 0, 0),
(8535,'CALORIC VESTIBULAR TEST W/REC BI MONOTHERMAL','CALORIC VESTIBULAR TEST W/REC BI MONOTHERMAL','92538','1','','1','0','','','',0, 1, 0, 0),
(8536,'VSTBLR FUNCJ NYSTAG FOVL&PERPH STIMJ OSCIL TRK','VSTBLR FUNCJ NYSTAG FOVL&PERPH STIMJ OSCIL TRK','92540','1','','1','0','','','',0, 1, 0, 0),
(8537,'SPONTANEOUS NYSTAGMUS TEST','SPONTANEOUS NYSTAGMUS TEST','92541','1','','1','0','','','',0, 1, 0, 0),
(8538,'POSITIONAL NYSTAGMUS TEST','POSITIONAL NYSTAGMUS TEST','92542','1','','1','0','','','',0, 1, 0, 0),
(8539,'OPTKINETIC NYSTAG BIDIR/FOVEAL/PERIPH STIM W/REC','OPTKINETIC NYSTAG BIDIR/FOVEAL/PERIPH STIM W/REC','92544','1','','1','0','','','',0, 1, 0, 0),
(8540,'OSCILLATING TRACKING TEST W/RECORDING','OSCILLATING TRACKING TEST W/RECORDING','92545','1','','1','0','','','',0, 1, 0, 0),
(8541,'SINUSOIDAL VERTICAL AXIS ROTATIONAL TESTING','SINUSOIDAL VERTICAL AXIS ROTATIONAL TESTING','92546','1','','1','0','','','',0, 1, 0, 0),
(8542,'USE VERTICAL ELECTRODES','USE VERTICAL ELECTRODES','92547','1','','1','0','','','',0, 1, 0, 0),
(8543,'COMPUTERIZED DYNAMIC POSTUROGRAPY','COMPUTERIZED DYNAMIC POSTUROGRAPY','92548','1','','1','0','','','',0, 1, 0, 0),
(8544,'TYMPANOMETRY AND REFLEX THRESHOLD MEASUREMENTS','TYMPANOMETRY AND REFLEX THRESHOLD MEASUREMENTS','92550','1','','1','0','','','',0, 1, 0, 0),
(8545,'SCREENING TEST PURE TONE AIR ONLY','SCREENING TEST PURE TONE AIR ONLY','92551','1','','1','0','','','',0, 1, 0, 0),
(8546,'PURE TONE AUDIOMETRY AIR ONLY','PURE TONE AUDIOMETRY AIR ONLY','92552','1','','1','0','','','',0, 1, 0, 0),
(8547,'PURE TONE AUDIOMETRY AIR & BONE','PURE TONE AUDIOMETRY AIR & BONE','92553','1','','1','0','','','',0, 1, 0, 0),
(8548,'SPEECH AUDIOMETRY THRESHOLD','SPEECH AUDIOMETRY THRESHOLD','92555','1','','1','0','','','',0, 1, 0, 0),
(8549,'SPEECH AUDIOMETRY THRESHOLD SPEECH RECOGNIJ','SPEECH AUDIOMETRY THRESHOLD SPEECH RECOGNIJ','92556','1','','1','0','','','',0, 1, 0, 0),
(8550,'COMPRE AUDIOMETRY THRESHOLD EVAL SP RECOGNIJ','COMPRE AUDIOMETRY THRESHOLD EVAL SP RECOGNIJ','92557','1','','1','0','','','',0, 1, 0, 0),
(8551,'EVOKED OTOACOUSTIC EMISSIONS SCREEN AUTO ANALYS','EVOKED OTOACOUSTIC EMISSIONS SCREEN AUTO ANALYS','92558','1','','1','0','','','',0, 1, 0, 0),
(8552,'AUDIOMETRIC TESTING GROUPS','AUDIOMETRIC TESTING GROUPS','92559','1','','1','0','','','',0, 1, 0, 0),
(8553,'BEKESY AUDIOMETRY SCREENING','BEKESY AUDIOMETRY SCREENING','92560','1','','1','0','','','',0, 1, 0, 0),
(8554,'BEKESY AUDIOMETRY DIAGNOSTIC','BEKESY AUDIOMETRY DIAGNOSTIC','92561','1','','1','0','','','',0, 1, 0, 0),
(8555,'LOUDNESS BALANCE BINAURAL/MONAURAL','LOUDNESS BALANCE BINAURAL/MONAURAL','92562','1','','1','0','','','',0, 1, 0, 0),
(8556,'TONE DECAY TEST','TONE DECAY TEST','92563','1','','1','0','','','',0, 1, 0, 0),
(8557,'SHORT INCREMENT SENSITIVITY INDEX','SHORT INCREMENT SENSITIVITY INDEX','92564','1','','1','0','','','',0, 1, 0, 0),
(8558,'STENGER TEST PURE TONE','STENGER TEST PURE TONE','92565','1','','1','0','','','',0, 1, 0, 0),
(8559,'TYMPANOMETRY','TYMPANOMETRY','92567','1','','1','0','','','',0, 1, 0, 0),
(8560,'ACOUSTIC REFLEX THRESHOLD','ACOUSTIC REFLEX THRESHOLD','92568','1','','1','0','','','',0, 1, 0, 0),
(8561,'ACOUSTIC IMMIT TEST TYMPANOM/ACOUST REFLX/DECAY','ACOUSTIC IMMIT TEST TYMPANOM/ACOUST REFLX/DECAY','92570','1','','1','0','','','',0, 1, 0, 0),
(8562,'FILTERED SPEECH TEST','FILTERED SPEECH TEST','92571','1','','1','0','','','',0, 1, 0, 0),
(8563,'STAGGERED SPONDAIC WORD','STAGGERED SPONDAIC WORD','92572','1','','1','0','','','',0, 1, 0, 0),
(8564,'SENSORINEURAL ACUITY LEVEL','SENSORINEURAL ACUITY LEVEL','92575','1','','1','0','','','',0, 1, 0, 0),
(8565,'SYNTHETIC SENTENCE IDENTIFICATION TEST','SYNTHETIC SENTENCE IDENTIFICATION TEST','92576','1','','1','0','','','',0, 1, 0, 0),
(8566,'STENGER TEST SPEECH','STENGER TEST SPEECH','92577','1','','1','0','','','',0, 1, 0, 0),
(8567,'VISUAL REINFORCEMENT AUDIOMETRY','VISUAL REINFORCEMENT AUDIOMETRY','92579','1','','1','0','','','',0, 1, 0, 0),
(8568,'CONDITIONING PLAY AUDIOMETRY','CONDITIONING PLAY AUDIOMETRY','92582','1','','1','0','','','',0, 1, 0, 0),
(8569,'SELECT PICTURE AUDIOMETRY','SELECT PICTURE AUDIOMETRY','92583','1','','1','0','','','',0, 1, 0, 0),
(8570,'ELECTROCOCHLEOGRAPHY','ELECTROCOCHLEOGRAPHY','92584','1','','1','0','','','',0, 1, 0, 0),
(8571,'AUDITORY EVOKED POTENTIALS COMPREHENSIVE','AUDITORY EVOKED POTENTIALS COMPREHENSIVE','92585','1','','1','0','','','',0, 1, 0, 0),
(8572,'AUDITORY EVOKED POTENTIALS LIMITED','AUDITORY EVOKED POTENTIALS LIMITED','92586','1','','1','0','','','',0, 1, 0, 0),
(8573,'DISTORT PRODUCT EVOKED OTOACOUSTIC EMISNS LIMITD','DISTORT PRODUCT EVOKED OTOACOUSTIC EMISNS LIMITD','92587','1','','1','0','','','',0, 1, 0, 0),
(8574,'DISTRT PROD EVOKD OTOACOUSTIC EMSNS COMP/DX EVAL','DISTRT PROD EVOKD OTOACOUSTIC EMSNS COMP/DX EVAL','92588','1','','1','0','','','',0, 1, 0, 0),
(8575,'HEARING AID EXAMINATION & SELECTION MONAURAL','HEARING AID EXAMINATION & SELECTION MONAURAL','92590','1','','1','0','','','',0, 1, 0, 0),
(8576,'HEARING AID EXAMINATION & SELECTION BINAURAL','HEARING AID EXAMINATION & SELECTION BINAURAL','92591','1','','1','0','','','',0, 1, 0, 0),
(8577,'HEARING AID CHECK MONAURAL','HEARING AID CHECK MONAURAL','92592','1','','1','0','','','',0, 1, 0, 0),
(8578,'HEARING AID CHECK BINAURAL','HEARING AID CHECK BINAURAL','92593','1','','1','0','','','',0, 1, 0, 0),
(8579,'ELECTROACOUS EVAL HEARING AID MONAURAL','ELECTROACOUS EVAL HEARING AID MONAURAL','92594','1','','1','0','','','',0, 1, 0, 0),
(8580,'ELECTROACOUS EVAL HEARING AID BINAURAL','ELECTROACOUS EVAL HEARING AID BINAURAL','92595','1','','1','0','','','',0, 1, 0, 0),
(8581,'EAR PROTECTOR ATTENUATION MEASUREMENTS','EAR PROTECTOR ATTENUATION MEASUREMENTS','92596','1','','1','0','','','',0, 1, 0, 0),
(8582,'EVAL&/FITG VOICE PROSTC DEV SUPLMNT ORAL SPEEC','EVAL&/FITG VOICE PROSTC DEV SUPLMNT ORAL SPEEC','92597','1','','1','0','','','',0, 1, 0, 0),
(8583,'ANALYSIS COCHLEAR IMPLT PT <7 YR PRGRMG','ANALYSIS COCHLEAR IMPLT PT <7 YR PRGRMG','92601','1','','1','0','','','',0, 1, 0, 0),
(8584,'ANALYSIS COCHLEAR IMPLT PT <7 YR SBSQ REPRGRMG','ANALYSIS COCHLEAR IMPLT PT <7 YR SBSQ REPRGRMG','92602','1','','1','0','','','',0, 1, 0, 0),
(8585,'ANALYSIS COCHLEAR IMPLT 7 YR/> PRGRMG','ANALYSIS COCHLEAR IMPLT 7 YR/> PRGRMG','92603','1','','1','0','','','',0, 1, 0, 0),
(8586,'ANALYSIS COCHLEAR IMPLT 7 YR/> SBSQ REPRGRMG','ANALYSIS COCHLEAR IMPLT 7 YR/> SBSQ REPRGRMG','92604','1','','1','0','','','',0, 1, 0, 0),
(8587,'EVAL RX N-SP-GEN AUGMT ALT COMMUN DEV F2F 1ST HR','EVAL RX N-SP-GEN AUGMT ALT COMMUN DEV F2F 1ST HR','92605','1','','1','0','','','',0, 1, 0, 0),
(8588,'THER SVC N-SP-GENRATJ DEV PRGRMG&MODIFICAJ','THER SVC N-SP-GENRATJ DEV PRGRMG&MODIFICAJ','92606','1','','1','0','','','',0, 1, 0, 0),
(8589,'RX SP-GENRATJ AUGMNT&COMUNICAJ DEV 1ST HR','RX SP-GENRATJ AUGMNT&COMUNICAJ DEV 1ST HR','92607','1','','1','0','','','',0, 1, 0, 0),
(8590,'RX SP-GENRATJ AUGMNT&COMUNICAJ DEV EA 30 MIN','RX SP-GENRATJ AUGMNT&COMUNICAJ DEV EA 30 MIN','92608','1','','1','0','','','',0, 1, 0, 0),
(8591,'THER SP-GENRATJ DEV PRGRMG&MODIFICAJ','THER SP-GENRATJ DEV PRGRMG&MODIFICAJ','92609','1','','1','0','','','',0, 1, 0, 0),
(8592,'EVAL ORAL&PHARYNGEAL SWLNG FUNCJ','EVAL ORAL&PHARYNGEAL SWLNG FUNCJ','92610','1','','1','0','','','',0, 1, 0, 0),
(8593,'MOTION FLUOR EVAL SWLNG FUNCJ C/V REC','MOTION FLUOR EVAL SWLNG FUNCJ C/V REC','92611','1','','1','0','','','',0, 1, 0, 0),
(8594,'FLX FIBOPT NDSC EVAL SWLNG C/V REC','FLX FIBOPT NDSC EVAL SWLNG C/V REC','92612','1','','1','0','','','',0, 1, 0, 0),
(8595,'FLX FIBOPT NDSC EVAL SWLNG C/V REC PHYS I&R','FLX FIBOPT NDSC EVAL SWLNG C/V REC PHYS I&R','92613','1','','1','0','','','',0, 1, 0, 0),
(8596,'FLX FIBOPT NDSC EVAL LARYN SENS C/V REC','FLX FIBOPT NDSC EVAL LARYN SENS C/V REC','92614','1','','1','0','','','',0, 1, 0, 0),
(8597,'FLX FIBOPT NDSC EVAL LARYN SENS PHYS I&R','FLX FIBOPT NDSC EVAL LARYN SENS PHYS I&R','92615','1','','1','0','','','',0, 1, 0, 0),
(8598,'FLX FIBOPT NDSC EVAL SWLNG&LARYN SENS C/V REC','FLX FIBOPT NDSC EVAL SWLNG&LARYN SENS C/V REC','92616','1','','1','0','','','',0, 1, 0, 0),
(8599,'FLX FIBOPT NDSC EVAL SWLNG&LARYN SENS PHYS I&R','FLX FIBOPT NDSC EVAL SWLNG&LARYN SENS PHYS I&R','92617','1','','1','0','','','',0, 1, 0, 0),
(8600,'EVAL RX N-SP-GEN AUGMT ALT COMMUN DEV ADD 30 MIN','EVAL RX N-SP-GEN AUGMT ALT COMMUN DEV ADD 30 MIN','92618','1','','1','0','','','',0, 1, 0, 0),
(8601,'EVAL CENTRAL AUDITORY FUNCJ W/REPRT 1ST 60 MIN','EVAL CENTRAL AUDITORY FUNCJ W/REPRT 1ST 60 MIN','92620','1','','1','0','','','',0, 1, 0, 0),
(8602,'EVAL CENTRAL AUDITORY FUNCJ W/REPRT EA 15 MIN','EVAL CENTRAL AUDITORY FUNCJ W/REPRT EA 15 MIN','92621','1','','1','0','','','',0, 1, 0, 0),
(8603,'ASSESSMENT TINNITUS','ASSESSMENT TINNITUS','92625','1','','1','0','','','',0, 1, 0, 0),
(8604,'EVALUATION AUDITORY REHAB STATUS 1ST HR','EVALUATION AUDITORY REHAB STATUS 1ST HR','92626','1','','1','0','','','',0, 1, 0, 0),
(8605,'EVALUATION AUDITORY REHAB STATUS EA 15 MIN','EVALUATION AUDITORY REHAB STATUS EA 15 MIN','92627','1','','1','0','','','',0, 1, 0, 0),
(8606,'AUDITORY REHABILITATION PRELINGUAL HEARING LOSS','AUDITORY REHABILITATION PRELINGUAL HEARING LOSS','92630','1','','1','0','','','',0, 1, 0, 0),
(8607,'AUDITORY REHABILITATION POSTLINGUAL HEARING LOSS','AUDITORY REHABILITATION POSTLINGUAL HEARING LOSS','92633','1','','1','0','','','',0, 1, 0, 0),
(8608,'ANALYSIS W/PRGRMG AUD BRAINSTEM IMPLANT PR HR','ANALYSIS W/PRGRMG AUD BRAINSTEM IMPLANT PR HR','92640','1','','1','0','','','',0, 1, 0, 0),
(8609,'UNLISTED OTORHINOLARYNGOLOGICAL SERVICE','UNLISTED OTORHINOLARYNGOLOGICAL SERVICE','92700','1','','1','0','','','',0, 1, 0, 0),
(8610,'PRQ TRLUML CORONARY ANGIOPLASTY ONE ART/BRANCH','PRQ TRLUML CORONARY ANGIOPLASTY ONE ART/BRANCH','92920','1','','1','0','','','',0, 1, 0, 0),
(8611,'PRQ TRLUML CORONARY ANGIOPLASTY ADDL BRANCH','PRQ TRLUML CORONARY ANGIOPLASTY ADDL BRANCH','92921','1','','1','0','','','',0, 1, 0, 0),
(8612,'PRQ TRLUML CORONARY ANGIO/ATHERECT ONE ART/BRNCH','PRQ TRLUML CORONARY ANGIO/ATHERECT ONE ART/BRNCH','92924','1','','1','0','','','',0, 1, 0, 0),
(8613,'PRQ TRLUML CORONARY ANGIO/ATHEREC ADDL ART/BRNCH','PRQ TRLUML CORONARY ANGIO/ATHEREC ADDL ART/BRNCH','92925','1','','1','0','','','',0, 1, 0, 0),
(8614,'PRQ TRLUML CORONARY STENT W/ANGIO ONE ART/BRNCH','PRQ TRLUML CORONARY STENT W/ANGIO ONE ART/BRNCH','92928','1','','1','0','','','',0, 1, 0, 0),
(8615,'PRQ TRLUML CORONARY STENT W/ANGIO ADDL ART/BRNCH','PRQ TRLUML CORONARY STENT W/ANGIO ADDL ART/BRNCH','92929','1','','1','0','','','',0, 1, 0, 0),
(8616,'PRQ TRLUML CORONRY STENT/ATH/ANGIO ONE ART/BRNCH','PRQ TRLUML CORONRY STENT/ATH/ANGIO ONE ART/BRNCH','92933','1','','1','0','','','',0, 1, 0, 0),
(8617,'PRQ TRLUML CORONARY STENT/ATH/ANGIO ADDL BRANCH','PRQ TRLUML CORONARY STENT/ATH/ANGIO ADDL BRANCH','92934','1','','1','0','','','',0, 1, 0, 0),
(8618,'PRQ TRLUML CORONARY BYP GRFT REVASC ONE VESSEL','PRQ TRLUML CORONARY BYP GRFT REVASC ONE VESSEL','92937','1','','1','0','','','',0, 1, 0, 0),
(8619,'PRQ TRLUML CORONARY BYP GRFT REVASC ADDL VESSEL','PRQ TRLUML CORONARY BYP GRFT REVASC ADDL VESSEL','92938','1','','1','0','','','',0, 1, 0, 0),
(8620,'PRQ TRLUML CORONRY TOT OCCLUS REVASC MI ONE VSL','PRQ TRLUML CORONRY TOT OCCLUS REVASC MI ONE VSL','92941','1','','1','0','','','',0, 1, 0, 0),
(8621,'PRQ TRLUML CORONRY CHRONIC OCCLUS REVASC ONE VSL','PRQ TRLUML CORONRY CHRONIC OCCLUS REVASC ONE VSL','92943','1','','1','0','','','',0, 1, 0, 0),
(8622,'PRQ TRLUML CORONRY CHRNIC OCCLUS REVASC ADDL VSL','PRQ TRLUML CORONRY CHRNIC OCCLUS REVASC ADDL VSL','92944','1','','1','0','','','',0, 1, 0, 0),
(8623,'CARDIOPULMONARY RESUSCITATION','CARDIOPULMONARY RESUSCITATION','92950','1','','1','0','','','',0, 1, 0, 0),
(8624,'TEMPORARY TRANSCUTANEOUS PACING','TEMPORARY TRANSCUTANEOUS PACING','92953','1','','1','0','','','',0, 1, 0, 0),
(8625,'CARDIOVERSION ELECTIVE ARRHYTHMIA EXTERNAL','CARDIOVERSION ELECTIVE ARRHYTHMIA EXTERNAL','92960','1','','1','0','','','',0, 1, 0, 0),
(8626,'CARDIOVERSION ELECTIVE ARRHYTHMIA INTERNAL SPX','CARDIOVERSION ELECTIVE ARRHYTHMIA INTERNAL SPX','92961','1','','1','0','','','',0, 1, 0, 0),
(8627,'CARDIOASSIST-METH CIRCULATORY ASSIST INTERNAL','CARDIOASSIST-METH CIRCULATORY ASSIST INTERNAL','92970','1','','1','0','','','',0, 1, 0, 0),
(8628,'CARDIOASSIST-METH CIRCULATORY ASSIST EXTERNAL','CARDIOASSIST-METH CIRCULATORY ASSIST EXTERNAL','92971','1','','1','0','','','',0, 1, 0, 0),
(8629,'PRQ TRANSLUMINAL CORONARY MECHANICL THROMBECTOMY','PRQ TRANSLUMINAL CORONARY MECHANICL THROMBECTOMY','92973','1','','1','0','','','',0, 1, 0, 0),
(8630,'TCAT PLACEMENT RADJ DLVR DEV SBSQ C IV BRACHYTX','TCAT PLACEMENT RADJ DLVR DEV SBSQ C IV BRACHYTX','92974','1','','1','0','','','',0, 1, 0, 0),
(8631,'THROMBOLYSIS INTRACORONARY NFS SLCTV ANGRPH','THROMBOLYSIS INTRACORONARY NFS SLCTV ANGRPH','92975','1','','1','0','','','',0, 1, 0, 0),
(8632,'THROMBOLYSIS CORONARY INTRAVENOUS INFUSION','THROMBOLYSIS CORONARY INTRAVENOUS INFUSION','92977','1','','1','0','','','',0, 1, 0, 0),
(8633,'INTRAVASC US CORONARY INTERP&RPT INITIAL VESSE','INTRAVASC US CORONARY INTERP&RPT INITIAL VESSE','92978','1','','1','0','','','',0, 1, 0, 0),
(8634,'INTRAVASC US CORONARY INTERP&RPT ADDL VESSEL','INTRAVASC US CORONARY INTERP&RPT ADDL VESSEL','92979','1','','1','0','','','',0, 1, 0, 0),
(8635,'PRQ BALLOON VALVULOPLASTY AORTIC VALVE','PRQ BALLOON VALVULOPLASTY AORTIC VALVE','92986','1','','1','0','','','',0, 1, 0, 0),
(8636,'PRQ BALLOON VALVULOPLASTY MITRAL VALVE','PRQ BALLOON VALVULOPLASTY MITRAL VALVE','92987','1','','1','0','','','',0, 1, 0, 0),
(8637,'PRQ BALLOON VALVULOPLASTY PULMONARY VALVE','PRQ BALLOON VALVULOPLASTY PULMONARY VALVE','92990','1','','1','0','','','',0, 1, 0, 0),
(8638,'ATRIAL SEPTECT/SEPTOST TRANSVENOUS BALLOON','ATRIAL SEPTECT/SEPTOST TRANSVENOUS BALLOON','92992','1','','1','0','','','',0, 1, 0, 0),
(8639,'ATRIAL SEPTECT/SEPTOSTOMY BLADE METHOD','ATRIAL SEPTECT/SEPTOSTOMY BLADE METHOD','92993','1','','1','0','','','',0, 1, 0, 0),
(8640,'PRQ TRLUML PULMONARY ART BALLOON ANGIOP 1 VSL','PRQ TRLUML PULMONARY ART BALLOON ANGIOP 1 VSL','92997','1','','1','0','','','',0, 1, 0, 0),
(8641,'PRQ TRLUML PULMONARY ART BALLOON ANGIOP EA VSL','PRQ TRLUML PULMONARY ART BALLOON ANGIOP EA VSL','92998','1','','1','0','','','',0, 1, 0, 0),
(8642,'ECG ROUTINE ECG W/LEAST 12 LDS W/I&R','ECG ROUTINE ECG W/LEAST 12 LDS W/I&R','93000','1','','1','0','','','',0, 1, 0, 0),
(8643,'ECG ROUTINE ECG W/LEAST 12 LDS TRCG ONLY W/O I&R','ECG ROUTINE ECG W/LEAST 12 LDS TRCG ONLY W/O I&R','93005','1','','1','0','','','',0, 1, 0, 0),
(8644,'ECG ROUTINE ECG W/LEAST 12 LDS I&R ONLY','ECG ROUTINE ECG W/LEAST 12 LDS I&R ONLY','93010','1','','1','0','','','',0, 1, 0, 0),
(8645,'CV STRS TST XERS&/OR RX CONT ECG W/SI&R','CV STRS TST XERS&/OR RX CONT ECG W/SI&R','93015','1','','1','0','','','',0, 1, 0, 0),
(8646,'CV STRS TST XERS&/OR RX CONT ECG W/O I&R','CV STRS TST XERS&/OR RX CONT ECG W/O I&R','93016','1','','1','0','','','',0, 1, 0, 0),
(8647,'CV STRS TST XERS&/OR RX CONT ECG TRCG ONLY','CV STRS TST XERS&/OR RX CONT ECG TRCG ONLY','93017','1','','1','0','','','',0, 1, 0, 0),
(8648,'CV STRS TST XERS&/OR RX CONT ECG I&R ONLY','CV STRS TST XERS&/OR RX CONT ECG I&R ONLY','93018','1','','1','0','','','',0, 1, 0, 0),
(8649,'ERGONOVINE PROVOCATION TST','ERGONOVINE PROVOCATION TST','93024','1','','1','0','','','',0, 1, 0, 0),
(8650,'MICROVOLT T-WAVE ASSESS VENTRICULAR ARRHYTHMIAS','MICROVOLT T-WAVE ASSESS VENTRICULAR ARRHYTHMIAS','93025','1','','1','0','','','',0, 1, 0, 0),
(8651,'RHYTHM ECG 1-3 LEADS W/INTERPRETATION & REPORT','RHYTHM ECG 1-3 LEADS W/INTERPRETATION & REPORT','93040','1','','1','0','','','',0, 1, 0, 0),
(8652,'RHYTHM ECG 1-3 LEADS TRACING ONLY W/O I&R','RHYTHM ECG 1-3 LEADS TRACING ONLY W/O I&R','93041','1','','1','0','','','',0, 1, 0, 0),
(8653,'RHYTHM ECG 1-3 LEADS INTERPRETATION & REPRT ON','RHYTHM ECG 1-3 LEADS INTERPRETATION & REPRT ON','93042','1','','1','0','','','',0, 1, 0, 0),
(8654,'ART PRESS WAVEFORM ANALYS CENTRAL ART PRESSURE','ART PRESS WAVEFORM ANALYS CENTRAL ART PRESSURE','93050','1','','1','0','','','',0, 1, 0, 0),
(8655,'XTRNL ECG & 48 HR RECORD SCAN STOR W/R&I','XTRNL ECG & 48 HR RECORD SCAN STOR W/R&I','93224','1','','1','0','','','',0, 1, 0, 0),
(8656,'XTRNL ECG & 48 HR RECORDING','XTRNL ECG & 48 HR RECORDING','93225','1','','1','0','','','',0, 1, 0, 0),
(8657,'EXTERNAL ECG SCANNING ANALYSIS REPORT','EXTERNAL ECG SCANNING ANALYSIS REPORT','93226','1','','1','0','','','',0, 1, 0, 0),
(8658,'XTRNL ECG CONTINUOUS RHYTHM W/I&R UP TO 48 HRS','XTRNL ECG CONTINUOUS RHYTHM W/I&R UP TO 48 HRS','93227','1','','1','0','','','',0, 1, 0, 0),
(8659,'XTRNL MOBILE CV TELEMETRY W/I&REPORT 30 DAYS','XTRNL MOBILE CV TELEMETRY W/I&REPORT 30 DAYS','93228','1','','1','0','','','',0, 1, 0, 0),
(8660,'XTRNL MOBILE CV TELEMETRY W/TECHNICAL SUPPORT','XTRNL MOBILE CV TELEMETRY W/TECHNICAL SUPPORT','93229','1','','1','0','','','',0, 1, 0, 0),
(8661,'PRGRMG DEV EVAL IMPLANTABLE SUBQ LEAD DFB SYSTEM','PRGRMG DEV EVAL IMPLANTABLE SUBQ LEAD DFB SYSTEM','93260','1','','1','0','','','',0, 1, 0, 0),
(8662,'INTERROGATION EVAL F2F IMPLANT SUBQ LEAD DEFIB','INTERROGATION EVAL F2F IMPLANT SUBQ LEAD DEFIB','93261','1','','1','0','','','',0, 1, 0, 0),
(8663,'XTRNL PT ACTIV ECG TRANSMIS W/R&I </30 DAYS','XTRNL PT ACTIV ECG TRANSMIS W/R&I </30 DAYS','93268','1','','1','0','','','',0, 1, 0, 0),
(8664,'XTRNL PT ACTIVATED ECG RECORD MONITOR 30 DAYS','XTRNL PT ACTIVATED ECG RECORD MONITOR 30 DAYS','93270','1','','1','0','','','',0, 1, 0, 0),
(8665,'XTRNL PT ACTIVATED ECG REC DWNLD 30 DAYS','XTRNL PT ACTIVATED ECG REC DWNLD 30 DAYS','93271','1','','1','0','','','',0, 1, 0, 0),
(8666,'XTRNL PT ACTIVTD ECG DWNLD W/R&I </30 DAYS','XTRNL PT ACTIVTD ECG DWNLD W/R&I </30 DAYS','93272','1','','1','0','','','',0, 1, 0, 0),
(8667,'SIGNAL AVERAGED ELECTROCARDIOGRAPHY W/WO ECG','SIGNAL AVERAGED ELECTROCARDIOGRAPHY W/WO ECG','93278','1','','1','0','','','',0, 1, 0, 0),
(8668,'PROGRAM EVAL IMPLANTABLE IN PRSN 1 LD PACEMAKER','PROGRAM EVAL IMPLANTABLE IN PRSN 1 LD PACEMAKER','93279','1','','1','0','','','',0, 1, 0, 0),
(8669,'PROGRAM EVAL IMPLANTABLE IN PERSN DUAL LD PACER','PROGRAM EVAL IMPLANTABLE IN PERSN DUAL LD PACER','93280','1','','1','0','','','',0, 1, 0, 0),
(8670,'PROGRAM EVAL IMPLANTABLE IN PRSN MULTI LD PACER','PROGRAM EVAL IMPLANTABLE IN PRSN MULTI LD PACER','93281','1','','1','0','','','',0, 1, 0, 0),
(8671,'PRGRMNG DEV EVAL IMPLANTABLE IN PERSN 1 LD DFB','PRGRMNG DEV EVAL IMPLANTABLE IN PERSN 1 LD DFB','93282','1','','1','0','','','',0, 1, 0, 0),
(8672,'PRGRMG EVAL IMPLANTABLE IN PRSN DUAL LEAD DFB','PRGRMG EVAL IMPLANTABLE IN PRSN DUAL LEAD DFB','93283','1','','1','0','','','',0, 1, 0, 0),
(8673,'PRGRMG EVAL IMPLANTABLE IN PERSON MULTI LEAD DFB','PRGRMG EVAL IMPLANTABLE IN PERSON MULTI LEAD DFB','93284','1','','1','0','','','',0, 1, 0, 0),
(8674,'PROGRAM EVAL IMPLANTABLE DEV IN PRSN ILR SYSTEM','PROGRAM EVAL IMPLANTABLE DEV IN PRSN ILR SYSTEM','93285','1','','1','0','','','',0, 1, 0, 0),
(8675,'PERI-PX EVAL&PROGRAM IN PRSN PACEMAKER SYSTEM','PERI-PX EVAL&PROGRAM IN PRSN PACEMAKER SYSTEM','93286','1','','1','0','','','',0, 1, 0, 0),
(8676,'PERI-PX DEV EVAL & PROG SING/DUAL/MULTI LEAD DFB','PERI-PX DEV EVAL & PROG SING/DUAL/MULTI LEAD DFB','93287','1','','1','0','','','',0, 1, 0, 0),
(8677,'INTERROGATION EVAL IN PERSON 1/DUAL/MLT LEAD PM','INTERROGATION EVAL IN PERSON 1/DUAL/MLT LEAD PM','93288','1','','1','0','','','',0, 1, 0, 0),
(8678,'INTERROG EVAL F2F 1/DUAL/MLT LEADS IMPLTBL DFB','INTERROG EVAL F2F 1/DUAL/MLT LEADS IMPLTBL DFB','93289','1','','1','0','','','',0, 1, 0, 0),
(8679,'INTERROGATION EVAL F2F IMPLANTABLE CV MNTR SYS','INTERROGATION EVAL F2F IMPLANTABLE CV MNTR SYS','93290','1','','1','0','','','',0, 1, 0, 0),
(8680,'INTERROGATION EVALUATION IN PERSON ILR SYSTEM','INTERROGATION EVALUATION IN PERSON ILR SYSTEM','93291','1','','1','0','','','',0, 1, 0, 0),
(8681,'INTERROGATION EVAL IN PERSON WR DEFIBRILLATOR','INTERROGATION EVAL IN PERSON WR DEFIBRILLATOR','93292','1','','1','0','','','',0, 1, 0, 0),
(8682,'TRANSTELEPHONIC RHYTHM STRIP PACEMAKER EVAL','TRANSTELEPHONIC RHYTHM STRIP PACEMAKER EVAL','93293','1','','1','0','','','',0, 1, 0, 0),
(8683,'INTERROGATION EVAL REMOTE </90 D 1/2/MLT LEAD PM','INTERROGATION EVAL REMOTE </90 D 1/2/MLT LEAD PM','93294','1','','1','0','','','',0, 1, 0, 0),
(8684,'INTERROGATION EVAL REMOTE </90 D 1/2/MLT LD DFB','INTERROGATION EVAL REMOTE </90 D 1/2/MLT LD DFB','93295','1','','1','0','','','',0, 1, 0, 0),
(8685,'INTERROGATION REMOTE </90 D TECHNICIAN REVIEW','INTERROGATION REMOTE </90 D TECHNICIAN REVIEW','93296','1','','1','0','','','',0, 1, 0, 0),
(8686,'INTERROGATION EVAL REMOTE </30 D CV MNTR SYS','INTERROGATION EVAL REMOTE </30 D CV MNTR SYS','93297','1','','1','0','','','',0, 1, 0, 0),
(8687,'INTERROGATION EVALUATION REMOTE </30 D ILR SYS','INTERROGATION EVALUATION REMOTE </30 D ILR SYS','93298','1','','1','0','','','',0, 1, 0, 0),
(8688,'INTERROGATION EVAL REMOTE </30 D TECH REVIEW','INTERROGATION EVAL REMOTE </30 D TECH REVIEW','93299','1','','1','0','','','',0, 1, 0, 0),
(8689,'COMPLETE TTHRC ECHO CONGENITAL CARDIAC ANOMALY','COMPLETE TTHRC ECHO CONGENITAL CARDIAC ANOMALY','93303','1','','1','0','','','',0, 1, 0, 0),
(8690,'F-UP/LIMITED TTHRC ECHO CONGENITAL CAR ANOMALY','F-UP/LIMITED TTHRC ECHO CONGENITAL CAR ANOMALY','93304','1','','1','0','','','',0, 1, 0, 0),
(8691,'ECHO TTHRC R-T 2D W/WOM-MODE COMPL SPEC&COLR D','ECHO TTHRC R-T 2D W/WOM-MODE COMPL SPEC&COLR D','93306','1','','1','0','','','',0, 1, 0, 0),
(8692,'ECHO TRANSTHORAC R-T 2D W/WO M-MODE REC COMP','ECHO TRANSTHORAC R-T 2D W/WO M-MODE REC COMP','93307','1','','1','0','','','',0, 1, 0, 0),
(8693,'ECHO TRANSTHORC R-T 2D W/WO M-MODE REC F-UP/LMTD','ECHO TRANSTHORC R-T 2D W/WO M-MODE REC F-UP/LMTD','93308','1','','1','0','','','',0, 1, 0, 0),
(8694,'ECHO TRANSESOPHAG R-T 2D W/PRB IMG ACQUISJ I&R','ECHO TRANSESOPHAG R-T 2D W/PRB IMG ACQUISJ I&R','93312','1','','1','0','','','',0, 1, 0, 0),
(8695,'ECHO R-T 2D W/PROBE PLACEMENT ONLY','ECHO R-T 2D W/PROBE PLACEMENT ONLY','93313','1','','1','0','','','',0, 1, 0, 0),
(8696,'ECHO TRANSESOPHAG R-T 2D IMG ACQUISJ I&R ONLY','ECHO TRANSESOPHAG R-T 2D IMG ACQUISJ I&R ONLY','93314','1','','1','0','','','',0, 1, 0, 0),
(8697,'ECHO TRANSESOPHAG CONGEN PROBE PLCMT IMGNG I&R','ECHO TRANSESOPHAG CONGEN PROBE PLCMT IMGNG I&R','93315','1','','1','0','','','',0, 1, 0, 0),
(8698,'ECHO TRANSESOPHAG CONGEN PROBE PLCMT ONLY','ECHO TRANSESOPHAG CONGEN PROBE PLCMT ONLY','93316','1','','1','0','','','',0, 1, 0, 0),
(8699,'ECHO TRANSESOPHAG IMAGE ACQUISJ INTERP&REPORT','ECHO TRANSESOPHAG IMAGE ACQUISJ INTERP&REPORT','93317','1','','1','0','','','',0, 1, 0, 0),
(8700,'ECHO TRANSESOPHAG MONTR CARDIAC PUMP FUNCTJ','ECHO TRANSESOPHAG MONTR CARDIAC PUMP FUNCTJ','93318','1','','1','0','','','',0, 1, 0, 0),
(8701,'DOPPLER ECHOCARD PULSE WAVE W/SPECTRAL DISPLAY','DOPPLER ECHOCARD PULSE WAVE W/SPECTRAL DISPLAY','93320','1','','1','0','','','',0, 1, 0, 0),
(8702,'DOP ECHOCARD PULSE WAVE W/SPECTRAL F-UP/LMTD STD','DOP ECHOCARD PULSE WAVE W/SPECTRAL F-UP/LMTD STD','93321','1','','1','0','','','',0, 1, 0, 0),
(8703,'DOP ECHOCARD COLOR FLOW VELOCITY MAPPING','DOP ECHOCARD COLOR FLOW VELOCITY MAPPING','93325','1','','1','0','','','',0, 1, 0, 0),
(8704,'ECHO TTHRC R-T 2D W/WO M-MODE COMPLETE REST&ST','ECHO TTHRC R-T 2D W/WO M-MODE COMPLETE REST&ST','93350','1','','1','0','','','',0, 1, 0, 0),
(8705,'ECHO TTHRC R-T 2D W/WO M-MODE REST&STRS CONT ECG','ECHO TTHRC R-T 2D W/WO M-MODE REST&STRS CONT ECG','93351','1','','1','0','','','',0, 1, 0, 0),
(8706,'USE OF ECHO CONTRAST AGENT DURING STRESS ECHO','USE OF ECHO CONTRAST AGENT DURING STRESS ECHO','93352','1','','1','0','','','',0, 1, 0, 0),
(8707,'ECHO TEE GUID TCAT ICAR/VESSEL STRUCTURAL INTVN','ECHO TEE GUID TCAT ICAR/VESSEL STRUCTURAL INTVN','93355','1','','1','0','','','',0, 1, 0, 0),
(8708,'RIGHT HEART CATH O2 SATURATION & CARDIAC OUTPUT','RIGHT HEART CATH O2 SATURATION & CARDIAC OUTPUT','93451','1','','1','0','','','',0, 1, 0, 0),
(8709,'L HRT CATH W/NJX L VENTRICULOGRAPHY IMG S&I','L HRT CATH W/NJX L VENTRICULOGRAPHY IMG S&I','93452','1','','1','0','','','',0, 1, 0, 0),
(8710,'R & L HRT CATH W/NJX L VENTRICULOG IMG S&I','R & L HRT CATH W/NJX L VENTRICULOG IMG S&I','93453','1','','1','0','','','',0, 1, 0, 0),
(8711,'CATH PLACEMENT & NJX CORONARY ART ANGIO IMG S&I','CATH PLACEMENT & NJX CORONARY ART ANGIO IMG S&I','93454','1','','1','0','','','',0, 1, 0, 0),
(8712,'CATH PLMT & NJX CORONARY ART/GRFT ANGIO IMG S&I','CATH PLMT & NJX CORONARY ART/GRFT ANGIO IMG S&I','93455','1','','1','0','','','',0, 1, 0, 0),
(8713,'CATH PLMT R HRT & ARTS W/NJX & ANGIO IMG S&I','CATH PLMT R HRT & ARTS W/NJX & ANGIO IMG S&I','93456','1','','1','0','','','',0, 1, 0, 0),
(8714,'CATH PLMT R HRT/ARTS/GRFTS W/NJX& ANGIO IMG S&I','CATH PLMT R HRT/ARTS/GRFTS W/NJX& ANGIO IMG S&I','93457','1','','1','0','','','',0, 1, 0, 0),
(8715,'CATH PLMT L HRT & ARTS W/NJX & ANGIO IMG S&I','CATH PLMT L HRT & ARTS W/NJX & ANGIO IMG S&I','93458','1','','1','0','','','',0, 1, 0, 0),
(8716,'CATH PLMT L HRT/ARTS/GRFTS WNJX & ANGIO IMG S&I','CATH PLMT L HRT/ARTS/GRFTS WNJX & ANGIO IMG S&I','93459','1','','1','0','','','',0, 1, 0, 0),
(8717,'R & L HRT CATH WINJX HRT ART& L VENTR IMG','R & L HRT CATH WINJX HRT ART& L VENTR IMG','93460','1','','1','0','','','',0, 1, 0, 0),
(8718,'R& L HRT CATH W/INJEC HRT ART/GRFT& L VENT I','R& L HRT CATH W/INJEC HRT ART/GRFT& L VENT I','93461','1','','1','0','','','',0, 1, 0, 0),
(8719,'LEFT HEART CATH BY TRANSEPTAL PUNCTURE','LEFT HEART CATH BY TRANSEPTAL PUNCTURE','93462','1','','1','0','','','',0, 1, 0, 0),
(8720,'MEDICATION ADMIN & HEMODYNAMIC MEASURMENT','MEDICATION ADMIN & HEMODYNAMIC MEASURMENT','93463','1','','1','0','','','',0, 1, 0, 0),
(8721,'PHYSIOLOGIC EXERCISE STUDY & HEMODYNAMIC MEASU','PHYSIOLOGIC EXERCISE STUDY & HEMODYNAMIC MEASU','93464','1','','1','0','','','',0, 1, 0, 0),
(8722,'INSERTION FLOW DIRECTED CATHETER FOR MONITORING','INSERTION FLOW DIRECTED CATHETER FOR MONITORING','93503','1','','1','0','','','',0, 1, 0, 0),
(8723,'ENDOMYOCARDIAL BIOPSY','ENDOMYOCARDIAL BIOPSY','93505','1','','1','0','','','',0, 1, 0, 0),
(8724,'R HRT CATHETERIZATION CONGENITAL CARDIAC ANOMALY','R HRT CATHETERIZATION CONGENITAL CARDIAC ANOMALY','93530','1','','1','0','','','',0, 1, 0, 0),
(8725,'CMBN R HRT & RETROGRADE L HRT CATHJ CGEN ANOMA','CMBN R HRT & RETROGRADE L HRT CATHJ CGEN ANOMA','93531','1','','1','0','','','',0, 1, 0, 0),
(8726,'CMBN R HRT T-SEPTAL L HRT CATHJ NTC SEPTUM CGEN','CMBN R HRT T-SEPTAL L HRT CATHJ NTC SEPTUM CGEN','93532','1','','1','0','','','',0, 1, 0, 0),
(8727,'CMBN R HRT T-SEPTAL L HRT CATHJ SEPTAL OPNG CGEN','CMBN R HRT T-SEPTAL L HRT CATHJ SEPTAL OPNG CGEN','93533','1','','1','0','','','',0, 1, 0, 0),
(8728,'INDIC DIL STD ARTL&/OR VEN CATHJ W/OUTP MEAS','INDIC DIL STD ARTL&/OR VEN CATHJ W/OUTP MEAS','93561','1','','1','0','','','',0, 1, 0, 0),
(8729,'INDIC DIL STD ARTL&/OR VEN CATHJ SBSQ OUTP MEA','INDIC DIL STD ARTL&/OR VEN CATHJ SBSQ OUTP MEA','93562','1','','1','0','','','',0, 1, 0, 0),
(8730,'NJX SEL HRT ART CONGENITAL HRT CATH W/S&I','NJX SEL HRT ART CONGENITAL HRT CATH W/S&I','93563','1','','1','0','','','',0, 1, 0, 0),
(8731,'NJX SEL HRT ART/GRFT CONGENITAL HRT CATH W/S&I','NJX SEL HRT ART/GRFT CONGENITAL HRT CATH W/S&I','93564','1','','1','0','','','',0, 1, 0, 0),
(8732,'NJX SEL L VENT/ATRIAL ANGIO HRT CATH W/S&I','NJX SEL L VENT/ATRIAL ANGIO HRT CATH W/S&I','93565','1','','1','0','','','',0, 1, 0, 0),
(8733,'NJX SEL R VENT/ATRIAL ANGIO HRT CATH W/S&I','NJX SEL R VENT/ATRIAL ANGIO HRT CATH W/S&I','93566','1','','1','0','','','',0, 1, 0, 0),
(8734,'NJX SUPRAVALV AORTOG HRT CATH W/S&I','NJX SUPRAVALV AORTOG HRT CATH W/S&I','93567','1','','1','0','','','',0, 1, 0, 0),
(8735,'NJX PULMONARY ANGIO HRT CATH W/S&I','NJX PULMONARY ANGIO HRT CATH W/S&I','93568','1','','1','0','','','',0, 1, 0, 0),
(8736,'IV DOP VEL&/OR PRESS C/FLO RSRV MEAS 1ST VSL','IV DOP VEL&/OR PRESS C/FLO RSRV MEAS 1ST VSL','93571','1','','1','0','','','',0, 1, 0, 0),
(8737,'IV DOP VEL&/OR PRESS C/FLO RSRV MEAS ADDL VSL','IV DOP VEL&/OR PRESS C/FLO RSRV MEAS ADDL VSL','93572','1','','1','0','','','',0, 1, 0, 0),
(8738,'PRQ TCAT CLSR CGEN INTRATRL COMUNICAJ W/IMPLT','PRQ TCAT CLSR CGEN INTRATRL COMUNICAJ W/IMPLT','93580','1','','1','0','','','',0, 1, 0, 0),
(8739,'PRQ TCAT CLSR CGEN VENTR SEPTAL DFCT W/IMPLT','PRQ TCAT CLSR CGEN VENTR SEPTAL DFCT W/IMPLT','93581','1','','1','0','','','',0, 1, 0, 0),
(8740,'PERCUTAN TRANSCATH CLOSURE PAT DUCT ARTERIOSUS','PERCUTAN TRANSCATH CLOSURE PAT DUCT ARTERIOSUS','93582','1','','1','0','','','',0, 1, 0, 0),
(8741,'PERCUTANEOUS TRANSCATHETER SEPTAL REDUCTION THER','PERCUTANEOUS TRANSCATHETER SEPTAL REDUCTION THER','93583','1','','1','0','','','',0, 1, 0, 0),
(8742,'BUNDLE OF HIS RECORDING','BUNDLE OF HIS RECORDING','93600','1','','1','0','','','',0, 1, 0, 0),
(8743,'INTRA-ATRIAL RECORDING','INTRA-ATRIAL RECORDING','93602','1','','1','0','','','',0, 1, 0, 0),
(8744,'RIGHT VENTRICULAR RECORDING','RIGHT VENTRICULAR RECORDING','93603','1','','1','0','','','',0, 1, 0, 0),
(8745,'INTRA-VENTRIC&/ATRIAL MAPG TACHYCARD W/CATH MA','INTRA-VENTRIC&/ATRIAL MAPG TACHYCARD W/CATH MA','93609','1','','1','0','','','',0, 1, 0, 0),
(8746,'INTRA-ATRIAL PACING','INTRA-ATRIAL PACING','93610','1','','1','0','','','',0, 1, 0, 0),
(8747,'INTRAVENTRICULAR PACING','INTRAVENTRICULAR PACING','93612','1','','1','0','','','',0, 1, 0, 0),
(8748,'INTRACARDIAC ELECTROPHYSIOLOGIC 3D MAPPING','INTRACARDIAC ELECTROPHYSIOLOGIC 3D MAPPING','93613','1','','1','0','','','',0, 1, 0, 0),
(8749,'ESOPHGL REC ATRIAL W/WO VENTRICULAR ELECTROGRAMS','ESOPHGL REC ATRIAL W/WO VENTRICULAR ELECTROGRAMS','93615','1','','1','0','','','',0, 1, 0, 0),
(8750,'ESOPHGL REC ATRIAL W/WO VENTR ELECTRGRAMS W/PACG','ESOPHGL REC ATRIAL W/WO VENTR ELECTRGRAMS W/PACG','93616','1','','1','0','','','',0, 1, 0, 0),
(8751,'INDUCTION ARRHYTHMIA ELECTRICAL PACING','INDUCTION ARRHYTHMIA ELECTRICAL PACING','93618','1','','1','0','','','',0, 1, 0, 0),
(8752,'COMPRE ELECTROPHYSIOLOGIC W/O ARRHYT INDUCTION','COMPRE ELECTROPHYSIOLOGIC W/O ARRHYT INDUCTION','93619','1','','1','0','','','',0, 1, 0, 0),
(8753,'COMPRE ELECTROPHYSIOLOGIC ARRHYTHMIA INDUCTION','COMPRE ELECTROPHYSIOLOGIC ARRHYTHMIA INDUCTION','93620','1','','1','0','','','',0, 1, 0, 0),
(8754,'COMPRE ELECTROPHYSIOL XM W/LEFT ATRIAL PACNG/REC','COMPRE ELECTROPHYSIOL XM W/LEFT ATRIAL PACNG/REC','93621','1','','1','0','','','',0, 1, 0, 0),
(8755,'COMPRE ELECTROPHYSIOL XM W/LEFT VENTR PACNG/REC','COMPRE ELECTROPHYSIOL XM W/LEFT VENTR PACNG/REC','93622','1','','1','0','','','',0, 1, 0, 0),
(8756,'PROGRAMMED STIMJ & PACG AFTER IV DRUG NFS','PROGRAMMED STIMJ & PACG AFTER IV DRUG NFS','93623','1','','1','0','','','',0, 1, 0, 0),
(8757,'ELECTROPHYSIOLOGIC FOLLOW-UP W/PAC/REC W/ARRHYT','ELECTROPHYSIOLOGIC FOLLOW-UP W/PAC/REC W/ARRHYT','93624','1','','1','0','','','',0, 1, 0, 0),
(8758,'INTRAOP EPICAR& ENDOCAR PACG& MAPG','INTRAOP EPICAR& ENDOCAR PACG& MAPG','93631','1','','1','0','','','',0, 1, 0, 0),
(8759,'EPHYS EVAL PACG CVDFB LDS INITIAL IMPLAN/REPLACE','EPHYS EVAL PACG CVDFB LDS INITIAL IMPLAN/REPLACE','93640','1','','1','0','','','',0, 1, 0, 0),
(8760,'EPHYS EVAL PACG CVDFB LDS W/TSTG OF PULSE GEN','EPHYS EVAL PACG CVDFB LDS W/TSTG OF PULSE GEN','93641','1','','1','0','','','',0, 1, 0, 0),
(8761,'EPHYS EVAL PACG CVDFB PRGRMG/REPRGRMG PARAMETERS','EPHYS EVAL PACG CVDFB PRGRMG/REPRGRMG PARAMETERS','93642','1','','1','0','','','',0, 1, 0, 0),
(8762,'EPHYS EVAL SUBQ IMPLANTABLE DEFIBRILLATOR','EPHYS EVAL SUBQ IMPLANTABLE DEFIBRILLATOR','93644','1','','1','0','','','',0, 1, 0, 0),
(8763,'ICAR CATHETER ABLATION ATRIOVENTR NODE FUNCTION','ICAR CATHETER ABLATION ATRIOVENTR NODE FUNCTION','93650','1','','1','0','','','',0, 1, 0, 0),
(8764,'EPHYS EVAL W/ABLATION SUPRAVENT ARRHYTHMIA','EPHYS EVAL W/ABLATION SUPRAVENT ARRHYTHMIA','93653','1','','1','0','','','',0, 1, 0, 0),
(8765,'EPHYS EVAL W/ABLATION VENTRICULAR TACHYCARDIA','EPHYS EVAL W/ABLATION VENTRICULAR TACHYCARDIA','93654','1','','1','0','','','',0, 1, 0, 0),
(8766,'ICAR CATHETER ABLATION ARRHYTHMIA ADD ON','ICAR CATHETER ABLATION ARRHYTHMIA ADD ON','93655','1','','1','0','','','',0, 1, 0, 0),
(8767,'EPHYS EVL TRNSPTL TX ATRIAL FIB ISOLAT PULM VEIN','EPHYS EVL TRNSPTL TX ATRIAL FIB ISOLAT PULM VEIN','93656','1','','1','0','','','',0, 1, 0, 0),
(8768,'ABLATE L/R ATRIAL FIBRIL W/ISOLATED PULM VEIN','ABLATE L/R ATRIAL FIBRIL W/ISOLATED PULM VEIN','93657','1','','1','0','','','',0, 1, 0, 0),
(8769,'CARDIOVASCULAR FUNCTION EVAL W/TILT TABLE W/MNTR','CARDIOVASCULAR FUNCTION EVAL W/TILT TABLE W/MNTR','93660','1','','1','0','','','',0, 1, 0, 0),
(8770,'INTRACARD ECHOCARD W/THER/DX IVNTJ INCL IMG S&I','INTRACARD ECHOCARD W/THER/DX IVNTJ INCL IMG S&I','93662','1','','1','0','','','',0, 1, 0, 0),
(8771,'PERIPHERAL ARTERIAL DISEASE REHAB PER SESSION','PERIPHERAL ARTERIAL DISEASE REHAB PER SESSION','93668','1','','1','0','','','',0, 1, 0, 0),
(8772,'BIOMPEDANCE-DERIVED PHYSIOLOGIC CV ANALYSIS','BIOMPEDANCE-DERIVED PHYSIOLOGIC CV ANALYSIS','93701','1','','1','0','','','',0, 1, 0, 0),
(8773,'BIS EXTRACELLULAR FLUID ALYS LYMPHEDEMA ASSMNT','BIS EXTRACELLULAR FLUID ALYS LYMPHEDEMA ASSMNT','93702','1','','1','0','','','',0, 1, 0, 0),
(8774,'ELECTRONIC ANALYSIS ANTITACHY PACEMAKER SYSTEM','ELECTRONIC ANALYSIS ANTITACHY PACEMAKER SYSTEM','93724','1','','1','0','','','',0, 1, 0, 0),
(8775,'TEMPRATURE GRADIENT STUDY','TEMPRATURE GRADIENT STUDY','93740','1','','1','0','','','',0, 1, 0, 0),
(8776,'1ST SET-UP & PRGRMG PHYS/QHP OF WEARABLE CVDFB','1ST SET-UP & PRGRMG PHYS/QHP OF WEARABLE CVDFB','93745','1','','1','0','','','',0, 1, 0, 0),
(8777,'INTERROGATION VAD IN PRSON W/PHYS/QHP ANALYSIS','INTERROGATION VAD IN PRSON W/PHYS/QHP ANALYSIS','93750','1','','1','0','','','',0, 1, 0, 0),
(8778,'DERMINATION OF VENOUS PRESSUE','DERMINATION OF VENOUS PRESSUE','93770','1','','1','0','','','',0, 1, 0, 0),
(8779,'AMBL BLD PRESS W/TAPE&/DISK 24/> HR ALYS I&R','AMBL BLD PRESS W/TAPE&/DISK 24/> HR ALYS I&R','93784','1','','1','0','','','',0, 1, 0, 0),
(8780,'BL BLD PRESS W/TAPE&/DISK 24/> HR REC ONL','BL BLD PRESS W/TAPE&/DISK 24/> HR REC ONL','93786','1','','1','0','','','',0, 1, 0, 0),
(8781,'AMBL BLD PRESS W/TAPE/DISK 24/>HR ALYS W/REPRT','AMBL BLD PRESS W/TAPE/DISK 24/>HR ALYS W/REPRT','93788','1','','1','0','','','',0, 1, 0, 0),
(8782,'AMBL BLD PRESS TAPE&/DISK 24/> HR REVIEW','AMBL BLD PRESS TAPE&/DISK 24/> HR REVIEW','93790','1','','1','0','','','',0, 1, 0, 0),
(8783,'OUTPATIENT CARDIAC REHAB W/O CONT ECG MONITOR','OUTPATIENT CARDIAC REHAB W/O CONT ECG MONITOR','93797','1','','1','0','','','',0, 1, 0, 0),
(8784,'OUTPATIENT CARDIAC REHAB W/CONT ECG MONITORING','OUTPATIENT CARDIAC REHAB W/CONT ECG MONITORING','93798','1','','1','0','','','',0, 1, 0, 0),
(8785,'UNLISTED CARDIOVASCULAR SERVICE/PROCEDURE','UNLISTED CARDIOVASCULAR SERVICE/PROCEDURE','93799','1','','1','0','','','',0, 1, 0, 0),
(8786,'DUPLEX SCAN EXTRACRANIAL ART COMPL BI STUDY','DUPLEX SCAN EXTRACRANIAL ART COMPL BI STUDY','93880','1','','1','0','','','',0, 1, 0, 0),
(8787,'DUPLEX SCAN EXTRACRANIAL ART UNI/LMTD STUDY','DUPLEX SCAN EXTRACRANIAL ART UNI/LMTD STUDY','93882','1','','1','0','','','',0, 1, 0, 0),
(8788,'TRANSCRANIAL DOPPLER STDY INTRACRANIAL ART COMPL','TRANSCRANIAL DOPPLER STDY INTRACRANIAL ART COMPL','93886','1','','1','0','','','',0, 1, 0, 0),
(8789,'TRANSCRANIAL DOPPLER STDY INTRACRANIAL ART LMTD','TRANSCRANIAL DOPPLER STDY INTRACRANIAL ART LMTD','93888','1','','1','0','','','',0, 1, 0, 0),
(8790,'TRANSCRANIAL DOPPLER INTRACRAN ART VASOREAC STDY','TRANSCRANIAL DOPPLER INTRACRAN ART VASOREAC STDY','93890','1','','1','0','','','',0, 1, 0, 0),
(8791,'TRANSCRANIAL DOPPLER INTRACRAN ART EMBOLI DETECT','TRANSCRANIAL DOPPLER INTRACRAN ART EMBOLI DETECT','93892','1','','1','0','','','',0, 1, 0, 0),
(8792,'TRANSCRAN DOPPLER INTRACRAN ART MICROBUBBLE INJ','TRANSCRAN DOPPLER INTRACRAN ART MICROBUBBLE INJ','93893','1','','1','0','','','',0, 1, 0, 0),
(8793,'CAROTID INTIMA MEDIA & CAROTID ATHEROMA EVAL BI','CAROTID INTIMA MEDIA & CAROTID ATHEROMA EVAL BI','93895','1','','1','0','','','',0, 1, 0, 0),
(8794,'NON-INVAS PHYSIOLOGIC STD EXTREMITY ART 2 LEVEL','NON-INVAS PHYSIOLOGIC STD EXTREMITY ART 2 LEVEL','93922','1','','1','0','','','',0, 1, 0, 0),
(8795,'NON-INVASIVE PHYSIOLOGIC STUDY EXTREMITY 3 LEVLS','NON-INVASIVE PHYSIOLOGIC STUDY EXTREMITY 3 LEVLS','93923','1','','1','0','','','',0, 1, 0, 0),
(8796,'N-INVAS PHYSIOLOGIC STD LXTR ART COMPL BI','N-INVAS PHYSIOLOGIC STD LXTR ART COMPL BI','93924','1','','1','0','','','',0, 1, 0, 0),
(8797,'DUP-SCAN LXTR ART/ARTL BPGS COMPL BI STUDY','DUP-SCAN LXTR ART/ARTL BPGS COMPL BI STUDY','93925','1','','1','0','','','',0, 1, 0, 0),
(8798,'DUP-SCAN LXTR ART/ARTL BPGS UNI/LMTD STUDY','DUP-SCAN LXTR ART/ARTL BPGS UNI/LMTD STUDY','93926','1','','1','0','','','',0, 1, 0, 0),
(8799,'DUP-SCAN UXTR ART/ARTL BPGS COMPL BI STUDY','DUP-SCAN UXTR ART/ARTL BPGS COMPL BI STUDY','93930','1','','1','0','','','',0, 1, 0, 0),
(8800,'DUP-SCAN UXTR ART/ARTL BPGS UNI/LMTD STUDY','DUP-SCAN UXTR ART/ARTL BPGS UNI/LMTD STUDY','93931','1','','1','0','','','',0, 1, 0, 0),
(8801,'N-INVAS PHYSIOLOGIC STD XTR VEINS COMPL BI STD','N-INVAS PHYSIOLOGIC STD XTR VEINS COMPL BI STD','93965','1','','1','0','','','',0, 1, 0, 0),
(8802,'DUP-SCAN XTR VEINS COMPLETE BILATERAL STUDY','DUP-SCAN XTR VEINS COMPLETE BILATERAL STUDY','93970','1','','1','0','','','',0, 1, 0, 0),
(8803,'DUP-SCAN XTR VEINS UNILATERAL/LIMITED STUDY','DUP-SCAN XTR VEINS UNILATERAL/LIMITED STUDY','93971','1','','1','0','','','',0, 1, 0, 0),
(8804,'DUP-SCAN ARTL FLO ABDL/PEL/SCROT&/RPR ORGN COM','DUP-SCAN ARTL FLO ABDL/PEL/SCROT&/RPR ORGN COM','93975','1','','1','0','','','',0, 1, 0, 0),
(8805,'DUP-SCAN ARTL FLO ABDL/PEL/SCROT&/RPR ORGN LMT','DUP-SCAN ARTL FLO ABDL/PEL/SCROT&/RPR ORGN LMT','93976','1','','1','0','','','',0, 1, 0, 0),
(8806,'DUP-SCAN AORTA IVC ILIAC VASCL/BPGS COMPLETE','DUP-SCAN AORTA IVC ILIAC VASCL/BPGS COMPLETE','93978','1','','1','0','','','',0, 1, 0, 0),
(8807,'DUP-SCAN AORTA IVC ILIAC VASCL/BPGS UNI/LMTD','DUP-SCAN AORTA IVC ILIAC VASCL/BPGS UNI/LMTD','93979','1','','1','0','','','',0, 1, 0, 0),
(8808,'DUP-SCAN ARTL INFL&VEN O/F PEN VSL COMPL','DUP-SCAN ARTL INFL&VEN O/F PEN VSL COMPL','93980','1','','1','0','','','',0, 1, 0, 0),
(8809,'DUP-SCAN ARTL INFL&VEN O/F PEN VSL F-UP/LMTD STD','DUP-SCAN ARTL INFL&VEN O/F PEN VSL F-UP/LMTD STD','93981','1','','1','0','','','',0, 1, 0, 0),
(8810,'IMPLANT WIRELESS PRESS SENSOR STUDY ANEURYSM SAC','IMPLANT WIRELESS PRESS SENSOR STUDY ANEURYSM SAC','93982','1','','1','0','','','',0, 1, 0, 0),
(8811,'DUPLEX SCAN HEMODIALYSIS ACCESS','DUPLEX SCAN HEMODIALYSIS ACCESS','93990','1','','1','0','','','',0, 1, 0, 0),
(8812,'UNLISTED NONINVASIVE VASCULAR DIAGNOSTIC STUDY','UNLISTED NONINVASIVE VASCULAR DIAGNOSTIC STUDY','93998','1','','1','0','','','',0, 1, 0, 0),
(8813,'VENTILATION ASSIST & MGMT INPATIENT 1ST DAY','VENTILATION ASSIST & MGMT INPATIENT 1ST DAY','94002','1','','1','0','','','',0, 1, 0, 0),
(8814,'VENTILATION ASSIST & MGMT INPATIENT EA SBSQ DA','VENTILATION ASSIST & MGMT INPATIENT EA SBSQ DA','94003','1','','1','0','','','',0, 1, 0, 0),
(8815,'VENTILATION ASSIST & MGMT NURSING FAC PR DAY','VENTILATION ASSIST & MGMT NURSING FAC PR DAY','94004','1','','1','0','','','',0, 1, 0, 0),
(8816,'HOME VENTILATOR MGMT CARE OVERSIGHT 30 MIN/>','HOME VENTILATOR MGMT CARE OVERSIGHT 30 MIN/>','94005','1','','1','0','','','',0, 1, 0, 0),
(8817,'SPMTRY W/VC EXPIRATORY FLO W/WO MXML VOL VNTJ','SPMTRY W/VC EXPIRATORY FLO W/WO MXML VOL VNTJ','94010','1','','1','0','','','',0, 1, 0, 0),
(8818,'MEAS SPIROMTRC FORCD EXPIRATORY FLO INFANT&/2 Y','MEAS SPIROMTRC FORCD EXPIRATORY FLO INFANT&/2 Y','94011','1','','1','0','','','',0, 1, 0, 0),
(8819,'MEAS SPIRO FRCD EXP FLO PRE&POST BRONCH INF/2YRS','MEAS SPIRO FRCD EXP FLO PRE&POST BRONCH INF/2YRS','94012','1','','1','0','','','',0, 1, 0, 0),
(8820,'MEASUREMENT LUNG VOLUMES INFANT/CHILD/2 YRS','MEASUREMENT LUNG VOLUMES INFANT/CHILD/2 YRS','94013','1','','1','0','','','',0, 1, 0, 0),
(8821,'PT-INITIATE SPIROMETRIC RECORDING PHYS/QHP R&I','PT-INITIATE SPIROMETRIC RECORDING PHYS/QHP R&I','94014','1','','1','0','','','',0, 1, 0, 0),
(8822,'PATIENT-INITIATED SPIROMETRIC RECORDING','PATIENT-INITIATED SPIROMETRIC RECORDING','94015','1','','1','0','','','',0, 1, 0, 0),
(8823,'PATIENT-INITIATED SPIROMETRIC PHYS/QHP R&I ONLY','PATIENT-INITIATED SPIROMETRIC PHYS/QHP R&I ONLY','94016','1','','1','0','','','',0, 1, 0, 0),
(8824,'BRNCDILAT RSPSE SPMTRY PRE&POST-BRNCDILAT ADMN','BRNCDILAT RSPSE SPMTRY PRE&POST-BRNCDILAT ADMN','94060','1','','1','0','','','',0, 1, 0, 0),
(8825,'BRNCSPSM PROVOCATION EVAL MLT SPMTRY W/ADMN AGT','BRNCSPSM PROVOCATION EVAL MLT SPMTRY W/ADMN AGT','94070','1','','1','0','','','',0, 1, 0, 0),
(8826,'VITAL CAPACITY TOTAL SEPARATE PROCEDURE','VITAL CAPACITY TOTAL SEPARATE PROCEDURE','94150','1','','1','0','','','',0, 1, 0, 0),
(8827,'MAX BREATHING CAPACITY MAXIMAL VOLUNTARY VENTJ','MAX BREATHING CAPACITY MAXIMAL VOLUNTARY VENTJ','94200','1','','1','0','','','',0, 1, 0, 0),
(8828,'EXPIRED GAS COLLECTION QUANT 1 PROCEDURE SPX','EXPIRED GAS COLLECTION QUANT 1 PROCEDURE SPX','94250','1','','1','0','','','',0, 1, 0, 0),
(8829,'RESPIRATORY FLOW VOLUME LOOP','RESPIRATORY FLOW VOLUME LOOP','94375','1','','1','0','','','',0, 1, 0, 0),
(8830,'BREATHING RESPONSE TO CO2','BREATHING RESPONSE TO CO2','94400','1','','1','0','','','',0, 1, 0, 0),
(8831,'BREATHING RESPONSE TO HYPOXIA','BREATHING RESPONSE TO HYPOXIA','94450','1','','1','0','','','',0, 1, 0, 0),
(8832,'HIGH ALTITUDE SIMULATJ TEST W/PHYS INTERP&REPORT','HIGH ALTITUDE SIMULATJ TEST W/PHYS INTERP&REPORT','94452','1','','1','0','','','',0, 1, 0, 0),
(8833,'HIGH ALTITUDE SIMULATJ W/PHYS I&R W/O2 TITRATION','HIGH ALTITUDE SIMULATJ W/PHYS I&R W/O2 TITRATION','94453','1','','1','0','','','',0, 1, 0, 0),
(8834,'INTRAPULMONARY SURFACTANT ADMINISTJ PHYS/QHP','INTRAPULMONARY SURFACTANT ADMINISTJ PHYS/QHP','94610','1','','1','0','','','',0, 1, 0, 0),
(8835,'PULMONARY STRESS TESTING SIMPLE','PULMONARY STRESS TESTING SIMPLE','94620','1','','1','0','','','',0, 1, 0, 0),
(8836,'PULMONARY STRESS TESTING COMPLEX','PULMONARY STRESS TESTING COMPLEX','94621','1','','1','0','','','',0, 1, 0, 0),
(8837,'PRESSURIZED/NONPRESSURIZED INHALATION TREATMENT','PRESSURIZED/NONPRESSURIZED INHALATION TREATMENT','94640','1','','1','0','','','',0, 1, 0, 0),
(8838,'PENTAMIDINE AERSL INHALATION PNEUMOCYSTIS/PROPH','PENTAMIDINE AERSL INHALATION PNEUMOCYSTIS/PROPH','94642','1','','1','0','','','',0, 1, 0, 0),
(8839,'CONTINUOUS INHALATION TREATMENT 1ST HR','CONTINUOUS INHALATION TREATMENT 1ST HR','94644','1','','1','0','','','',0, 1, 0, 0),
(8840,'CONTINUOUS INHALATION TREATMENT EA ADDL HR','CONTINUOUS INHALATION TREATMENT EA ADDL HR','94645','1','','1','0','','','',0, 1, 0, 0),
(8841,'CPAP VENTILATION CPAP INITIATION&MGMT','CPAP VENTILATION CPAP INITIATION&MGMT','94660','1','','1','0','','','',0, 1, 0, 0),
(8842,'CONTINUOUS NEGATIVE PRESSURE VENTJ INITIAT&MGM','CONTINUOUS NEGATIVE PRESSURE VENTJ INITIAT&MGM','94662','1','','1','0','','','',0, 1, 0, 0),
(8843,'DEMO&/EVAL OF PT UTILIZ AERSL GEN/NEB/INHLR/IP','DEMO&/EVAL OF PT UTILIZ AERSL GEN/NEB/INHLR/IP','94664','1','','1','0','','','',0, 1, 0, 0),
(8844,'MANJ CH WALL FACILITATE LNG FUNCJ 1 DEMO&/EVAL','MANJ CH WALL FACILITATE LNG FUNCJ 1 DEMO&/EVAL','94667','1','','1','0','','','',0, 1, 0, 0),
(8845,'MANJ CHEST WALL FACILITATE LUNG FUNCTION SUBSQ','MANJ CHEST WALL FACILITATE LUNG FUNCTION SUBSQ','94668','1','','1','0','','','',0, 1, 0, 0),
(8846,'MECHANICAL CHEST WALL OSCILLATION LUNG FUNCTION','MECHANICAL CHEST WALL OSCILLATION LUNG FUNCTION','94669','1','','1','0','','','',0, 1, 0, 0),
(8847,'O2 UPTK EXP GAS ANALYSIS REST&XERS DIRECT SIMP','O2 UPTK EXP GAS ANALYSIS REST&XERS DIRECT SIMP','94680','1','','1','0','','','',0, 1, 0, 0),
(8848,'O2 UPTK EXP GAS ALYS W/CO2 OUTPUT % O2 XTRC','O2 UPTK EXP GAS ALYS W/CO2 OUTPUT % O2 XTRC','94681','1','','1','0','','','',0, 1, 0, 0),
(8849,'O2 UPTAKE EXP GAS ANALYSIS REST INDIRECT SPX','O2 UPTAKE EXP GAS ANALYSIS REST INDIRECT SPX','94690','1','','1','0','','','',0, 1, 0, 0),
(8850,'PLETHYSMOGRAPHY LUNG VOLUMES W/WO AIRWAY RESIST','PLETHYSMOGRAPHY LUNG VOLUMES W/WO AIRWAY RESIST','94726','1','','1','0','','','',0, 1, 0, 0),
(8851,'GAS DILUT/WASHOUT LUNG VOL W/WO DISTRIB VENT&V','GAS DILUT/WASHOUT LUNG VOL W/WO DISTRIB VENT&V','94727','1','','1','0','','','',0, 1, 0, 0),
(8852,'AIRWAY RESISTANCE BY IMPULSE OSCILLOMETRY','AIRWAY RESISTANCE BY IMPULSE OSCILLOMETRY','94728','1','','1','0','','','',0, 1, 0, 0),
(8853,'CO DIFFUSING CAPACITY','CO DIFFUSING CAPACITY','94729','1','','1','0','','','',0, 1, 0, 0),
(8854,'PULMONARY COMPLIANCE STUDY','PULMONARY COMPLIANCE STUDY','94750','1','','1','0','','','',0, 1, 0, 0),
(8855,'NONINVASIVE EAR/PULSE OXIMETRY SINGLE DETER','NONINVASIVE EAR/PULSE OXIMETRY SINGLE DETER','94760','1','','1','0','','','',0, 1, 0, 0),
(8856,'NONINVASIVE EAR/PULSE OXIMETRY MULTIPLE DETER','NONINVASIVE EAR/PULSE OXIMETRY MULTIPLE DETER','94761','1','','1','0','','','',0, 1, 0, 0),
(8857,'NONINVASIVE EAR/PULSE OXIMETRY OVERNIGHT MONITOR','NONINVASIVE EAR/PULSE OXIMETRY OVERNIGHT MONITOR','94762','1','','1','0','','','',0, 1, 0, 0),
(8858,'CARBON DIOXIDE EXP GAS DETER INFRARED ANALYZER','CARBON DIOXIDE EXP GAS DETER INFRARED ANALYZER','94770','1','','1','0','','','',0, 1, 0, 0),
(8859,'CIRCADIAN RESPIRATRY PATTERN REC 12-24 HR INFANT','CIRCADIAN RESPIRATRY PATTERN REC 12-24 HR INFANT','94772','1','','1','0','','','',0, 1, 0, 0),
(8860,'PEDIATRIC APNEA MONITOR ATTACHMENT PHYS I&R','PEDIATRIC APNEA MONITOR ATTACHMENT PHYS I&R','94774','1','','1','0','','','',0, 1, 0, 0),
(8861,'PEDIATRIC APNEA MONITOR ATTACHMENT','PEDIATRIC APNEA MONITOR ATTACHMENT','94775','1','','1','0','','','',0, 1, 0, 0),
(8862,'PEDIATRIC APNEA MONITOR ANALYSES COMPUTER','PEDIATRIC APNEA MONITOR ANALYSES COMPUTER','94776','1','','1','0','','','',0, 1, 0, 0),
(8863,'PEDIATRIC APNEA MONITOR PHYS/QHP REVIEW','PEDIATRIC APNEA MONITOR PHYS/QHP REVIEW','94777','1','','1','0','','','',0, 1, 0, 0),
(8864,'CAR SEAT/BED TESTING W/INTERP & REPORT 60 MIN','CAR SEAT/BED TESTING W/INTERP & REPORT 60 MIN','94780','1','','1','0','','','',0, 1, 0, 0),
(8865,'CAR SEAT/BED TESTNG W/INTERP & REPORT ADDL 30MIN','CAR SEAT/BED TESTNG W/INTERP & REPORT ADDL 30MIN','94781','1','','1','0','','','',0, 1, 0, 0),
(8866,'UNLISTED PULMONARY SERVICE/PROCEDURE','UNLISTED PULMONARY SERVICE/PROCEDURE','94799','1','','1','0','','','',0, 1, 0, 0),
(8867,'PERCUTANEOUS TESTS W/ALLERGENIC EXTRACTS','PERCUTANEOUS TESTS W/ALLERGENIC EXTRACTS','95004','1','','1','0','','','',0, 1, 0, 0),
(8868,'NITRIC OXIDE EXPIRED GAS DETERMINATION','NITRIC OXIDE EXPIRED GAS DETERMINATION','95012','1','','1','0','','','',0, 1, 0, 0),
(8869,'ALLG TSTG PERQ & IC VENOMS IMMED REACT W/I&R','ALLG TSTG PERQ & IC VENOMS IMMED REACT W/I&R','95017','1','','1','0','','','',0, 1, 0, 0),
(8870,'ALLG TEST PERQ & IC DRUG/BIOL IMMED REACT W/I&R','ALLG TEST PERQ & IC DRUG/BIOL IMMED REACT W/I&R','95018','1','','1','0','','','',0, 1, 0, 0),
(8871,'INTRACUTANEOUS TESTS W/ALLERGENIC EXTRACTS','INTRACUTANEOUS TESTS W/ALLERGENIC EXTRACTS','95024','1','','1','0','','','',0, 1, 0, 0),
(8872,'INTRACUTANEOUS TESTS W/ALLERGENIC XTRCS AIRBORNE','INTRACUTANEOUS TESTS W/ALLERGENIC XTRCS AIRBORNE','95027','1','','1','0','','','',0, 1, 0, 0),
(8873,'IC TSTS W/ALLGIC XTRCS DLYD TYP RXN W/READING','IC TSTS W/ALLGIC XTRCS DLYD TYP RXN W/READING','95028','1','','1','0','','','',0, 1, 0, 0),
(8874,'PATCH/APPLICATION TEST SPECIFY NUMBER TESTS','PATCH/APPLICATION TEST SPECIFY NUMBER TESTS','95044','1','','1','0','','','',0, 1, 0, 0),
(8875,'PHOTO PATCH TEST SPECIFY NUMBER TSTS','PHOTO PATCH TEST SPECIFY NUMBER TSTS','95052','1','','1','0','','','',0, 1, 0, 0),
(8876,'PHOTO TESTS','PHOTO TESTS','95056','1','','1','0','','','',0, 1, 0, 0),
(8877,'OPHTHALMIC MUCOUS MEMBRANE TESTS','OPHTHALMIC MUCOUS MEMBRANE TESTS','95060','1','','1','0','','','',0, 1, 0, 0),
(8878,'DIRECT NASAL MUCOUS MEMBRANE TEST','DIRECT NASAL MUCOUS MEMBRANE TEST','95065','1','','1','0','','','',0, 1, 0, 0),
(8879,'INHLJ BRNCL CHALLENGE TSTG W/HISTAM/METHACHOL','INHLJ BRNCL CHALLENGE TSTG W/HISTAM/METHACHOL','95070','1','','1','0','','','',0, 1, 0, 0),
(8880,'INHLJ BRNCL CHALLENGE TSTG W/AGS/GASES','INHLJ BRNCL CHALLENGE TSTG W/AGS/GASES','95071','1','','1','0','','','',0, 1, 0, 0),
(8881,'INGESTION CHALLENGE TEST INITIAL 120 MINUTES','INGESTION CHALLENGE TEST INITIAL 120 MINUTES','95076','1','','1','0','','','',0, 1, 0, 0),
(8882,'INGESTION CHALLENGE TEST EACH ADDL 60 MINUTES','INGESTION CHALLENGE TEST EACH ADDL 60 MINUTES','95079','1','','1','0','','','',0, 1, 0, 0),
(8883,'PROF SVCS ALLG IMMNTX X W/PRV ALLGIC XTRCS 1 NJX','PROF SVCS ALLG IMMNTX X W/PRV ALLGIC XTRCS 1 NJX','95115','1','','1','0','','','',0, 1, 0, 0),
(8884,'PROF SVCS ALLG IMMNTX X W/PRV ALLGIC XTRCS NJXS','PROF SVCS ALLG IMMNTX X W/PRV ALLGIC XTRCS NJXS','95117','1','','1','0','','','',0, 1, 0, 0),
(8885,'PROF SVCS ALLG IMMNTX W/PRV ALLGIC XTRC 1 NJX','PROF SVCS ALLG IMMNTX W/PRV ALLGIC XTRC 1 NJX','95120','1','','1','0','','','',0, 1, 0, 0),
(8886,'PROF SVCS ALLG IMMNTX W/PRV ALLGIC XTRC 2/> NJX','PROF SVCS ALLG IMMNTX W/PRV ALLGIC XTRC 2/> NJX','95125','1','','1','0','','','',0, 1, 0, 0),
(8887,'PROF SVCS ALLG IMMNTX W/PRV XTRC 1 STING INSECT','PROF SVCS ALLG IMMNTX W/PRV XTRC 1 STING INSECT','95130','1','','1','0','','','',0, 1, 0, 0),
(8888,'PROF SVCS ALLG IMMNTX W/PRV XTRC 2 STING INSECT','PROF SVCS ALLG IMMNTX W/PRV XTRC 2 STING INSECT','95131','1','','1','0','','','',0, 1, 0, 0),
(8889,'PROF SVCS ALLG IMMNTX W/PRV XTRC 3 STING INSECT','PROF SVCS ALLG IMMNTX W/PRV XTRC 3 STING INSECT','95132','1','','1','0','','','',0, 1, 0, 0),
(8890,'PROF SVCS ALLG IMMNTX W/PRV XTRC 4 STING INSECT','PROF SVCS ALLG IMMNTX W/PRV XTRC 4 STING INSECT','95133','1','','1','0','','','',0, 1, 0, 0),
(8891,'PROF SVCS ALLG IMMNTX W/PRV XTRC 5 STING INSECT','PROF SVCS ALLG IMMNTX W/PRV XTRC 5 STING INSECT','95134','1','','1','0','','','',0, 1, 0, 0),
(8892,'PREPJ& ANTIGEN PRV ALLERGEN IMMUNOTHERAPY 1 DO','PREPJ& ANTIGEN PRV ALLERGEN IMMUNOTHERAPY 1 DO','95144','1','','1','0','','','',0, 1, 0, 0),
(8893,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 1 INSECT','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 1 INSECT','95145','1','','1','0','','','',0, 1, 0, 0),
(8894,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 2 INSECT','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 2 INSECT','95146','1','','1','0','','','',0, 1, 0, 0),
(8895,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 3 INSECT','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 3 INSECT','95147','1','','1','0','','','',0, 1, 0, 0),
(8896,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 4 INSECT','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 4 INSECT','95148','1','','1','0','','','',0, 1, 0, 0),
(8897,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 5 INSECT','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY 5 INSECT','95149','1','','1','0','','','',0, 1, 0, 0),
(8898,'PREPJ& ALLERGEN IMMUNOTHERAPY 1/MLT ANTIGEN','PREPJ& ALLERGEN IMMUNOTHERAPY 1/MLT ANTIGEN','95165','1','','1','0','','','',0, 1, 0, 0),
(8899,'PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY WHL INSE','PREPJ& ANTIGEN ALLERGEN IMMUNOTHERAPY WHL INSE','95170','1','','1','0','','','',0, 1, 0, 0),
(8900,'RAPID DESENSITIZATION PROCEDURE EACH HOUR','RAPID DESENSITIZATION PROCEDURE EACH HOUR','95180','1','','1','0','','','',0, 1, 0, 0),
(8901,'UNLISTED ALLERGY/CLINICAL IMMUNOLOGIC SRVC/PX','UNLISTED ALLERGY/CLINICAL IMMUNOLOGIC SRVC/PX','95199','1','','1','0','','','',0, 1, 0, 0),
(8902,'GLUC MNTR CONT REC FROM INTERSTITIAL TISS FLUID','GLUC MNTR CONT REC FROM INTERSTITIAL TISS FLUID','95250','1','','1','0','','','',0, 1, 0, 0),
(8903,'GLUC MNTR CONT REC FROM NTRSTL TISS FLU I&R','GLUC MNTR CONT REC FROM NTRSTL TISS FLU I&R','95251','1','','1','0','','','',0, 1, 0, 0),
(8904,'POLYSOM <6 YRS SLEEP STAGE 4/> ADDL PARAM ATTND','POLYSOM <6 YRS SLEEP STAGE 4/> ADDL PARAM ATTND','95782','1','','1','0','','','',0, 1, 0, 0),
(8905,'POLYSOM <6 YRS SLEEP W/CPAP/BILVL VENT 4/> PARAM','POLYSOM <6 YRS SLEEP W/CPAP/BILVL VENT 4/> PARAM','95783','1','','1','0','','','',0, 1, 0, 0),
(8906,'SLP STDY UNATND W/HRT RATE/O2 SAT/RESP/SLP TIME','SLP STDY UNATND W/HRT RATE/O2 SAT/RESP/SLP TIME','95800','1','','1','0','','','',0, 1, 0, 0),
(8907,'SLP STDY UNATND W/MIN HRT RATE/O2 SAT/RESP ANAL','SLP STDY UNATND W/MIN HRT RATE/O2 SAT/RESP ANAL','95801','1','','1','0','','','',0, 1, 0, 0),
(8908,'ACTIGRAPHY TESTING RECORDING ANALYSIS I&R','ACTIGRAPHY TESTING RECORDING ANALYSIS I&R','95803','1','','1','0','','','',0, 1, 0, 0),
(8909,'MLT SLEEP LATENCY/MAINT OF WAKEFULNESS TSTG','MLT SLEEP LATENCY/MAINT OF WAKEFULNESS TSTG','95805','1','','1','0','','','',0, 1, 0, 0),
(8910,'SLEEP STD AIRFLOW HRT RATE&O2 SAT EFFORT UNATT','SLEEP STD AIRFLOW HRT RATE&O2 SAT EFFORT UNATT','95806','1','','1','0','','','',0, 1, 0, 0),
(8911,'SLEEP STD REC VNTJ RESPIR ECG/HRT RATE&O2 ATTN','SLEEP STD REC VNTJ RESPIR ECG/HRT RATE&O2 ATTN','95807','1','','1','0','','','',0, 1, 0, 0),
(8912,'POLYSOM ANY AGE SLEEP STAGE 1-3 ADDL PARAM ATTND','POLYSOM ANY AGE SLEEP STAGE 1-3 ADDL PARAM ATTND','95808','1','','1','0','','','',0, 1, 0, 0),
(8913,'POLYSOM 6/>YRS SLEEP 4/> ADDL PARAM ATTND','POLYSOM 6/>YRS SLEEP 4/> ADDL PARAM ATTND','95810','1','','1','0','','','',0, 1, 0, 0),
(8914,'POLYSOM 6/>YRS SLEEP W/CPAP 4/> ADDL PARAM ATTND','POLYSOM 6/>YRS SLEEP W/CPAP 4/> ADDL PARAM ATTND','95811','1','','1','0','','','',0, 1, 0, 0),
(8915,'ELECTROENCEPHALOGRAM EXTEND MONITORING 41-60 MIN','ELECTROENCEPHALOGRAM EXTEND MONITORING 41-60 MIN','95812','1','','1','0','','','',0, 1, 0, 0),
(8916,'ELECTROENCEPHALOGRAM EXTND MNTR >1 HR','ELECTROENCEPHALOGRAM EXTND MNTR >1 HR','95813','1','','1','0','','','',0, 1, 0, 0),
(8917,'ELECTROENCEPHALOGRAM W/REC AWAKE&DROWSY','ELECTROENCEPHALOGRAM W/REC AWAKE&DROWSY','95816','1','','1','0','','','',0, 1, 0, 0),
(8918,'ELECTROENCEPHALOGRAM W/REC AWAKE&ASLEEP','ELECTROENCEPHALOGRAM W/REC AWAKE&ASLEEP','95819','1','','1','0','','','',0, 1, 0, 0),
(8919,'ELECTROENCEPHALOGRAM REC COMA/SLEEP ONLY','ELECTROENCEPHALOGRAM REC COMA/SLEEP ONLY','95822','1','','1','0','','','',0, 1, 0, 0),
(8920,'ELECTROENCEPHALOGRAM CERE DEATH EVAL ONLY','ELECTROENCEPHALOGRAM CERE DEATH EVAL ONLY','95824','1','','1','0','','','',0, 1, 0, 0),
(8921,'ELECTROENCEPHALOGRAM ALL NIGHT RECORDING','ELECTROENCEPHALOGRAM ALL NIGHT RECORDING','95827','1','','1','0','','','',0, 1, 0, 0),
(8922,'ELECTROCORTICOGRAM SURGERY SPX','ELECTROCORTICOGRAM SURGERY SPX','95829','1','','1','0','','','',0, 1, 0, 0),
(8923,'INSERTION SPHENOIDAL ELECTRODES EEG PHYS/QHP','INSERTION SPHENOIDAL ELECTRODES EEG PHYS/QHP','95830','1','','1','0','','','',0, 1, 0, 0),
(8924,'MUSC TSTG MNL W/REPRT XTR EX HAND/TRNK','MUSC TSTG MNL W/REPRT XTR EX HAND/TRNK','95831','1','','1','0','','','',0, 1, 0, 0),
(8925,'MUSC TSTG MNL W/REPRT HAND W/WO CMPRSN NRML SIDE','MUSC TSTG MNL W/REPRT HAND W/WO CMPRSN NRML SIDE','95832','1','','1','0','','','',0, 1, 0, 0),
(8926,'MUSC TSTG MNL W/REPRT TOTAL EVAL BODY EX HANDS','MUSC TSTG MNL W/REPRT TOTAL EVAL BODY EX HANDS','95833','1','','1','0','','','',0, 1, 0, 0),
(8927,'MUSC TSTG MNL W/REPRT TOTAL EVAL BODY W/HANDS','MUSC TSTG MNL W/REPRT TOTAL EVAL BODY W/HANDS','95834','1','','1','0','','','',0, 1, 0, 0),
(8928,'ROM MEAS&REPRT EA XTR EX HAND/EA TRNK SCTJ SPI','ROM MEAS&REPRT EA XTR EX HAND/EA TRNK SCTJ SPI','95851','1','','1','0','','','',0, 1, 0, 0),
(8929,'ROM MEAS&REPRT HAND W/WO COMPARISON NORMAL SID','ROM MEAS&REPRT HAND W/WO COMPARISON NORMAL SID','95852','1','','1','0','','','',0, 1, 0, 0),
(8930,'CHOLINESTERASE INHIBITOR CHALLENGE TEST','CHOLINESTERASE INHIBITOR CHALLENGE TEST','95857','1','','1','0','','','',0, 1, 0, 0),
(8931,'NDL EMG 1 XTR W/WO RELATED PARASPINAL AREAS','NDL EMG 1 XTR W/WO RELATED PARASPINAL AREAS','95860','1','','1','0','','','',0, 1, 0, 0),
(8932,'NDL EMG 2 XTR W/WO RELATED PARASPINAL AREAS','NDL EMG 2 XTR W/WO RELATED PARASPINAL AREAS','95861','1','','1','0','','','',0, 1, 0, 0),
(8933,'NDL EMG 3 XTR W/WO RELATED PARASPINAL AREAS','NDL EMG 3 XTR W/WO RELATED PARASPINAL AREAS','95863','1','','1','0','','','',0, 1, 0, 0),
(8934,'NDL EMG 4 XTR W/WO RELATED PARASPINAL AREAS','NDL EMG 4 XTR W/WO RELATED PARASPINAL AREAS','95864','1','','1','0','','','',0, 1, 0, 0),
(8935,'NEEDLE ELECTROMYOGRAPHY LARYNX','NEEDLE ELECTROMYOGRAPHY LARYNX','95865','1','','1','0','','','',0, 1, 0, 0),
(8936,'NEEDLE ELECTROMYOGRAPHY HEMIDIAPHRAGM','NEEDLE ELECTROMYOGRAPHY HEMIDIAPHRAGM','95866','1','','1','0','','','',0, 1, 0, 0),
(8937,'NEEDLE ELECTROMYOGRAPHY CRANIAL NRV MUSCLE UNI','NEEDLE ELECTROMYOGRAPHY CRANIAL NRV MUSCLE UNI','95867','1','','1','0','','','',0, 1, 0, 0),
(8938,'NEEDLE ELECTROMYOGRAPHY CRANIAL NRV MUSCLE BI','NEEDLE ELECTROMYOGRAPHY CRANIAL NRV MUSCLE BI','95868','1','','1','0','','','',0, 1, 0, 0),
(8939,'NEEDLE EMG THRC PARASPI MUSC EXCLUDING T1/T12','NEEDLE EMG THRC PARASPI MUSC EXCLUDING T1/T12','95869','1','','1','0','','','',0, 1, 0, 0),
(8940,'NEEDLE EMG LMTD STD MUSC 1 XTR/NON-LIMB UNI/BI','NEEDLE EMG LMTD STD MUSC 1 XTR/NON-LIMB UNI/BI','95870','1','','1','0','','','',0, 1, 0, 0),
(8941,'NEEDLE EMG W/1 FIBER ELECTRODE QUAN MEAS JITTER','NEEDLE EMG W/1 FIBER ELECTRODE QUAN MEAS JITTER','95872','1','','1','0','','','',0, 1, 0, 0),
(8942,'ELECTRICAL STIMULATION GUID W/CHEMODENERVATION','ELECTRICAL STIMULATION GUID W/CHEMODENERVATION','95873','1','','1','0','','','',0, 1, 0, 0),
(8943,'NEEDLE EMG GUID W/CHEMODENERVATION','NEEDLE EMG GUID W/CHEMODENERVATION','95874','1','','1','0','','','',0, 1, 0, 0),
(8944,'ISCHEMIC LIMB XERS TST SPEC ACQUISJ METAB','ISCHEMIC LIMB XERS TST SPEC ACQUISJ METAB','95875','1','','1','0','','','',0, 1, 0, 0),
(8945,'NEEDLE EMG EA EXTREMITY W/PARASPINL AREA LIMITED','NEEDLE EMG EA EXTREMITY W/PARASPINL AREA LIMITED','95885','1','','1','0','','','',0, 1, 0, 0),
(8946,'NEEDLE EMG EA EXTREMTY W/PARASPINL AREA COMPLETE','NEEDLE EMG EA EXTREMTY W/PARASPINL AREA COMPLETE','95886','1','','1','0','','','',0, 1, 0, 0),
(8947,'NEEDLE EMG NONEXTREMTY MSCLES W/NERVE CONDUCTION','NEEDLE EMG NONEXTREMTY MSCLES W/NERVE CONDUCTION','95887','1','','1','0','','','',0, 1, 0, 0),
(8948,'MOTOR &/SENS NRV CNDJ PRECONF ELTRD ARRAY LIMB','MOTOR &/SENS NRV CNDJ PRECONF ELTRD ARRAY LIMB','95905','1','','1','0','','','',0, 1, 0, 0),
(8949,'NERVE CONDUCTION STUDIES 1-2 STUDIES','NERVE CONDUCTION STUDIES 1-2 STUDIES','95907','1','','1','0','','','',0, 1, 0, 0),
(8950,'NERVE CONDUCTION STUDIES 3-4 STUDIES','NERVE CONDUCTION STUDIES 3-4 STUDIES','95908','1','','1','0','','','',0, 1, 0, 0),
(8951,'NERVE CONDUCTION STUDIES 5-6 STUDIES','NERVE CONDUCTION STUDIES 5-6 STUDIES','95909','1','','1','0','','','',0, 1, 0, 0),
(8952,'NERVE CONDUCTION STUDIES 7-8 STUDIES','NERVE CONDUCTION STUDIES 7-8 STUDIES','95910','1','','1','0','','','',0, 1, 0, 0),
(8953,'NERVE CONDUCTION STUDIES 9-10 STUDIES','NERVE CONDUCTION STUDIES 9-10 STUDIES','95911','1','','1','0','','','',0, 1, 0, 0),
(8954,'NERVE CONDUCTION STUDIES 11-12 STUDIES','NERVE CONDUCTION STUDIES 11-12 STUDIES','95912','1','','1','0','','','',0, 1, 0, 0),
(8955,'NERVE CONDUCTION STUDIES 13/> STUDIES','NERVE CONDUCTION STUDIES 13/> STUDIES','95913','1','','1','0','','','',0, 1, 0, 0),
(8956,'TSTG ANS FUNCJ CARDIOVAGAL INNERVAJ PARASYMP','TSTG ANS FUNCJ CARDIOVAGAL INNERVAJ PARASYMP','95921','1','','1','0','','','',0, 1, 0, 0),
(8957,'TSTG ANS FUNCJ VASOMOTOR ADRENERGIC INNERVAJ','TSTG ANS FUNCJ VASOMOTOR ADRENERGIC INNERVAJ','95922','1','','1','0','','','',0, 1, 0, 0),
(8958,'TESTING AUTONOMIC NERVOUS SYSTEM FUNCTION','TESTING AUTONOMIC NERVOUS SYSTEM FUNCTION','95923','1','','1','0','','','',0, 1, 0, 0),
(8959,'TSTG ANS FUNCJ PARASYMP&SYMP W/5 MIN PASIVE TILT','TSTG ANS FUNCJ PARASYMP&SYMP W/5 MIN PASIVE TILT','95924','1','','1','0','','','',0, 1, 0, 0),
(8960,'SHORT-LATENCY SOMATOSENS EP STD UPR LIMBS','SHORT-LATENCY SOMATOSENS EP STD UPR LIMBS','95925','1','','1','0','','','',0, 1, 0, 0),
(8961,'SHORT-LATENCY SOMATOSENS EP STD LWR LIMBS','SHORT-LATENCY SOMATOSENS EP STD LWR LIMBS','95926','1','','1','0','','','',0, 1, 0, 0),
(8962,'SHORT-LATENCY SOMATOSENS EP STD TRNK/HEAD','SHORT-LATENCY SOMATOSENS EP STD TRNK/HEAD','95927','1','','1','0','','','',0, 1, 0, 0),
(8963,'CTR MOTOR EP STD TRANSCRNL MOTOR STIMJ UPR LIMBS','CTR MOTOR EP STD TRANSCRNL MOTOR STIMJ UPR LIMBS','95928','1','','1','0','','','',0, 1, 0, 0),
(8964,'CTR MOTOR EP STD TRANSCRNL MOTOR STIMJ LWR LIMBS','CTR MOTOR EP STD TRANSCRNL MOTOR STIMJ LWR LIMBS','95929','1','','1','0','','','',0, 1, 0, 0),
(8965,'VISUAL EP TSTG CNS CHECKERBOARD/FLASH','VISUAL EP TSTG CNS CHECKERBOARD/FLASH','95930','1','','1','0','','','',0, 1, 0, 0),
(8966,'ORBICULARIS OCULI REFLX ELECTRODIAGNOSTIC TEST','ORBICULARIS OCULI REFLX ELECTRODIAGNOSTIC TEST','95933','1','','1','0','','','',0, 1, 0, 0),
(8967,'NEUROMUSCULAR JUNCT TSTG EA NRV ANY 1 METH','NEUROMUSCULAR JUNCT TSTG EA NRV ANY 1 METH','95937','1','','1','0','','','',0, 1, 0, 0),
(8968,'SHORT-LATENCY SOMATOSENS EP STD UPR & LOW LIMB','SHORT-LATENCY SOMATOSENS EP STD UPR & LOW LIMB','95938','1','','1','0','','','',0, 1, 0, 0),
(8969,'CTR MOTR EP STD TRANSCRNL MOTR STIM UPR&LOW LI','CTR MOTR EP STD TRANSCRNL MOTR STIM UPR&LOW LI','95939','1','','1','0','','','',0, 1, 0, 0),
(8970,'IONM 1 ON 1 IN OR W/ATTENDANCE EACH 15 MINUTES','IONM 1 ON 1 IN OR W/ATTENDANCE EACH 15 MINUTES','95940','1','','1','0','','','',0, 1, 0, 0),
(8971,'IONM REMOTE/NEARBY/>1 PATIENT IN OR PER HOUR','IONM REMOTE/NEARBY/>1 PATIENT IN OR PER HOUR','95941','1','','1','0','','','',0, 1, 0, 0),
(8972,'PARASYMP & SYMP NRV FUNCJ HRT RATE VARIABILITY','PARASYMP & SYMP NRV FUNCJ HRT RATE VARIABILITY','95943','1','','1','0','','','',0, 1, 0, 0),
(8973,'MONITOR ID& LATERALIZATION SEIZURE FOCUS EEG','MONITOR ID& LATERALIZATION SEIZURE FOCUS EEG','95950','1','','1','0','','','',0, 1, 0, 0),
(8974,'LOCALIZE CEREBRAL SEIZURE CABLE/RADIO EEG/VIDEO','LOCALIZE CEREBRAL SEIZURE CABLE/RADIO EEG/VIDEO','95951','1','','1','0','','','',0, 1, 0, 0),
(8975,'LOCALIZE CEREBRAL SEIZURE CPTR PORTABLE EEG','LOCALIZE CEREBRAL SEIZURE CPTR PORTABLE EEG','95953','1','','1','0','','','',0, 1, 0, 0),
(8976,'RX/PHYSICAL EEG ACTIVAJ PHYS/QHP ATTENDANCE','RX/PHYSICAL EEG ACTIVAJ PHYS/QHP ATTENDANCE','95954','1','','1','0','','','',0, 1, 0, 0),
(8977,'EEG NONINTRACRANIAL SURGERY','EEG NONINTRACRANIAL SURGERY','95955','1','','1','0','','','',0, 1, 0, 0),
(8978,'MNTR SEIZURE CMPTR 16CHAN EEG ATND EA 24 HR','MNTR SEIZURE CMPTR 16CHAN EEG ATND EA 24 HR','95956','1','','1','0','','','',0, 1, 0, 0),
(8979,'DIGITAL ANALYSIS ELECTROENCEPHALOGRAM','DIGITAL ANALYSIS ELECTROENCEPHALOGRAM','95957','1','','1','0','','','',0, 1, 0, 0),
(8980,'WADA ACTIVATION TEST HEMISPHERIC FUNCTION W/EEG','WADA ACTIVATION TEST HEMISPHERIC FUNCTION W/EEG','95958','1','','1','0','','','',0, 1, 0, 0),
(8981,'FUNCJAL CORT&SUBCORT MAPG PHYS/QHP ATTND INIT HR','FUNCJAL CORT&SUBCORT MAPG PHYS/QHP ATTND INIT HR','95961','1','','1','0','','','',0, 1, 0, 0),
(8982,'FUNCJAL CORT&SUBCORT MAPG PHYS/QHP ATTND ADDL HR','FUNCJAL CORT&SUBCORT MAPG PHYS/QHP ATTND ADDL HR','95962','1','','1','0','','','',0, 1, 0, 0),
(8983,'MAGNETOENCEPHALOGRAPHY SPON BRAIN ACTIVITY','MAGNETOENCEPHALOGRAPHY SPON BRAIN ACTIVITY','95965','1','','1','0','','','',0, 1, 0, 0),
(8984,'MAGNETOENCEPHALOGRAPY EVOKED FIELDS 1 MODALITY','MAGNETOENCEPHALOGRAPY EVOKED FIELDS 1 MODALITY','95966','1','','1','0','','','',0, 1, 0, 0),
(8985,'MAGNETOENCEPHALOGRAPY EVOKED FIELDS EACH ADDL','MAGNETOENCEPHALOGRAPY EVOKED FIELDS EACH ADDL','95967','1','','1','0','','','',0, 1, 0, 0),
(8986,'ELEC ALYS NSTIM PLS GEN BRN/SC/PERPH W/O REPRGRM','ELEC ALYS NSTIM PLS GEN BRN/SC/PERPH W/O REPRGRM','95970','1','','1','0','','','',0, 1, 0, 0),
(8987,'ELEC ALYS NSTIM PLS GEN SMPL SC/PERPH W/PRGRMG','ELEC ALYS NSTIM PLS GEN SMPL SC/PERPH W/PRGRMG','95971','1','','1','0','','','',0, 1, 0, 0),
(8988,'ELEC ALYS NSTIM PLS GEN CPLX SC/PERPH W/PRGRMG','ELEC ALYS NSTIM PLS GEN CPLX SC/PERPH W/PRGRMG','95972','1','','1','0','','','',0, 1, 0, 0),
(8989,'ELEC ALYS NSTIM PLS GEN CPLX CRNL NRV 1ST HR','ELEC ALYS NSTIM PLS GEN CPLX CRNL NRV 1ST HR','95974','1','','1','0','','','',0, 1, 0, 0),
(8990,'ELEC ALYS NSTIM PLS GEN CPLX CRNL NRV EA 30 MIN','ELEC ALYS NSTIM PLS GEN CPLX CRNL NRV EA 30 MIN','95975','1','','1','0','','','',0, 1, 0, 0),
(8991,'ELEC ALYS NSTIM PLS GEN CPLX DP BRN 1ST HR','ELEC ALYS NSTIM PLS GEN CPLX DP BRN 1ST HR','95978','1','','1','0','','','',0, 1, 0, 0),
(8992,'ELEC ALYS NSTIM PLS GEN CPLX DP BRN EA 30 MIN','ELEC ALYS NSTIM PLS GEN CPLX DP BRN EA 30 MIN','95979','1','','1','0','','','',0, 1, 0, 0),
(8993,'ELEC ALYS NSTIM PLS GEN GASTRIC INTRAOP W/PRGRMG','ELEC ALYS NSTIM PLS GEN GASTRIC INTRAOP W/PRGRMG','95980','1','','1','0','','','',0, 1, 0, 0),
(8994,'ELEC ALYS NSTIM GEN GASTRIC SBSQ W/O REPRGRMG','ELEC ALYS NSTIM GEN GASTRIC SBSQ W/O REPRGRMG','95981','1','','1','0','','','',0, 1, 0, 0),
(8995,'ELEC ALYS NSTIM PLS GEN GASTRIC SBSQ W/REPRGRMG','ELEC ALYS NSTIM PLS GEN GASTRIC SBSQ W/REPRGRMG','95982','1','','1','0','','','',0, 1, 0, 0),
(8996,'REFILL&MAINTENANCE PUMP DRUG DLVR SPINAL/BRAIN','REFILL&MAINTENANCE PUMP DRUG DLVR SPINAL/BRAIN','95990','1','','1','0','','','',0, 1, 0, 0),
(8997,'RFL&MAIN IMPLT PMP/RSVR DLVR SPI/BRN PHY/QHP','RFL&MAIN IMPLT PMP/RSVR DLVR SPI/BRN PHY/QHP','95991','1','','1','0','','','',0, 1, 0, 0),
(8998,'CANALITH REPOSITIONING PROCEDURE','CANALITH REPOSITIONING PROCEDURE','95992','1','','1','0','','','',0, 1, 0, 0),
(8999,'UNLIS NEUROLOGICAL/NEUROMUSCULAR DX PX','UNLIS NEUROLOGICAL/NEUROMUSCULAR DX PX','95999','1','','1','0','','','',0, 1, 0, 0),
(9000,'COMPRE CPTR MTN ALYS VIDEO TAPING 3D KINEMATICS','COMPRE CPTR MTN ALYS VIDEO TAPING 3D KINEMATICS','96000','1','','1','0','','','',0, 1, 0, 0),
(9001,'COMPRE CPTR MTN ALYS W/DYN PLNTR PRES MEAS WALKG','COMPRE CPTR MTN ALYS W/DYN PLNTR PRES MEAS WALKG','96001','1','','1','0','','','',0, 1, 0, 0),
(9002,'DYN SURF EMG WALKG/FUNCJAL ACTV 1-12 MUSC','DYN SURF EMG WALKG/FUNCJAL ACTV 1-12 MUSC','96002','1','','1','0','','','',0, 1, 0, 0),
(9003,'DYN FINE WIRE EMG WALKG/FUNCJAL ACTV 1 MUSC','DYN FINE WIRE EMG WALKG/FUNCJAL ACTV 1 MUSC','96003','1','','1','0','','','',0, 1, 0, 0),
(9004,'PHYS/QHP R&I CPTR MTN ALYS WALK/FUNCJL ACTV REPR','PHYS/QHP R&I CPTR MTN ALYS WALK/FUNCJL ACTV REPR','96004','1','','1','0','','','',0, 1, 0, 0),
(9005,'TEST SELECT & ADMN FUNCTL BRAIN MAP PHYS/QHP','TEST SELECT & ADMN FUNCTL BRAIN MAP PHYS/QHP','96020','1','','1','0','','','',0, 1, 0, 0),
(9006,'MEDICAL GENETICS COUNSELING EACH 30 MINUTES','MEDICAL GENETICS COUNSELING EACH 30 MINUTES','96040','1','','1','0','','','',0, 1, 0, 0),
(9007,'PSYCHOLOGICAL TESTING PR HR WITH PATIENT','PSYCHOLOGICAL TESTING PR HR WITH PATIENT','96101','1','','1','0','','','',0, 1, 0, 0),
(9008,'PSYCHOLOGICAL TESTING ADMN BY TECH PR HR','PSYCHOLOGICAL TESTING ADMN BY TECH PR HR','96102','1','','1','0','','','',0, 1, 0, 0),
(9009,'PSYCHOLOGICAL TESTING COMPUTER W/PROF I&R','PSYCHOLOGICAL TESTING COMPUTER W/PROF I&R','96103','1','','1','0','','','',0, 1, 0, 0),
(9010,'ASSESSMENT APHASIA W/INTERP & REPORT PER HOUR','ASSESSMENT APHASIA W/INTERP & REPORT PER HOUR','96105','1','','1','0','','','',0, 1, 0, 0),
(9011,'DEVELOPMENTAL SCREEN W/SCORING & DOC STD INSTRM','DEVELOPMENTAL SCREEN W/SCORING & DOC STD INSTRM','96110','1','','1','0','','','',0, 1, 0, 0),
(9012,'DEVELOPMENTAL TESTING W/INTERP & REPORT','DEVELOPMENTAL TESTING W/INTERP & REPORT','96111','1','','1','0','','','',0, 1, 0, 0),
(9013,'NUBHVL STATUS XM PR HR W/PT INTERPJ&PREPJ','NUBHVL STATUS XM PR HR W/PT INTERPJ&PREPJ','96116','1','','1','0','','','',0, 1, 0, 0),
(9014,'NUROPSYC TESTING PR HR W/PT & INTERPJ TIME','NUROPSYC TESTING PR HR W/PT & INTERPJ TIME','96118','1','','1','0','','','',0, 1, 0, 0),
(9015,'NEUROPSYC TSTG W/PROF I&R ADMN BY TECH PR HR','NEUROPSYC TSTG W/PROF I&R ADMN BY TECH PR HR','96119','1','','1','0','','','',0, 1, 0, 0),
(9016,'NEUROPSYCHOLOG TESTING COMPUTER W/PROF I&R','NEUROPSYCHOLOG TESTING COMPUTER W/PROF I&R','96120','1','','1','0','','','',0, 1, 0, 0),
(9017,'STANDARDIZED COGNITIVE PERFORMANCE TESTING','STANDARDIZED COGNITIVE PERFORMANCE TESTING','96125','1','','1','0','','','',0, 1, 0, 0),
(9018,'BEHAV ASSMT W/SCORE & DOCD/STAND INSTRUMENT','BEHAV ASSMT W/SCORE & DOCD/STAND INSTRUMENT','96127','1','','1','0','','','',0, 1, 0, 0),
(9019,'HLTH&BEHAVIOR ASSMT EA 15 MIN W/PT 1ST ASSMT','HLTH&BEHAVIOR ASSMT EA 15 MIN W/PT 1ST ASSMT','96150','1','','1','0','','','',0, 1, 0, 0),
(9020,'HLTH&BEHAVIOR ASSMT EA 15 MIN W/PT RE-ASSMT','HLTH&BEHAVIOR ASSMT EA 15 MIN W/PT RE-ASSMT','96151','1','','1','0','','','',0, 1, 0, 0),
(9021,'HLTH&BEHAVIOR IVNTJ EA 15 MIN INDIV','HLTH&BEHAVIOR IVNTJ EA 15 MIN INDIV','96152','1','','1','0','','','',0, 1, 0, 0),
(9022,'HLTH&BEHAVIOR IVNTJ EA 15 MIN GRP 2/>PTS','HLTH&BEHAVIOR IVNTJ EA 15 MIN GRP 2/>PTS','96153','1','','1','0','','','',0, 1, 0, 0),
(9023,'HLTH&BEHAVIOR IVNTJ EA 15 MIN FAM W/PT','HLTH&BEHAVIOR IVNTJ EA 15 MIN FAM W/PT','96154','1','','1','0','','','',0, 1, 0, 0),
(9024,'HLTH&BEHAVIOR IVNTJ EA 15 MIN FAM W/O PT','HLTH&BEHAVIOR IVNTJ EA 15 MIN FAM W/O PT','96155','1','','1','0','','','',0, 1, 0, 0),
(9025,'IV INFUSION HYDRATION INITIAL 31 MIN-1 HOUR','IV INFUSION HYDRATION INITIAL 31 MIN-1 HOUR','96360','1','','1','0','','','',0, 1, 0, 0),
(9026,'IV INFUSION HYDRATION EACH ADDITIONAL HOUR','IV INFUSION HYDRATION EACH ADDITIONAL HOUR','96361','1','','1','0','','','',0, 1, 0, 0),
(9027,'IV INFUSION THERAPY/PROPHYLAXIS /DX 1ST TO 1 HR','IV INFUSION THERAPY/PROPHYLAXIS /DX 1ST TO 1 HR','96365','1','','1','0','','','',0, 1, 0, 0),
(9028,'IV INFUSION THERAPY PROPHYLAXIS/DX EA HOUR','IV INFUSION THERAPY PROPHYLAXIS/DX EA HOUR','96366','1','','1','0','','','',0, 1, 0, 0),
(9029,'IV INFUSION THER PROPH ADDL SEQUENTIAL TO 1 HR','IV INFUSION THER PROPH ADDL SEQUENTIAL TO 1 HR','96367','1','','1','0','','','',0, 1, 0, 0),
(9030,'IV NFS THERAPY PROPHYLAXIS/DX CONCURRENT NFS','IV NFS THERAPY PROPHYLAXIS/DX CONCURRENT NFS','96368','1','','1','0','','','',0, 1, 0, 0),
(9031,'SUBCUTANEOUS INFUSION INITIAL 1 HR W/PUMP SET-UP','SUBCUTANEOUS INFUSION INITIAL 1 HR W/PUMP SET-UP','96369','1','','1','0','','','',0, 1, 0, 0),
(9032,'SUBCUTANEOUS INFUSION EACH ADDITIONAL HOUR','SUBCUTANEOUS INFUSION EACH ADDITIONAL HOUR','96370','1','','1','0','','','',0, 1, 0, 0),
(9033,'SUBQ INFUSION ADDITIONAL PUMP INFUSION SITE','SUBQ INFUSION ADDITIONAL PUMP INFUSION SITE','96371','1','','1','0','','','',0, 1, 0, 0),
(9034,'THERAPEUTIC PROPHYLACTIC/DX INJECTION SUBQ/IM','THERAPEUTIC PROPHYLACTIC/DX INJECTION SUBQ/IM','96372','1','','1','0','','','',0, 1, 0, 0),
(9035,'THERAPEUTIC PROPHYLACTIC/DX NJX INTRA-ARTERIAL','THERAPEUTIC PROPHYLACTIC/DX NJX INTRA-ARTERIAL','96373','1','','1','0','','','',0, 1, 0, 0),
(9036,'THER PROPH/DX NJX IV PUSH SINGLE/1ST SBST/DRUG','THER PROPH/DX NJX IV PUSH SINGLE/1ST SBST/DRUG','96374','1','','1','0','','','',0, 1, 0, 0),
(9037,'THERAPEUTIC INJECTION IV PUSH EACH NEW DRUG','THERAPEUTIC INJECTION IV PUSH EACH NEW DRUG','96375','1','','1','0','','','',0, 1, 0, 0),
(9038,'THER PROPH/DX NJX EA SEQL IV PUSH SBST/DRUG FAC','THER PROPH/DX NJX EA SEQL IV PUSH SBST/DRUG FAC','96376','1','','1','0','','','',0, 1, 0, 0),
(9039,'UNLISTED THERAPEUTIC PROPH/DX IV/IA NJX/NFS','UNLISTED THERAPEUTIC PROPH/DX IV/IA NJX/NFS','96379','1','','1','0','','','',0, 1, 0, 0),
(9040,'CHEMOTX ADMN SUBQ/IM NON-HORMONAL ANTI-NEO','CHEMOTX ADMN SUBQ/IM NON-HORMONAL ANTI-NEO','96401','1','','1','0','','','',0, 1, 0, 0),
(9041,'CHEMOTX ADMN SUBQ/IM HORMONAL ANTI-NEO','CHEMOTX ADMN SUBQ/IM HORMONAL ANTI-NEO','96402','1','','1','0','','','',0, 1, 0, 0),
(9042,'CHEMOTHERAPY ADMINISTRATION INTRALESIONAL </7','CHEMOTHERAPY ADMINISTRATION INTRALESIONAL </7','96405','1','','1','0','','','',0, 1, 0, 0),
(9043,'CHEMOTHERAPY ADMINISTRATION INTRALESIONAL >7','CHEMOTHERAPY ADMINISTRATION INTRALESIONAL >7','96406','1','','1','0','','','',0, 1, 0, 0),
(9044,'CHEMOTX ADMN IV PUSH TQ 1/1ST SBST/DRUG','CHEMOTX ADMN IV PUSH TQ 1/1ST SBST/DRUG','96409','1','','1','0','','','',0, 1, 0, 0),
(9045,'CHEMOTX ADMN IV PUSH TQ EA SBST/DRUG','CHEMOTX ADMN IV PUSH TQ EA SBST/DRUG','96411','1','','1','0','','','',0, 1, 0, 0),
(9046,'CHEMOTX ADMN IV NFS TQ UP 1 HR 1/1ST SBST/DRUG','CHEMOTX ADMN IV NFS TQ UP 1 HR 1/1ST SBST/DRUG','96413','1','','1','0','','','',0, 1, 0, 0),
(9047,'CHEMOTHERAPY ADMN IV INFUSION TQ EA HR','CHEMOTHERAPY ADMN IV INFUSION TQ EA HR','96415','1','','1','0','','','',0, 1, 0, 0),
(9048,'CHEMOTX ADMN TQ INIT PROLNG CHEMOTX NFUS PMP','CHEMOTX ADMN TQ INIT PROLNG CHEMOTX NFUS PMP','96416','1','','1','0','','','',0, 1, 0, 0),
(9049,'CHEMOTX ADMN IV NFS TQ EA SEQL NFS TO 1 HR','CHEMOTX ADMN IV NFS TQ EA SEQL NFS TO 1 HR','96417','1','','1','0','','','',0, 1, 0, 0),
(9050,'CHEMOTHERAPY ADMIN INTRA-ARTERIAL PUSH TQ','CHEMOTHERAPY ADMIN INTRA-ARTERIAL PUSH TQ','96420','1','','1','0','','','',0, 1, 0, 0),
(9051,'CHEMOTHERAPY ADMIN INTRA-ARTERIAL INFUS </1 HR','CHEMOTHERAPY ADMIN INTRA-ARTERIAL INFUS </1 HR','96422','1','','1','0','','','',0, 1, 0, 0),
(9052,'CHEMOTHERAPY ADMN INTRAARTERIAL INFUSION EA HR','CHEMOTHERAPY ADMN INTRAARTERIAL INFUSION EA HR','96423','1','','1','0','','','',0, 1, 0, 0),
(9053,'CHEMOTX ADMN IA NFS >8 HR PRTBLE IMPLTBL PMP','CHEMOTX ADMN IA NFS >8 HR PRTBLE IMPLTBL PMP','96425','1','','1','0','','','',0, 1, 0, 0),
(9054,'CHEMOTX ADMN PLEURAL CAVITY REQ&W/THORACNTS','CHEMOTX ADMN PLEURAL CAVITY REQ&W/THORACNTS','96440','1','','1','0','','','',0, 1, 0, 0),
(9055,'CHEMOTX ADMN PRTL CAVITY PORT/CATH','CHEMOTX ADMN PRTL CAVITY PORT/CATH','96446','1','','1','0','','','',0, 1, 0, 0),
(9056,'CHEMOTX ADMN CNS REQ SPINAL PUNCTURE','CHEMOTX ADMN CNS REQ SPINAL PUNCTURE','96450','1','','1','0','','','',0, 1, 0, 0),
(9057,'REFILLING & MAINTENANCE PORTABLE PUMP','REFILLING & MAINTENANCE PORTABLE PUMP','96521','1','','1','0','','','',0, 1, 0, 0),
(9058,'REFILL&MAINTENANCE PUMP DRUG DLVR SYSTEMIC','REFILL&MAINTENANCE PUMP DRUG DLVR SYSTEMIC','96522','1','','1','0','','','',0, 1, 0, 0),
(9059,'IRRIGAJ IMPLNTD VENOUS ACCESS DRUG DELIVERY SYST','IRRIGAJ IMPLNTD VENOUS ACCESS DRUG DELIVERY SYST','96523','1','','1','0','','','',0, 1, 0, 0),
(9060,'CHEMOTX NJX SUBARACHND/INTRAVENTR RSVR 1/MULT','CHEMOTX NJX SUBARACHND/INTRAVENTR RSVR 1/MULT','96542','1','','1','0','','','',0, 1, 0, 0),
(9061,'UNLISTED CHEMOTHERAPY PROCEDURE','UNLISTED CHEMOTHERAPY PROCEDURE','96549','1','','1','0','','','',0, 1, 0, 0),
(9062,'PDT XTRNL APPL LIGHT DSTR LES SKN BY ACTIVJ RX','PDT XTRNL APPL LIGHT DSTR LES SKN BY ACTIVJ RX','96567','1','','1','0','','','',0, 1, 0, 0),
(9063,'PDT NDSC ABL ABNOR TISS VIA ACTIVJ RX 30 MIN','PDT NDSC ABL ABNOR TISS VIA ACTIVJ RX 30 MIN','96570','1','','1','0','','','',0, 1, 0, 0),
(9064,'PDT NDSC ABL ABNOR TISS VIA ACTIVJ RX A 15 MIN','PDT NDSC ABL ABNOR TISS VIA ACTIVJ RX A 15 MIN','96571','1','','1','0','','','',0, 1, 0, 0),
(9065,'ACTINOTHERAPY ULTRAVIOLET LIGHT','ACTINOTHERAPY ULTRAVIOLET LIGHT','96900','1','','1','0','','','',0, 1, 0, 0),
(9066,'MCRSCP XM HAIR PLUCK/CLIP FOR CNTS/STRUCT ABNORM','MCRSCP XM HAIR PLUCK/CLIP FOR CNTS/STRUCT ABNORM','96902','1','','1','0','','','',0, 1, 0, 0),
(9067,'WHOLE BODY INTEGUMENTARY PHOTOGRAPHY','WHOLE BODY INTEGUMENTARY PHOTOGRAPHY','96904','1','','1','0','','','',0, 1, 0, 0),
(9068,'PHOTOCHEMOTX TAR&UVB/PETROLATUM/UVB','PHOTOCHEMOTX TAR&UVB/PETROLATUM/UVB','96910','1','','1','0','','','',0, 1, 0, 0),
(9069,'PHOTOCHEMOTX PSORALENS&ULTRAVIOLET PUVA','PHOTOCHEMOTX PSORALENS&ULTRAVIOLET PUVA','96912','1','','1','0','','','',0, 1, 0, 0),
(9070,'PHOTOCHEMOTHERAPY DERMATOSES 4-8 HRS SUPERVISION','PHOTOCHEMOTHERAPY DERMATOSES 4-8 HRS SUPERVISION','96913','1','','1','0','','','',0, 1, 0, 0),
(9071,'LASER SKIN DISEASE PSORIASIS TOT AREA <250 SQ CM','LASER SKIN DISEASE PSORIASIS TOT AREA <250 SQ CM','96920','1','','1','0','','','',0, 1, 0, 0),
(9072,'LASER SKIN DISEASE PSORIASIS 250-500 SQ CM','LASER SKIN DISEASE PSORIASIS 250-500 SQ CM','96921','1','','1','0','','','',0, 1, 0, 0),
(9073,'LASER SKIN DISEASE PSORIASIS >500 SQ CM','LASER SKIN DISEASE PSORIASIS >500 SQ CM','96922','1','','1','0','','','',0, 1, 0, 0),
(9074,'RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ I&R 1ST','RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ I&R 1ST','96931','1','','1','0','','','',0, 1, 0, 0),
(9075,'RCM CELULR & SUBCELULR SKN IMGNG IMG ACQUISITION','RCM CELULR & SUBCELULR SKN IMGNG IMG ACQUISITION','96932','1','','1','0','','','',0, 1, 0, 0),
(9076,'RCM CELULR & SUBCELULR SKN IMGNG I&R 1ST LES','RCM CELULR & SUBCELULR SKN IMGNG I&R 1ST LES','96933','1','','1','0','','','',0, 1, 0, 0),
(9077,'RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ I&R ADD','RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ I&R ADD','96934','1','','1','0','','','',0, 1, 0, 0),
(9078,'RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ EA ADDL','RCM CELULR & SUBCELULR SKN IMGNG IMG ACQ EA ADDL','96935','1','','1','0','','','',0, 1, 0, 0),
(9079,'RCM CELULR & SUBCELULR SKN IMGNG I&R EA ADDL','RCM CELULR & SUBCELULR SKN IMGNG I&R EA ADDL','96936','1','','1','0','','','',0, 1, 0, 0),
(9080,'UNLISTED SPECIAL DERMATOLOGICAL SERVICE/PROCED','UNLISTED SPECIAL DERMATOLOGICAL SERVICE/PROCED','96999','1','','1','0','','','',0, 1, 0, 0),
(9081,'PHYSICAL THERAPY EVALUATION','PHYSICAL THERAPY EVALUATION','97001','1','','1','0','','','',0, 1, 0, 0),
(9082,'PHYSICAL THERAPY RE-EVALUATION','PHYSICAL THERAPY RE-EVALUATION','97002','1','','1','0','','','',0, 1, 0, 0),
(9083,'OCCUPATIONAL THERAPY EVALUATION','OCCUPATIONAL THERAPY EVALUATION','97003','1','','1','0','','','',0, 1, 0, 0),
(9084,'OCCUPATIONAL THERAPY RE-EVALUATION','OCCUPATIONAL THERAPY RE-EVALUATION','97004','1','','1','0','','','',0, 1, 0, 0),
(9085,'ATHLETIC TRAINING EVALUATION','ATHLETIC TRAINING EVALUATION','97005','1','','1','0','','','',0, 1, 0, 0),
(9086,'ATHLETIC TRAINING RE-EVALUATION','ATHLETIC TRAINING RE-EVALUATION','97006','1','','1','0','','','',0, 1, 0, 0),
(9087,'APPLICATION MODALITY 1/> AREAS HOT/COLD PACKS','APPLICATION MODALITY 1/> AREAS HOT/COLD PACKS','97010','1','','1','0','','','',0, 1, 0, 0),
(9088,'APPL MODALITY 1/> AREAS TRACTION MECHANICAL','APPL MODALITY 1/> AREAS TRACTION MECHANICAL','97012','1','','1','0','','','',0, 1, 0, 0),
(9089,'APPL MODALITY 1/> AREAS ELEC STIMJ UNATTENDED','APPL MODALITY 1/> AREAS ELEC STIMJ UNATTENDED','97014','1','','1','0','','','',0, 1, 0, 0),
(9090,'APPL MODALITY 1/> AREAS VASOPNEUMATIC DEVICES','APPL MODALITY 1/> AREAS VASOPNEUMATIC DEVICES','97016','1','','1','0','','','',0, 1, 0, 0),
(9091,'APPL MODALITY 1/> AREAS PARAFFIN BATH','APPL MODALITY 1/> AREAS PARAFFIN BATH','97018','1','','1','0','','','',0, 1, 0, 0),
(9092,'APPLICATION MODALITY 1/> AREAS WHIRLPOOL','APPLICATION MODALITY 1/> AREAS WHIRLPOOL','97022','1','','1','0','','','',0, 1, 0, 0),
(9093,'APPLICATION MODALITY 1/> AREAS DIATHERMY','APPLICATION MODALITY 1/> AREAS DIATHERMY','97024','1','','1','0','','','',0, 1, 0, 0),
(9094,'APPLICATION MODALITY 1/> AREAS INFRARED','APPLICATION MODALITY 1/> AREAS INFRARED','97026','1','','1','0','','','',0, 1, 0, 0),
(9095,'APPL MODALITY 1/> AREAS ULTRAVIOLET','APPL MODALITY 1/> AREAS ULTRAVIOLET','97028','1','','1','0','','','',0, 1, 0, 0),
(9096,'APPL MODALITY 1/> AREAS ELEC STIMJ EA 15 MIN','APPL MODALITY 1/> AREAS ELEC STIMJ EA 15 MIN','97032','1','','1','0','','','',0, 1, 0, 0),
(9097,'APPL MODALITY 1/> AREAS IONTOPHORESIS EA 15 MIN','APPL MODALITY 1/> AREAS IONTOPHORESIS EA 15 MIN','97033','1','','1','0','','','',0, 1, 0, 0),
(9098,'APPL MODALITY 1/> AREAS CONTRAST BATHS EA 15 MIN','APPL MODALITY 1/> AREAS CONTRAST BATHS EA 15 MIN','97034','1','','1','0','','','',0, 1, 0, 0),
(9099,'APPL MODALITY 1/> AREAS ULTRASOUND EA 15 MIN','APPL MODALITY 1/> AREAS ULTRASOUND EA 15 MIN','97035','1','','1','0','','','',0, 1, 0, 0),
(9100,'APPL MODALITY 1/> AREAS HUBBARD TANK EA 15 MIN','APPL MODALITY 1/> AREAS HUBBARD TANK EA 15 MIN','97036','1','','1','0','','','',0, 1, 0, 0),
(9101,'UNLIST MODALITY SPEC TYPE&TIME CONSTANT ATTEND','UNLIST MODALITY SPEC TYPE&TIME CONSTANT ATTEND','97039','1','','1','0','','','',0, 1, 0, 0),
(9102,'THERAPEUTIC PX 1/> AREAS EACH 15 MIN EXERCISES','THERAPEUTIC PX 1/> AREAS EACH 15 MIN EXERCISES','97110','1','','1','0','','','',0, 1, 0, 0),
(9103,'THER PX 1/> AREAS EACH 15 MIN NEUROMUSC REEDUCA','THER PX 1/> AREAS EACH 15 MIN NEUROMUSC REEDUCA','97112','1','','1','0','','','',0, 1, 0, 0),
(9104,'THER PX 1/> AREAS EACH 15 MIN AQUA THER W/XERSS','THER PX 1/> AREAS EACH 15 MIN AQUA THER W/XERSS','97113','1','','1','0','','','',0, 1, 0, 0),
(9105,'THER PX 1/> AREAS EA 15 MIN GAIT TRAINJ W/STAIR','THER PX 1/> AREAS EA 15 MIN GAIT TRAINJ W/STAIR','97116','1','','1','0','','','',0, 1, 0, 0),
(9106,'THER PX 1/> AREAS EACH 15 MINUTES MASSAGE','THER PX 1/> AREAS EACH 15 MINUTES MASSAGE','97124','1','','1','0','','','',0, 1, 0, 0),
(9107,'UNLISTED THERAPEUTIC PROCEDURE SPECIFY','UNLISTED THERAPEUTIC PROCEDURE SPECIFY','97139','1','','1','0','','','',0, 1, 0, 0),
(9108,'MANUAL THERAPY TQS 1/> REGIONS EACH 15 MINUTES','MANUAL THERAPY TQS 1/> REGIONS EACH 15 MINUTES','97140','1','','1','0','','','',0, 1, 0, 0),
(9109,'THERAPEUTIC PROCEDURES GROUP 2/> INDIVIDUALS','THERAPEUTIC PROCEDURES GROUP 2/> INDIVIDUALS','97150','1','','1','0','','','',0, 1, 0, 0),
(9110,'THERAPEUT ACTVITY DIRECT PT CONTACT EACH 15 MIN','THERAPEUT ACTVITY DIRECT PT CONTACT EACH 15 MIN','97530','1','','1','0','','','',0, 1, 0, 0),
(9111,'DEVELOPMENT OF COGNITIVE SKILLS EACH 15 MINUTES','DEVELOPMENT OF COGNITIVE SKILLS EACH 15 MINUTES','97532','1','','1','0','','','',0, 1, 0, 0),
(9112,'SENSORY INTEGRATIVE TECHNIQUES EACH 15 MINUTES','SENSORY INTEGRATIVE TECHNIQUES EACH 15 MINUTES','97533','1','','1','0','','','',0, 1, 0, 0),
(9113,'SELF-CARE/HOME MGMT TRAINING EACH 15 MINUTES','SELF-CARE/HOME MGMT TRAINING EACH 15 MINUTES','97535','1','','1','0','','','',0, 1, 0, 0),
(9114,'COMMUNITY/WORK REINTEGRATION TRAINJ EA 15 MIN','COMMUNITY/WORK REINTEGRATION TRAINJ EA 15 MIN','97537','1','','1','0','','','',0, 1, 0, 0),
(9115,'WHEELCHAIR MGMT EA 15 MIN','WHEELCHAIR MGMT EA 15 MIN','97542','1','','1','0','','','',0, 1, 0, 0),
(9116,'WORK HARDENING/CONDITIONING 1ST 2 HR','WORK HARDENING/CONDITIONING 1ST 2 HR','97545','1','','1','0','','','',0, 1, 0, 0),
(9117,'WORK HARDENING/CONDITIONING EACH HOUR','WORK HARDENING/CONDITIONING EACH HOUR','97546','1','','1','0','','','',0, 1, 0, 0),
(9118,'DEBRIDEMENT OPEN WOUND 20 SQ CM/<','DEBRIDEMENT OPEN WOUND 20 SQ CM/<','97597','1','','1','0','','','',0, 1, 0, 0),
(9119,'DEBRIDEMENT OPEN WOUND EACH ADDITIONAL 20 SQ CM','DEBRIDEMENT OPEN WOUND EACH ADDITIONAL 20 SQ CM','97598','1','','1','0','','','',0, 1, 0, 0),
(9120,'RMVL DEVITAL TISS N-SLCTV DBRDMT W/O ANES 1 SESS','RMVL DEVITAL TISS N-SLCTV DBRDMT W/O ANES 1 SESS','97602','1','','1','0','','','',0, 1, 0, 0),
(9121,'NEGATIVE PRESSURE WOUND THERAPY DME </= 50 SQ CM','NEGATIVE PRESSURE WOUND THERAPY DME </= 50 SQ CM','97605','1','','1','0','','','',0, 1, 0, 0),
(9122,'NEGATIVE PRESSURE WOUND THERAPY DME >50 SQ CM','NEGATIVE PRESSURE WOUND THERAPY DME >50 SQ CM','97606','1','','1','0','','','',0, 1, 0, 0),
(9123,'NEG PRESSURE WOUND THERAPY NON DME </= 50 SQ CM','NEG PRESSURE WOUND THERAPY NON DME </= 50 SQ CM','97607','1','','1','0','','','',0, 1, 0, 0),
(9124,'NEG PRESSURE WOUND THERAPY NON DME >50 SQ CM','NEG PRESSURE WOUND THERAPY NON DME >50 SQ CM','97608','1','','1','0','','','',0, 1, 0, 0),
(9125,'LOW FREQUENCY NON-THERMAL ULTRASOUND PER DAY','LOW FREQUENCY NON-THERMAL ULTRASOUND PER DAY','97610','1','','1','0','','','',0, 1, 0, 0),
(9126,'PHYSICAL PERFORMANCE TEST/MEAS W/REPRT EA 15 MIN','PHYSICAL PERFORMANCE TEST/MEAS W/REPRT EA 15 MIN','97750','1','','1','0','','','',0, 1, 0, 0),
(9127,'ASSTV TECHNOL ASSMT DIR CNTCT W/REPRT EA 15 MIN','ASSTV TECHNOL ASSMT DIR CNTCT W/REPRT EA 15 MIN','97755','1','','1','0','','','',0, 1, 0, 0),
(9128,'ORTHOTIC MGMT&TRAINJ UXTR LXTR&/TRNK EA 15','ORTHOTIC MGMT&TRAINJ UXTR LXTR&/TRNK EA 15','97760','1','','1','0','','','',0, 1, 0, 0),
(9129,'PROSTHETIC TRAINING UPPR&/LOWER EXTREM EA 15 M','PROSTHETIC TRAINING UPPR&/LOWER EXTREM EA 15 M','97761','1','','1','0','','','',0, 1, 0, 0),
(9130,'CHECKOUT ORTHOTIC/PROSTHETIC ESTAB PT EA 15 MIN','CHECKOUT ORTHOTIC/PROSTHETIC ESTAB PT EA 15 MIN','97762','1','','1','0','','','',0, 1, 0, 0),
(9131,'UNLISTED PHYSICAL MEDICINE/REHAB SERVICE/PROC','UNLISTED PHYSICAL MEDICINE/REHAB SERVICE/PROC','97799','1','','1','0','','','',0, 1, 0, 0),
(9132,'MEDICAL NUTRITION ASSMT&IVNTJ INDIV EACH 15 MI','MEDICAL NUTRITION ASSMT&IVNTJ INDIV EACH 15 MI','97802','1','','1','0','','','',0, 1, 0, 0),
(9133,'MEDICAL NUTRITION RE-ASSMT&IVNTJ INDIV EA 15 M','MEDICAL NUTRITION RE-ASSMT&IVNTJ INDIV EA 15 M','97803','1','','1','0','','','',0, 1, 0, 0),
(9134,'MEDICAL NUTRITION THERAPY GRP2/ INDIV EA 30 MI','MEDICAL NUTRITION THERAPY GRP2/ INDIV EA 30 MI','97804','1','','1','0','','','',0, 1, 0, 0),
(9135,'ACUPUNCTURE 1/> NDLES W/O ELEC STIMJ INIT 15 MIN','ACUPUNCTURE 1/> NDLES W/O ELEC STIMJ INIT 15 MIN','97810','1','','1','0','','','',0, 1, 0, 0),
(9136,'ACUPUNCTURE 1/> NDLS W/O ELEC STIMJ EA 15 MIN','ACUPUNCTURE 1/> NDLS W/O ELEC STIMJ EA 15 MIN','97811','1','','1','0','','','',0, 1, 0, 0),
(9137,'ACUPUNCTURE 1/> NDLS W/ELEC STIMJ 1ST 15 MIN','ACUPUNCTURE 1/> NDLS W/ELEC STIMJ 1ST 15 MIN','97813','1','','1','0','','','',0, 1, 0, 0),
(9138,'ACUP 1/> NDLS W/ELEC STIMJ EA 15 MIN W/RE-INSJ','ACUP 1/> NDLS W/ELEC STIMJ EA 15 MIN W/RE-INSJ','97814','1','','1','0','','','',0, 1, 0, 0),
(9139,'OSTEOPATHIC MANIPULATIVE TX 1-2 BODY REGIONS','OSTEOPATHIC MANIPULATIVE TX 1-2 BODY REGIONS','98925','1','','1','0','','','',0, 1, 0, 0),
(9140,'OSTEOPATHIC MANIPULATIVE TX 3-4 BODY REGIONS','OSTEOPATHIC MANIPULATIVE TX 3-4 BODY REGIONS','98926','1','','1','0','','','',0, 1, 0, 0),
(9141,'OSTEOPATHIC MANIPULATIVE TX 5-6 BODY REGIONS','OSTEOPATHIC MANIPULATIVE TX 5-6 BODY REGIONS','98927','1','','1','0','','','',0, 1, 0, 0),
(9142,'OSTEOPATHIC MANIPULATIVE TX 7-8 BODY REGIONS','OSTEOPATHIC MANIPULATIVE TX 7-8 BODY REGIONS','98928','1','','1','0','','','',0, 1, 0, 0),
(9143,'OSTEOPATHIC MANIPULATIVE TX 9-10 BODY REGIONS','OSTEOPATHIC MANIPULATIVE TX 9-10 BODY REGIONS','98929','1','','1','0','','','',0, 1, 0, 0),
(9144,'CHIROPRACTIC MANIPULATIVE TX SPINAL 1-2 REGIONS','CHIROPRACTIC MANIPULATIVE TX SPINAL 1-2 REGIONS','98940','1','','1','0','','','',0, 1, 0, 0),
(9145,'CHIROPRACTIC MANIPULATIVE TX SPINAL 3-4 REGIONS','CHIROPRACTIC MANIPULATIVE TX SPINAL 3-4 REGIONS','98941','1','','1','0','','','',0, 1, 0, 0),
(9146,'CHIROPRACTIC MANIPULATIVE TX SPINAL 5 REGIONS','CHIROPRACTIC MANIPULATIVE TX SPINAL 5 REGIONS','98942','1','','1','0','','','',0, 1, 0, 0),
(9147,'CHIROPRACTIC MANIPLTV TX EXTRASPINAL 1/> REGION','CHIROPRACTIC MANIPLTV TX EXTRASPINAL 1/> REGION','98943','1','','1','0','','','',0, 1, 0, 0),
(9148,'EDUCATION&TRAINING SELF-MGMT NONPHYS 1 PT','EDUCATION&TRAINING SELF-MGMT NONPHYS 1 PT','98960','1','','1','0','','','',0, 1, 0, 0),
(9149,'EDUCATION&TRAINING SELF-MGMT NONPHYS 2-4 PTS','EDUCATION&TRAINING SELF-MGMT NONPHYS 2-4 PTS','98961','1','','1','0','','','',0, 1, 0, 0),
(9150,'EDUCATION&TRAINING SELF-MGMT NONPHYS 5-8 PTS','EDUCATION&TRAINING SELF-MGMT NONPHYS 5-8 PTS','98962','1','','1','0','','','',0, 1, 0, 0),
(9151,'NONPHYSICIAN TELEPHONE ASSESSMENT 5-10 MIN','NONPHYSICIAN TELEPHONE ASSESSMENT 5-10 MIN','98966','1','','1','0','','','',0, 1, 0, 0),
(9152,'NONPHYSICIAN TELEPHONE ASSESSMENT 11-20 MIN','NONPHYSICIAN TELEPHONE ASSESSMENT 11-20 MIN','98967','1','','1','0','','','',0, 1, 0, 0),
(9153,'NONPHYSICIAN TELEPHONE ASSESSMENT 21-30 MIN','NONPHYSICIAN TELEPHONE ASSESSMENT 21-30 MIN','98968','1','','1','0','','','',0, 1, 0, 0),
(9154,'NONPHYSICIAN ONLINE ASSESSMENT AND MANAGEMENT','NONPHYSICIAN ONLINE ASSESSMENT AND MANAGEMENT','98969','1','','1','0','','','',0, 1, 0, 0),
(9155,'HANDLG&/OR CONVEY OF SPEC FOR TR OFFICE TO LAB','HANDLG&/OR CONVEY OF SPEC FOR TR OFFICE TO LAB','99000','1','','1','0','','','',0, 1, 0, 0),
(9156,'HANDLG&/OR CONVEY OF SPEC FOR TR FROM PT TO LAB','HANDLG&/OR CONVEY OF SPEC FOR TR FROM PT TO LAB','99001','1','','1','0','','','',0, 1, 0, 0),
(9157,'HANDLE/CONVEY/ANY OTH SVC DEVICE FIT PHYS/QHP','HANDLE/CONVEY/ANY OTH SVC DEVICE FIT PHYS/QHP','99002','1','','1','0','','','',0, 1, 0, 0),
(9158,'POSTOP FOLLOW UP VISIT RELATED TO ORIGINAL PX','POSTOP FOLLOW UP VISIT RELATED TO ORIGINAL PX','99024','1','','1','0','','','',0, 1, 0, 0),
(9159,'HOSPITAL MANDATED CALL SERVICE IN-HOSPITAL EA HR','HOSPITAL MANDATED CALL SERVICE IN-HOSPITAL EA HR','99026','1','','1','0','','','',0, 1, 0, 0),
(9160,'HOSPITAL MANDATED CALL SVC OUT-OF-HOSPITAL EA HR','HOSPITAL MANDATED CALL SVC OUT-OF-HOSPITAL EA HR','99027','1','','1','0','','','',0, 1, 0, 0),
(9161,'SERVICES PROVIDED OFFICE OTH/THN REG SCHED HOURS','SERVICES PROVIDED OFFICE OTH/THN REG SCHED HOURS','99050','1','','1','0','','','',0, 1, 0, 0),
(9162,'SVC PRV OFFICE REG SCHEDD EVN WKEND/HOLIDAY HRS','SVC PRV OFFICE REG SCHEDD EVN WKEND/HOLIDAY HRS','99051','1','','1','0','','','',0, 1, 0, 0),
(9163,'SERVICES PROVIDED BTW 10 PM&8 AM AT 24-HR FACI','SERVICES PROVIDED BTW 10 PM&8 AM AT 24-HR FACI','99053','1','','1','0','','','',0, 1, 0, 0),
(9164,'SVC TYPICAL PRV OFFICE PRV OUT OFFICE REQUEST PT','SVC TYPICAL PRV OFFICE PRV OUT OFFICE REQUEST PT','99056','1','','1','0','','','',0, 1, 0, 0),
(9165,'SVC PRV EMER BASIS IN OFFICE DISRUPTING SVCS','SVC PRV EMER BASIS IN OFFICE DISRUPTING SVCS','99058','1','','1','0','','','',0, 1, 0, 0),
(9166,'SVC PRV EMER OUT OFFICE DISRUPTS OFFICE SVC','SVC PRV EMER OUT OFFICE DISRUPTS OFFICE SVC','99060','1','','1','0','','','',0, 1, 0, 0),
(9167,'SUPPLIES&MATERIALS ABOVE/BEYOND PROV BY PHYS/QHP','SUPPLIES&MATERIALS ABOVE/BEYOND PROV BY PHYS/QHP','99070','1','','1','0','','','',0, 1, 0, 0),
(9168,'EDUCATIONAL SUPPLIES PRV BY THE PHYS AT COST','EDUCATIONAL SUPPLIES PRV BY THE PHYS AT COST','99071','1','','1','0','','','',0, 1, 0, 0),
(9169,'MEDICAL TESTIMONY','MEDICAL TESTIMONY','99075','1','','1','0','','','',0, 1, 0, 0),
(9170,'PHYS/QHP EDUCATION SVCS RENDERED PTS GRP SETTING','PHYS/QHP EDUCATION SVCS RENDERED PTS GRP SETTING','99078','1','','1','0','','','',0, 1, 0, 0),
(9171,'SPEC REPORTS > USUAL MED COMUNICAJ/STAND RPRTG','SPEC REPORTS > USUAL MED COMUNICAJ/STAND RPRTG','99080','1','','1','0','','','',0, 1, 0, 0),
(9172,'UNUSUAL TRAVEL','UNUSUAL TRAVEL','99082','1','','1','0','','','',0, 1, 0, 0),
(9173,'ANALYSIS CLINICAL DATA STORED IN COMPUTERS','ANALYSIS CLINICAL DATA STORED IN COMPUTERS','99090','1','','1','0','','','',0, 1, 0, 0),
(9174,'COLLJ&INTERPJ PHYS/QHP PHYSIO COMPUTR DATA 30 MI','COLLJ&INTERPJ PHYS/QHP PHYSIO COMPUTR DATA 30 MI','99091','1','','1','0','','','',0, 1, 0, 0),
(9175,'ANESTHESIA EXTREME AGE PATIENT UNDER 1 YR/<','ANESTHESIA EXTREME AGE PATIENT UNDER 1 YR/<','99100','1','','1','0','','','',0, 1, 0, 0),
(9176,'ANES COMPLICJ UTILIZATION TOTAL BODY HYPOTHERMIA','ANES COMPLICJ UTILIZATION TOTAL BODY HYPOTHERMIA','99116','1','','1','0','','','',0, 1, 0, 0),
(9177,'ANES COMPLICJ UTILIZATION CONTROLLED HYPOTENSION','ANES COMPLICJ UTILIZATION CONTROLLED HYPOTENSION','99135','1','','1','0','','','',0, 1, 0, 0),
(9178,'ANES COMPLICJ EMERGENCY CONDITIONS SPECIFY','ANES COMPLICJ EMERGENCY CONDITIONS SPECIFY','99140','1','','1','0','','','',0, 1, 0, 0),
(9179,'MODERATE SEDATJ SAME PHYS/QHP <5 YRS INIT 30 MIN','MODERATE SEDATJ SAME PHYS/QHP <5 YRS INIT 30 MIN','99143','1','','1','0','','','',0, 1, 0, 0),
(9180,'MODERATE SEDATJ SAME PHYS/QHP 5/>YRS INIT 30 MIN','MODERATE SEDATJ SAME PHYS/QHP 5/>YRS INIT 30 MIN','99144','1','','1','0','','','',0, 1, 0, 0),
(9181,'MODERATE SEDATJ SAME PHYS/QHP EACH ADDL 15 MIN','MODERATE SEDATJ SAME PHYS/QHP EACH ADDL 15 MIN','99145','1','','1','0','','','',0, 1, 0, 0),
(9182,'MOD SEDATJ DIFF PHYS/QHP <5 YRS INIT 30 MIN','MOD SEDATJ DIFF PHYS/QHP <5 YRS INIT 30 MIN','99148','1','','1','0','','','',0, 1, 0, 0),
(9183,'MODERATE SEDATJ DIFF PHYS/QHP 5/>YRS INIT 30 MIN','MODERATE SEDATJ DIFF PHYS/QHP 5/>YRS INIT 30 MIN','99149','1','','1','0','','','',0, 1, 0, 0),
(9184,'MODERATE SEDATJ DIFF PHYS/QHP EA ADDL 15 MIN','MODERATE SEDATJ DIFF PHYS/QHP EA ADDL 15 MIN','99150','1','','1','0','','','',0, 1, 0, 0),
(9185,'ANOGENITAL XM MAGNIFY CHILD/SUSPECT TRAUMA W IMG','ANOGENITAL XM MAGNIFY CHILD/SUSPECT TRAUMA W IMG','99170','1','','1','0','','','',0, 1, 0, 0),
(9186,'VISUAL FUNCT SCRNG AUTO SEMI-AUTO BI QUAN DETERM','VISUAL FUNCT SCRNG AUTO SEMI-AUTO BI QUAN DETERM','99172','1','','1','0','','','',0, 1, 0, 0),
(9187,'SCREENING TEST VISUAL ACUITY QUANTITATIVE BILAT','SCREENING TEST VISUAL ACUITY QUANTITATIVE BILAT','99173','1','','1','0','','','',0, 1, 0, 0),
(9188,'INSTRUMENT BASED OCULAR SCR BI W/RMT ANAL & RPT','INSTRUMENT BASED OCULAR SCR BI W/RMT ANAL & RPT','99174','1','','1','0','','','',0, 1, 0, 0),
(9189,'IPECAC/SIMILAR ADMN EMESIS&OBS STOMACH EMPTIED','IPECAC/SIMILAR ADMN EMESIS&OBS STOMACH EMPTIED','99175','1','','1','0','','','',0, 1, 0, 0),
(9190,'INSTRUMENT BASED OCULAR SCR BI W/ONSITE ANALYSIS','INSTRUMENT BASED OCULAR SCR BI W/ONSITE ANALYSIS','99177','1','','1','0','','','',0, 1, 0, 0),
(9191,'PHYS/QHP ATTN&SUPVJ HYPRBARIC OXYGEN TX/SESSION','PHYS/QHP ATTN&SUPVJ HYPRBARIC OXYGEN TX/SESSION','99183','1','','1','0','','','',0, 1, 0, 0),
(9192,'INITIAT SELECTIVE HEAD/BODY HYPOTHERMIA NEONATE','INITIAT SELECTIVE HEAD/BODY HYPOTHERMIA NEONATE','99184','1','','1','0','','','',0, 1, 0, 0),
(9193,'APPLICATION TOPICAL FLUORIDE VARNISH BY PHS/QHP','APPLICATION TOPICAL FLUORIDE VARNISH BY PHS/QHP','99188','1','','1','0','','','',0, 1, 0, 0),
(9194,'ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH EA HR','ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH EA HR','99190','1','','1','0','','','',0, 1, 0, 0),
(9195,'ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH 45 MI','ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH 45 MI','99191','1','','1','0','','','',0, 1, 0, 0),
(9196,'ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH 30 MI','ASSEMBLY&OPERJ PUMP OXYGENATOR/HEAT EXCH 30 MI','99192','1','','1','0','','','',0, 1, 0, 0),
(9197,'PHLEBOTOMY THERAPEUTIC SEPARATE PROCEDURE','PHLEBOTOMY THERAPEUTIC SEPARATE PROCEDURE','99195','1','','1','0','','','',0, 1, 0, 0),
(9198,'UNLISTED SPECIAL SERVICE PROCEDURE/REPORT','UNLISTED SPECIAL SERVICE PROCEDURE/REPORT','99199','1','','1','0','','','',0, 1, 0, 0),
(9199,'OFFICE OUTPATIENT NEW 10 MINUTES','OFFICE OUTPATIENT NEW 10 MINUTES','99201','1','','1','0','','','',0, 1, 0, 0),
(9200,'OFFICE OUTPATIENT NEW 20 MINUTES','OFFICE OUTPATIENT NEW 20 MINUTES','99202','1','','1','0','','','',0, 1, 0, 0),
(9201,'OFFICE OUTPATIENT NEW 30 MINUTES','OFFICE OUTPATIENT NEW 30 MINUTES','99203','1','','1','0','','','',0, 1, 0, 0),
(9202,'OFFICE OUTPATIENT NEW 45 MINUTES','OFFICE OUTPATIENT NEW 45 MINUTES','99204','1','','1','0','','','',0, 1, 0, 0),
(9203,'OFFICE OUTPATIENT NEW 60 MINUTES','OFFICE OUTPATIENT NEW 60 MINUTES','99205','1','','1','0','','','',0, 1, 0, 0),
(9204,'OFFICE OUTPATIENT VISIT 5 MINUTES','OFFICE OUTPATIENT VISIT 5 MINUTES','99211','1','','1','0','','','',0, 1, 0, 0),
(9205,'OFFICE OUTPATIENT VISIT 10 MINUTES','OFFICE OUTPATIENT VISIT 10 MINUTES','99212','1','','1','0','','','',0, 1, 0, 0),
(9206,'OFFICE OUTPATIENT VISIT 15 MINUTES','OFFICE OUTPATIENT VISIT 15 MINUTES','99213','1','','1','0','','','',0, 1, 0, 0),
(9207,'OFFICE OUTPATIENT VISIT 25 MINUTES','OFFICE OUTPATIENT VISIT 25 MINUTES','99214','1','','1','0','','','',0, 1, 0, 0),
(9208,'OFFICE OUTPATIENT VISIT 40 MINUTES','OFFICE OUTPATIENT VISIT 40 MINUTES','99215','1','','1','0','','','',0, 1, 0, 0),
(9209,'OBSERVATION CARE DISCHARGE MANAGEMENT','OBSERVATION CARE DISCHARGE MANAGEMENT','99217','1','','1','0','','','',0, 1, 0, 0),
(9210,'INITIAL OBSERVATION CARE/DAY 30 MINUTES','INITIAL OBSERVATION CARE/DAY 30 MINUTES','99218','1','','1','0','','','',0, 1, 0, 0),
(9211,'INITIAL OBSERVATION CARE/DAY 50 MINUTES','INITIAL OBSERVATION CARE/DAY 50 MINUTES','99219','1','','1','0','','','',0, 1, 0, 0),
(9212,'INITIAL OBSERVATION CARE/DAY 70 MINUTES','INITIAL OBSERVATION CARE/DAY 70 MINUTES','99220','1','','1','0','','','',0, 1, 0, 0),
(9213,'INITIAL HOSPITAL CARE/DAY 30 MINUTES','INITIAL HOSPITAL CARE/DAY 30 MINUTES','99221','1','','1','0','','','',0, 1, 0, 0),
(9214,'INITIAL HOSPITAL CARE/DAY 50 MINUTES','INITIAL HOSPITAL CARE/DAY 50 MINUTES','99222','1','','1','0','','','',0, 1, 0, 0),
(9215,'INITIAL HOSPITAL CARE/DAY 70 MINUTES','INITIAL HOSPITAL CARE/DAY 70 MINUTES','99223','1','','1','0','','','',0, 1, 0, 0),
(9216,'SBSQ OBSERVATION CARE/DAY 15 MINUTES','SBSQ OBSERVATION CARE/DAY 15 MINUTES','99224','1','','1','0','','','',0, 1, 0, 0),
(9217,'SBSQ OBSERVATION CARE/DAY 25 MINUTES','SBSQ OBSERVATION CARE/DAY 25 MINUTES','99225','1','','1','0','','','',0, 1, 0, 0),
(9218,'SBSQ OBSERVATION CARE/DAY 35 MINUTES','SBSQ OBSERVATION CARE/DAY 35 MINUTES','99226','1','','1','0','','','',0, 1, 0, 0),
(9219,'SBSQ HOSPITAL CARE/DAY 15 MINUTES','SBSQ HOSPITAL CARE/DAY 15 MINUTES','99231','1','','1','0','','','',0, 1, 0, 0),
(9220,'SBSQ HOSPITAL CARE/DAY 25 MINUTES','SBSQ HOSPITAL CARE/DAY 25 MINUTES','99232','1','','1','0','','','',0, 1, 0, 0),
(9221,'SBSQ HOSPITAL CARE/DAY 35 MINUTES','SBSQ HOSPITAL CARE/DAY 35 MINUTES','99233','1','','1','0','','','',0, 1, 0, 0),
(9222,'OBSERVATION/INPATIENT HOSPITAL CARE 40 MINUTES','OBSERVATION/INPATIENT HOSPITAL CARE 40 MINUTES','99234','1','','1','0','','','',0, 1, 0, 0),
(9223,'OBSERVATION/INPATIENT HOSPITAL CARE 50 MINUTES','OBSERVATION/INPATIENT HOSPITAL CARE 50 MINUTES','99235','1','','1','0','','','',0, 1, 0, 0),
(9224,'OBSERVATION/INPATIENT HOSPITAL CARE 55 MINUTES','OBSERVATION/INPATIENT HOSPITAL CARE 55 MINUTES','99236','1','','1','0','','','',0, 1, 0, 0),
(9225,'HOSPITAL DISCHARGE DAY MANAGEMENT 30 MIN/<','HOSPITAL DISCHARGE DAY MANAGEMENT 30 MIN/<','99238','1','','1','0','','','',0, 1, 0, 0),
(9226,'HOSPITAL DISCHARGE DAY MANAGEMENT > 30 MIN','HOSPITAL DISCHARGE DAY MANAGEMENT > 30 MIN','99239','1','','1','0','','','',0, 1, 0, 0),
(9227,'OFFICE CONSULTATION NEW/ESTAB PATIENT 15 MIN','OFFICE CONSULTATION NEW/ESTAB PATIENT 15 MIN','99241','1','','1','0','','','',0, 1, 0, 0),
(9228,'OFFICE CONSULTATION NEW/ESTAB PATIENT 30 MIN','OFFICE CONSULTATION NEW/ESTAB PATIENT 30 MIN','99242','1','','1','0','','','',0, 1, 0, 0),
(9229,'OFFICE CONSULTATION NEW/ESTAB PATIENT 40 MIN','OFFICE CONSULTATION NEW/ESTAB PATIENT 40 MIN','99243','1','','1','0','','','',0, 1, 0, 0),
(9230,'OFFICE CONSULTATION NEW/ESTAB PATIENT 60 MIN','OFFICE CONSULTATION NEW/ESTAB PATIENT 60 MIN','99244','1','','1','0','','','',0, 1, 0, 0),
(9231,'OFFICE CONSULTATION NEW/ESTAB PATIENT 80 MIN','OFFICE CONSULTATION NEW/ESTAB PATIENT 80 MIN','99245','1','','1','0','','','',0, 1, 0, 0),
(9232,'INITIAL INPATIENT CONSULT NEW/ESTAB PT 20 MIN','INITIAL INPATIENT CONSULT NEW/ESTAB PT 20 MIN','99251','1','','1','0','','','',0, 1, 0, 0),
(9233,'INITIAL INPATIENT CONSULT NEW/ESTAB PT 40 MIN','INITIAL INPATIENT CONSULT NEW/ESTAB PT 40 MIN','99252','1','','1','0','','','',0, 1, 0, 0),
(9234,'INITIAL INPATIENT CONSULT NEW/ESTAB PT 55 MIN','INITIAL INPATIENT CONSULT NEW/ESTAB PT 55 MIN','99253','1','','1','0','','','',0, 1, 0, 0),
(9235,'INITIAL INPATIENT CONSULT NEW/ESTAB PT 80 MIN','INITIAL INPATIENT CONSULT NEW/ESTAB PT 80 MIN','99254','1','','1','0','','','',0, 1, 0, 0),
(9236,'INITIAL INPATIENT CONSULT NEW/ESTAB PT 110 MIN','INITIAL INPATIENT CONSULT NEW/ESTAB PT 110 MIN','99255','1','','1','0','','','',0, 1, 0, 0),
(9237,'EMERGENCY DEPARTMENT VISIT LIMITED/MINOR PROB','EMERGENCY DEPARTMENT VISIT LIMITED/MINOR PROB','99281','1','','1','0','','','',0, 1, 0, 0),
(9238,'EMERGENCY DEPARTMENT VISIT LOW/MODER SEVERITY','EMERGENCY DEPARTMENT VISIT LOW/MODER SEVERITY','99282','1','','1','0','','','',0, 1, 0, 0),
(9239,'EMERGENCY DEPARTMENT VISIT MODERATE SEVERITY','EMERGENCY DEPARTMENT VISIT MODERATE SEVERITY','99283','1','','1','0','','','',0, 1, 0, 0),
(9240,'EMERGENCY DEPARTMENT VISIT HIGH/URGENT SEVERITY','EMERGENCY DEPARTMENT VISIT HIGH/URGENT SEVERITY','99284','1','','1','0','','','',0, 1, 0, 0),
(9241,'EMERGENCY DEPT VISIT HIGH SEVERITY&THREAT FUNCJ','EMERGENCY DEPT VISIT HIGH SEVERITY&THREAT FUNCJ','99285','1','','1','0','','','',0, 1, 0, 0),
(9242,'PHYS/QHP DIRECTION EMERGENCY MEDICAL SYSTEMS','PHYS/QHP DIRECTION EMERGENCY MEDICAL SYSTEMS','99288','1','','1','0','','','',0, 1, 0, 0),
(9243,'CRITICAL CARE ILL/INJURED PATIENT INIT 30-74 MIN','CRITICAL CARE ILL/INJURED PATIENT INIT 30-74 MIN','99291','1','','1','0','','','',0, 1, 0, 0),
(9244,'CRITICAL CARE ILL/INJURED PATIENT ADDL 30 MIN','CRITICAL CARE ILL/INJURED PATIENT ADDL 30 MIN','99292','1','','1','0','','','',0, 1, 0, 0),
(9245,'INITIAL NURSING FACILITY CARE/DAY 25 MINUTES','INITIAL NURSING FACILITY CARE/DAY 25 MINUTES','99304','1','','1','0','','','',0, 1, 0, 0),
(9246,'INITIAL NURSING FACILITY CARE/DAY 35 MINUTES','INITIAL NURSING FACILITY CARE/DAY 35 MINUTES','99305','1','','1','0','','','',0, 1, 0, 0),
(9247,'INITIAL NURSING FACILITY CARE/DAY 45 MINUTES','INITIAL NURSING FACILITY CARE/DAY 45 MINUTES','99306','1','','1','0','','','',0, 1, 0, 0),
(9248,'SBSQ NURSING FACILITY CARE/DAY E/M STABLE 10 MIN','SBSQ NURSING FACILITY CARE/DAY E/M STABLE 10 MIN','99307','1','','1','0','','','',0, 1, 0, 0),
(9249,'SBSQ NURSING FACIL CARE/DAY MINOR COMPLJ 15 MIN','SBSQ NURSING FACIL CARE/DAY MINOR COMPLJ 15 MIN','99308','1','','1','0','','','',0, 1, 0, 0),
(9250,'SBSQ NURSING FACIL CARE/DAY NEW PROBLEM 25 MIN','SBSQ NURSING FACIL CARE/DAY NEW PROBLEM 25 MIN','99309','1','','1','0','','','',0, 1, 0, 0),
(9251,'SBSQ NURS FACIL CARE/DAY UNSTABL/NEW PROB 35 MIN','SBSQ NURS FACIL CARE/DAY UNSTABL/NEW PROB 35 MIN','99310','1','','1','0','','','',0, 1, 0, 0),
(9252,'NURSING FACILITY DISCHARGE MANAGEMENT 30 MINUTES','NURSING FACILITY DISCHARGE MANAGEMENT 30 MINUTES','99315','1','','1','0','','','',0, 1, 0, 0),
(9253,'NURSING FACILITY DISCHARGE MANAGEMENT 30 MINUTES','NURSING FACILITY DISCHARGE MANAGEMENT 30 MINUTES','99316','1','','1','0','','','',0, 1, 0, 0),
(9254,'E/M ANNUAL NURSING FACILITY ASSESS STABLE 30 MIN','E/M ANNUAL NURSING FACILITY ASSESS STABLE 30 MIN','99318','1','','1','0','','','',0, 1, 0, 0),
(9255,'DOMICIL/REST HOME NEW PT VISIT LOW SEVER 20 MIN','DOMICIL/REST HOME NEW PT VISIT LOW SEVER 20 MIN','99324','1','','1','0','','','',0, 1, 0, 0),
(9256,'DOMICIL/REST HOME NEW PT VISIT MOD SEVER 30 MIN','DOMICIL/REST HOME NEW PT VISIT MOD SEVER 30 MIN','99325','1','','1','0','','','',0, 1, 0, 0),
(9257,'DOMICIL/REST HOME NEW PT HI-MOD SEVER 45 MINUTES','DOMICIL/REST HOME NEW PT HI-MOD SEVER 45 MINUTES','99326','1','','1','0','','','',0, 1, 0, 0),
(9258,'DOMICIL/REST HOME NEW PT VISIT HI SEVER 60 MIN','DOMICIL/REST HOME NEW PT VISIT HI SEVER 60 MIN','99327','1','','1','0','','','',0, 1, 0, 0),
(9259,'DOM/R-HOME E/M NEW PT SIGNIF NEW PROB 75 MINUTES','DOM/R-HOME E/M NEW PT SIGNIF NEW PROB 75 MINUTES','99328','1','','1','0','','','',0, 1, 0, 0),
(9260,'DOM/R-HOME E/M EST PT SELF-LMTD/MINOR 15 MINUTES','DOM/R-HOME E/M EST PT SELF-LMTD/MINOR 15 MINUTES','99334','1','','1','0','','','',0, 1, 0, 0),
(9261,'DOM/R-HOME E/M EST PT LW MOD SEVERITY 25 MINUTES','DOM/R-HOME E/M EST PT LW MOD SEVERITY 25 MINUTES','99335','1','','1','0','','','',0, 1, 0, 0),
(9262,'DOM/R-HOME E/M EST PT MOD HI SEVERITY 40 MINUTES','DOM/R-HOME E/M EST PT MOD HI SEVERITY 40 MINUTES','99336','1','','1','0','','','',0, 1, 0, 0),
(9263,'DOM/R-HOME E/M EST PT SIGNIF NEW PROB 60 MINUTES','DOM/R-HOME E/M EST PT SIGNIF NEW PROB 60 MINUTES','99337','1','','1','0','','','',0, 1, 0, 0),
(9264,'INDIV PHYS SUPVJ HOME/DOM/R-HOME MO 15-29 MIN','INDIV PHYS SUPVJ HOME/DOM/R-HOME MO 15-29 MIN','99339','1','','1','0','','','',0, 1, 0, 0),
(9265,'INDIV PHYS SUPVJ HOME/DOM/R-HOME MO 30 MIN/>','INDIV PHYS SUPVJ HOME/DOM/R-HOME MO 30 MIN/>','99340','1','','1','0','','','',0, 1, 0, 0),
(9266,'HOME VISIT NEW PATIENT LOW SEVERITY 20 MINUTES','HOME VISIT NEW PATIENT LOW SEVERITY 20 MINUTES','99341','1','','1','0','','','',0, 1, 0, 0),
(9267,'HOME VISIT NEW PATIENT MOD SEVERITY 30 MINUTES','HOME VISIT NEW PATIENT MOD SEVERITY 30 MINUTES','99342','1','','1','0','','','',0, 1, 0, 0),
(9268,'HOME VST NEW PATIENT MOD-HI SEVERITY 45 MINUTES','HOME VST NEW PATIENT MOD-HI SEVERITY 45 MINUTES','99343','1','','1','0','','','',0, 1, 0, 0),
(9269,'HOME VISIT NEW PATIENT HI SEVERITY 60 MINUTES','HOME VISIT NEW PATIENT HI SEVERITY 60 MINUTES','99344','1','','1','0','','','',0, 1, 0, 0),
(9270,'HOME VISIT NEW PT UNSTABL/SIGNIF NEW PROB 75 MIN','HOME VISIT NEW PT UNSTABL/SIGNIF NEW PROB 75 MIN','99345','1','','1','0','','','',0, 1, 0, 0),
(9271,'HOME VISIT EST PT SELF LIMITED/MINOR 15 MINUTES','HOME VISIT EST PT SELF LIMITED/MINOR 15 MINUTES','99347','1','','1','0','','','',0, 1, 0, 0),
(9272,'HOME VISIT EST PT LOW-MOD SEVERITY 25 MINUTES','HOME VISIT EST PT LOW-MOD SEVERITY 25 MINUTES','99348','1','','1','0','','','',0, 1, 0, 0),
(9273,'HOME VISIT EST PT MOD-HI SEVERITY 40 MINUTES','HOME VISIT EST PT MOD-HI SEVERITY 40 MINUTES','99349','1','','1','0','','','',0, 1, 0, 0),
(9274,'HOME VST EST PT UNSTABLE/SIGNIF NEW PROB 60 MINS','HOME VST EST PT UNSTABLE/SIGNIF NEW PROB 60 MINS','99350','1','','1','0','','','',0, 1, 0, 0),
(9275,'PROLNG E&M/PSYCTX SVC OFFICE O/P DIR CON 1ST HR','PROLNG E&M/PSYCTX SVC OFFICE O/P DIR CON 1ST HR','99354','1','','1','0','','','',0, 1, 0, 0),
(9276,'PROLNG E&M/PSYCTX SVC OFFICE O/P DIR CON ADDL 30','PROLNG E&M/PSYCTX SVC OFFICE O/P DIR CON ADDL 30','99355','1','','1','0','','','',0, 1, 0, 0),
(9277,'PROLONGED SERVICE I/P REQ UNIT/FLOOR TIME 1ST HR','PROLONGED SERVICE I/P REQ UNIT/FLOOR TIME 1ST HR','99356','1','','1','0','','','',0, 1, 0, 0),
(9278,'PROLONGED SVC I/P REQ UNIT/FLOOR TIME EA 30 MIN','PROLONGED SVC I/P REQ UNIT/FLOOR TIME EA 30 MIN','99357','1','','1','0','','','',0, 1, 0, 0),
(9279,'PROLNG E/M SVC BEFORE&/AFTER DIR PT CARE 1ST HR','PROLNG E/M SVC BEFORE&/AFTER DIR PT CARE 1ST HR','99358','1','','1','0','','','',0, 1, 0, 0),
(9280,'PROLNG E/M BEFORE&/AFTER DIR CARE EA 30 MINUTES','PROLNG E/M BEFORE&/AFTER DIR CARE EA 30 MINUTES','99359','1','','1','0','','','',0, 1, 0, 0),
(9281,'PHYS STANDBY SVC PROLNG PHYS ATTN EA 30 MINUTES','PHYS STANDBY SVC PROLNG PHYS ATTN EA 30 MINUTES','99360','1','','1','0','','','',0, 1, 0, 0),
(9282,'ANTICOAGULANT MGMT OUTPATIENT INIT 90 DAYS','ANTICOAGULANT MGMT OUTPATIENT INIT 90 DAYS','99363','1','','1','0','','','',0, 1, 0, 0),
(9283,'ANTICOAGULANT MGMT OUTPATIENT EA SBSQ 90 DAYS','ANTICOAGULANT MGMT OUTPATIENT EA SBSQ 90 DAYS','99364','1','','1','0','','','',0, 1, 0, 0),
(9284,'TEAM CONFERENCE FACE-TO-FACE NONPHYSICIAN','TEAM CONFERENCE FACE-TO-FACE NONPHYSICIAN','99366','1','','1','0','','','',0, 1, 0, 0),
(9285,'TEAM CONFERENCE NON-FACE-TO-FACE PHYSICIAN','TEAM CONFERENCE NON-FACE-TO-FACE PHYSICIAN','99367','1','','1','0','','','',0, 1, 0, 0),
(9286,'TEAM CONFERENCE NON-FACE-TO-FACE NONPHYSICIAN','TEAM CONFERENCE NON-FACE-TO-FACE NONPHYSICIAN','99368','1','','1','0','','','',0, 1, 0, 0),
(9287,'SUPVJ PT HOME HEALTH AGENCY MO 15-29 MINUTES','SUPVJ PT HOME HEALTH AGENCY MO 15-29 MINUTES','99374','1','','1','0','','','',0, 1, 0, 0),
(9288,'SUPERVISION PT HOME HEALTH AGENCY MONTH 30 MIN/>','SUPERVISION PT HOME HEALTH AGENCY MONTH 30 MIN/>','99375','1','','1','0','','','',0, 1, 0, 0),
(9289,'SUPERVISION HOSPICE PATIENT/MONTH 15-29 MIN','SUPERVISION HOSPICE PATIENT/MONTH 15-29 MIN','99377','1','','1','0','','','',0, 1, 0, 0),
(9290,'SUPERVISION HOSPICE PATIENT/MONTH 30 MINUTES/>','SUPERVISION HOSPICE PATIENT/MONTH 30 MINUTES/>','99378','1','','1','0','','','',0, 1, 0, 0),
(9291,'SUPERVISION NURS FACILITY PATIENT MO 15-29 MIN','SUPERVISION NURS FACILITY PATIENT MO 15-29 MIN','99379','1','','1','0','','','',0, 1, 0, 0),
(9292,'SUPERVISION NURS FACILITY PATIENT MONTH 30 MIN/>','SUPERVISION NURS FACILITY PATIENT MONTH 30 MIN/>','99380','1','','1','0','','','',0, 1, 0, 0),
(9293,'INITIAL PREVENTIVE MEDICINE NEW PATIENT <1YEAR','INITIAL PREVENTIVE MEDICINE NEW PATIENT <1YEAR','99381','1','','1','0','','','',0, 1, 0, 0),
(9294,'INITIAL PREVENTIVE MEDICINE NEW PT AGE 1-4 YRS','INITIAL PREVENTIVE MEDICINE NEW PT AGE 1-4 YRS','99382','1','','1','0','','','',0, 1, 0, 0),
(9295,'INITIAL PREVENTIVE MEDICINE NEW PT AGE 5-11 YRS','INITIAL PREVENTIVE MEDICINE NEW PT AGE 5-11 YRS','99383','1','','1','0','','','',0, 1, 0, 0),
(9296,'INITIAL PREVENTIVE MEDICINE NEW PT AGE 12-17 YR','INITIAL PREVENTIVE MEDICINE NEW PT AGE 12-17 YR','99384','1','','1','0','','','',0, 1, 0, 0),
(9297,'INITIAL PREVENTIVE MEDICINE NEW PT AGE 18-39YRS','INITIAL PREVENTIVE MEDICINE NEW PT AGE 18-39YRS','99385','1','','1','0','','','',0, 1, 0, 0),
(9298,'INITIAL PREVENTIVE MEDICINE NEW PATIENT 40-64YRS','INITIAL PREVENTIVE MEDICINE NEW PATIENT 40-64YRS','99386','1','','1','0','','','',0, 1, 0, 0),
(9299,'INITIAL PREVENTIVE MEDICINE NEW PATIENT 65YRS&>','INITIAL PREVENTIVE MEDICINE NEW PATIENT 65YRS&>','99387','1','','1','0','','','',0, 1, 0, 0),
(9300,'PERIODIC PREVENTIVE MED ESTABLISHED PATIENT <1Y','PERIODIC PREVENTIVE MED ESTABLISHED PATIENT <1Y','99391','1','','1','0','','','',0, 1, 0, 0),
(9301,'PERIODIC PREVENTIVE MED EST PATIENT 1-4YRS','PERIODIC PREVENTIVE MED EST PATIENT 1-4YRS','99392','1','','1','0','','','',0, 1, 0, 0),
(9302,'PERIODIC PREVENTIVE MED EST PATIENT 5-11YRS','PERIODIC PREVENTIVE MED EST PATIENT 5-11YRS','99393','1','','1','0','','','',0, 1, 0, 0),
(9303,'PERIODIC PREVENTIVE MED EST PATIENT 12-17YRS','PERIODIC PREVENTIVE MED EST PATIENT 12-17YRS','99394','1','','1','0','','','',0, 1, 0, 0),
(9304,'PERIODIC PREVENTIVE MED EST PATIENT 18-39 YRS','PERIODIC PREVENTIVE MED EST PATIENT 18-39 YRS','99395','1','','1','0','','','',0, 1, 0, 0),
(9305,'PERIODIC PREVENTIVE MED EST PATIENT 40-64YRS','PERIODIC PREVENTIVE MED EST PATIENT 40-64YRS','99396','1','','1','0','','','',0, 1, 0, 0),
(9306,'PERIODIC PREVENTIVE MED EST PATIENT 65YRS& OLDER','PERIODIC PREVENTIVE MED EST PATIENT 65YRS& OLDER','99397','1','','1','0','','','',0, 1, 0, 0),
(9307,'PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 15 MIN','PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 15 MIN','99401','1','','1','0','','','',0, 1, 0, 0),
(9308,'PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 30 MIN','PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 30 MIN','99402','1','','1','0','','','',0, 1, 0, 0),
(9309,'PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 45 MIN','PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 45 MIN','99403','1','','1','0','','','',0, 1, 0, 0),
(9310,'PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 60 MIN','PREVENT MED COUNSEL&/RISK FACTOR REDJ SPX 60 MIN','99404','1','','1','0','','','',0, 1, 0, 0),
(9311,'TOBACCO USE CESSATION INTERMEDIATE 3-10 MINUTES','TOBACCO USE CESSATION INTERMEDIATE 3-10 MINUTES','99406','1','','1','0','','','',0, 1, 0, 0),
(9312,'TOBACCO USE CESSATION INTENSIVE >10 MINUTES','TOBACCO USE CESSATION INTENSIVE >10 MINUTES','99407','1','','1','0','','','',0, 1, 0, 0),
(9313,'ALCOHOL/SUBSTANCE SCREEN & INTERVEN 15-30 MIN','ALCOHOL/SUBSTANCE SCREEN & INTERVEN 15-30 MIN','99408','1','','1','0','','','',0, 1, 0, 0),
(9314,'ALCOHOL/SUBSTANCE SCREEN & INTERVENTION >30 MIN','ALCOHOL/SUBSTANCE SCREEN & INTERVENTION >30 MIN','99409','1','','1','0','','','',0, 1, 0, 0),
(9315,'PREV MED COUNSEL & RISK FACTOR REDJ GRP SPX 30 M','PREV MED COUNSEL & RISK FACTOR REDJ GRP SPX 30 M','99411','1','','1','0','','','',0, 1, 0, 0),
(9316,'PREV MED COUNSEL & RISK FACTOR REDJ GRP SPX 60 M','PREV MED COUNSEL & RISK FACTOR REDJ GRP SPX 60 M','99412','1','','1','0','','','',0, 1, 0, 0),
(9317,'PROLNG CLINCL STAFF SVC DURING O/P E/M 1ST HR','PROLNG CLINCL STAFF SVC DURING O/P E/M 1ST HR','99415','1','','1','0','','','',0, 1, 0, 0),
(9318,'PROLNG CLINCL STAFF SVC DURING O/P E/M EA 30 MIN','PROLNG CLINCL STAFF SVC DURING O/P E/M EA 30 MIN','99416','1','','1','0','','','',0, 1, 0, 0),
(9319,'ADMN & INTERPJ HEALTH RISK ASSESSMENT INSTRUMENT','ADMN & INTERPJ HEALTH RISK ASSESSMENT INSTRUMENT','99420','1','','1','0','','','',0, 1, 0, 0),
(9320,'UNLISTED PREVENTIVE MEDICINE SERVICE','UNLISTED PREVENTIVE MEDICINE SERVICE','99429','1','','1','0','','','',0, 1, 0, 0),
(9321,'PHYS/QHP TELEPHONE EVALUATION 5-10 MIN','PHYS/QHP TELEPHONE EVALUATION 5-10 MIN','99441','1','','1','0','','','',0, 1, 0, 0),
(9322,'PHYS/QHP TELEPHONE EVALUATION 11-20 MIN','PHYS/QHP TELEPHONE EVALUATION 11-20 MIN','99442','1','','1','0','','','',0, 1, 0, 0),
(9323,'PHYS/QHP TELEPHONE EVALUATION 21-30 MIN','PHYS/QHP TELEPHONE EVALUATION 21-30 MIN','99443','1','','1','0','','','',0, 1, 0, 0),
(9324,'PHYS/QHP ONLINE EVALUATION & MANAGEMENT SERVICE','PHYS/QHP ONLINE EVALUATION & MANAGEMENT SERVICE','99444','1','','1','0','','','',0, 1, 0, 0),
(9325,'INTERPROF PHONE/INTERNET ASSESS/MANAGE 5-10','INTERPROF PHONE/INTERNET ASSESS/MANAGE 5-10','99446','1','','1','0','','','',0, 1, 0, 0),
(9326,'INTERPROF PHONE/INTERNET ASSESS/MANAGE 11-20','INTERPROF PHONE/INTERNET ASSESS/MANAGE 11-20','99447','1','','1','0','','','',0, 1, 0, 0),
(9327,'INTERPROF PHONE/INTERNET ASSESS/MANAGE 21-30','INTERPROF PHONE/INTERNET ASSESS/MANAGE 21-30','99448','1','','1','0','','','',0, 1, 0, 0),
(9328,'INTERPROF PHONE/INTERNET ASSESS/MANAGE 31/>','INTERPROF PHONE/INTERNET ASSESS/MANAGE 31/>','99449','1','','1','0','','','',0, 1, 0, 0),
(9329,'BASIC LIFE AND/OR DISABILITY EXAMINATION','BASIC LIFE AND/OR DISABILITY EXAMINATION','99450','1','','1','0','','','',0, 1, 0, 0),
(9330,'WORK RELATED/MED DBLT XM TREATING PHYS','WORK RELATED/MED DBLT XM TREATING PHYS','99455','1','','1','0','','','',0, 1, 0, 0),
(9331,'WORK RELATED/MED DBLT XM OTH/THN TREATING PHYS','WORK RELATED/MED DBLT XM OTH/THN TREATING PHYS','99456','1','','1','0','','','',0, 1, 0, 0),
(9332,'1ST HOSP/BIRTHING CENTER CARE PER DAY NML NB','1ST HOSP/BIRTHING CENTER CARE PER DAY NML NB','99460','1','','1','0','','','',0, 1, 0, 0),
(9333,'1ST CARE PR DAY NML NB XCPT HOSP/BIRTHING CENTER','1ST CARE PR DAY NML NB XCPT HOSP/BIRTHING CENTER','99461','1','','1','0','','','',0, 1, 0, 0),
(9334,'SUBQ HOSPITAL CARE PER DAY E/M NORMAL NEWBORN','SUBQ HOSPITAL CARE PER DAY E/M NORMAL NEWBORN','99462','1','','1','0','','','',0, 1, 0, 0),
(9335,'1ST HOSP/BIRTHING CENTER NB ADMIT & DSCHG SM DAT','1ST HOSP/BIRTHING CENTER NB ADMIT & DSCHG SM DAT','99463','1','','1','0','','','',0, 1, 0, 0),
(9336,'ATTN AT DELIVERY 1ST STABILIZATION OF NEWBORN','ATTN AT DELIVERY 1ST STABILIZATION OF NEWBORN','99464','1','','1','0','','','',0, 1, 0, 0),
(9337,'DELIVERY/BIRTHING ROOM RESUSCITATION','DELIVERY/BIRTHING ROOM RESUSCITATION','99465','1','','1','0','','','',0, 1, 0, 0),
(9338,'CRITICAL CARE INTERFACILITY TRANSPORT 30-74 MIN','CRITICAL CARE INTERFACILITY TRANSPORT 30-74 MIN','99466','1','','1','0','','','',0, 1, 0, 0),
(9339,'CRITICAL CARE INTERFACILITY TRANSPORT EA 30 MIN','CRITICAL CARE INTERFACILITY TRANSPORT EA 30 MIN','99467','1','','1','0','','','',0, 1, 0, 0),
(9340,'1ST INPATIENT CRITICAL CARE PR DAY AGE 28 DAYS/<','1ST INPATIENT CRITICAL CARE PR DAY AGE 28 DAYS/<','99468','1','','1','0','','','',0, 1, 0, 0),
(9341,'SUBQ I/P CRITICAL CARE PR DAY AGE 28 DAYS/<','SUBQ I/P CRITICAL CARE PR DAY AGE 28 DAYS/<','99469','1','','1','0','','','',0, 1, 0, 0),
(9342,'INITIAL PED CRITICAL CARE 29 DAYS THRU 24 MONTHS','INITIAL PED CRITICAL CARE 29 DAYS THRU 24 MONTHS','99471','1','','1','0','','','',0, 1, 0, 0),
(9343,'SUBSQ PED CRITICAL CARE 29 DAYS THRU 24 MO','SUBSQ PED CRITICAL CARE 29 DAYS THRU 24 MO','99472','1','','1','0','','','',0, 1, 0, 0),
(9344,'INITIAL PED CRITICAL CARE 2 THRU 5 YEARS','INITIAL PED CRITICAL CARE 2 THRU 5 YEARS','99475','1','','1','0','','','',0, 1, 0, 0),
(9345,'SUBSEQUENT PED CRITICAL CARE 2 THRU 5 YEARS','SUBSEQUENT PED CRITICAL CARE 2 THRU 5 YEARS','99476','1','','1','0','','','',0, 1, 0, 0),
(9346,'INITIAL HOSP NEONATE 28 D/< NOT CRITICALLY ILL','INITIAL HOSP NEONATE 28 D/< NOT CRITICALLY ILL','99477','1','','1','0','','','',0, 1, 0, 0),
(9347,'SUBSEQUENT INTENSIVE CARE INFANT < 1500 GRAMS','SUBSEQUENT INTENSIVE CARE INFANT < 1500 GRAMS','99478','1','','1','0','','','',0, 1, 0, 0),
(9348,'SUBSEQUENT INTENSIVE CARE INFANT 1500-2500 GRAMS','SUBSEQUENT INTENSIVE CARE INFANT 1500-2500 GRAMS','99479','1','','1','0','','','',0, 1, 0, 0),
(9349,'SUBSEQUENT INTENSIVE CARE INFANT 2501-5000 GRAMS','SUBSEQUENT INTENSIVE CARE INFANT 2501-5000 GRAMS','99480','1','','1','0','','','',0, 1, 0, 0),
(9350,'SUPERVISION INTERFACILITY TRANSPORT INIT 30 MIN','SUPERVISION INTERFACILITY TRANSPORT INIT 30 MIN','99485','1','','1','0','','','',0, 1, 0, 0),
(9351,'SUPERVISION INTERFACILITY TRANSPORT ADDL 30 MIN','SUPERVISION INTERFACILITY TRANSPORT ADDL 30 MIN','99486','1','','1','0','','','',0, 1, 0, 0),
(9352,'CMPLX CHRON CARE MGMT W/O PT VST 1ST HR PER MO','CMPLX CHRON CARE MGMT W/O PT VST 1ST HR PER MO','99487','1','','1','0','','','',0, 1, 0, 0),
(9353,'CMPLX CHRON CARE MGMT EA ADDL 30 MIN PER MONTH','CMPLX CHRON CARE MGMT EA ADDL 30 MIN PER MONTH','99489','1','','1','0','','','',0, 1, 0, 0),
(9354,'CHRON CARE MANAGEMENT SRVC 20 MIN PER MONTH','CHRON CARE MANAGEMENT SRVC 20 MIN PER MONTH','99490','1','','1','0','','','',0, 1, 0, 0),
(9355,'TRANSITIONAL CARE MANAGE SRVC 14 DAY DISCHARGE','TRANSITIONAL CARE MANAGE SRVC 14 DAY DISCHARGE','99495','1','','1','0','','','',0, 1, 0, 0),
(9356,'TRANSITIONAL CARE MANAGE SRVC 7 DAY DISCHARGE','TRANSITIONAL CARE MANAGE SRVC 7 DAY DISCHARGE','99496','1','','1','0','','','',0, 1, 0, 0),
(9357,'ADVANCE CARE PLANNING FIRST 30 MINS','ADVANCE CARE PLANNING FIRST 30 MINS','99497','1','','1','0','','','',0, 1, 0, 0),
(9358,'ADVANCE CARE PLANNING EA ADDL 30 MINS','ADVANCE CARE PLANNING EA ADDL 30 MINS','99498','1','','1','0','','','',0, 1, 0, 0),
(9359,'UNLISTED EVALUATION AND MANAGEMENT SERVICE','UNLISTED EVALUATION AND MANAGEMENT SERVICE','99499','1','','1','0','','','',0, 1, 0, 0),
(9360,'HOME VISIT PRENATAL MONITORING & ASSESSMENT','HOME VISIT PRENATAL MONITORING & ASSESSMENT','99500','1','','1','0','','','',0, 1, 0, 0),
(9361,'HOME VISIT POSTNATAL ASSMT&F-UP CARE','HOME VISIT POSTNATAL ASSMT&F-UP CARE','99501','1','','1','0','','','',0, 1, 0, 0),
(9362,'HOME VISIT NEWBORN CARE & ASSESSMENT','HOME VISIT NEWBORN CARE & ASSESSMENT','99502','1','','1','0','','','',0, 1, 0, 0),
(9363,'HOME VISIT RESPIRATORY THERAPY CARE','HOME VISIT RESPIRATORY THERAPY CARE','99503','1','','1','0','','','',0, 1, 0, 0),
(9364,'HOME VISIT MECHANICAL VENTILATION CARE','HOME VISIT MECHANICAL VENTILATION CARE','99504','1','','1','0','','','',0, 1, 0, 0),
(9365,'HOME VISIT STOMA CARE&MAINT CLST&CSTOST','HOME VISIT STOMA CARE&MAINT CLST&CSTOST','99505','1','','1','0','','','',0, 1, 0, 0),
(9366,'HOME VISIT INTRAMUSCULAR INJECTIONS','HOME VISIT INTRAMUSCULAR INJECTIONS','99506','1','','1','0','','','',0, 1, 0, 0),
(9367,'HOME VISIT CARE&MAINT CATH','HOME VISIT CARE&MAINT CATH','99507','1','','1','0','','','',0, 1, 0, 0),
(9368,'HOME VISIT ASSISTANCE DAILY LIV&PRSONAL CARE','HOME VISIT ASSISTANCE DAILY LIV&PRSONAL CARE','99509','1','','1','0','','','',0, 1, 0, 0),
(9369,'HOME VISIT INDIV FAM/MARRIAGE COUNSELING','HOME VISIT INDIV FAM/MARRIAGE COUNSELING','99510','1','','1','0','','','',0, 1, 0, 0),
(9370,'HOME VISIT FECAL IMPACTION MGMT&ENEMA ADMN','HOME VISIT FECAL IMPACTION MGMT&ENEMA ADMN','99511','1','','1','0','','','',0, 1, 0, 0),
(9371,'HOME VISIT HEMODIALYSIS','HOME VISIT HEMODIALYSIS','99512','1','','1','0','','','',0, 1, 0, 0),
(9372,'UNLISTED HOME VISIT SERVICE/PROCEDURE','UNLISTED HOME VISIT SERVICE/PROCEDURE','99600','1','','1','0','','','',0, 1, 0, 0),
(9373,'HOME NFS/SPECTY DRUG ADMN PR VST </2 HR','HOME NFS/SPECTY DRUG ADMN PR VST </2 HR','99601','1','','1','0','','','',0, 1, 0, 0),
(9374,'HOME NFS/SPECTY DRUG ADMN PR VST </2 HR EA HR','HOME NFS/SPECTY DRUG ADMN PR VST </2 HR EA HR','99602','1','','1','0','','','',0, 1, 0, 0),
(9375,'MEDICATION THERAPY INITIAL 15 MIN NEW PATIENT','MEDICATION THERAPY INITIAL 15 MIN NEW PATIENT','99605','1','','1','0','','','',0, 1, 0, 0),
(9376,'MEDICATION THERAPY INITIAL 15 MIN ESTABLISHED PT','MEDICATION THERAPY INITIAL 15 MIN ESTABLISHED PT','99606','1','','1','0','','','',0, 1, 0, 0),
(9377,'MEDICATION THERAPY EACH ADDITIONAL 15 MIN','MEDICATION THERAPY EACH ADDITIONAL 15 MIN','99607','1','','1','0','','','',0, 1, 0, 0),
(9378,'HRT FAILURE ASSESSED','HRT FAILURE ASSESSED','0001F','104','','1','0','','','',0, 1, 0, 0),
(9379,'OSTEOARTHRITIS COMPOSITE','OSTEOARTHRITIS COMPOSITE','0005F','104','','1','0','','','',0, 1, 0, 0),
(9380,'COMMUNITY-ACQUIRED BACTERIAL PNEUMONIA ASSMT','COMMUNITY-ACQUIRED BACTERIAL PNEUMONIA ASSMT','0012F','104','','1','0','','','',0, 1, 0, 0),
(9381,'COMP PREOP ASSESS CATARACT SURG W/IOL PLACEMNT','COMP PREOP ASSESS CATARACT SURG W/IOL PLACEMNT','0014F','104','','1','0','','','',0, 1, 0, 0),
(9382,'MELANOMA FOLLOW UP COMPLETED','MELANOMA FOLLOW UP COMPLETED','0015F','104','','1','0','','','',0, 1, 0, 0),
(9383,'INITIAL PRENATAL CARE VISIT','INITIAL PRENATAL CARE VISIT','0500F','104','','1','0','','','',0, 1, 0, 0),
(9384,'PRENATAL FLOW SHEET','PRENATAL FLOW SHEET','0501F','104','','1','0','','','',0, 1, 0, 0),
(9385,'SUBSEQUENT PRENATAL CARE VISIT','SUBSEQUENT PRENATAL CARE VISIT','0502F','104','','1','0','','','',0, 1, 0, 0),
(9386,'POSTPARTUM CARE VISIT','POSTPARTUM CARE VISIT','0503F','104','','1','0','','','',0, 1, 0, 0),
(9387,'HEMODIALYSIS PLAN OF CARE DOCUMENTED','HEMODIALYSIS PLAN OF CARE DOCUMENTED','0505F','104','','1','0','','','',0, 1, 0, 0),
(9388,'PERITONEAL DIALYSIS PLAN DOCUMENTED','PERITONEAL DIALYSIS PLAN DOCUMENTED','0507F','104','','1','0','','','',0, 1, 0, 0),
(9389,'URINARY INCONTINENCE PLAN OF CARE DOCUMENTED','URINARY INCONTINENCE PLAN OF CARE DOCUMENTED','0509F','104','','1','0','','','',0, 1, 0, 0),
(9390,'ELEVATED BLOOD PRESSURE PLAN OF CARE DOCUMENTED','ELEVATED BLOOD PRESSURE PLAN OF CARE DOCUMENTED','0513F','104','','1','0','','','',0, 1, 0, 0),
(9391,'PLAN/CARE INCRSD HGB LVL DOCD PT ON ESA THXPY','PLAN/CARE INCRSD HGB LVL DOCD PT ON ESA THXPY','0514F','104','','1','0','','','',0, 1, 0, 0),
(9392,'ANEMIA PLAN OF CARE DOCUMENTED','ANEMIA PLAN OF CARE DOCUMENTED','0516F','104','','1','0','','','',0, 1, 0, 0),
(9393,'GLAUCOMA PLAN OF CARE DOCUMENTED','GLAUCOMA PLAN OF CARE DOCUMENTED','0517F','104','','1','0','','','',0, 1, 0, 0),
(9394,'FALLS PLAN OF CARE DOCUMENTED','FALLS PLAN OF CARE DOCUMENTED','0518F','104','','1','0','','','',0, 1, 0, 0),
(9395,'PLANNED CHEMO REGIMEN DOCD PRIOR START NEW TX','PLANNED CHEMO REGIMEN DOCD PRIOR START NEW TX','0519F','104','','1','0','','','',0, 1, 0, 0),
(9396,'RAD DOSE LIMTS EST PRIOR3D RAD FOR MIN 2 TIS/ORG','RAD DOSE LIMTS EST PRIOR3D RAD FOR MIN 2 TIS/ORG','0520F','104','','1','0','','','',0, 1, 0, 0),
(9397,'PLAN OF CARE TO ADDRESS PAIN DOCUMENTED','PLAN OF CARE TO ADDRESS PAIN DOCUMENTED','0521F','104','','1','0','','','',0, 1, 0, 0),
(9398,'INITIAL VISIT FOR EPISODE','INITIAL VISIT FOR EPISODE','0525F','104','','1','0','','','',0, 1, 0, 0),
(9399,'SUBSEQUENT VISIT FOR EPISODE','SUBSEQUENT VISIT FOR EPISODE','0526F','104','','1','0','','','',0, 1, 0, 0),
(9400,'RCMND FLLW-UP 2ND CLNSCPY 10/> YRS DOCD RPRT','RCMND FLLW-UP 2ND CLNSCPY 10/> YRS DOCD RPRT','0528F','104','','1','0','','','',0, 1, 0, 0),
(9401,'INTRVL 3/> YRS PTS LAST COLONOSCOPY DOCD','INTRVL 3/> YRS PTS LAST COLONOSCOPY DOCD','0529F','104','','1','0','','','',0, 1, 0, 0),
(9402,'DYSPNEA MANAGEMENT PLAN DOCUMENTED','DYSPNEA MANAGEMENT PLAN DOCUMENTED','0535F','104','','1','0','','','',0, 1, 0, 0),
(9403,'GLUCORTICOID MANAGEMENT PLAN DOCUMENTED','GLUCORTICOID MANAGEMENT PLAN DOCUMENTED','0540F','104','','1','0','','','',0, 1, 0, 0),
(9404,'PLAN FOR FOLLOW-UP CARE FOR MDD DOCD','PLAN FOR FOLLOW-UP CARE FOR MDD DOCD','0545F','104','','1','0','','','',0, 1, 0, 0),
(9405,'CYTOPATH REPORT ON NONGYN SPECIMEN 2 WKNG DAYS','CYTOPATH REPORT ON NONGYN SPECIMEN 2 WKNG DAYS','0550F','104','','1','0','','','',0, 1, 0, 0),
(9406,'CYTOPATH REPORT NONGYN SPCMN DOCD NON-ROUTINE','CYTOPATH REPORT NONGYN SPCMN DOCD NON-ROUTINE','0551F','104','','1','0','','','',0, 1, 0, 0),
(9407,'SYMPTOM MANAGEMENT PLAN OF CARE DOCUMENTED','SYMPTOM MANAGEMENT PLAN OF CARE DOCUMENTED','0555F','104','','1','0','','','',0, 1, 0, 0),
(9408,'PLAN OF CARE TO ACHIEVE LIPID CONTROL DOCUMENTED','PLAN OF CARE TO ACHIEVE LIPID CONTROL DOCUMENTED','0556F','104','','1','0','','','',0, 1, 0, 0),
(9409,'PLAN OF CARE TO MANAGE ANGINAL SYMPTOMS DOCD','PLAN OF CARE TO MANAGE ANGINAL SYMPTOMS DOCD','0557F','104','','1','0','','','',0, 1, 0, 0),
(9410,'HIV RNA CONTROL PLAN OF CARE DOCD','HIV RNA CONTROL PLAN OF CARE DOCD','0575F','104','','1','0','','','',0, 1, 0, 0),
(9411,'MULTIDISCIPLINARY CARE PLAN DEVELOPED/UPDATED','MULTIDISCIPLINARY CARE PLAN DEVELOPED/UPDATED','0580F','104','','1','0','','','',0, 1, 0, 0),
(9412,'PT TRANSFERRED FROM ANESTHETIZING TO CC UNIT','PT TRANSFERRED FROM ANESTHETIZING TO CC UNIT','0581F','104','','1','0','','','',0, 1, 0, 0),
(9413,'PT NOT TRANSFERRED FROM ANESTHETIZING TO CC UNIT','PT NOT TRANSFERRED FROM ANESTHETIZING TO CC UNIT','0582F','104','','1','0','','','',0, 1, 0, 0),
(9414,'TRANSFER OF CARE CHECKLIST USED','TRANSFER OF CARE CHECKLIST USED','0583F','104','','1','0','','','',0, 1, 0, 0),
(9415,'TRANSFER OF CARE CHECKLIST NOT USED','TRANSFER OF CARE CHECKLIST NOT USED','0584F','104','','1','0','','','',0, 1, 0, 0),
(9416,'TOBACCO USE ASSESSED','TOBACCO USE ASSESSED','1000F','104','','1','0','','','',0, 1, 0, 0),
(9417,'ANGINAL SYMPTOMS & LEVEL ACTIVITY ASSESSED','ANGINAL SYMPTOMS & LEVEL ACTIVITY ASSESSED','1002F','104','','1','0','','','',0, 1, 0, 0),
(9418,'LEVEL ACTIVITY ASSESSED','LEVEL ACTIVITY ASSESSED','1003F','104','','1','0','','','',0, 1, 0, 0),
(9419,'CLINICAL SYMPTOMS VOL OVERLOAD ASSESSED','CLINICAL SYMPTOMS VOL OVERLOAD ASSESSED','1004F','104','','1','0','','','',0, 1, 0, 0),
(9420,'ASTHMA SYMPTOMS EVALUATED','ASTHMA SYMPTOMS EVALUATED','1005F','104','','1','0','','','',0, 1, 0, 0),
(9421,'OSTEOARTHRITIS SYMPTOMS&FUNCJAL STATUS ASSES','OSTEOARTHRITIS SYMPTOMS&FUNCJAL STATUS ASSES','1006F','104','','1','0','','','',0, 1, 0, 0),
(9422,'ANTI-INFLAMMATORY/ANALGESIC SYMPTOM RELIEF ASSES','ANTI-INFLAMMATORY/ANALGESIC SYMPTOM RELIEF ASSES','1007F','104','','1','0','','','',0, 1, 0, 0),
(9423,'GI&RENAL PRESCRIBED/OTC NSAID RISK FACTORS ASSES','GI&RENAL PRESCRIBED/OTC NSAID RISK FACTORS ASSES','1008F','104','','1','0','','','',0, 1, 0, 0),
(9424,'SEVERITY OF ANGINA ASSESSED BY LEVEL OF ACTIVITY','SEVERITY OF ANGINA ASSESSED BY LEVEL OF ACTIVITY','1010F','104','','1','0','','','',0, 1, 0, 0),
(9425,'ANGINA PRESENT','ANGINA PRESENT','1011F','104','','1','0','','','',0, 1, 0, 0),
(9426,'ANGINA ABSENT','ANGINA ABSENT','1012F','104','','1','0','','','',0, 1, 0, 0),
(9427,'COPD SYMPTOMS ASSESSED/TOOL COMPLETED','COPD SYMPTOMS ASSESSED/TOOL COMPLETED','1015F','104','','1','0','','','',0, 1, 0, 0),
(9428,'DYSPNEA ASSESSED NOT PRESENT','DYSPNEA ASSESSED NOT PRESENT','1018F','104','','1','0','','','',0, 1, 0, 0),
(9429,'DYSPNEA ASSESSED PRESENT','DYSPNEA ASSESSED PRESENT','1019F','104','','1','0','','','',0, 1, 0, 0),
(9430,'PNEUMOCOCCUS IMMUNIZATION STATUS ASSESSED','PNEUMOCOCCUS IMMUNIZATION STATUS ASSESSED','1022F','104','','1','0','','','',0, 1, 0, 0),
(9431,'CO-MORBID CONDITIONS ASSESSED','CO-MORBID CONDITIONS ASSESSED','1026F','104','','1','0','','','',0, 1, 0, 0),
(9432,'INFLUENZA IMMUNIZATION STATUS ASSESSED','INFLUENZA IMMUNIZATION STATUS ASSESSED','1030F','104','','1','0','','','',0, 1, 0, 0),
(9433,'SMOKING & 2ND HAND SMOKE IN THE HOME ASSESSED','SMOKING & 2ND HAND SMOKE IN THE HOME ASSESSED','1031F','104','','1','0','','','',0, 1, 0, 0),
(9434,'CURRENT SMOKER/EXPOSED TO SECONDHAND SMOKE','CURRENT SMOKER/EXPOSED TO SECONDHAND SMOKE','1032F','104','','1','0','','','',0, 1, 0, 0),
(9435,'TOBACCO NON-SMOKER & NO 2NDHAND SMOKE EXPOSURE','TOBACCO NON-SMOKER & NO 2NDHAND SMOKE EXPOSURE','1033F','104','','1','0','','','',0, 1, 0, 0),
(9436,'CURRENT TOBACCO SMOKER','CURRENT TOBACCO SMOKER','1034F','104','','1','0','','','',0, 1, 0, 0),
(9437,'CURRENT SMOKELESS TOBACCO USER','CURRENT SMOKELESS TOBACCO USER','1035F','104','','1','0','','','',0, 1, 0, 0),
(9438,'CURRENT TOBACCO NON-USER CAD CAP COPD PV DM','CURRENT TOBACCO NON-USER CAD CAP COPD PV DM','1036F','104','','1','0','','','',0, 1, 0, 0),
(9439,'PERSISTENT ASTHMA MILD MODERATE OR SEVERE ASTHMA','PERSISTENT ASTHMA MILD MODERATE OR SEVERE ASTHMA','1038F','104','','1','0','','','',0, 1, 0, 0),
(9440,'INTERMITTENT ASTHMA','INTERMITTENT ASTHMA','1039F','104','','1','0','','','',0, 1, 0, 0),
(9441,'DSM-5 CRITERIA MDD DOCD AT THE INITIAL EVAL','DSM-5 CRITERIA MDD DOCD AT THE INITIAL EVAL','1040F','104','','1','0','','','',0, 1, 0, 0),
(9442,'HISTORY NEW OR CHANGING MOLES','HISTORY NEW OR CHANGING MOLES','1050F','104','','1','0','','','',0, 1, 0, 0),
(9443,'TYPE ANATOMIC LOCATION AND ACTIVITY ALL ASSESSED','TYPE ANATOMIC LOCATION AND ACTIVITY ALL ASSESSED','1052F','104','','1','0','','','',0, 1, 0, 0),
(9444,'VISUAL FUNCTIONAL STATUS ASSESSED','VISUAL FUNCTIONAL STATUS ASSESSED','1055F','104','','1','0','','','',0, 1, 0, 0),
(9445,'DOC PERM/PERSISTENT/PAROXYSMAL ATRIAL FIB','DOC PERM/PERSISTENT/PAROXYSMAL ATRIAL FIB','1060F','104','','1','0','','','',0, 1, 0, 0),
(9446,'DOC ABSENCE PERM&PERSISTENT&PAROXYSM ATRIAL FIB','DOC ABSENCE PERM&PERSISTENT&PAROXYSM ATRIAL FIB','1061F','104','','1','0','','','',0, 1, 0, 0),
(9447,'ISCHEMIC STROKE SYMP ONSET <3 HRS PRIOR ARRIVAL','ISCHEMIC STROKE SYMP ONSET <3 HRS PRIOR ARRIVAL','1065F','104','','1','0','','','',0, 1, 0, 0),
(9448,'ISCHEMIC STROKE SYMP ONSET >/=3 HRS PRIOR ARRIVA','ISCHEMIC STROKE SYMP ONSET >/=3 HRS PRIOR ARRIVA','1066F','104','','1','0','','','',0, 1, 0, 0),
(9449,'ALARM SYMPTOMS ASSESSED NONE PRESENT','ALARM SYMPTOMS ASSESSED NONE PRESENT','1070F','104','','1','0','','','',0, 1, 0, 0),
(9450,'ALARM SYMPTOMS ASSESSED 1/> PRESENT','ALARM SYMPTOMS ASSESSED 1/> PRESENT','1071F','104','','1','0','','','',0, 1, 0, 0),
(9451,'PRESENCE/ABSENCE URINARY INCONTINENCE ASSESSED','PRESENCE/ABSENCE URINARY INCONTINENCE ASSESSED','1090F','104','','1','0','','','',0, 1, 0, 0),
(9452,'URINE INCONTINENCE CHARACTERIZED','URINE INCONTINENCE CHARACTERIZED','1091F','104','','1','0','','','',0, 1, 0, 0),
(9453,'PT FALLS ASSESS DOCD 2/> FALLS/FALL W/INJURY/YR','PT FALLS ASSESS DOCD 2/> FALLS/FALL W/INJURY/YR','1100F','104','','1','0','','','',0, 1, 0, 0),
(9454,'PT FALLS ASSESS DOCD W/O FALL/INJURY PAST YEAR','PT FALLS ASSESS DOCD W/O FALL/INJURY PAST YEAR','1101F','104','','1','0','','','',0, 1, 0, 0),
(9455,'PT DISCHARGE INPT FACILITY WITHIN LAST 60 DAYS','PT DISCHARGE INPT FACILITY WITHIN LAST 60 DAYS','1110F','104','','1','0','','','',0, 1, 0, 0),
(9456,'DISCHRG MEDS RECONCILED W/CURRENT MED LIST','DISCHRG MEDS RECONCILED W/CURRENT MED LIST','1111F','104','','1','0','','','',0, 1, 0, 0),
(9457,'AURICULAR/PERIAURICULAR PAIN ASSESSED','AURICULAR/PERIAURICULAR PAIN ASSESSED','1116F','104','','1','0','','','',0, 1, 0, 0),
(9458,'GERD SYMPTOMS ASSESSED AFTER 12 MONTHS THERAPY','GERD SYMPTOMS ASSESSED AFTER 12 MONTHS THERAPY','1118F','104','','1','0','','','',0, 1, 0, 0),
(9459,'INITIAL EVALUATION FOR CONDITION','INITIAL EVALUATION FOR CONDITION','1119F','104','','1','0','','','',0, 1, 0, 0),
(9460,'SUBSEQUENT EVALUATION CONDITION','SUBSEQUENT EVALUATION CONDITION','1121F','104','','1','0','','','',0, 1, 0, 0),
(9461,'ADV CARE PLN TLKD & ALT DCSN MAKER DOCD','ADV CARE PLN TLKD & ALT DCSN MAKER DOCD','1123F','104','','1','0','','','',0, 1, 0, 0),
(9462,'ADV CARE PLN/ NO ALT DCSN MKR DOCD OR REFUSAL','ADV CARE PLN/ NO ALT DCSN MKR DOCD OR REFUSAL','1124F','104','','1','0','','','',0, 1, 0, 0),
(9463,'PAIN SEVERITY QUANTIFIED PAIN PRESENT','PAIN SEVERITY QUANTIFIED PAIN PRESENT','1125F','104','','1','0','','','',0, 1, 0, 0),
(9464,'PAIN SEVERITY QUANTIFIED NO PAIN PRESENT','PAIN SEVERITY QUANTIFIED NO PAIN PRESENT','1126F','104','','1','0','','','',0, 1, 0, 0),
(9465,'NEW EPISODE FOR CONDITION','NEW EPISODE FOR CONDITION','1127F','104','','1','0','','','',0, 1, 0, 0),
(9466,'SUBS EPISODE FOR CONDITION','SUBS EPISODE FOR CONDITION','1128F','104','','1','0','','','',0, 1, 0, 0),
(9467,'BK PAIN & FXN ASSESSED CERTAIN ASPECTS OF CARE','BK PAIN & FXN ASSESSED CERTAIN ASPECTS OF CARE','1130F','104','','1','0','','','',0, 1, 0, 0),
(9468,'EPISODE BACK PAIN LASTING SIX WEEKS/<','EPISODE BACK PAIN LASTING SIX WEEKS/<','1134F','104','','1','0','','','',0, 1, 0, 0),
(9469,'EPISODE BACK PAIN LASTING >SIX WEEKS','EPISODE BACK PAIN LASTING >SIX WEEKS','1135F','104','','1','0','','','',0, 1, 0, 0),
(9470,'EPISODE BACK PAIN LASTING 12 WEEKS/<','EPISODE BACK PAIN LASTING 12 WEEKS/<','1136F','104','','1','0','','','',0, 1, 0, 0),
(9471,'EPISODE BACK PAIN LASTING >12 WKS','EPISODE BACK PAIN LASTING >12 WKS','1137F','104','','1','0','','','',0, 1, 0, 0),
(9472,'DOC PT W/SUBSTANTIAL RISK DEATH WITHIN 1 YEAR','DOC PT W/SUBSTANTIAL RISK DEATH WITHIN 1 YEAR','1150F','104','','1','0','','','',0, 1, 0, 0),
(9473,'DOC PT W/O SUBSTANTIAL RISK DEATH WITHIN 1 YEAR','DOC PT W/O SUBSTANTIAL RISK DEATH WITHIN 1 YEAR','1151F','104','','1','0','','','',0, 1, 0, 0),
(9474,'DOC ADVANCED DISEASE DX CARE GOALS COMFORT','DOC ADVANCED DISEASE DX CARE GOALS COMFORT','1152F','104','','1','0','','','',0, 1, 0, 0),
(9475,'DOC ADVANCED DISEASE DX CARE GOALS W/O COMFORT','DOC ADVANCED DISEASE DX CARE GOALS W/O COMFORT','1153F','104','','1','0','','','',0, 1, 0, 0),
(9476,'ADVNC CARE PLAN OR EQV LGL DOC IN MED RCRD','ADVNC CARE PLAN OR EQV LGL DOC IN MED RCRD','1157F','104','','1','0','','','',0, 1, 0, 0),
(9477,'ADVNC CARE PLANNING TLK DOCD IN MED RCRD','ADVNC CARE PLANNING TLK DOCD IN MED RCRD','1158F','104','','1','0','','','',0, 1, 0, 0),
(9478,'MEDICATION LIST DOCUMENTED IN MEDICAL RECORD','MEDICATION LIST DOCUMENTED IN MEDICAL RECORD','1159F','104','','1','0','','','',0, 1, 0, 0),
(9479,'RVW ALL MEDS BY RXNG PRCTIONR OR CLIN RPH DOCD','RVW ALL MEDS BY RXNG PRCTIONR OR CLIN RPH DOCD','1160F','104','','1','0','','','',0, 1, 0, 0),
(9480,'FUNCTIONAL STATUS ASSESSED','FUNCTIONAL STATUS ASSESSED','1170F','104','','1','0','','','',0, 1, 0, 0),
(9481,'FUNCTIONAL STATUS DEMENTIA ASSESS RESULTS RVWD','FUNCTIONAL STATUS DEMENTIA ASSESS RESULTS RVWD','1175F','104','','1','0','','','',0, 1, 0, 0),
(9482,'THROMBOEMBOLIC RISK ASSESSED','THROMBOEMBOLIC RISK ASSESSED','1180F','104','','1','0','','','',0, 1, 0, 0),
(9483,'NEUROPSYCHIATRIC SYMPTS ASSESSED RESULTS REVIEWD','NEUROPSYCHIATRIC SYMPTS ASSESSED RESULTS REVIEWD','1181F','104','','1','0','','','',0, 1, 0, 0),
(9484,'NEUROPSYCHIATRIC SYMPTOMS ONE OR MORE PRESENT','NEUROPSYCHIATRIC SYMPTOMS ONE OR MORE PRESENT','1182F','104','','1','0','','','',0, 1, 0, 0),
(9485,'NEUROPSYCHIATRIC SYMPTOMS ABSENT','NEUROPSYCHIATRIC SYMPTOMS ABSENT','1183F','104','','1','0','','','',0, 1, 0, 0),
(9486,'SEIZURE TYPE FREQUENCY DOCUMENTED','SEIZURE TYPE FREQUENCY DOCUMENTED','1200F','104','','1','0','','','',0, 1, 0, 0),
(9487,'ETIOLOGY OF EPILEPSY SYNDROME RVWD & DOCD','ETIOLOGY OF EPILEPSY SYNDROME RVWD & DOCD','1205F','104','','1','0','','','',0, 1, 0, 0),
(9488,'PATIENT SCREENED DEPRESSION','PATIENT SCREENED DEPRESSION','1220F','104','','1','0','','','',0, 1, 0, 0),
(9489,'PARKINSON DISEASE DIAGNOSIS REVIEWED','PARKINSON DISEASE DIAGNOSIS REVIEWED','1400F','104','','1','0','','','',0, 1, 0, 0),
(9490,'SYMPTOMS IMPROVED/CONSIST W/TXMNT GOAL ASSESSMNT','SYMPTOMS IMPROVED/CONSIST W/TXMNT GOAL ASSESSMNT','1450F','104','','1','0','','','',0, 1, 0, 0),
(9491,'SYMPTOMS SHOW CLIN IMPRTNT DROP SINCE ASSESSMENT','SYMPTOMS SHOW CLIN IMPRTNT DROP SINCE ASSESSMENT','1451F','104','','1','0','','','',0, 1, 0, 0),
(9492,'QUALIFYING CARD EVENT/DIAGNOSIS PRIOR 12 MONTHS','QUALIFYING CARD EVENT/DIAGNOSIS PRIOR 12 MONTHS','1460F','104','','1','0','','','',0, 1, 0, 0),
(9493,'NO QUAL CARD EVENT/DIAG IN PREVIOUS 12 MONTHS','NO QUAL CARD EVENT/DIAG IN PREVIOUS 12 MONTHS','1461F','104','','1','0','','','',0, 1, 0, 0),
(9494,'DEMENTIA SEVERITY CLASSIFIED MILD','DEMENTIA SEVERITY CLASSIFIED MILD','1490F','104','','1','0','','','',0, 1, 0, 0),
(9495,'DEMENTIA SEVERITY CLASSIFIED MODERATE','DEMENTIA SEVERITY CLASSIFIED MODERATE','1491F','104','','1','0','','','',0, 1, 0, 0),
(9496,'DEMENTIA SEVERITY CLASSIFIED SEVERE','DEMENTIA SEVERITY CLASSIFIED SEVERE','1493F','104','','1','0','','','',0, 1, 0, 0),
(9497,'COGNITION ASSESSED AND REVIEWED','COGNITION ASSESSED AND REVIEWED','1494F','104','','1','0','','','',0, 1, 0, 0),
(9498,'SYMP&SIGN DISTAL SYMM POLYNEUROPATHY REVWD&DOCD','SYMP&SIGN DISTAL SYMM POLYNEUROPATHY REVWD&DOCD','1500F','104','','1','0','','','',0, 1, 0, 0),
(9499,'NOT INITIAL EVALUATION FOR CONDITION','NOT INITIAL EVALUATION FOR CONDITION','1501F','104','','1','0','','','',0, 1, 0, 0),
(9500,'PT QUERIED RE PAIN W/FUNC USING RELIABLE INSTRM','PT QUERIED RE PAIN W/FUNC USING RELIABLE INSTRM','1502F','104','','1','0','','','',0, 1, 0, 0),
(9501,'PT QUERIED RE SYMP RESPIRATORY INSUFFICIENCY','PT QUERIED RE SYMP RESPIRATORY INSUFFICIENCY','1503F','104','','1','0','','','',0, 1, 0, 0),
(9502,'PATIENT HAS RESPIRATORY INSUFFICIENCY','PATIENT HAS RESPIRATORY INSUFFICIENCY','1504F','104','','1','0','','','',0, 1, 0, 0),
(9503,'PATIENT DOES NOT HAVE RESPIRATORY INSUFFICIENCY','PATIENT DOES NOT HAVE RESPIRATORY INSUFFICIENCY','1505F','104','','1','0','','','',0, 1, 0, 0),
(9504,'BLOOD PRESSURE MEASURED','BLOOD PRESSURE MEASURED','2000F','104','','1','0','','','',0, 1, 0, 0),
(9505,'WEIGHT RECORDED','WEIGHT RECORDED','2001F','104','','1','0','','','',0, 1, 0, 0),
(9506,'CLINICAL SIGNS VOLUME OVERLOAD ASSESSED','CLINICAL SIGNS VOLUME OVERLOAD ASSESSED','2002F','104','','1','0','','','',0, 1, 0, 0),
(9507,'INITIAL EXAMINATION INVOLVED JOINTS','INITIAL EXAMINATION INVOLVED JOINTS','2004F','104','','1','0','','','',0, 1, 0, 0),
(9508,'VITAL SIGNS RECORDED','VITAL SIGNS RECORDED','2010F','104','','1','0','','','',0, 1, 0, 0),
(9509,'MENTAL STATUS ASSESSED','MENTAL STATUS ASSESSED','2014F','104','','1','0','','','',0, 1, 0, 0),
(9510,'ASTHMA IMPAIRMENT ASSESSED','ASTHMA IMPAIRMENT ASSESSED','2015F','104','','1','0','','','',0, 1, 0, 0),
(9511,'ASTHMA RISK ASSESSED','ASTHMA RISK ASSESSED','2016F','104','','1','0','','','',0, 1, 0, 0),
(9512,'HYDRATION STATUS ASSESSED','HYDRATION STATUS ASSESSED','2018F','104','','1','0','','','',0, 1, 0, 0),
(9513,'DILATED MACULAR EXAM PERFORMED','DILATED MACULAR EXAM PERFORMED','2019F','104','','1','0','','','',0, 1, 0, 0),
(9514,'DILATED FUNDUS EVALUATION PERFORMED','DILATED FUNDUS EVALUATION PERFORMED','2020F','104','','1','0','','','',0, 1, 0, 0),
(9515,'DILATED MACULAR OR FUNDUS EXAM PERFORMED','DILATED MACULAR OR FUNDUS EXAM PERFORMED','2021F','104','','1','0','','','',0, 1, 0, 0),
(9516,'DILAT RETINAL EYE EXAM W/INTERP OPHTHAL/OPTOM','DILAT RETINAL EYE EXAM W/INTERP OPHTHAL/OPTOM','2022F','104','','1','0','','','',0, 1, 0, 0),
(9517,'7 STANDARD FIELD STEREOSCOPIC PHOTOS W/INTERPJ','7 STANDARD FIELD STEREOSCOPIC PHOTOS W/INTERPJ','2024F','104','','1','0','','','',0, 1, 0, 0),
(9518,'EYE IMAGING VALIDATED MATCH PHOTOS DIAGNOSIS','EYE IMAGING VALIDATED MATCH PHOTOS DIAGNOSIS','2026F','104','','1','0','','','',0, 1, 0, 0),
(9519,'OPTIC NERVE HEAD EVALUATION PERFORMED','OPTIC NERVE HEAD EVALUATION PERFORMED','2027F','104','','1','0','','','',0, 1, 0, 0),
(9520,'FOOT EXAMINATION PERFORMED','FOOT EXAMINATION PERFORMED','2028F','104','','1','0','','','',0, 1, 0, 0),
(9521,'COMPLETE PHYSICAL SKIN EXAM PERFORMED','COMPLETE PHYSICAL SKIN EXAM PERFORMED','2029F','104','','1','0','','','',0, 1, 0, 0),
(9522,'HYDRATION STATUS DOCD NORMALLY HYDRATED','HYDRATION STATUS DOCD NORMALLY HYDRATED','2030F','104','','1','0','','','',0, 1, 0, 0),
(9523,'HYDRATION STATUS DOCUMENTED DEHYDRATED','HYDRATION STATUS DOCUMENTED DEHYDRATED','2031F','104','','1','0','','','',0, 1, 0, 0),
(9524,'TYMPANIC MEMBRANE MOBILITY ASSESS','TYMPANIC MEMBRANE MOBILITY ASSESS','2035F','104','','1','0','','','',0, 1, 0, 0),
(9525,'PHYS EXAM ON DATE OF INIT VST FOR LBP DONE','PHYS EXAM ON DATE OF INIT VST FOR LBP DONE','2040F','104','','1','0','','','',0, 1, 0, 0),
(9526,'DOC MNTL HLTH ASSES PRIOR INTVN BACK PAIN 6WKS','DOC MNTL HLTH ASSES PRIOR INTVN BACK PAIN 6WKS','2044F','104','','1','0','','','',0, 1, 0, 0),
(9527,'WOUND CHARACTERISTICS DOCD PRIOR DEBRIDEMENT','WOUND CHARACTERISTICS DOCD PRIOR DEBRIDEMENT','2050F','104','','1','0','','','',0, 1, 0, 0),
(9528,'PT INTRVWD BY EVAL CLINICIAN </DATE DIAG MDD','PT INTRVWD BY EVAL CLINICIAN </DATE DIAG MDD','2060F','104','','1','0','','','',0, 1, 0, 0),
(9529,'CHEST X-RAY RESULTS DOCUMENTED & REVIEWED','CHEST X-RAY RESULTS DOCUMENTED & REVIEWED','3006F','104','','1','0','','','',0, 1, 0, 0),
(9530,'BODY MASS INDEX DOCUMENTED','BODY MASS INDEX DOCUMENTED','3008F','104','','1','0','','','',0, 1, 0, 0),
(9531,'LIPID PANEL RESULTS DOCUMENTED & REVIEWED','LIPID PANEL RESULTS DOCUMENTED & REVIEWED','3011F','104','','1','0','','','',0, 1, 0, 0),
(9532,'SCREENING MAMMOGRAPHY RESULTS DOC&REV','SCREENING MAMMOGRAPHY RESULTS DOC&REV','3014F','104','','1','0','','','',0, 1, 0, 0),
(9533,'CERVICAL CANCER SCREENING RESULTS DOCD & RVWD','CERVICAL CANCER SCREENING RESULTS DOCD & RVWD','3015F','104','','1','0','','','',0, 1, 0, 0),
(9534,'PT SCRND UNHLTHY OH USE BY SYSTMTC SCRNG METHD','PT SCRND UNHLTHY OH USE BY SYSTMTC SCRNG METHD','3016F','104','','1','0','','','',0, 1, 0, 0),
(9535,'COLORECTAL CANCER SCREENING RESULTS DOC&REV','COLORECTAL CANCER SCREENING RESULTS DOC&REV','3017F','104','','1','0','','','',0, 1, 0, 0),
(9536,'PRE-PRX RISK ASSESS DEPTH&QUAL BOWEL PREP','PRE-PRX RISK ASSESS DEPTH&QUAL BOWEL PREP','3018F','104','','1','0','','','',0, 1, 0, 0),
(9537,'LVEF ASSESSMENT PLANNED POST DISCHARGE','LVEF ASSESSMENT PLANNED POST DISCHARGE','3019F','104','','1','0','','','',0, 1, 0, 0),
(9538,'LEFT VENTRICULAR FUNCTION ASSESSMENT DOCUMENTED','LEFT VENTRICULAR FUNCTION ASSESSMENT DOCUMENTED','3020F','104','','1','0','','','',0, 1, 0, 0),
(9539,'LEFT VENTRICULAR EJECTION FRACTION <40%','LEFT VENTRICULAR EJECTION FRACTION <40%','3021F','104','','1','0','','','',0, 1, 0, 0),
(9540,'LEFT VENTRICULAR EJECTION FRACTION >/EQUAL 40%','LEFT VENTRICULAR EJECTION FRACTION >/EQUAL 40%','3022F','104','','1','0','','','',0, 1, 0, 0),
(9541,'SPIROMETRY RESULTS DOCUMENTED AND REVIEWED','SPIROMETRY RESULTS DOCUMENTED AND REVIEWED','3023F','104','','1','0','','','',0, 1, 0, 0),
(9542,'SPIROMETRY TEST RESULTS FEV/FVC <70% W/COPD','SPIROMETRY TEST RESULTS FEV/FVC <70% W/COPD','3025F','104','','1','0','','','',0, 1, 0, 0),
(9543,'SPIROMETRY TEST RESULTS FEV/FVC >/=70% W/O COPD','SPIROMETRY TEST RESULTS FEV/FVC >/=70% W/O COPD','3027F','104','','1','0','','','',0, 1, 0, 0),
(9544,'OXYGEN SATURATION RESULTS DOCUMENTED & REVIEWE','OXYGEN SATURATION RESULTS DOCUMENTED & REVIEWE','3028F','104','','1','0','','','',0, 1, 0, 0),
(9545,'OXYGEN SATUR </EQUAL 88%/PAO2 </EQUAL 55 MM','OXYGEN SATUR </EQUAL 88%/PAO2 </EQUAL 55 MM','3035F','104','','1','0','','','',0, 1, 0, 0),
(9546,'OXYGEN SATURATION >88%/PAO2 >55 MM HG','OXYGEN SATURATION >88%/PAO2 >55 MM HG','3037F','104','','1','0','','','',0, 1, 0, 0),
(9547,'PULMONARY FUNC TEST WITHIN 12 MON PRIOR SURG','PULMONARY FUNC TEST WITHIN 12 MON PRIOR SURG','3038F','104','','1','0','','','',0, 1, 0, 0),
(9548,'FUNCTIONAL EXPIRATORY VOLUME < 40%','FUNCTIONAL EXPIRATORY VOLUME < 40%','3040F','104','','1','0','','','',0, 1, 0, 0),
(9549,'FUNCTJL EXPIR VOLUME >/EQUAL 40% PREDICTED VALUE','FUNCTJL EXPIR VOLUME >/EQUAL 40% PREDICTED VALUE','3042F','104','','1','0','','','',0, 1, 0, 0),
(9550,'MOST RECENT HEMOGLOBIN A1C LEVEL < 7.0%','MOST RECENT HEMOGLOBIN A1C LEVEL < 7.0%','3044F','104','','1','0','','','',0, 1, 0, 0),
(9551,'MOST RECENT HEMOGLOBIN A1C LEVEL GT 7.0-9.0 %','MOST RECENT HEMOGLOBIN A1C LEVEL GT 7.0-9.0 %','3045F','104','','1','0','','','',0, 1, 0, 0),
(9552,'MOST RECENT HEMOGLOBIN A1C LEVEL >9.0%','MOST RECENT HEMOGLOBIN A1C LEVEL >9.0%','3046F','104','','1','0','','','',0, 1, 0, 0),
(9553,'MOST RECENT LDL-C <100 MG/DL','MOST RECENT LDL-C <100 MG/DL','3048F','104','','1','0','','','',0, 1, 0, 0),
(9554,'MOST RECENT LDL-C 100-129 MG/DL','MOST RECENT LDL-C 100-129 MG/DL','3049F','104','','1','0','','','',0, 1, 0, 0),
(9555,'MOST RECENT LDL-C >/EQUAL 130 MG/DL','MOST RECENT LDL-C >/EQUAL 130 MG/DL','3050F','104','','1','0','','','',0, 1, 0, 0),
(9556,'LVEF LESS THAN OR EQUAL TO 35%','LVEF LESS THAN OR EQUAL TO 35%','3055F','104','','1','0','','','',0, 1, 0, 0),
(9557,'LVEF GREATER THAN 35%','LVEF GREATER THAN 35%','3056F','104','','1','0','','','',0, 1, 0, 0),
(9558,'POSITIVE MICROALBUMINURIA TEST RESULT DOC&REV','POSITIVE MICROALBUMINURIA TEST RESULT DOC&REV','3060F','104','','1','0','','','',0, 1, 0, 0),
(9559,'NEGATIVE MICROALBUMINURIA TEST RESULT DOC&REV','NEGATIVE MICROALBUMINURIA TEST RESULT DOC&REV','3061F','104','','1','0','','','',0, 1, 0, 0),
(9560,'POSITIVE MACROALBUMINURIA TEST RESULT DOC&REV','POSITIVE MACROALBUMINURIA TEST RESULT DOC&REV','3062F','104','','1','0','','','',0, 1, 0, 0),
(9561,'DOCUMENTATION OF TREATMENT FOR NEPHROPATHY','DOCUMENTATION OF TREATMENT FOR NEPHROPATHY','3066F','104','','1','0','','','',0, 1, 0, 0),
(9562,'LOW RISK FOR RETINOPATHY','LOW RISK FOR RETINOPATHY','3072F','104','','1','0','','','',0, 1, 0, 0),
(9563,'DOCUMENTED LENGTH CORNEAL POWER & LENS POWER','DOCUMENTED LENGTH CORNEAL POWER & LENS POWER','3073F','104','','1','0','','','',0, 1, 0, 0),
(9564,'MOST RECENT SYSTOLIC BLOOD PRESSURE <130 MM HG','MOST RECENT SYSTOLIC BLOOD PRESSURE <130 MM HG','3074F','104','','1','0','','','',0, 1, 0, 0),
(9565,'MOST RECENT SYSTOLIC BLOOD PRESS 130-139MM HG','MOST RECENT SYSTOLIC BLOOD PRESS 130-139MM HG','3075F','104','','1','0','','','',0, 1, 0, 0),
(9566,'MOST RECENT SYSTOLIC BLOOD PRES>/EQUAL 140 MM HG','MOST RECENT SYSTOLIC BLOOD PRES>/EQUAL 140 MM HG','3077F','104','','1','0','','','',0, 1, 0, 0),
(9567,'MOST RECENT DIASTOLIC BLOOD PRESSURE < 80 MM HG','MOST RECENT DIASTOLIC BLOOD PRESSURE < 80 MM HG','3078F','104','','1','0','','','',0, 1, 0, 0),
(9568,'MOST RECENT DIASTOLIC BLOOD PRESSURE 80-89 MM HG','MOST RECENT DIASTOLIC BLOOD PRESSURE 80-89 MM HG','3079F','104','','1','0','','','',0, 1, 0, 0),
(9569,'MOST RECENT DIASTOL BLOOD PRES >/EQUAL 90 MM HG','MOST RECENT DIASTOL BLOOD PRES >/EQUAL 90 MM HG','3080F','104','','1','0','','','',0, 1, 0, 0),
(9570,'KT/V <1.2 (CLEARANCE OF UREA (KT)/VOLUME (V))','KT/V <1.2 (CLEARANCE OF UREA (KT)/VOLUME (V))','3082F','104','','1','0','','','',0, 1, 0, 0),
(9571,'KT/V EQUAL/>1.2 & <1.7','KT/V EQUAL/>1.2 & <1.7','3083F','104','','1','0','','','',0, 1, 0, 0),
(9572,'KT/V >/= 1.7','KT/V >/= 1.7','3084F','104','','1','0','','','',0, 1, 0, 0),
(9573,'SUICIDE RISK ASSESSED','SUICIDE RISK ASSESSED','3085F','104','','1','0','','','',0, 1, 0, 0),
(9574,'MAJOR DEPRESSIVE DISORDER MILD','MAJOR DEPRESSIVE DISORDER MILD','3088F','104','','1','0','','','',0, 1, 0, 0),
(9575,'MAJOR DEPRESSIVE DISORDER MODERATE','MAJOR DEPRESSIVE DISORDER MODERATE','3089F','104','','1','0','','','',0, 1, 0, 0),
(9576,'MDD SEVERE WITHOUT PSYCHOTIC FEATURES','MDD SEVERE WITHOUT PSYCHOTIC FEATURES','3090F','104','','1','0','','','',0, 1, 0, 0),
(9577,'MAJOR DESPRESV DISORDER SEVERE W/PSYCHOT FEATURE','MAJOR DESPRESV DISORDER SEVERE W/PSYCHOT FEATURE','3091F','104','','1','0','','','',0, 1, 0, 0),
(9578,'MAJOR DEPRESSIVE DISORDER REMISSION','MAJOR DEPRESSIVE DISORDER REMISSION','3092F','104','','1','0','','','',0, 1, 0, 0),
(9579,'DOC NEW DIAG DX INIT/RECURRENT EPISODE OF MDD','DOC NEW DIAG DX INIT/RECURRENT EPISODE OF MDD','3093F','104','','1','0','','','',0, 1, 0, 0),
(9580,'CENTRAL DUAL ENERGY ABSORPTIOMETRY DOCD','CENTRAL DUAL ENERGY ABSORPTIOMETRY DOCD','3095F','104','','1','0','','','',0, 1, 0, 0),
(9581,'CENTRAL DUAL ENERGY ABSORPTIOMETRY ORDERED','CENTRAL DUAL ENERGY ABSORPTIOMETRY ORDERED','3096F','104','','1','0','','','',0, 1, 0, 0),
(9582,'CAROTID IMAGNG REPORT DIR/INDIR MEAS VESSEL DIAM','CAROTID IMAGNG REPORT DIR/INDIR MEAS VESSEL DIAM','3100F','104','','1','0','','','',0, 1, 0, 0),
(9583,'CT/MRI HMRHG/MASS LESION/ACUTE INFRC DOC','CT/MRI HMRHG/MASS LESION/ACUTE INFRC DOC','3110F','104','','1','0','','','',0, 1, 0, 0),
(9584,'CT OR MRI BRAIN DONE W/IN 24 HRS HOSP ARRIVAL','CT OR MRI BRAIN DONE W/IN 24 HRS HOSP ARRIVAL','3111F','104','','1','0','','','',0, 1, 0, 0),
(9585,'CT/MRI BRAIN DONE 24 HRS AFTER HOSP ARRIVAL','CT/MRI BRAIN DONE 24 HRS AFTER HOSP ARRIVAL','3112F','104','','1','0','','','',0, 1, 0, 0),
(9586,'QUANT RESULTS EVAL CURR LEVEL ACTIVITY CLIN SYMP','QUANT RESULTS EVAL CURR LEVEL ACTIVITY CLIN SYMP','3115F','104','','1','0','','','',0, 1, 0, 0),
(9587,'HF DISEASE SPECIFIC ASSESSMENT TOOL COMPLETED','HF DISEASE SPECIFIC ASSESSMENT TOOL COMPLETED','3117F','104','','1','0','','','',0, 1, 0, 0),
(9588,'NEW YORK HEART ASSOCIATION (NYHA) CLASS DOCD','NEW YORK HEART ASSOCIATION (NYHA) CLASS DOCD','3118F','104','','1','0','','','',0, 1, 0, 0),
(9589,'NO EVAL LEVEL OF ACTIVITY OR CLINICAL SYMPTOMS','NO EVAL LEVEL OF ACTIVITY OR CLINICAL SYMPTOMS','3119F','104','','1','0','','','',0, 1, 0, 0),
(9590,'12-LEAD ECG PERFORMED','12-LEAD ECG PERFORMED','3120F','104','','1','0','','','',0, 1, 0, 0),
(9591,'ESOPH BX RPRT W/DYSPLAS INFO AND APPROP GRADING','ESOPH BX RPRT W/DYSPLAS INFO AND APPROP GRADING','3126F','104','','1','0','','','',0, 1, 0, 0),
(9592,'UPPER GI ENDOSCOPY PERFORMED','UPPER GI ENDOSCOPY PERFORMED','3130F','104','','1','0','','','',0, 1, 0, 0),
(9593,'DOC REFERAL FOR UPPER GI ENDOSCOPY','DOC REFERAL FOR UPPER GI ENDOSCOPY','3132F','104','','1','0','','','',0, 1, 0, 0),
(9594,'UPPER GI ENDO REPORT SHOWS POSS BARRETT''S ESOPH','UPPER GI ENDO REPORT SHOWS POSS BARRETT''S ESOPH','3140F','104','','1','0','','','',0, 1, 0, 0),
(9595,'UPPER GI ENDO REPORT SHOW NO SUSPECT BARRETT''S','UPPER GI ENDO REPORT SHOW NO SUSPECT BARRETT''S','3141F','104','','1','0','','','',0, 1, 0, 0),
(9596,'BARIUM SWALLOW TEST ORDERED','BARIUM SWALLOW TEST ORDERED','3142F','104','','1','0','','','',0, 1, 0, 0),
(9597,'FORCEPS ESOPHAGEAL BIOPSY PERFORMED','FORCEPS ESOPHAGEAL BIOPSY PERFORMED','3150F','104','','1','0','','','',0, 1, 0, 0),
(9598,'CYTOGEN TEST DONE MARROW DIAG OR PRIOR TXMNT','CYTOGEN TEST DONE MARROW DIAG OR PRIOR TXMNT','3155F','104','','1','0','','','',0, 1, 0, 0),
(9599,'DOC IRON STORES PRIOR START EPO THERAPY','DOC IRON STORES PRIOR START EPO THERAPY','3160F','104','','1','0','','','',0, 1, 0, 0),
(9600,'FLOW CYTOMETRY W/DIAG/PRIOR INITIATING TREATMENT','FLOW CYTOMETRY W/DIAG/PRIOR INITIATING TREATMENT','3170F','104','','1','0','','','',0, 1, 0, 0),
(9601,'BARIUM SWALLOW TEST NOT ORDERED','BARIUM SWALLOW TEST NOT ORDERED','3200F','104','','1','0','','','',0, 1, 0, 0),
(9602,'GROUP A STREP TEST PERFORMED','GROUP A STREP TEST PERFORMED','3210F','104','','1','0','','','',0, 1, 0, 0),
(9603,'DOCUMENTED IMMUNITY HEPATITIS A','DOCUMENTED IMMUNITY HEPATITIS A','3215F','104','','1','0','','','',0, 1, 0, 0),
(9604,'DOCUMENTED IMMUNITY HEPATITIS B','DOCUMENTED IMMUNITY HEPATITIS B','3216F','104','','1','0','','','',0, 1, 0, 0),
(9605,'HEP C RNA TEST 6 MOS BEFORE ANTIVIRAL TX','HEP C RNA TEST 6 MOS BEFORE ANTIVIRAL TX','3218F','104','','1','0','','','',0, 1, 0, 0),
(9606,'HEP C QUANT RNA TEST 12 WKS AFTER ANTIVIRAL TX','HEP C QUANT RNA TEST 12 WKS AFTER ANTIVIRAL TX','3220F','104','','1','0','','','',0, 1, 0, 0),
(9607,'HEARING TEST 6 MOS PRIOR TO EAR TUBE INSERTION','HEARING TEST 6 MOS PRIOR TO EAR TUBE INSERTION','3230F','104','','1','0','','','',0, 1, 0, 0),
(9608,'NONPRIM ANATOMIC LOCATION OF SPECIMEN SITE','NONPRIM ANATOMIC LOCATION OF SPECIMEN SITE','3250F','104','','1','0','','','',0, 1, 0, 0),
(9609,'TUMOR/NODES/HISTO GRADE DOCUMENTED','TUMOR/NODES/HISTO GRADE DOCUMENTED','3260F','104','','1','0','','','',0, 1, 0, 0),
(9610,'RNA TESTING FOR HEP C VIREMIA ORDERED/DOCD','RNA TESTING FOR HEP C VIREMIA ORDERED/DOCD','3265F','104','','1','0','','','',0, 1, 0, 0),
(9611,'HEPATITIS C GENOTYPE PRIOR ANTIVIRAL TREATMENT','HEPATITIS C GENOTYPE PRIOR ANTIVIRAL TREATMENT','3266F','104','','1','0','','','',0, 1, 0, 0),
(9612,'PATH RPRT INCLUDES PT & PN CAT GLEASON','PATH RPRT INCLUDES PT & PN CAT GLEASON','3267F','104','','1','0','','','',0, 1, 0, 0),
(9613,'PSA & TUMOR STAGE&GLEASON SCORE PRIOR INIT','PSA & TUMOR STAGE&GLEASON SCORE PRIOR INIT','3268F','104','','1','0','','','',0, 1, 0, 0),
(9614,'BONE SCAN PRIOR INITIAT TX/DX PROSTATE CANCER','BONE SCAN PRIOR INITIAT TX/DX PROSTATE CANCER','3269F','104','','1','0','','','',0, 1, 0, 0),
(9615,'BONE SCAN NOT PRIOR INITIAT TX/DX PROSTATE CA','BONE SCAN NOT PRIOR INITIAT TX/DX PROSTATE CA','3270F','104','','1','0','','','',0, 1, 0, 0),
(9616,'LOW RISK OF RECURRENCE PROSTATE CANCER','LOW RISK OF RECURRENCE PROSTATE CANCER','3271F','104','','1','0','','','',0, 1, 0, 0),
(9617,'INTERMED RISK OF RECURRENCE PROSTATE CANCER','INTERMED RISK OF RECURRENCE PROSTATE CANCER','3272F','104','','1','0','','','',0, 1, 0, 0),
(9618,'HIGH RISK OF RECURRENCE PROSTATE CANCER','HIGH RISK OF RECURRENCE PROSTATE CANCER','3273F','104','','1','0','','','',0, 1, 0, 0),
(9619,'PROST CANCER RSK RECUR NOT DETER/LOW/INTERMED/HI','PROST CANCER RSK RECUR NOT DETER/LOW/INTERMED/HI','3274F','104','','1','0','','','',0, 1, 0, 0),
(9620,'SERUM LEVELS CALCUM PHOSPH PARATHYR & LIPID PR','SERUM LEVELS CALCUM PHOSPH PARATHYR & LIPID PR','3278F','104','','1','0','','','',0, 1, 0, 0),
(9621,'HEMOGLOBIN LEVEL>/EQUAL 13 G/DL','HEMOGLOBIN LEVEL>/EQUAL 13 G/DL','3279F','104','','1','0','','','',0, 1, 0, 0),
(9622,'HEMOGLOBIN LEVEL 11 G/DL-12.9 G/DL','HEMOGLOBIN LEVEL 11 G/DL-12.9 G/DL','3280F','104','','1','0','','','',0, 1, 0, 0),
(9623,'HEMOGLOBIN LEVEL <11 G/DL','HEMOGLOBIN LEVEL <11 G/DL','3281F','104','','1','0','','','',0, 1, 0, 0),
(9624,'INTRAOCULAR PRESS REDUCED >/EQUAL 15%','INTRAOCULAR PRESS REDUCED >/EQUAL 15%','3284F','104','','1','0','','','',0, 1, 0, 0),
(9625,'IOP REDUCED <15% PRE-INTERVENTION LEVEL','IOP REDUCED <15% PRE-INTERVENTION LEVEL','3285F','104','','1','0','','','',0, 1, 0, 0),
(9626,'FALLS RISK ASSESSMENT DOCUMENTED','FALLS RISK ASSESSMENT DOCUMENTED','3288F','104','','1','0','','','',0, 1, 0, 0),
(9627,'PATIENT IS D (RH) NEGATIVE AND UNSENSITIZED','PATIENT IS D (RH) NEGATIVE AND UNSENSITIZED','3290F','104','','1','0','','','',0, 1, 0, 0),
(9628,'PATIENT IS D (RH) POSITIVE OR SENSITIZED','PATIENT IS D (RH) POSITIVE OR SENSITIZED','3291F','104','','1','0','','','',0, 1, 0, 0),
(9629,'HIV TSTNG ASK/DOCD/RVWD AT 1ST/2ND PRENATAL VST','HIV TSTNG ASK/DOCD/RVWD AT 1ST/2ND PRENATAL VST','3292F','104','','1','0','','','',0, 1, 0, 0),
(9630,'ABO AND RH BLOOD TYPING DOCUMENTED AS PERFORMED','ABO AND RH BLOOD TYPING DOCUMENTED AS PERFORMED','3293F','104','','1','0','','','',0, 1, 0, 0),
(9631,'GBS SCRNING DOCD DONE DURING WK 35-37 GESTATION','GBS SCRNING DOCD DONE DURING WK 35-37 GESTATION','3294F','104','','1','0','','','',0, 1, 0, 0),
(9632,'AJCC STAGE DOCUMENTED & REVIEWED','AJCC STAGE DOCUMENTED & REVIEWED','3300F','104','','1','0','','','',0, 1, 0, 0),
(9633,'CANCER STAGE DOCD METASTATIC & REVIEWED','CANCER STAGE DOCD METASTATIC & REVIEWED','3301F','104','','1','0','','','',0, 1, 0, 0),
(9634,'ESTROGEN/PROGEST RECEPTOR POSITIVE BREAST CANCER','ESTROGEN/PROGEST RECEPTOR POSITIVE BREAST CANCER','3315F','104','','1','0','','','',0, 1, 0, 0),
(9635,'ESTROGEN/PROGEST RECEPTOR NEGATIVE BREAST CANCER','ESTROGEN/PROGEST RECEPTOR NEGATIVE BREAST CANCER','3316F','104','','1','0','','','',0, 1, 0, 0),
(9636,'PATH REPRT MALIGNANCY DOCD & RVWD INITIATE CHE','PATH REPRT MALIGNANCY DOCD & RVWD INITIATE CHE','3317F','104','','1','0','','','',0, 1, 0, 0),
(9637,'PATH REPRT MALIGNANCY DOCD & RVWD INITIA RAD','PATH REPRT MALIGNANCY DOCD & RVWD INITIA RAD','3318F','104','','1','0','','','',0, 1, 0, 0),
(9638,'1 DX IMG ORDER CHEST XRAY CT US MRI PET/NUC MED','1 DX IMG ORDER CHEST XRAY CT US MRI PET/NUC MED','3319F','104','','1','0','','','',0, 1, 0, 0),
(9639,'0 DX IMG ORDER CHEST XRAY CT US MRI PET/NUC MED','0 DX IMG ORDER CHEST XRAY CT US MRI PET/NUC MED','3320F','104','','1','0','','','',0, 1, 0, 0),
(9640,'AJCC CANCER STAGE 0 OR IA MELANOMA','AJCC CANCER STAGE 0 OR IA MELANOMA','3321F','104','','1','0','','','',0, 1, 0, 0),
(9641,'MELANOMA THAN AJCC STAGE 0','MELANOMA THAN AJCC STAGE 0','3322F','104','','1','0','','','',0, 1, 0, 0),
(9642,'CLIN TUMOR NODE METASTASES STAGE DOCD PRIOR SURG','CLIN TUMOR NODE METASTASES STAGE DOCD PRIOR SURG','3323F','104','','1','0','','','',0, 1, 0, 0),
(9643,'MRI CT SCAN ORDERED REVIEWED/REQUESTED','MRI CT SCAN ORDERED REVIEWED/REQUESTED','3324F','104','','1','0','','','',0, 1, 0, 0),
(9644,'PREOP ASSES 12 MOS PRIOR CATARACT SURG W/IO LENS','PREOP ASSES 12 MOS PRIOR CATARACT SURG W/IO LENS','3325F','104','','1','0','','','',0, 1, 0, 0),
(9645,'PERFORMANCE STATUS DOCD RVWD 2 WKS PRIOR SURG','PERFORMANCE STATUS DOCD RVWD 2 WKS PRIOR SURG','3328F','104','','1','0','','','',0, 1, 0, 0),
(9646,'IMAGING STUDY ORDERED','IMAGING STUDY ORDERED','3330F','104','','1','0','','','',0, 1, 0, 0),
(9647,'IMAGING STUDY NOT ORDERED','IMAGING STUDY NOT ORDERED','3331F','104','','1','0','','','',0, 1, 0, 0),
(9648,'MAMMO ASSESSMENT CAT INCOMP ADDTNL IMAGE DOCD','MAMMO ASSESSMENT CAT INCOMP ADDTNL IMAGE DOCD','3340F','104','','1','0','','','',0, 1, 0, 0),
(9649,'MAMMO ASSESSMENT CAT NEGATIVE DOCD','MAMMO ASSESSMENT CAT NEGATIVE DOCD','3341F','104','','1','0','','','',0, 1, 0, 0),
(9650,'MAMMO ASSESSMENT CAT BENIGN DOCD','MAMMO ASSESSMENT CAT BENIGN DOCD','3342F','104','','1','0','','','',0, 1, 0, 0),
(9651,'MAMMO ASSESSMENT CAT PROB BENIGN DOCD','MAMMO ASSESSMENT CAT PROB BENIGN DOCD','3343F','104','','1','0','','','',0, 1, 0, 0),
(9652,'MAMMO ASSESSMENT CAT SUSPICIOUS DOCD','MAMMO ASSESSMENT CAT SUSPICIOUS DOCD','3344F','104','','1','0','','','',0, 1, 0, 0),
(9653,'MAMMO ASSESSMENT CAT HIGH CHANCE MALIG DOCD','MAMMO ASSESSMENT CAT HIGH CHANCE MALIG DOCD','3345F','104','','1','0','','','',0, 1, 0, 0),
(9654,'MAMMO ASSESSMENT CAT BIOPSY PROVEN MALIG DOCD','MAMMO ASSESSMENT CAT BIOPSY PROVEN MALIG DOCD','3350F','104','','1','0','','','',0, 1, 0, 0),
(9655,'NEG DEP SYMP CAT USING STAND DEP ASSESS TOOL','NEG DEP SYMP CAT USING STAND DEP ASSESS TOOL','3351F','104','','1','0','','','',0, 1, 0, 0),
(9656,'NO SIGNIF DEP SYMP CAT BY STAND DEP ASSESS TOOL','NO SIGNIF DEP SYMP CAT BY STAND DEP ASSESS TOOL','3352F','104','','1','0','','','',0, 1, 0, 0),
(9657,'MILD TO MOD DEP SYMP BY STAND DEP ASSESS TOOL','MILD TO MOD DEP SYMP BY STAND DEP ASSESS TOOL','3353F','104','','1','0','','','',0, 1, 0, 0),
(9658,'CLIN SIGN DEP SYMP BY STAND DEP ASSESS TOOL','CLIN SIGN DEP SYMP BY STAND DEP ASSESS TOOL','3354F','104','','1','0','','','',0, 1, 0, 0),
(9659,'AJCC BREAST CANCER STAGE 0 DOCUMENTED','AJCC BREAST CANCER STAGE 0 DOCUMENTED','3370F','104','','1','0','','','',0, 1, 0, 0),
(9660,'AJCC BREAST CANCER STAGE I T1MIC T1A/T1B','AJCC BREAST CANCER STAGE I T1MIC T1A/T1B','3372F','104','','1','0','','','',0, 1, 0, 0),
(9661,'AJCC BREAST CANCER STAGE I T1C','AJCC BREAST CANCER STAGE I T1C','3374F','104','','1','0','','','',0, 1, 0, 0),
(9662,'AJCC BREAST CANCER STAGE II','AJCC BREAST CANCER STAGE II','3376F','104','','1','0','','','',0, 1, 0, 0),
(9663,'AJCC BREAST CANCER STAGE III','AJCC BREAST CANCER STAGE III','3378F','104','','1','0','','','',0, 1, 0, 0),
(9664,'AJCC BREAST CANCER STAGE IV','AJCC BREAST CANCER STAGE IV','3380F','104','','1','0','','','',0, 1, 0, 0),
(9665,'AJCC COLON CANCER STAGE 0','AJCC COLON CANCER STAGE 0','3382F','104','','1','0','','','',0, 1, 0, 0),
(9666,'AJCC COLON CANCER STAGE I','AJCC COLON CANCER STAGE I','3384F','104','','1','0','','','',0, 1, 0, 0),
(9667,'AJCC COLON CANCER STAGE II','AJCC COLON CANCER STAGE II','3386F','104','','1','0','','','',0, 1, 0, 0),
(9668,'AJCC COLON CANCER STAGE III DOCD','AJCC COLON CANCER STAGE III DOCD','3388F','104','','1','0','','','',0, 1, 0, 0),
(9669,'AJCC COLON CANCER STAGE IV DOCD','AJCC COLON CANCER STAGE IV DOCD','3390F','104','','1','0','','','',0, 1, 0, 0),
(9670,'QUANT HER2 IHC EVAL OF BRST CANCER ASCO/CAP','QUANT HER2 IHC EVAL OF BRST CANCER ASCO/CAP','3394F','104','','1','0','','','',0, 1, 0, 0),
(9671,'QUANT NON-HER2 IHC EVAL OF BRST CANCER PERFORMED','QUANT NON-HER2 IHC EVAL OF BRST CANCER PERFORMED','3395F','104','','1','0','','','',0, 1, 0, 0),
(9672,'DYSPNEA SCRND NO-MILD DYSPNEA','DYSPNEA SCRND NO-MILD DYSPNEA','3450F','104','','1','0','','','',0, 1, 0, 0),
(9673,'DYSPNEA SCRND MOD-SEVERE DYSPNEA','DYSPNEA SCRND MOD-SEVERE DYSPNEA','3451F','104','','1','0','','','',0, 1, 0, 0),
(9674,'DYSPNEA NOT SCREENED','DYSPNEA NOT SCREENED','3452F','104','','1','0','','','',0, 1, 0, 0),
(9675,'TB SCRNG DONE INTRPD </6 MOS START RA THXPY','TB SCRNG DONE INTRPD </6 MOS START RA THXPY','3455F','104','','1','0','','','',0, 1, 0, 0),
(9676,'RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY LOW','RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY LOW','3470F','104','','1','0','','','',0, 1, 0, 0),
(9677,'RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY MOD','RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY MOD','3471F','104','','1','0','','','',0, 1, 0, 0),
(9678,'RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY HIGH','RHEUMATOID ARTHRITIS (RA) DISEASE ACTIVITY HIGH','3472F','104','','1','0','','','',0, 1, 0, 0),
(9679,'DISEASE PROGNOSIS RA ASSESSED POOR PROG DOCD','DISEASE PROGNOSIS RA ASSESSED POOR PROG DOCD','3475F','104','','1','0','','','',0, 1, 0, 0),
(9680,'DISEASE PROGNOSIS RA ASSESSED GOOD PROG DOCD','DISEASE PROGNOSIS RA ASSESSED GOOD PROG DOCD','3476F','104','','1','0','','','',0, 1, 0, 0),
(9681,'HISTORY OF AIDS-DEFINING CONDITION','HISTORY OF AIDS-DEFINING CONDITION','3490F','104','','1','0','','','',0, 1, 0, 0),
(9682,'HIV INDETERMINATE INFANTS BORN OF HIV MOTHERS','HIV INDETERMINATE INFANTS BORN OF HIV MOTHERS','3491F','104','','1','0','','','',0, 1, 0, 0),
(9683,'HISTORY OF NADIR CD4+ CELL COUNT <350 CELLS/MM3','HISTORY OF NADIR CD4+ CELL COUNT <350 CELLS/MM3','3492F','104','','1','0','','','',0, 1, 0, 0),
(9684,'NO HIST NADIR CD4+ CELL CNT <350&AIDS CONDITION','NO HIST NADIR CD4+ CELL CNT <350&AIDS CONDITION','3493F','104','','1','0','','','',0, 1, 0, 0),
(9685,'CD4+ CELL COUNT <200 CELLS/MM','CD4+ CELL COUNT <200 CELLS/MM','3494F','104','','1','0','','','',0, 1, 0, 0),
(9686,'CD4+ CELL COUNT 200-499 CELLS/MM (HIV)','CD4+ CELL COUNT 200-499 CELLS/MM (HIV)','3495F','104','','1','0','','','',0, 1, 0, 0),
(9687,'CD4+ CELL COUNT >= 500 CELLS/MM','CD4+ CELL COUNT >= 500 CELLS/MM','3496F','104','','1','0','','','',0, 1, 0, 0),
(9688,'CD4+ CELL PERCENTAGE <15% HIV','CD4+ CELL PERCENTAGE <15% HIV','3497F','104','','1','0','','','',0, 1, 0, 0),
(9689,'CD4+ CELL PERCENTAGE >= 15% HIV','CD4+ CELL PERCENTAGE >= 15% HIV','3498F','104','','1','0','','','',0, 1, 0, 0),
(9690,'CD4+CELL CNT/CD4+CELL % DOCD AS DONE','CD4+CELL CNT/CD4+CELL % DOCD AS DONE','3500F','104','','1','0','','','',0, 1, 0, 0),
(9691,'HIV RNA VIRAL LOAD <LIMITS OF QUANTIF','HIV RNA VIRAL LOAD <LIMITS OF QUANTIF','3502F','104','','1','0','','','',0, 1, 0, 0),
(9692,'HIV RNA VIRAL LOAD NOT <LIMITS OF QUANTIF','HIV RNA VIRAL LOAD NOT <LIMITS OF QUANTIF','3503F','104','','1','0','','','',0, 1, 0, 0),
(9693,'DOCJ TB SCREEN PERFORMED & RESULTS INTERPRET','DOCJ TB SCREEN PERFORMED & RESULTS INTERPRET','3510F','104','','1','0','','','',0, 1, 0, 0),
(9694,'CHLAMYDIA/GONORRHEA TSTS DOCD AS DONE','CHLAMYDIA/GONORRHEA TSTS DOCD AS DONE','3511F','104','','1','0','','','',0, 1, 0, 0),
(9695,'SYPHILIS SCREENING DOCUMENTED AS DONE','SYPHILIS SCREENING DOCUMENTED AS DONE','3512F','104','','1','0','','','',0, 1, 0, 0),
(9696,'HEPATITIS B SCREENING DOCUMENTED AS PERFORMED','HEPATITIS B SCREENING DOCUMENTED AS PERFORMED','3513F','104','','1','0','','','',0, 1, 0, 0),
(9697,'HEPATITIS C SCREENING DOCUMENTED AS PERFORMED','HEPATITIS C SCREENING DOCUMENTED AS PERFORMED','3514F','104','','1','0','','','',0, 1, 0, 0),
(9698,'PATIENT HAS DOCUMENTED IMMUNITY TO HEPATITIS C','PATIENT HAS DOCUMENTED IMMUNITY TO HEPATITIS C','3515F','104','','1','0','','','',0, 1, 0, 0),
(9699,'HBV STATUS ASSESSED W/ RESULTS IN 1 YR','HBV STATUS ASSESSED W/ RESULTS IN 1 YR','3517F','104','','1','0','','','',0, 1, 0, 0),
(9700,'CLOSTRIDIUM DIFFICILE TESTING PERFORMED','CLOSTRIDIUM DIFFICILE TESTING PERFORMED','3520F','104','','1','0','','','',0, 1, 0, 0),
(9701,'LOW RISK FOR THROMBOEMBOLISM','LOW RISK FOR THROMBOEMBOLISM','3550F','104','','1','0','','','',0, 1, 0, 0),
(9702,'INTERMEDIATE RISK FOR THROMBOEMBOLISM','INTERMEDIATE RISK FOR THROMBOEMBOLISM','3551F','104','','1','0','','','',0, 1, 0, 0),
(9703,'HIGH RISK FOR THROMBOEMBOLISM','HIGH RISK FOR THROMBOEMBOLISM','3552F','104','','1','0','','','',0, 1, 0, 0),
(9704,'PT HAD INR MEASUREMENT PERFORMED','PT HAD INR MEASUREMENT PERFORMED','3555F','104','','1','0','','','',0, 1, 0, 0),
(9705,'REPORT BONE SCINTIGRAPHY W/X-RAY SAME REGION','REPORT BONE SCINTIGRAPHY W/X-RAY SAME REGION','3570F','104','','1','0','','','',0, 1, 0, 0),
(9706,'PT POTENTIAL RISK FRACTURE WEIGHT-BEARING SITE','PT POTENTIAL RISK FRACTURE WEIGHT-BEARING SITE','3572F','104','','1','0','','','',0, 1, 0, 0),
(9707,'PT NOT POTENT RISK FRACTURE WEIGHT-BEARING SITE','PT NOT POTENT RISK FRACTURE WEIGHT-BEARING SITE','3573F','104','','1','0','','','',0, 1, 0, 0),
(9708,'ELECTROENCEPHALOGRAM ORDERED RVWD OR REQ','ELECTROENCEPHALOGRAM ORDERED RVWD OR REQ','3650F','104','','1','0','','','',0, 1, 0, 0),
(9709,'PSYCHIATRIC DISORDERS/DISTURBANCES ASSESSED','PSYCHIATRIC DISORDERS/DISTURBANCES ASSESSED','3700F','104','','1','0','','','',0, 1, 0, 0),
(9710,'COGNITIVE IMPAIRMENT/DYSFUNCTION ASSESSED','COGNITIVE IMPAIRMENT/DYSFUNCTION ASSESSED','3720F','104','','1','0','','','',0, 1, 0, 0),
(9711,'SCREENING FOR DEPRESSION PERFORMED','SCREENING FOR DEPRESSION PERFORMED','3725F','104','','1','0','','','',0, 1, 0, 0),
(9712,'PT NOT RCVNG CORTICOSTERIDS>/=10MG/DAY 60/> DAYS','PT NOT RCVNG CORTICOSTERIDS>/=10MG/DAY 60/> DAYS','3750F','104','','1','0','','','',0, 1, 0, 0),
(9713,'ELECTRODIAG STUDIES DSP DOCD RVWD W/IN 6 MONTHS','ELECTRODIAG STUDIES DSP DOCD RVWD W/IN 6 MONTHS','3751F','104','','1','0','','','',0, 1, 0, 0),
(9714,'ELECTRODIAG STUDIES DSP NOT DOCD RVWD W/IN 6 MON','ELECTRODIAG STUDIES DSP NOT DOCD RVWD W/IN 6 MON','3752F','104','','1','0','','','',0, 1, 0, 0),
(9715,'PT HAS CLINICAL SYMP&SIGNS NEUROPATHY W/CAUSE','PT HAS CLINICAL SYMP&SIGNS NEUROPATHY W/CAUSE','3753F','104','','1','0','','','',0, 1, 0, 0),
(9716,'SCREENING TSTS DIABETES MELLITUS RVWD RQSTD ORD','SCREENING TSTS DIABETES MELLITUS RVWD RQSTD ORD','3754F','104','','1','0','','','',0, 1, 0, 0),
(9717,'COGNITIVE&BEHAVIORAL IMPAIRMENT SCRNG PERFORMED','COGNITIVE&BEHAVIORAL IMPAIRMENT SCRNG PERFORMED','3755F','104','','1','0','','','',0, 1, 0, 0),
(9718,'PT HAS PSEUDOBULBAR AFFECT/SIALORRHEA/ALS SYMP','PT HAS PSEUDOBULBAR AFFECT/SIALORRHEA/ALS SYMP','3756F','104','','1','0','','','',0, 1, 0, 0),
(9719,'NO PSEUDOBULBAR AFFECT/SIALORRHEA/ALS SYMP','NO PSEUDOBULBAR AFFECT/SIALORRHEA/ALS SYMP','3757F','104','','1','0','','','',0, 1, 0, 0),
(9720,'PULM FUNC TESTING/PEAK COUGH EXPIRATORY FLOW','PULM FUNC TESTING/PEAK COUGH EXPIRATORY FLOW','3758F','104','','1','0','','','',0, 1, 0, 0),
(9721,'PT SCRND DYSPHAGIA WT LOSS IMPAIRED NUTRITION','PT SCRND DYSPHAGIA WT LOSS IMPAIRED NUTRITION','3759F','104','','1','0','','','',0, 1, 0, 0),
(9722,'PT W/DYSPHAG/WT LOSS/IMPAIRED NUTRITION','PT W/DYSPHAG/WT LOSS/IMPAIRED NUTRITION','3760F','104','','1','0','','','',0, 1, 0, 0),
(9723,'PT WO/DYSPHAG/WT LOSS/IMPAIRED NUTRITION','PT WO/DYSPHAG/WT LOSS/IMPAIRED NUTRITION','3761F','104','','1','0','','','',0, 1, 0, 0),
(9724,'PATIENT IS DYSARTHRIC','PATIENT IS DYSARTHRIC','3762F','104','','1','0','','','',0, 1, 0, 0),
(9725,'PATIENT IS NOT DYSARTHRIC','PATIENT IS NOT DYSARTHRIC','3763F','104','','1','0','','','',0, 1, 0, 0),
(9726,'ADENOMA(S)/NEOPLASM DETECTED SCRNG CLNSCPY','ADENOMA(S)/NEOPLASM DETECTED SCRNG CLNSCPY','3775F','104','','1','0','','','',0, 1, 0, 0),
(9727,'ADENOMA(S)/NEOPLASM NOT DETECTED SCRNG CLNSCPY','ADENOMA(S)/NEOPLASM NOT DETECTED SCRNG CLNSCPY','3776F','104','','1','0','','','',0, 1, 0, 0),
(9728,'TOBACCO USE CESSATION IVNTJ COUNSELING','TOBACCO USE CESSATION IVNTJ COUNSELING','4000F','104','','1','0','','','',0, 1, 0, 0),
(9729,'TOBACCO USE CESSATION IVNTJ PHARMACOLOGIC THER','TOBACCO USE CESSATION IVNTJ PHARMACOLOGIC THER','4001F','104','','1','0','','','',0, 1, 0, 0),
(9730,'PT EDUCATION WRTTN/ORAL HRT FAILURE PTS PFRMD','PT EDUCATION WRTTN/ORAL HRT FAILURE PTS PFRMD','4003F','104','','1','0','','','',0, 1, 0, 0),
(9731,'PT SCRND TOBACCO USE RCVD TOBACCO CESSATION TALK','PT SCRND TOBACCO USE RCVD TOBACCO CESSATION TALK','4004F','104','','1','0','','','',0, 1, 0, 0),
(9732,'PHARMACOLOGIC OSTEOPOROSIS THERAPY PRESCRIBED','PHARMACOLOGIC OSTEOPOROSIS THERAPY PRESCRIBED','4005F','104','','1','0','','','',0, 1, 0, 0),
(9733,'BETA BLOCKER THERAPY RXD/CURRENTLY BEING TAKEN','BETA BLOCKER THERAPY RXD/CURRENTLY BEING TAKEN','4008F','104','','1','0','','','',0, 1, 0, 0),
(9734,'ACE INHIBITOR/ARB THERAPY RXD/CURRENTLY TAKEN','ACE INHIBITOR/ARB THERAPY RXD/CURRENTLY TAKEN','4010F','104','','1','0','','','',0, 1, 0, 0),
(9735,'ORAL ANTIPLATELET THERAPY PRESCRIBED','ORAL ANTIPLATELET THERAPY PRESCRIBED','4011F','104','','1','0','','','',0, 1, 0, 0),
(9736,'WARFARIN THERAPY PRESCRIBED','WARFARIN THERAPY PRESCRIBED','4012F','104','','1','0','','','',0, 1, 0, 0),
(9737,'STATIN THERAPY RXD/CURRENTLY TAKEN','STATIN THERAPY RXD/CURRENTLY TAKEN','4013F','104','','1','0','','','',0, 1, 0, 0),
(9738,'DSCHRG INSTRUCTIONS HRT FAILURE XCP PTS 18 YR','DSCHRG INSTRUCTIONS HRT FAILURE XCP PTS 18 YR','4014F','104','','1','0','','','',0, 1, 0, 0),
(9739,'PRSISTENT ASTHMA LONG TERM CTRL MED PRESCRIBED','PRSISTENT ASTHMA LONG TERM CTRL MED PRESCRIBED','4015F','104','','1','0','','','',0, 1, 0, 0),
(9740,'ANTI-INFLAMMATORY/ANALGESIC AGT PRESCRIBED','ANTI-INFLAMMATORY/ANALGESIC AGT PRESCRIBED','4016F','104','','1','0','','','',0, 1, 0, 0),
(9741,'GI PROPHYLAXIS NSAID USE PRESCRIBED','GI PROPHYLAXIS NSAID USE PRESCRIBED','4017F','104','','1','0','','','',0, 1, 0, 0),
(9742,'THERAPEUTIC EXERCISE INVOLVED JTS INST/PRESCRIBE','THERAPEUTIC EXERCISE INVOLVED JTS INST/PRESCRIBE','4018F','104','','1','0','','','',0, 1, 0, 0),
(9743,'DOCUMENT COUNSELING EXERCISE CALCIUM & VITAMIN','DOCUMENT COUNSELING EXERCISE CALCIUM & VITAMIN','4019F','104','','1','0','','','',0, 1, 0, 0),
(9744,'INHALED BRONCHODILATOR PRESCRIBED','INHALED BRONCHODILATOR PRESCRIBED','4025F','104','','1','0','','','',0, 1, 0, 0),
(9745,'LONG-TERM OXYGEN THERAPY PRESCRIBED','LONG-TERM OXYGEN THERAPY PRESCRIBED','4030F','104','','1','0','','','',0, 1, 0, 0),
(9746,'PULMONARY REHABILITATION RECOMMENDED','PULMONARY REHABILITATION RECOMMENDED','4033F','104','','1','0','','','',0, 1, 0, 0),
(9747,'INFLUENZA IMMUNIZATION RECOMMENDED','INFLUENZA IMMUNIZATION RECOMMENDED','4035F','104','','1','0','','','',0, 1, 0, 0),
(9748,'INFLUENZA IMMUNIZATION ORDERED OR ADMINISTERED','INFLUENZA IMMUNIZATION ORDERED OR ADMINISTERED','4037F','104','','1','0','','','',0, 1, 0, 0),
(9749,'PNEUMOCOCCAL VACCINE ADMIN RCVD PRIOR','PNEUMOCOCCAL VACCINE ADMIN RCVD PRIOR','4040F','104','','1','0','','','',0, 1, 0, 0),
(9750,'DOC ORDER CEFAZOLIN/CEFUROXIME ANTIMICRB PROPHYL','DOC ORDER CEFAZOLIN/CEFUROXIME ANTIMICRB PROPHYL','4041F','104','','1','0','','','',0, 1, 0, 0),
(9751,'DOC PROPHY ANTIBIO NOT GIVEN W/IN 4 HR PRIOR SUR','DOC PROPHY ANTIBIO NOT GIVEN W/IN 4 HR PRIOR SUR','4042F','104','','1','0','','','',0, 1, 0, 0),
(9752,'DOC ORDER DISCONT ANTIBIO W/IN 48 HOURS OF SURG','DOC ORDER DISCONT ANTIBIO W/IN 48 HOURS OF SURG','4043F','104','','1','0','','','',0, 1, 0, 0),
(9753,'DOC ORDER VTE PROPHYL W/IN 24 HRS PRIOR SURG','DOC ORDER VTE PROPHYL W/IN 24 HRS PRIOR SURG','4044F','104','','1','0','','','',0, 1, 0, 0),
(9754,'APPROPRIATE EMPIRIC ANTIBIOTIC PRESCRIBED','APPROPRIATE EMPIRIC ANTIBIOTIC PRESCRIBED','4045F','104','','1','0','','','',0, 1, 0, 0),
(9755,'DOCD ANTIBIO W/IN 4 HRS PRIOR/INTRAOP SURG INCIS','DOCD ANTIBIO W/IN 4 HRS PRIOR/INTRAOP SURG INCIS','4046F','104','','1','0','','','',0, 1, 0, 0),
(9756,'DOC ORDER ANTIBIO GIVEN W/IN 1 HR PRIOR SURG/INC','DOC ORDER ANTIBIO GIVEN W/IN 1 HR PRIOR SURG/INC','4047F','104','','1','0','','','',0, 1, 0, 0),
(9757,'DOC ANTIBIO GIVEN W/IN 1 HR PRIOR SURG/INCIS','DOC ANTIBIO GIVEN W/IN 1 HR PRIOR SURG/INCIS','4048F','104','','1','0','','','',0, 1, 0, 0),
(9758,'DOC ORDER GIVEN TO STOP ANTIBIO W/IN 24 HRS SURG','DOC ORDER GIVEN TO STOP ANTIBIO W/IN 24 HRS SURG','4049F','104','','1','0','','','',0, 1, 0, 0),
(9759,'HYPERTENSION PLAN OF CARE DOCUMENTED','HYPERTENSION PLAN OF CARE DOCUMENTED','4050F','104','','1','0','','','',0, 1, 0, 0),
(9760,'REFERRED FOR AN ARTERIO-VENOUS (AV) FISTULA','REFERRED FOR AN ARTERIO-VENOUS (AV) FISTULA','4051F','104','','1','0','','','',0, 1, 0, 0),
(9761,'HEMODIAL VIA FUNCTIONG AV FISTULA','HEMODIAL VIA FUNCTIONG AV FISTULA','4052F','104','','1','0','','','',0, 1, 0, 0),
(9762,'HEMODIALYSIS VIA FUNCTIONING AVGRAFT','HEMODIALYSIS VIA FUNCTIONING AVGRAFT','4053F','104','','1','0','','','',0, 1, 0, 0),
(9763,'HEMODIALYSIS VIA CATHETER','HEMODIALYSIS VIA CATHETER','4054F','104','','1','0','','','',0, 1, 0, 0),
(9764,'PATIENT RECEIVING PERITONEAL DIALYSIS','PATIENT RECEIVING PERITONEAL DIALYSIS','4055F','104','','1','0','','','',0, 1, 0, 0),
(9765,'APPROPRIATE ORAL REHYD SOLUTION RECOMMENDED','APPROPRIATE ORAL REHYD SOLUTION RECOMMENDED','4056F','104','','1','0','','','',0, 1, 0, 0),
(9766,'PAG PROVIDED TO CAREGIVER','PAG PROVIDED TO CAREGIVER','4058F','104','','1','0','','','',0, 1, 0, 0),
(9767,'PSYCHOTHERAPY SERVICES PROVIDED','PSYCHOTHERAPY SERVICES PROVIDED','4060F','104','','1','0','','','',0, 1, 0, 0),
(9768,'PATIENT REFERRAL FOR PSYCHOTHERAPY DOCUMENTED','PATIENT REFERRAL FOR PSYCHOTHERAPY DOCUMENTED','4062F','104','','1','0','','','',0, 1, 0, 0),
(9769,'ANTIDEPRESSANT RXTHXY CONSIDER & NOT PRESCRIBE','ANTIDEPRESSANT RXTHXY CONSIDER & NOT PRESCRIBE','4063F','104','','1','0','','','',0, 1, 0, 0),
(9770,'ANTIDEPRESSANT PHARMACOTHERAPY PRESCRIBED','ANTIDEPRESSANT PHARMACOTHERAPY PRESCRIBED','4064F','104','','1','0','','','',0, 1, 0, 0),
(9771,'ANTIPSYCHOTIC PHARMACOTHERAPY PRESCRIBED','ANTIPSYCHOTIC PHARMACOTHERAPY PRESCRIBED','4065F','104','','1','0','','','',0, 1, 0, 0),
(9772,'ELECTROCONVULSIVE THERAPY (ECT) PROVIDED','ELECTROCONVULSIVE THERAPY (ECT) PROVIDED','4066F','104','','1','0','','','',0, 1, 0, 0),
(9773,'PT REFERRAL ELECTROCONVULSIVE THXPY (ECT) DOCD','PT REFERRAL ELECTROCONVULSIVE THXPY (ECT) DOCD','4067F','104','','1','0','','','',0, 1, 0, 0),
(9774,'VENOUS THROMBOEMBOLISM (VTE) PROPHYLAXIS RCVD','VENOUS THROMBOEMBOLISM (VTE) PROPHYLAXIS RCVD','4069F','104','','1','0','','','',0, 1, 0, 0),
(9775,'DEEP VEIN THROMB PROPHYL RECVD BY HOSP DAY 2','DEEP VEIN THROMB PROPHYL RECVD BY HOSP DAY 2','4070F','104','','1','0','','','',0, 1, 0, 0),
(9776,'ORAL ANTIPLATELET THERAPY PRESCRBED AT DISCHARGE','ORAL ANTIPLATELET THERAPY PRESCRBED AT DISCHARGE','4073F','104','','1','0','','','',0, 1, 0, 0),
(9777,'ANTICOAGULANT THERAPY PRESCRIBED AT DISCHARGE','ANTICOAGULANT THERAPY PRESCRIBED AT DISCHARGE','4075F','104','','1','0','','','',0, 1, 0, 0),
(9778,'DOC T-PA ADMINISTRATION WAS CONSIDERED','DOC T-PA ADMINISTRATION WAS CONSIDERED','4077F','104','','1','0','','','',0, 1, 0, 0),
(9779,'DOC REHAB SERVICES WERE CONSIDERED','DOC REHAB SERVICES WERE CONSIDERED','4079F','104','','1','0','','','',0, 1, 0, 0),
(9780,'ASPIRIN RECVD W/IN 24 HRS PRIOR ED ARRIVAL/STAY','ASPIRIN RECVD W/IN 24 HRS PRIOR ED ARRIVAL/STAY','4084F','104','','1','0','','','',0, 1, 0, 0),
(9781,'ASPIRIN OR CLOPIDOGREL PRESCRIBED','ASPIRIN OR CLOPIDOGREL PRESCRIBED','4086F','104','','1','0','','','',0, 1, 0, 0),
(9782,'PATIENT RECEIVING ERYTHROPOIETIN THERAPY','PATIENT RECEIVING ERYTHROPOIETIN THERAPY','4090F','104','','1','0','','','',0, 1, 0, 0),
(9783,'PATIENT NOT RECEIVING ERYTHORPOIETIN THERAPY','PATIENT NOT RECEIVING ERYTHORPOIETIN THERAPY','4095F','104','','1','0','','','',0, 1, 0, 0),
(9784,'BISPHOS THXPY VENOUS ORDERED OR RECEIVED','BISPHOS THXPY VENOUS ORDERED OR RECEIVED','4100F','104','','1','0','','','',0, 1, 0, 0),
(9785,'LIMA GRAFT USED IN 1ST ISOLATED CABG PXD','LIMA GRAFT USED IN 1ST ISOLATED CABG PXD','4110F','104','','1','0','','','',0, 1, 0, 0),
(9786,'BETA BLOCKER GIVEN W/IN 24 HRS PRIOR SURG INC','BETA BLOCKER GIVEN W/IN 24 HRS PRIOR SURG INC','4115F','104','','1','0','','','',0, 1, 0, 0),
(9787,'ANTIBIOTIC PRESCRIBED OR DISPENSED','ANTIBIOTIC PRESCRIBED OR DISPENSED','4120F','104','','1','0','','','',0, 1, 0, 0),
(9788,'ANTIBIOTIC NEITHER PRESCRIBED NOR DISPENSED','ANTIBIOTIC NEITHER PRESCRIBED NOR DISPENSED','4124F','104','','1','0','','','',0, 1, 0, 0),
(9789,'ACUTE OTITIS EXTERNA TOPICAL PREPS PRESCRIBED','ACUTE OTITIS EXTERNA TOPICAL PREPS PRESCRIBED','4130F','104','','1','0','','','',0, 1, 0, 0),
(9790,'SYSTEMIC ANTIMICROBIAL TX PRESCRIBED','SYSTEMIC ANTIMICROBIAL TX PRESCRIBED','4131F','104','','1','0','','','',0, 1, 0, 0),
(9791,'SYSTEMIC ANTIMICROBIAL TX NOT PRESCRIBED','SYSTEMIC ANTIMICROBIAL TX NOT PRESCRIBED','4132F','104','','1','0','','','',0, 1, 0, 0),
(9792,'ANTIHISTAMINE/DECONGESTANT PRESCRIBED','ANTIHISTAMINE/DECONGESTANT PRESCRIBED','4133F','104','','1','0','','','',0, 1, 0, 0),
(9793,'ANTIHISTAMINE/DECONGESTANT NOT PRESCRIBED','ANTIHISTAMINE/DECONGESTANT NOT PRESCRIBED','4134F','104','','1','0','','','',0, 1, 0, 0),
(9794,'SYSTEMIC CORTICOSTEROIDS PRESCRIBED','SYSTEMIC CORTICOSTEROIDS PRESCRIBED','4135F','104','','1','0','','','',0, 1, 0, 0),
(9795,'SYSTEMIC CORTICOSTEROIDS NOT PRESCRIBED','SYSTEMIC CORTICOSTEROIDS NOT PRESCRIBED','4136F','104','','1','0','','','',0, 1, 0, 0),
(9796,'INHALED CORTICOSTEROIDS PRESCRIBED','INHALED CORTICOSTEROIDS PRESCRIBED','4140F','104','','1','0','','','',0, 1, 0, 0),
(9797,'CORTICOSTEROID SPARING THERAPY PRESCRIBED','CORTICOSTEROID SPARING THERAPY PRESCRIBED','4142F','104','','1','0','','','',0, 1, 0, 0),
(9798,'ALTERNATIVE LONG-TERM CONTROL MEDICATION RXD','ALTERNATIVE LONG-TERM CONTROL MEDICATION RXD','4144F','104','','1','0','','','',0, 1, 0, 0),
(9799,'2+ ANTI-HYPERTENSIVE AGENTS RXD OR TAKEN','2+ ANTI-HYPERTENSIVE AGENTS RXD OR TAKEN','4145F','104','','1','0','','','',0, 1, 0, 0),
(9800,'HEPATITIS A VACCINE ADMIN OR PREVIOSLY RECVD','HEPATITIS A VACCINE ADMIN OR PREVIOSLY RECVD','4148F','104','','1','0','','','',0, 1, 0, 0),
(9801,'HEPATITIS B VACCCINE ADMIN OR PREVIOSLY RECVD','HEPATITIS B VACCCINE ADMIN OR PREVIOSLY RECVD','4149F','104','','1','0','','','',0, 1, 0, 0),
(9802,'CURRENT HEPATITIS C ANTIVIRAL TREATMENT','CURRENT HEPATITIS C ANTIVIRAL TREATMENT','4150F','104','','1','0','','','',0, 1, 0, 0),
(9803,'NO CURRENT HEPATITIS C ANTIVIRAL TREATMENT','NO CURRENT HEPATITIS C ANTIVIRAL TREATMENT','4151F','104','','1','0','','','',0, 1, 0, 0),
(9804,'COMB PEGINTERF/RIBAVIRIN TX PRESCRIBED','COMB PEGINTERF/RIBAVIRIN TX PRESCRIBED','4153F','104','','1','0','','','',0, 1, 0, 0),
(9805,'HEPATITIS A VACCINE SERIES PREVIOUSLY RECEIVED','HEPATITIS A VACCINE SERIES PREVIOUSLY RECEIVED','4155F','104','','1','0','','','',0, 1, 0, 0),
(9806,'HEPATITIS B VACCINE SERIES PREVIOUSLY RECEIVED','HEPATITIS B VACCINE SERIES PREVIOUSLY RECEIVED','4157F','104','','1','0','','','',0, 1, 0, 0),
(9807,'PATIENT COUNSELED ABOUT RISKS ALCOHOL USE','PATIENT COUNSELED ABOUT RISKS ALCOHOL USE','4158F','104','','1','0','','','',0, 1, 0, 0),
(9808,'CONTRACEPTION COUNSEL BEFORE ANTIVIRAL TX','CONTRACEPTION COUNSEL BEFORE ANTIVIRAL TX','4159F','104','','1','0','','','',0, 1, 0, 0),
(9809,'PT COUNSELING TREATMENT OPTIONS PROSTATE CANCER','PT COUNSELING TREATMENT OPTIONS PROSTATE CANCER','4163F','104','','1','0','','','',0, 1, 0, 0),
(9810,'ADJUVANT HORMONAL THXPY RX/ADMIN','ADJUVANT HORMONAL THXPY RX/ADMIN','4164F','104','','1','0','','','',0, 1, 0, 0),
(9811,'3D-CRT OR INTENSITY MODUL RAD THXPY RECVD','3D-CRT OR INTENSITY MODUL RAD THXPY RECVD','4165F','104','','1','0','','','',0, 1, 0, 0),
(9812,'HEAD-BED ELEV 30-45 DEG 1ST VENT DAY ORDERED','HEAD-BED ELEV 30-45 DEG 1ST VENT DAY ORDERED','4167F','104','','1','0','','','',0, 1, 0, 0),
(9813,'PT RCVG CARE ICU & RCVNG MECH VENT 24 HRS/<','PT RCVG CARE ICU & RCVNG MECH VENT 24 HRS/<','4168F','104','','1','0','','','',0, 1, 0, 0),
(9814,'PT NOT RCVG CARE IN ICU/NOT RCVG MECHL VENT','PT NOT RCVG CARE IN ICU/NOT RCVG MECHL VENT','4169F','104','','1','0','','','',0, 1, 0, 0),
(9815,'PATIENT RECEIVING (ESA) THERAPY','PATIENT RECEIVING (ESA) THERAPY','4171F','104','','1','0','','','',0, 1, 0, 0),
(9816,'PATIENT NOT RECEIVING (ESA) THERAPY','PATIENT NOT RECEIVING (ESA) THERAPY','4172F','104','','1','0','','','',0, 1, 0, 0),
(9817,'TLK VIS FXN & QUAL LIFE/TRXMNT FOR PT/CRGVR','TLK VIS FXN & QUAL LIFE/TRXMNT FOR PT/CRGVR','4174F','104','','1','0','','','',0, 1, 0, 0),
(9818,'CORRECT VISUAL ACUIT 20/40/> W/IN 90 DAYS SURG','CORRECT VISUAL ACUIT 20/40/> W/IN 90 DAYS SURG','4175F','104','','1','0','','','',0, 1, 0, 0),
(9819,'COUNSEL UV LITE PROTEC PREV/PROG CATARACT DEVEL','COUNSEL UV LITE PROTEC PREV/PROG CATARACT DEVEL','4176F','104','','1','0','','','',0, 1, 0, 0),
(9820,'COUNSEL BENEF/RISK AREDS PREV AGE RELATED AMD','COUNSEL BENEF/RISK AREDS PREV AGE RELATED AMD','4177F','104','','1','0','','','',0, 1, 0, 0),
(9821,'ANTI-D IMMUNE GLOBULIN RCVD 26-30 WKS GESTATION','ANTI-D IMMUNE GLOBULIN RCVD 26-30 WKS GESTATION','4178F','104','','1','0','','','',0, 1, 0, 0),
(9822,'TAMOXIFEN OR AROMATASE INHIBITOR (AI) RXD','TAMOXIFEN OR AROMATASE INHIBITOR (AI) RXD','4179F','104','','1','0','','','',0, 1, 0, 0),
(9823,'ADJVNT CHEMO RFRRD RXD/RCVD STAGE III COLON CA','ADJVNT CHEMO RFRRD RXD/RCVD STAGE III COLON CA','4180F','104','','1','0','','','',0, 1, 0, 0),
(9824,'CONFORMAL RADIATION THERAPY RECEIVED','CONFORMAL RADIATION THERAPY RECEIVED','4181F','104','','1','0','','','',0, 1, 0, 0),
(9825,'CONFORMAL RADIATION THERAPY NOT RECEIVED','CONFORMAL RADIATION THERAPY NOT RECEIVED','4182F','104','','1','0','','','',0, 1, 0, 0),
(9826,'NONSTOP 12MON THXPY W/PPI OR H2 H2RA RCVD','NONSTOP 12MON THXPY W/PPI OR H2 H2RA RCVD','4185F','104','','1','0','','','',0, 1, 0, 0),
(9827,'NO CONTIN 12MON THXPY W/PPI OR H2 H2RA RCVD','NO CONTIN 12MON THXPY W/PPI OR H2 H2RA RCVD','4186F','104','','1','0','','','',0, 1, 0, 0),
(9828,'DIS MODFY ANTI-RHEU DRUG THXPY RX/GVN','DIS MODFY ANTI-RHEU DRUG THXPY RX/GVN','4187F','104','','1','0','','','',0, 1, 0, 0),
(9829,'APPROP ACE/ARB THXP MONIT TEST ORDRD/DONE','APPROP ACE/ARB THXP MONIT TEST ORDRD/DONE','4188F','104','','1','0','','','',0, 1, 0, 0),
(9830,'APPROP DIGOXIN THXP MONIT TST ORDRD/DONE','APPROP DIGOXIN THXP MONIT TST ORDRD/DONE','4189F','104','','1','0','','','',0, 1, 0, 0),
(9831,'APPROP DIURETIC THXP MONIT TST ORDRD/DONE','APPROP DIURETIC THXP MONIT TST ORDRD/DONE','4190F','104','','1','0','','','',0, 1, 0, 0),
(9832,'APPROP ANTICONVUL THXP MONIT TST ORDRD/DONE','APPROP ANTICONVUL THXP MONIT TST ORDRD/DONE','4191F','104','','1','0','','','',0, 1, 0, 0),
(9833,'PATIENT NOT RECEIVING GLUCOCORTICOID','PATIENT NOT RECEIVING GLUCOCORTICOID','4192F','104','','1','0','','','',0, 1, 0, 0),
(9834,'PATIENT RCVNG <10 MG DAILY PREDNISONE','PATIENT RCVNG <10 MG DAILY PREDNISONE','4193F','104','','1','0','','','',0, 1, 0, 0),
(9835,'PATIENT RCVNG >/=10 MG DAILY PREDNISONE','PATIENT RCVNG >/=10 MG DAILY PREDNISONE','4194F','104','','1','0','','','',0, 1, 0, 0),
(9836,'PT RCVNG 1ST BIOL ANTI-RHEUM DRUG THXRPY FOR RA','PT RCVNG 1ST BIOL ANTI-RHEUM DRUG THXRPY FOR RA','4195F','104','','1','0','','','',0, 1, 0, 0),
(9837,'PT NOT RCVNG 1ST BIOL ANTI-RHEUM DRUG THXPY RA','PT NOT RCVNG 1ST BIOL ANTI-RHEUM DRUG THXPY RA','4196F','104','','1','0','','','',0, 1, 0, 0),
(9838,'EXTRNL BM RADIOTHXPY TO PROST W/WO NODAL IRRAD','EXTRNL BM RADIOTHXPY TO PROST W/WO NODAL IRRAD','4200F','104','','1','0','','','',0, 1, 0, 0),
(9839,'EXTRNL BM RADIOTHXPY W/WO NODAL IRRAD AS ADJV','EXTRNL BM RADIOTHXPY W/WO NODAL IRRAD AS ADJV','4201F','104','','1','0','','','',0, 1, 0, 0),
(9840,'ACE/ARB MEDICATION THERAPY 6 MONTHS/>','ACE/ARB MEDICATION THERAPY 6 MONTHS/>','4210F','104','','1','0','','','',0, 1, 0, 0),
(9841,'DIGOXIN MEDICATION THERAPY 6 MONTHS/>','DIGOXIN MEDICATION THERAPY 6 MONTHS/>','4220F','104','','1','0','','','',0, 1, 0, 0),
(9842,'DIURETIC MEDICATION THERAPY 6 MOS/>','DIURETIC MEDICATION THERAPY 6 MOS/>','4221F','104','','1','0','','','',0, 1, 0, 0),
(9843,'ANTICONVUL MED THERAPY 6 MOS/>','ANTICONVUL MED THERAPY 6 MOS/>','4230F','104','','1','0','','','',0, 1, 0, 0),
(9844,'INSTR THER XRCS-DR FLLWUP PT EPSD BACK PN >12 WK','INSTR THER XRCS-DR FLLWUP PT EPSD BACK PN >12 WK','4240F','104','','1','0','','','',0, 1, 0, 0),
(9845,'TLK RE SPRVSD XRCS PROG TO PTS BACK PN >12WKS','TLK RE SPRVSD XRCS PROG TO PTS BACK PN >12WKS','4242F','104','','1','0','','','',0, 1, 0, 0),
(9846,'PT TLK 1ST VST TO KEEP/RESUME NORMAL ACTIVITIES','PT TLK 1ST VST TO KEEP/RESUME NORMAL ACTIVITIES','4245F','104','','1','0','','','',0, 1, 0, 0),
(9847,'COUNSEL INIT BACK PAIN AGNST BED REST 4 DAYS/>','COUNSEL INIT BACK PAIN AGNST BED REST 4 DAYS/>','4248F','104','','1','0','','','',0, 1, 0, 0),
(9848,'ACTV WRMNG INTRAOP FOR NORMOTHERMIA','ACTV WRMNG INTRAOP FOR NORMOTHERMIA','4250F','104','','1','0','','','',0, 1, 0, 0),
(9849,'DURATION GEN NEUR ANESTH 60 MINS/> DOC RECORD','DURATION GEN NEUR ANESTH 60 MINS/> DOC RECORD','4255F','104','','1','0','','','',0, 1, 0, 0),
(9850,'DURATION GEN NEUR ANESTH <60 MIN DOCD RECORD','DURATION GEN NEUR ANESTH <60 MIN DOCD RECORD','4256F','104','','1','0','','','',0, 1, 0, 0),
(9851,'WOUND SURFACE CULTURE TECHNIQUE USED','WOUND SURFACE CULTURE TECHNIQUE USED','4260F','104','','1','0','','','',0, 1, 0, 0),
(9852,'TECH OTHER THAN SURFACE CULTURE WOUND EXUD USED','TECH OTHER THAN SURFACE CULTURE WOUND EXUD USED','4261F','104','','1','0','','','',0, 1, 0, 0),
(9853,'USE OF WET TO DRY DRESSINGS PRESCRIBED RECMD','USE OF WET TO DRY DRESSINGS PRESCRIBED RECMD','4265F','104','','1','0','','','',0, 1, 0, 0),
(9854,'USE WET TO DRY DRESSINGS NEITHER RXD NOR RECMD','USE WET TO DRY DRESSINGS NEITHER RXD NOR RECMD','4266F','104','','1','0','','','',0, 1, 0, 0),
(9855,'COMPRESSION THERAPY PRESCRIBED','COMPRESSION THERAPY PRESCRIBED','4267F','104','','1','0','','','',0, 1, 0, 0),
(9856,'PT ED RE NEED LONG TERM COMPRESS THXPY RCVD','PT ED RE NEED LONG TERM COMPRESS THXPY RCVD','4268F','104','','1','0','','','',0, 1, 0, 0),
(9857,'APPROP METHOD OFFLOADING PRESCRIBED','APPROP METHOD OFFLOADING PRESCRIBED','4269F','104','','1','0','','','',0, 1, 0, 0),
(9858,'PT RCVNG POTENT ANTI R-VIRAL THX 6 MON OR MORE','PT RCVNG POTENT ANTI R-VIRAL THX 6 MON OR MORE','4270F','104','','1','0','','','',0, 1, 0, 0),
(9859,'PT RCVNG POT ANTI R-VIRAL THX <6 MON/NOT RCVN','PT RCVNG POT ANTI R-VIRAL THX <6 MON/NOT RCVN','4271F','104','','1','0','','','',0, 1, 0, 0),
(9860,'FLU IMMUNO ADMIND/PREVIOUSLY RCVD','FLU IMMUNO ADMIND/PREVIOUSLY RCVD','4274F','104','','1','0','','','',0, 1, 0, 0),
(9861,'POTENT ANTIRETROVIRAL THERAPY PRESCRIBED','POTENT ANTIRETROVIRAL THERAPY PRESCRIBED','4276F','104','','1','0','','','',0, 1, 0, 0),
(9862,'PNEUMOCYSTIS JIROVECI PNEUMONIA PROPHYLAXIS RXD','PNEUMOCYSTIS JIROVECI PNEUMONIA PROPHYLAXIS RXD','4279F','104','','1','0','','','',0, 1, 0, 0),
(9863,'PNEUMOCYS JIROVECI PNEUMO PRPHYLXS PRSCRBD 3 MON','PNEUMOCYS JIROVECI PNEUMO PRPHYLXS PRSCRBD 3 MON','4280F','104','','1','0','','','',0, 1, 0, 0),
(9864,'PATIENT SCREENED FOR INJECTION DRUG USE','PATIENT SCREENED FOR INJECTION DRUG USE','4290F','104','','1','0','','','',0, 1, 0, 0),
(9865,'PT SCRND HGH-RSK SEXUAL BEHAVIOR','PT SCRND HGH-RSK SEXUAL BEHAVIOR','4293F','104','','1','0','','','',0, 1, 0, 0),
(9866,'PT RCVNG WARFARIN THXPY NONVALV AFIB OR AFLUT','PT RCVNG WARFARIN THXPY NONVALV AFIB OR AFLUT','4300F','104','','1','0','','','',0, 1, 0, 0),
(9867,'PT NOT RCVNG WARFARIN THXPY NONVALV AFIB/AFLUT','PT NOT RCVNG WARFARIN THXPY NONVALV AFIB/AFLUT','4301F','104','','1','0','','','',0, 1, 0, 0),
(9868,'PT EDUC FOOT CARE & DAILY INSPCTN FEET RCVD','PT EDUC FOOT CARE & DAILY INSPCTN FEET RCVD','4305F','104','','1','0','','','',0, 1, 0, 0),
(9869,'PT COUNSEL PSYCHOSOC&PHARM TX OPIOID ADDICTION','PT COUNSEL PSYCHOSOC&PHARM TX OPIOID ADDICTION','4306F','104','','1','0','','','',0, 1, 0, 0),
(9870,'PT COUNSEL PSYCHSOC & PHARM TX ALCOHOL DEPEND','PT COUNSEL PSYCHSOC & PHARM TX ALCOHOL DEPEND','4320F','104','','1','0','','','',0, 1, 0, 0),
(9871,'CRGVR PROVIDED W/ED REFERRED ADDL RESOURCES','CRGVR PROVIDED W/ED REFERRED ADDL RESOURCES','4322F','104','','1','0','','','',0, 1, 0, 0),
(9872,'PT QUERIED PARKINSONS MED-RELATED COMPLICATION','PT QUERIED PARKINSONS MED-RELATED COMPLICATION','4324F','104','','1','0','','','',0, 1, 0, 0),
(9873,'MEDICAL & SURGICAL TREATMENT OPTION REVIEW W/P','MEDICAL & SURGICAL TREATMENT OPTION REVIEW W/P','4325F','104','','1','0','','','',0, 1, 0, 0),
(9874,'PT/CAREGIVER QUERIED AUTONOMIC DYSFUNCJ SYMPTOMS','PT/CAREGIVER QUERIED AUTONOMIC DYSFUNCJ SYMPTOMS','4326F','104','','1','0','','','',0, 1, 0, 0),
(9875,'PT/CAREGIVER QUERIED SLEEP DISTURBANCES','PT/CAREGIVER QUERIED SLEEP DISTURBANCES','4328F','104','','1','0','','','',0, 1, 0, 0),
(9876,'EPILEPSY SPECIFIC SAFETY COUNSELING TO PATIENT','EPILEPSY SPECIFIC SAFETY COUNSELING TO PATIENT','4330F','104','','1','0','','','',0, 1, 0, 0),
(9877,'COUNSEL WOMEN CHILDBEARING POTENTIAL W/EPILEPSY','COUNSEL WOMEN CHILDBEARING POTENTIAL W/EPILEPSY','4340F','104','','1','0','','','',0, 1, 0, 0),
(9878,'COUNSELING PROVIDED SYMP MNGMNT PALLIATION','COUNSELING PROVIDED SYMP MNGMNT PALLIATION','4350F','104','','1','0','','','',0, 1, 0, 0),
(9879,'REHAB THERAPY OPTIONS DISCUSSED W/PATIENT','REHAB THERAPY OPTIONS DISCUSSED W/PATIENT','4400F','104','','1','0','','','',0, 1, 0, 0),
(9880,'SELF-CARE EDUCATION PROVIDED TO PATIENT','SELF-CARE EDUCATION PROVIDED TO PATIENT','4450F','104','','1','0','','','',0, 1, 0, 0),
(9881,'IMPLANT CARDIOVERT-DEFIB (ICD) COUNSELING PROV','IMPLANT CARDIOVERT-DEFIB (ICD) COUNSELING PROV','4470F','104','','1','0','','','',0, 1, 0, 0),
(9882,'PT RCVNG ACE/ARB BETA BLOCKER TX 3 MONS/LONGER','PT RCVNG ACE/ARB BETA BLOCKER TX 3 MONS/LONGER','4480F','104','','1','0','','','',0, 1, 0, 0),
(9883,'PT RCVNG ACE/ARB AND BETA BLOCKER < 3 MONTHS','PT RCVNG ACE/ARB AND BETA BLOCKER < 3 MONTHS','4481F','104','','1','0','','','',0, 1, 0, 0),
(9884,'REFERRED TO OUTPT CARD REHABILITATION PROGRAM','REFERRED TO OUTPT CARD REHABILITATION PROGRAM','4500F','104','','1','0','','','',0, 1, 0, 0),
(9885,'PREVIOUS CARDIAC REHAB FOR QUAL CARD EVENT DONE','PREVIOUS CARDIAC REHAB FOR QUAL CARD EVENT DONE','4510F','104','','1','0','','','',0, 1, 0, 0),
(9886,'NEUROPSYCHIATRIC INTERVENTION ORDERED','NEUROPSYCHIATRIC INTERVENTION ORDERED','4525F','104','','1','0','','','',0, 1, 0, 0),
(9887,'NEUROPSYCHIATRIC INTERVENTION RECEIVED','NEUROPSYCHIATRIC INTERVENTION RECEIVED','4526F','104','','1','0','','','',0, 1, 0, 0),
(9888,'DISEASE MODIFYING PHARMACOTHERAPY DISCUSSED','DISEASE MODIFYING PHARMACOTHERAPY DISCUSSED','4540F','104','','1','0','','','',0, 1, 0, 0),
(9889,'TX PSEUDOBULBAR AFFECT SIALORRHEA/ALS SYMP','TX PSEUDOBULBAR AFFECT SIALORRHEA/ALS SYMP','4541F','104','','1','0','','','',0, 1, 0, 0),
(9890,'OPTIONS NONINVASIVE RESP SUPPORT DISCUSSED W/PT','OPTIONS NONINVASIVE RESP SUPPORT DISCUSSED W/PT','4550F','104','','1','0','','','',0, 1, 0, 0),
(9891,'NUTRITIONAL SUPPORT OFFERED','NUTRITIONAL SUPPORT OFFERED','4551F','104','','1','0','','','',0, 1, 0, 0),
(9892,'PT OFFERED REFERRAL SPEECH LANGUAGE PATHOLOGIST','PT OFFERED REFERRAL SPEECH LANGUAGE PATHOLOGIST','4552F','104','','1','0','','','',0, 1, 0, 0),
(9893,'PT OFFERED ASSISTANCE PLANNING END LIFE ISSUES','PT OFFERED ASSISTANCE PLANNING END LIFE ISSUES','4553F','104','','1','0','','','',0, 1, 0, 0),
(9894,'PT RECEIVED INHALATIONAL ANESTHETIC AGENT','PT RECEIVED INHALATIONAL ANESTHETIC AGENT','4554F','104','','1','0','','','',0, 1, 0, 0),
(9895,'PT DID NOT RECEIVE INHALATIONAL ANESTHETIC AGENT','PT DID NOT RECEIVE INHALATIONAL ANESTHETIC AGENT','4555F','104','','1','0','','','',0, 1, 0, 0),
(9896,'PT SHOWS 3+RISK FACTORS POST-OP NAUSEA&VOMITING','PT SHOWS 3+RISK FACTORS POST-OP NAUSEA&VOMITING','4556F','104','','1','0','','','',0, 1, 0, 0),
(9897,'PT NO EXHIBIT 3+ RISK FACTORS POST-OP NAUSEA/VOM','PT NO EXHIBIT 3+ RISK FACTORS POST-OP NAUSEA/VOM','4557F','104','','1','0','','','',0, 1, 0, 0),
(9898,'PT RCEVD 2 PROPHYLACTIC RX AGENTS PRE&INTRA-OP','PT RCEVD 2 PROPHYLACTIC RX AGENTS PRE&INTRA-OP','4558F','104','','1','0','','','',0, 1, 0, 0),
(9899,'1BODY TEMP MEAS>=35.5C IN 30-15 MINS POST ANESTH','1BODY TEMP MEAS>=35.5C IN 30-15 MINS POST ANESTH','4559F','104','','1','0','','','',0, 1, 0, 0),
(9900,'ANESTH DID NOT INVOLVE GENERAL/NEURAXIAL ANESTH','ANESTH DID NOT INVOLVE GENERAL/NEURAXIAL ANESTH','4560F','104','','1','0','','','',0, 1, 0, 0),
(9901,'PATIENT HAS A CORONARY ARTERY STENT','PATIENT HAS A CORONARY ARTERY STENT','4561F','104','','1','0','','','',0, 1, 0, 0),
(9902,'PATIENT DOES NOT HAVE A CORONARY ARTERY STENT','PATIENT DOES NOT HAVE A CORONARY ARTERY STENT','4562F','104','','1','0','','','',0, 1, 0, 0),
(9903,'PT RECVD ASPIRIN W/IN 24 HRS PRIOR ANESTH START','PT RECVD ASPIRIN W/IN 24 HRS PRIOR ANESTH START','4563F','104','','1','0','','','',0, 1, 0, 0),
(9904,'COUNSEL NEW/CHANGING MOLES SELF-EXAMINATION','COUNSEL NEW/CHANGING MOLES SELF-EXAMINATION','5005F','104','','1','0','','','',0, 1, 0, 0),
(9905,'DILATED MACULAR/FUNDUS XM COMMUNJ TX PHYS/QHP','DILATED MACULAR/FUNDUS XM COMMUNJ TX PHYS/QHP','5010F','104','','1','0','','','',0, 1, 0, 0),
(9906,'DOCD CONTACT THAT FX EXISTED & PT TSTED/TXD OP','DOCD CONTACT THAT FX EXISTED & PT TSTED/TXD OP','5015F','104','','1','0','','','',0, 1, 0, 0),
(9907,'TX SUMM RPRT COMMUN PHYS&PT 1 MO COMPLETE','TX SUMM RPRT COMMUN PHYS&PT 1 MO COMPLETE','5020F','104','','1','0','','','',0, 1, 0, 0),
(9908,'TX COMMUN PROVIDERS CONTINUING CARE 1 MO DX','TX COMMUN PROVIDERS CONTINUING CARE 1 MO DX','5050F','104','','1','0','','','',0, 1, 0, 0),
(9909,'FINDNGS DIAG MAM TO MNGNG PRACT 3 DAYS INTERP','FINDNGS DIAG MAM TO MNGNG PRACT 3 DAYS INTERP','5060F','104','','1','0','','','',0, 1, 0, 0),
(9910,'DOC DIRECT COMM DIAG MAMMO FNDNGS-PHONE/PERSON','DOC DIRECT COMM DIAG MAMMO FNDNGS-PHONE/PERSON','5062F','104','','1','0','','','',0, 1, 0, 0),
(9911,'FX RISK REF PHYS/QHP COMMJ 24 HRS IMAGING STUDY','FX RISK REF PHYS/QHP COMMJ 24 HRS IMAGING STUDY','5100F','104','','1','0','','','',0, 1, 0, 0),
(9912,'CONSID NEURO EVAL APPROP SURG THXPY EPIL 3YRS','CONSID NEURO EVAL APPROP SURG THXPY EPIL 3YRS','5200F','104','','1','0','','','',0, 1, 0, 0),
(9913,'ASTHMA DISCHARGE PLAN PRESENT','ASTHMA DISCHARGE PLAN PRESENT','5250F','104','','1','0','','','',0, 1, 0, 0),
(9914,'RATIONALE FOR LEVEL OF CARE DOCUMENTED','RATIONALE FOR LEVEL OF CARE DOCUMENTED','6005F','104','','1','0','','','',0, 1, 0, 0),
(9915,'DYSPHAGIA SCREENING PRIOR ORAL INTAKE','DYSPHAGIA SCREENING PRIOR ORAL INTAKE','6010F','104','','1','0','','','',0, 1, 0, 0),
(9916,'PATIENT OK FOR PER ORAL INTAKE (FOOD/MEDICATION)','PATIENT OK FOR PER ORAL INTAKE (FOOD/MEDICATION)','6015F','104','','1','0','','','',0, 1, 0, 0),
(9917,'NOTHING BY MOUTH ORDERED','NOTHING BY MOUTH ORDERED','6020F','104','','1','0','','','',0, 1, 0, 0),
(9918,'ALL ELEM OF MAX STERILE BARRIER TECHNQ FLWD','ALL ELEM OF MAX STERILE BARRIER TECHNQ FLWD','6030F','104','','1','0','','','',0, 1, 0, 0),
(9919,'USE APPROP RAD DOSE RDXN DEV/MAN TECHS DOCD','USE APPROP RAD DOSE RDXN DEV/MAN TECHS DOCD','6040F','104','','1','0','','','',0, 1, 0, 0),
(9920,'RAD EXPOS/TIME IN LAST RPRT FLUORO PRXD DOCD','RAD EXPOS/TIME IN LAST RPRT FLUORO PRXD DOCD','6045F','104','','1','0','','','',0, 1, 0, 0),
(9921,'PATIENT QUERIED COUNSELED RE AED SIDE EFFECTS','PATIENT QUERIED COUNSELED RE AED SIDE EFFECTS','6070F','104','','1','0','','','',0, 1, 0, 0),
(9922,'PATIENT QUERIED ABOUT FALLS','PATIENT QUERIED ABOUT FALLS','6080F','104','','1','0','','','',0, 1, 0, 0),
(9923,'PATIENT SAFETY COUNSEL DISEASE STAGE APPROPRIATE','PATIENT SAFETY COUNSEL DISEASE STAGE APPROPRIATE','6090F','104','','1','0','','','',0, 1, 0, 0),
(9924,'VERIFY CORRECT PT SITE PXD DOCUMENTED','VERIFY CORRECT PT SITE PXD DOCUMENTED','6100F','104','','1','0','','','',0, 1, 0, 0),
(9925,'SAFETY COUNSELING DEMENTIA PROVIDED','SAFETY COUNSELING DEMENTIA PROVIDED','6101F','104','','1','0','','','',0, 1, 0, 0),
(9926,'SAFETY COUNSELING DEMENTIA ORDERED','SAFETY COUNSELING DEMENTIA ORDERED','6102F','104','','1','0','','','',0, 1, 0, 0),
(9927,'COUNSELING PROV RE RISKS DRIVING ALT TO DRIVING','COUNSELING PROV RE RISKS DRIVING ALT TO DRIVING','6110F','104','','1','0','','','',0, 1, 0, 0),
(9928,'PT NOT RCVNG 1ST COURSE OF ANTI-TNF THERAPY','PT NOT RCVNG 1ST COURSE OF ANTI-TNF THERAPY','6150F','104','','1','0','','','',0, 1, 0, 0),
(9929,'PT INFORMATION ENTERED INTO RECALL SYSTEM','PT INFORMATION ENTERED INTO RECALL SYSTEM','7010F','104','','1','0','','','',0, 1, 0, 0),
(9930,'MAMMO ASSESSMENT CAT IN DATABASE FOR RATE','MAMMO ASSESSMENT CAT IN DATABASE FOR RATE','7020F','104','','1','0','','','',0, 1, 0, 0),
(9931,'INFO SYSTEM ANALYSIS ABNORMAL INTERPRATE','INFO SYSTEM ANALYSIS ABNORMAL INTERPRATE','7025F','104','','1','0','','','',0, 1, 0, 0),
(9932,'AORTIC ANEURYSM<5CM MAX DIAM CENTERLINE/AXIAL CT','AORTIC ANEURYSM<5CM MAX DIAM CENTERLINE/AXIAL CT','9001F','104','','1','0','','','',0, 1, 0, 0),
(9933,'AORTIC ANEURYSM 5-5.4CM MAX DIAM CTRLN/AXIAL CT','AORTIC ANEURYSM 5-5.4CM MAX DIAM CTRLN/AXIAL CT','9002F','104','','1','0','','','',0, 1, 0, 0),
(9934,'AORTIC ARYSM 5.5-5.9CM MAX DIAM CTRLN/AXIAL CT','AORTIC ARYSM 5.5-5.9CM MAX DIAM CTRLN/AXIAL CT','9003F','104','','1','0','','','',0, 1, 0, 0),
(9935,'AORTIC ANEURYSM 6/> CM MAX DIAM CTRLN/AXIAL CT','AORTIC ANEURYSM 6/> CM MAX DIAM CTRLN/AXIAL CT','9004F','104','','1','0','','','',0, 1, 0, 0),
(9936,'ASYMPT CAROT STEN NO ISCHEM/STRK CAROT/VRTBROBAS','ASYMPT CAROT STEN NO ISCHEM/STRK CAROT/VRTBROBAS','9005F','104','','1','0','','','',0, 1, 0, 0),
(9937,'SYMPT CAROT STENOS IPSIL CAROT TIA/STRK<120DAYS','SYMPT CAROT STENOS IPSIL CAROT TIA/STRK<120DAYS','9006F','104','','1','0','','','',0, 1, 0, 0),
(9938,'OTHER CAROTID STENT IPSIL TIA/STRK 120 DAYS/>','OTHER CAROTID STENT IPSIL TIA/STRK 120 DAYS/>','9007F','104','','1','0','','','',0, 1, 0, 0),
(9939,'EXTRACORPOREAL SHOCK WAVE MUSCSKEL NOS LOW ENRGY','EXTRACORPOREAL SHOCK WAVE MUSCSKEL NOS LOW ENRGY','0019T','104','','1','0','','','',0, 1, 0, 0),
(9940,'CEREBRAL PERFUSION ANALYS CT W/BLOOD FLOW&VOLUME','CEREBRAL PERFUSION ANALYS CT W/BLOOD FLOW&VOLUME','0042T','104','','1','0','','','',0, 1, 0, 0),
(9941,'IMPLTJ TOT RPLCMT HRT SYS W/RCP CARDIECTOMY','IMPLTJ TOT RPLCMT HRT SYS W/RCP CARDIECTOMY','0051T','104','','1','0','','','',0, 1, 0, 0),
(9942,'RPLCMT/RPR THRC UNIT TOT RPLCMT HRT SYS','RPLCMT/RPR THRC UNIT TOT RPLCMT HRT SYS','0052T','104','','1','0','','','',0, 1, 0, 0),
(9943,'RPLCMT/RPR IMPLTBL COMPNT TOT RPLCMT HRT EX THRC','RPLCMT/RPR IMPLTBL COMPNT TOT RPLCMT HRT EX THRC','0053T','104','','1','0','','','',0, 1, 0, 0),
(9944,'CPTR-ASST MUSCSKEL NAVIGJ ORTHO FLUOR IMAGES','CPTR-ASST MUSCSKEL NAVIGJ ORTHO FLUOR IMAGES','0054T','104','','1','0','','','',0, 1, 0, 0),
(9945,'CPTR-ASST MUSCSKEL NAVIGJ ORTHO CT/MRI','CPTR-ASST MUSCSKEL NAVIGJ ORTHO CT/MRI','0055T','104','','1','0','','','',0, 1, 0, 0),
(9946,'CRYOPRESERVATION REPRODUCTIVE TISSUE OVARIAN','CRYOPRESERVATION REPRODUCTIVE TISSUE OVARIAN','0058T','104','','1','0','','','',0, 1, 0, 0),
(9947,'US ABLATJ UTERINE LEIOMYOMATA < 200 CC TISSUE','US ABLATJ UTERINE LEIOMYOMATA < 200 CC TISSUE','0071T','104','','1','0','','','',0, 1, 0, 0),
(9948,'US ABLATJ UTERINE LEIOMYOMAT >/EQUAL 200 CC TISS','US ABLATJ UTERINE LEIOMYOMAT >/EQUAL 200 CC TISS','0072T','104','','1','0','','','',0, 1, 0, 0),
(9949,'TCAT PLMT XTRC VRT CRTD STENT RS&I PRQ 1ST VSL','TCAT PLMT XTRC VRT CRTD STENT RS&I PRQ 1ST VSL','0075T','104','','1','0','','','',0, 1, 0, 0),
(9950,'TCAT PLMT XTRC VRT CRTD STENT RS&IPRQ EA VSL','TCAT PLMT XTRC VRT CRTD STENT RS&IPRQ EA VSL','0076T','104','','1','0','','','',0, 1, 0, 0),
(9951,'BREATH TEST HEART TRANSPLANT REJECTION','BREATH TEST HEART TRANSPLANT REJECTION','0085T','104','','1','0','','','',0, 1, 0, 0),
(9952,'RMVL TOT DISC ARTHRP ANT APPR CRV EA NTRSPC','RMVL TOT DISC ARTHRP ANT APPR CRV EA NTRSPC','0095T','104','','1','0','','','',0, 1, 0, 0),
(9953,'REVJ TOT DISC ARTHRP ANT APPR CRV EA NTRSPC','REVJ TOT DISC ARTHRP ANT APPR CRV EA NTRSPC','0098T','104','','1','0','','','',0, 1, 0, 0),
(9954,'PLMT SCJNCL RTA PROSTH&PLS&IMPLTJ INTRA-OC RTA','PLMT SCJNCL RTA PROSTH&PLS&IMPLTJ INTRA-OC RTA','0100T','104','','1','0','','','',0, 1, 0, 0),
(9955,'EXTRCORPL SHOCK WAVE MUSCSKELE NOS HIGH ENERGY','EXTRCORPL SHOCK WAVE MUSCSKELE NOS HIGH ENERGY','0101T','104','','1','0','','','',0, 1, 0, 0),
(9956,'EXTRCRPL SHOCK WAVE W/ANES LAT HUMERL EPICONDYLE','EXTRCRPL SHOCK WAVE W/ANES LAT HUMERL EPICONDYLE','0102T','104','','1','0','','','',0, 1, 0, 0),
(9957,'QUANT SENSORY TEST&INTERPJ/XTR W/TOUCH STIMULI','QUANT SENSORY TEST&INTERPJ/XTR W/TOUCH STIMULI','0106T','104','','1','0','','','',0, 1, 0, 0),
(9958,'QUANT SENSORY TEST&INTERPJ/XTR W/VIBRJ STIMULI','QUANT SENSORY TEST&INTERPJ/XTR W/VIBRJ STIMULI','0107T','104','','1','0','','','',0, 1, 0, 0),
(9959,'QUANT SENSORY TEST&INTERPJ/XTR W/COOL STIMULI','QUANT SENSORY TEST&INTERPJ/XTR W/COOL STIMULI','0108T','104','','1','0','','','',0, 1, 0, 0),
(9960,'QUANT SENAORY TEST&INTERPJ/XTR W/HT-PN STIMULI','QUANT SENAORY TEST&INTERPJ/XTR W/HT-PN STIMULI','0109T','104','','1','0','','','',0, 1, 0, 0),
(9961,'QUANT SENSORY TEST&INTERPJ/XTR OTHER STIMULI','QUANT SENSORY TEST&INTERPJ/XTR OTHER STIMULI','0110T','104','','1','0','','','',0, 1, 0, 0),
(9962,'LONG-CHAIN OMEGA-3 FATTY ACIDS RBC MEMBS','LONG-CHAIN OMEGA-3 FATTY ACIDS RBC MEMBS','0111T','104','','1','0','','','',0, 1, 0, 0),
(9963,'COMMON CAROTID INTIMA MEDIA THICKNESS STUDY','COMMON CAROTID INTIMA MEDIA THICKNESS STUDY','0126T','104','','1','0','','','',0, 1, 0, 0),
(9964,'COMPUTER AIDED DETECTION BREAST MRI','COMPUTER AIDED DETECTION BREAST MRI','0159T','104','','1','0','','','',0, 1, 0, 0),
(9965,'TOT DISC ARTHRP ANT APPR DSKC PREP LMBR EA','TOT DISC ARTHRP ANT APPR DSKC PREP LMBR EA','0163T','104','','1','0','','','',0, 1, 0, 0),
(9966,'RMVL TOT DISC ARTHRP ANT APPR LMBR EA NTRSPC','RMVL TOT DISC ARTHRP ANT APPR LMBR EA NTRSPC','0164T','104','','1','0','','','',0, 1, 0, 0),
(9967,'REVJ TOT DISC ARTHRP ANT APPR LMBR EA NTRSPC','REVJ TOT DISC ARTHRP ANT APPR LMBR EA NTRSPC','0165T','104','','1','0','','','',0, 1, 0, 0),
(9968,'STEREOTACTIC PLACEMENT CATHETER BRAIN','STEREOTACTIC PLACEMENT CATHETER BRAIN','0169T','104','','1','0','','','',0, 1, 0, 0),
(9969,'PST SPINOUS PROCESS DEVICE INSERT LMBR 1 LVL','PST SPINOUS PROCESS DEVICE INSERT LMBR 1 LVL','0171T','104','','1','0','','','',0, 1, 0, 0),
(9970,'PST SPINOUS PROCESS DEVICE INSERT LMBR EA LVL','PST SPINOUS PROCESS DEVICE INSERT LMBR EA LVL','0172T','104','','1','0','','','',0, 1, 0, 0),
(9971,'CAD CHEST RADIOGRAPH CONCURRENT W/INTERPRETATION','CAD CHEST RADIOGRAPH CONCURRENT W/INTERPRETATION','0174T','104','','1','0','','','',0, 1, 0, 0),
(9972,'CAD CHEST RADIOGRAPH REMOTE FROM PRIMARY INTERPJ','CAD CHEST RADIOGRAPH REMOTE FROM PRIMARY INTERPJ','0175T','104','','1','0','','','',0, 1, 0, 0),
(9973,'64 LEAD ECG W/INTERPRETATION & REPORT','64 LEAD ECG W/INTERPRETATION & REPORT','0178T','104','','1','0','','','',0, 1, 0, 0),
(9974,'64 LEAD ECG W/TRACING & GRAPHICS','64 LEAD ECG W/TRACING & GRAPHICS','0179T','104','','1','0','','','',0, 1, 0, 0),
(9975,'64 LEAD ECG W/INTERPRETATION & REPORT ONLY','64 LEAD ECG W/INTERPRETATION & REPORT ONLY','0180T','104','','1','0','','','',0, 1, 0, 0),
(9976,'RECTAL TUMOR EXCISION TRANSANAL ENDOSCOPIC','RECTAL TUMOR EXCISION TRANSANAL ENDOSCOPIC','0184T','104','','1','0','','','',0, 1, 0, 0),
(9977,'VIDEOCONFERENCED CRITICAL CARE FIRST 30-74 MIN','VIDEOCONFERENCED CRITICAL CARE FIRST 30-74 MIN','0188T','104','','1','0','','','',0, 1, 0, 0),
(9978,'VIDEOCONFERENCED CRITICAL CARE EA ADDL 30 MIN','VIDEOCONFERENCED CRITICAL CARE EA ADDL 30 MIN','0189T','104','','1','0','','','',0, 1, 0, 0),
(9979,'INTRAOCULAR RADIATION SRC APPLICATOR PLACEMENT','INTRAOCULAR RADIATION SRC APPLICATOR PLACEMENT','0190T','104','','1','0','','','',0, 1, 0, 0),
(9980,'ANT SEGMENT INSERTION DRAINAGE W/O RESERVOIR INT','ANT SEGMENT INSERTION DRAINAGE W/O RESERVOIR INT','0191T','104','','1','0','','','',0, 1, 0, 0),
(9981,'ARTHRODESIS PRESACRAL INTRBDY W/O INSTRUM L5/S1','ARTHRODESIS PRESACRAL INTRBDY W/O INSTRUM L5/S1','0195T','104','','1','0','','','',0, 1, 0, 0),
(9982,'ARTHRODESIS PRESACRAL INTRBDY W/O INSTRUM L4/L5','ARTHRODESIS PRESACRAL INTRBDY W/O INSTRUM L4/L5','0196T','104','','1','0','','','',0, 1, 0, 0),
(9983,'MEAS OCULAR BLOOD FLOW REPEAT IO PRES SAMP W/I&R','MEAS OCULAR BLOOD FLOW REPEAT IO PRES SAMP W/I&R','0198T','104','','1','0','','','',0, 1, 0, 0),
(9984,'PERQ SAC AGMNTJ UNI W/WO BALO/MCHNL DEV 1/> NDL','PERQ SAC AGMNTJ UNI W/WO BALO/MCHNL DEV 1/> NDL','0200T','104','','1','0','','','',0, 1, 0, 0),
(9985,'PERQ SAC AGMNTJ BI W/WO BALO/MCHNL DEV 2/> NDLS','PERQ SAC AGMNTJ BI W/WO BALO/MCHNL DEV 2/> NDLS','0201T','104','','1','0','','','',0, 1, 0, 0),
(9986,'POST VERT ARTHRPLSTY W/WO BONE CEMENT 1 LUMB LVL','POST VERT ARTHRPLSTY W/WO BONE CEMENT 1 LUMB LVL','0202T','104','','1','0','','','',0, 1, 0, 0),
(9987,'IV CATH CORONARY VESSEL/GRAFT SPECTROSCPY EA VSL','IV CATH CORONARY VESSEL/GRAFT SPECTROSCPY EA VSL','0205T','104','','1','0','','','',0, 1, 0, 0),
(9988,'CPTR DBS ALYS MLT CYCLS CAR ELEC DTA 2/> ECG LDS','CPTR DBS ALYS MLT CYCLS CAR ELEC DTA 2/> ECG LDS','0206T','104','','1','0','','','',0, 1, 0, 0),
(9989,'EVAC MEIBOMIAN GLNDS AUTO HT& INTMT PRESS UNI','EVAC MEIBOMIAN GLNDS AUTO HT& INTMT PRESS UNI','0207T','104','','1','0','','','',0, 1, 0, 0),
(9990,'PURE TONE AUDIOMETRY AUTOMATED AIR ONLY','PURE TONE AUDIOMETRY AUTOMATED AIR ONLY','0208T','104','','1','0','','','',0, 1, 0, 0),
(9991,'PURE TONE AUDIOMETRY AUTOMATED AIR & BONE','PURE TONE AUDIOMETRY AUTOMATED AIR & BONE','0209T','104','','1','0','','','',0, 1, 0, 0),
(9992,'SPEECH AUDIOMETRY THRESHOLD AUTOMATED','SPEECH AUDIOMETRY THRESHOLD AUTOMATED','0210T','104','','1','0','','','',0, 1, 0, 0),
(9993,'SPEECH AUDIOM THRESHLD AUTO W/SPEECH RECOGNITION','SPEECH AUDIOM THRESHLD AUTO W/SPEECH RECOGNITION','0211T','104','','1','0','','','',0, 1, 0, 0),
(9994,'COMPRE AUDIOM THRESHOLD EVAL & SPEECH RECOG','COMPRE AUDIOM THRESHOLD EVAL & SPEECH RECOG','0212T','104','','1','0','','','',0, 1, 0, 0),
(9995,'NJX DX/THER PARAVER FCT JT W/US CER/THOR 1 LVL','NJX DX/THER PARAVER FCT JT W/US CER/THOR 1 LVL','0213T','104','','1','0','','','',0, 1, 0, 0),
(9996,'NJX DX/THER PARAVER FCT JT W/US CER/THOR 2ND LVL','NJX DX/THER PARAVER FCT JT W/US CER/THOR 2ND LVL','0214T','104','','1','0','','','',0, 1, 0, 0),
(9997,'NJX PARAVERTBRL FACET JT W/US CER/THOR 3RD&> LVL','NJX PARAVERTBRL FACET JT W/US CER/THOR 3RD&> LVL','0215T','104','','1','0','','','',0, 1, 0, 0),
(9998,'NJX DX/THER PARAVER FCT JT W/US LUMB/SAC 1 LVL','NJX DX/THER PARAVER FCT JT W/US LUMB/SAC 1 LVL','0216T','104','','1','0','','','',0, 1, 0, 0),
(9999,'NJX DX/THER PARAVER FCT JT W/US LUMB/SAC LVL 2','NJX DX/THER PARAVER FCT JT W/US LUMB/SAC LVL 2','0217T','104','','1','0','','','',0, 1, 0, 0);

INSERT INTO `codes` (`id`, `code_text`, `code_text_short`, `code`, `code_type`, `modifier`, `units`, `fee`, `superbill`, `related_code`, `taxrates`, `cyp_factor`, `active`, `reportable`, `financial_reporting`) VALUES

(10000,'NJX PARAVERTBRL FCT JT W/US LUMB/SAC 3RD&> LVL','NJX PARAVERTBRL FCT JT W/US LUMB/SAC 3RD&> LVL','0218T','104','','1','0','','','',0, 1, 0, 0),
(10001,'PLMT POST FACET IMPLANT UNI/BI W/IMG & GRFT CERV','PLMT POST FACET IMPLANT UNI/BI W/IMG & GRFT CERV','0219T','104','','1','0','','','',0, 1, 0, 0),
(10002,'PLMT POST FACET IMPLT UNI/BI W/IMG & GRFT THOR','PLMT POST FACET IMPLT UNI/BI W/IMG & GRFT THOR','0220T','104','','1','0','','','',0, 1, 0, 0),
(10003,'PLMT POST FACET IMPLT UNI/BI W/IMG & GRFT LUMB','PLMT POST FACET IMPLT UNI/BI W/IMG & GRFT LUMB','0221T','104','','1','0','','','',0, 1, 0, 0),
(10004,'PLACE POSTERIOR INTRAFACET IMPLANT ADDL SEGMENT','PLACE POSTERIOR INTRAFACET IMPLANT ADDL SEGMENT','0222T','104','','1','0','','','',0, 1, 0, 0),
(10005,'NJX ANES/STEROID TFRML EDRL W/US CER/THOR 1 LVL','NJX ANES/STEROID TFRML EDRL W/US CER/THOR 1 LVL','0228T','104','','1','0','','','',0, 1, 0, 0),
(10006,'NJX ANES/STERD TFRML EDRL W/US CER/THOR EA ADDL','NJX ANES/STERD TFRML EDRL W/US CER/THOR EA ADDL','0229T','104','','1','0','','','',0, 1, 0, 0),
(10007,'NJX ANES/STEROID TFRML EDRL W/US LUM/SAC 1 LVL','NJX ANES/STEROID TFRML EDRL W/US LUM/SAC 1 LVL','0230T','104','','1','0','','','',0, 1, 0, 0),
(10008,'NJX ANES/STEROID TFRML EDRL W/US LUM/SAC EA ADDL','NJX ANES/STEROID TFRML EDRL W/US LUM/SAC EA ADDL','0231T','104','','1','0','','','',0, 1, 0, 0),
(10009,'NJX PLTLT PLASMA W/IMG HARVEST/PREPARATION','NJX PLTLT PLASMA W/IMG HARVEST/PREPARATION','0232T','104','','1','0','','','',0, 1, 0, 0),
(10010,'TRLUML PERIPHERAL ATHERECTOMY RENAL ARTERY EA','TRLUML PERIPHERAL ATHERECTOMY RENAL ARTERY EA','0234T','104','','1','0','','','',0, 1, 0, 0),
(10011,'TRLUML PERIPHERAL ATHERECTOMY VISCERAL ARTERY EA','TRLUML PERIPHERAL ATHERECTOMY VISCERAL ARTERY EA','0235T','104','','1','0','','','',0, 1, 0, 0),
(10012,'TRLUML PERIPH ATHRC W/RS&I ABDOM AORTA','TRLUML PERIPH ATHRC W/RS&I ABDOM AORTA','0236T','104','','1','0','','','',0, 1, 0, 0),
(10013,'TRLUML PERIPH ATHRC W/RS&I BRCHIOCPHL EA VSL','TRLUML PERIPH ATHRC W/RS&I BRCHIOCPHL EA VSL','0237T','104','','1','0','','','',0, 1, 0, 0),
(10014,'TRLUML PERIPHERAL ATHERECTOMY ILIAC ARTERY EA','TRLUML PERIPHERAL ATHERECTOMY ILIAC ARTERY EA','0238T','104','','1','0','','','',0, 1, 0, 0),
(10015,'LIGATION HEMORRHOID BUNDLE W/US','LIGATION HEMORRHOID BUNDLE W/US','0249T','104','','1','0','','','',0, 1, 0, 0),
(10016,'INSERT ANT SGM DRAINAGE DEV W/O RESERVR INT APPR','INSERT ANT SGM DRAINAGE DEV W/O RESERVR INT APPR','0253T','104','','1','0','','','',0, 1, 0, 0),
(10017,'EVASC ILIAC ART BIFURC W/ENDOPROSTH UNI','EVASC ILIAC ART BIFURC W/ENDOPROSTH UNI','0254T','104','','1','0','','','',0, 1, 0, 0),
(10018,'EVASC ILIAC ART BIFURC W/ENDOPROSTH UNI RS&I','EVASC ILIAC ART BIFURC W/ENDOPROSTH UNI RS&I','0255T','104','','1','0','','','',0, 1, 0, 0),
(10019,'AUTO BONE MARRW CELL RX COMPLT BONE MARRW HARVST','AUTO BONE MARRW CELL RX COMPLT BONE MARRW HARVST','0263T','104','','1','0','','','',0, 1, 0, 0),
(10020,'AUTO BONE MARRW CELL RX COMP W/O BONE MAR HARVST','AUTO BONE MARRW CELL RX COMP W/O BONE MAR HARVST','0264T','104','','1','0','','','',0, 1, 0, 0),
(10021,'BONE MAR HARVST ONLY FOR INTMUSC AUTOLO CELL RX','BONE MAR HARVST ONLY FOR INTMUSC AUTOLO CELL RX','0265T','104','','1','0','','','',0, 1, 0, 0),
(10022,'IM/REPL CARTD SINUS BAROREFLX ACTIV DEV TOT SYST','IM/REPL CARTD SINUS BAROREFLX ACTIV DEV TOT SYST','0266T','104','','1','0','','','',0, 1, 0, 0),
(10023,'IM/REPL CARTD SINS BAROREFLX ACTIV DEV LEAD ONLY','IM/REPL CARTD SINS BAROREFLX ACTIV DEV LEAD ONLY','0267T','104','','1','0','','','',0, 1, 0, 0),
(10024,'IM/REPL CARTD SINS BARREFLX ACT DEV PLS GEN ONLY','IM/REPL CARTD SINS BARREFLX ACT DEV PLS GEN ONLY','0268T','104','','1','0','','','',0, 1, 0, 0),
(10025,'REV/REMVL CARTD SINS BARREFLX ACT DEV TOT SYSTEM','REV/REMVL CARTD SINS BARREFLX ACT DEV TOT SYSTEM','0269T','104','','1','0','','','',0, 1, 0, 0),
(10026,'REV/REMVL CARTD SINS BARREFLX ACT DEV LEAD ONLY','REV/REMVL CARTD SINS BARREFLX ACT DEV LEAD ONLY','0270T','104','','1','0','','','',0, 1, 0, 0),
(10027,'REV/REM CARTD SINS BARREFLX ACT DEV PLS GEN ONLY','REV/REM CARTD SINS BARREFLX ACT DEV PLS GEN ONLY','0271T','104','','1','0','','','',0, 1, 0, 0),
(10028,'INTRGORTION DEV EVAL CARTD SINS BARREFLX W/I&R','INTRGORTION DEV EVAL CARTD SINS BARREFLX W/I&R','0272T','104','','1','0','','','',0, 1, 0, 0),
(10029,'INTROGATION DEV EVAL CARTD SINS BARREFLX W/PRGRM','INTROGATION DEV EVAL CARTD SINS BARREFLX W/PRGRM','0273T','104','','1','0','','','',0, 1, 0, 0),
(10030,'PERC LAMINO-/LAMINECTOMY IMAGE GUIDE CERV/THORAC','PERC LAMINO-/LAMINECTOMY IMAGE GUIDE CERV/THORAC','0274T','104','','1','0','','','',0, 1, 0, 0),
(10031,'PERC LAMINO-/LAMINECTOMY INDIR IMAG GUIDE LUMBAR','PERC LAMINO-/LAMINECTOMY INDIR IMAG GUIDE LUMBAR','0275T','104','','1','0','','','',0, 1, 0, 0),
(10032,'TRNSCUT ELECT MODLATION PAIN REPROCES EA TX SESS','TRNSCUT ELECT MODLATION PAIN REPROCES EA TX SESS','0278T','104','','1','0','','','',0, 1, 0, 0),
(10033,'PERC TRANSCTH CLOSR LT ATRIAL APPNDGE IMPLNT S&I','PERC TRANSCTH CLOSR LT ATRIAL APPNDGE IMPLNT S&I','0281T','104','','1','0','','','',0, 1, 0, 0),
(10034,'PERC/OPEN IMPLNT NEUROSTIM ELECTRODE SUBQ TRIAL','PERC/OPEN IMPLNT NEUROSTIM ELECTRODE SUBQ TRIAL','0282T','104','','1','0','','','',0, 1, 0, 0),
(10035,'PERC/OPEN IMPLNT NEUROSTIM ELECTRODE SUBQ PERM','PERC/OPEN IMPLNT NEUROSTIM ELECTRODE SUBQ PERM','0283T','104','','1','0','','','',0, 1, 0, 0),
(10036,'REV/REMVL PG/ELCTRODES IMAGNG ADDN NEW ELCTRODES','REV/REMVL PG/ELCTRODES IMAGNG ADDN NEW ELCTRODES','0284T','104','','1','0','','','',0, 1, 0, 0),
(10037,'ELEC ANLYS IMPLANT SUBQ FIELD STIM PG REPROGRAMM','ELEC ANLYS IMPLANT SUBQ FIELD STIM PG REPROGRAMM','0285T','104','','1','0','','','',0, 1, 0, 0),
(10038,'NEAR INFRARED SPECTROSCPY STUDIES LOW EXT WOUNDS','NEAR INFRARED SPECTROSCPY STUDIES LOW EXT WOUNDS','0286T','104','','1','0','','','',0, 1, 0, 0),
(10039,'NEARINFRED GUIDANCE VASC ACES RL TIME DIG VISU','NEARINFRED GUIDANCE VASC ACES RL TIME DIG VISU','0287T','104','','1','0','','','',0, 1, 0, 0),
(10040,'ANSCPY W/DELVRY THERMAL ENERGY MUSCLE ANAL CANAL','ANSCPY W/DELVRY THERMAL ENERGY MUSCLE ANAL CANAL','0288T','104','','1','0','','','',0, 1, 0, 0),
(10041,'CORNEA INCISNS DONOR CORNEA W/LASR KERTPLSTY','CORNEA INCISNS DONOR CORNEA W/LASR KERTPLSTY','0289T','104','','1','0','','','',0, 1, 0, 0),
(10042,'CORNEA INCISNS RECIPIENT CORNEA W/LASR KERTPLSTY','CORNEA INCISNS RECIPIENT CORNEA W/LASR KERTPLSTY','0290T','104','','1','0','','','',0, 1, 0, 0),
(10043,'INTRAV OPTCL CHERNCE TMGRPHY W/S&I INTL VESL','INTRAV OPTCL CHERNCE TMGRPHY W/S&I INTL VESL','0291T','104','','1','0','','','',0, 1, 0, 0),
(10044,'INTRAV OPTCAL COHRNCE TMGRPHY W/S&I ADL VESL','INTRAV OPTCAL COHRNCE TMGRPHY W/S&I ADL VESL','0292T','104','','1','0','','','',0, 1, 0, 0),
(10045,'INS LT ATRL HEMODYN MOTR CMPLETE SYST W/S&I','INS LT ATRL HEMODYN MOTR CMPLETE SYST W/S&I','0293T','104','','1','0','','','',0, 1, 0, 0),
(10046,'INS LT ATRL HEMDYN MTR PRSR SENSR LEAD W/S&I','INS LT ATRL HEMDYN MTR PRSR SENSR LEAD W/S&I','0294T','104','','1','0','','','',0, 1, 0, 0),
(10047,'EXT ECG > 48HR TO 21 DAY RCRD SCAN ANLYS REP R&I','EXT ECG > 48HR TO 21 DAY RCRD SCAN ANLYS REP R&I','0295T','104','','1','0','','','',0, 1, 0, 0),
(10048,'EXT ECG > 48HR TO 21 DAY RCRD W/CONECT INTL RCRD','EXT ECG > 48HR TO 21 DAY RCRD W/CONECT INTL RCRD','0296T','104','','1','0','','','',0, 1, 0, 0),
(10049,'EXT ECG > 48HR TO 21 DAY SCAN ANALYSIS W/REPORT','EXT ECG > 48HR TO 21 DAY SCAN ANALYSIS W/REPORT','0297T','104','','1','0','','','',0, 1, 0, 0),
(10050,'EXT ECG > 48HR TO 21 DAY REVIEW AND INTERPRETATN','EXT ECG > 48HR TO 21 DAY REVIEW AND INTERPRETATN','0298T','104','','1','0','','','',0, 1, 0, 0),
(10051,'ESW HI ENERGY W/TOPCAL APP &DRESNG CARE 1ST WND','ESW HI ENERGY W/TOPCAL APP &DRESNG CARE 1ST WND','0299T','104','','1','0','','','',0, 1, 0, 0),
(10052,'ESW HI ENERGY W/TOPCAL APP &DRESNG CARE ADL WND','ESW HI ENERGY W/TOPCAL APP &DRESNG CARE ADL WND','0300T','104','','1','0','','','',0, 1, 0, 0),
(10053,'DEST/REDUC MALIG BRST TUMR W/US THRMORX GUIDANCE','DEST/REDUC MALIG BRST TUMR W/US THRMORX GUIDANCE','0301T','104','','1','0','','','',0, 1, 0, 0),
(10054,'INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS COMPL','INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS COMPL','0302T','104','','1','0','','','',0, 1, 0, 0),
(10055,'INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS ELTRD','INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS ELTRD','0303T','104','','1','0','','','',0, 1, 0, 0),
(10056,'INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS DEVICE','INSJ/RMVL RPLCMT ICAR ISCHM MNTRNG SYS DEVICE','0304T','104','','1','0','','','',0, 1, 0, 0),
(10057,'PROGRAM EVAL ICAR ISCHM MNTRNG SYS','PROGRAM EVAL ICAR ISCHM MNTRNG SYS','0305T','104','','1','0','','','',0, 1, 0, 0),
(10058,'INTERROGATION EVAL ICAR ISCHM MNTRNG SYS','INTERROGATION EVAL ICAR ISCHM MNTRNG SYS','0306T','104','','1','0','','','',0, 1, 0, 0),
(10059,'RMVL INTRACARDIAC ISCHEMIA MONITORING DEVICE','RMVL INTRACARDIAC ISCHEMIA MONITORING DEVICE','0307T','104','','1','0','','','',0, 1, 0, 0),
(10060,'INSJ OC TLSCP PROSTH RMVL CRYSTALLINE/IO LENS','INSJ OC TLSCP PROSTH RMVL CRYSTALLINE/IO LENS','0308T','104','','1','0','','','',0, 1, 0, 0),
(10061,'ARTHRODESIS PRESACRAL INTRBDY W/INSTRUMENT L4/L5','ARTHRODESIS PRESACRAL INTRBDY W/INSTRUMENT L4/L5','0309T','104','','1','0','','','',0, 1, 0, 0),
(10062,'MOTOR FUNCTION MAPPING NAVIGATED TMS TX PLAN','MOTOR FUNCTION MAPPING NAVIGATED TMS TX PLAN','0310T','104','','1','0','','','',0, 1, 0, 0),
(10063,'LAPS IMPLTJ NSTIM ELTRD ARRAY&PLS GEN VAGUS NRV','LAPS IMPLTJ NSTIM ELTRD ARRAY&PLS GEN VAGUS NRV','0312T','104','','1','0','','','',0, 1, 0, 0),
(10064,'LAPS REVJ/REPLCMT NSTIM ELTRD ARRAY VAGUS NRV','LAPS REVJ/REPLCMT NSTIM ELTRD ARRAY VAGUS NRV','0313T','104','','1','0','','','',0, 1, 0, 0),
(10065,'LAPS RMVL NSTIM ELTRD ARRAY & PLS GEN VAGUS NRV','LAPS RMVL NSTIM ELTRD ARRAY & PLS GEN VAGUS NRV','0314T','104','','1','0','','','',0, 1, 0, 0),
(10066,'REMOVAL PULSE GENERATOR VAGUS NERVE','REMOVAL PULSE GENERATOR VAGUS NERVE','0315T','104','','1','0','','','',0, 1, 0, 0),
(10067,'REPLACEMENT PULSE GENERATOR VAGUS NERVE','REPLACEMENT PULSE GENERATOR VAGUS NERVE','0316T','104','','1','0','','','',0, 1, 0, 0),
(10068,'ELEC ALYS NSTIM PLS GEN VAGUS NRV W/REPRGRMG','ELEC ALYS NSTIM PLS GEN VAGUS NRV W/REPRGRMG','0317T','104','','1','0','','','',0, 1, 0, 0),
(10069,'MNTR INTRAOCULAR PRESS 24HRS/> UNI/BI W/INTERP','MNTR INTRAOCULAR PRESS 24HRS/> UNI/BI W/INTERP','0329T','104','','1','0','','','',0, 1, 0, 0),
(10070,'TEAR FILM IMAGING UNILATERAL OR BILATERAL W/I&R','TEAR FILM IMAGING UNILATERAL OR BILATERAL W/I&R','0330T','104','','1','0','','','',0, 1, 0, 0),
(10071,'MYOCRD SYMPATHETIC INNERVAJ IMG PLNR QUAL&QUANT','MYOCRD SYMPATHETIC INNERVAJ IMG PLNR QUAL&QUANT','0331T','104','','1','0','','','',0, 1, 0, 0),
(10072,'MYOCRD SYMP INNERVAJ IMG PLNR QUAL&QUANT W/SPECT','MYOCRD SYMP INNERVAJ IMG PLNR QUAL&QUANT W/SPECT','0332T','104','','1','0','','','',0, 1, 0, 0),
(10073,'VISUAL EVOKED POTENTIAL ACUITY SCREENING AUTO','VISUAL EVOKED POTENTIAL ACUITY SCREENING AUTO','0333T','104','','1','0','','','',0, 1, 0, 0),
(10074,'EXTRA-OSSEOUS JOINT IMPLANT TALOTARSAL STABILIZE','EXTRA-OSSEOUS JOINT IMPLANT TALOTARSAL STABILIZE','0335T','104','','1','0','','','',0, 1, 0, 0),
(10075,'LAPS ABLATJ UTERINE FIBROIDS W/INTRAOP US GDNC','LAPS ABLATJ UTERINE FIBROIDS W/INTRAOP US GDNC','0336T','104','','1','0','','','',0, 1, 0, 0),
(10076,'ENDOTHELIAL FUNCTION ASSESSMENT NON-INVASIVE','ENDOTHELIAL FUNCTION ASSESSMENT NON-INVASIVE','0337T','104','','1','0','','','',0, 1, 0, 0),
(10077,'TRANSCATHETER RENAL SYMPATH DENERVATION UNILAT','TRANSCATHETER RENAL SYMPATH DENERVATION UNILAT','0338T','104','','1','0','','','',0, 1, 0, 0),
(10078,'TRANSCATHETER RENAL SYMPATH DENERVATION BILAT','TRANSCATHETER RENAL SYMPATH DENERVATION BILAT','0339T','104','','1','0','','','',0, 1, 0, 0),
(10079,'ABLATE PULM TUMORS W/PLEURA/CHEST WALL EXTSN','ABLATE PULM TUMORS W/PLEURA/CHEST WALL EXTSN','0340T','104','','1','0','','','',0, 1, 0, 0),
(10080,'QUANT PUPILLOMETRY W/INTERP&REPORT UNILAT/BILAT','QUANT PUPILLOMETRY W/INTERP&REPORT UNILAT/BILAT','0341T','104','','1','0','','','',0, 1, 0, 0),
(10081,'THERAPEUTIC APHERESIS W/SELECTIVE HDL DELIP','THERAPEUTIC APHERESIS W/SELECTIVE HDL DELIP','0342T','104','','1','0','','','',0, 1, 0, 0),
(10082,'TRANSCATH MITRAL VALVE REPAIR VIA CORONARY SINUS','TRANSCATH MITRAL VALVE REPAIR VIA CORONARY SINUS','0345T','104','','1','0','','','',0, 1, 0, 0),
(10083,'ULTRASOUND ELASTOGRAPHY','ULTRASOUND ELASTOGRAPHY','0346T','104','','1','0','','','',0, 1, 0, 0),
(10084,'PLACE INTERSTITIAL DEVICE(S) IN BONE FOR RSA','PLACE INTERSTITIAL DEVICE(S) IN BONE FOR RSA','0347T','104','','1','0','','','',0, 1, 0, 0),
(10085,'RADIOSTEREOMETRIC ANALYSIS SPINE EXAM','RADIOSTEREOMETRIC ANALYSIS SPINE EXAM','0348T','104','','1','0','','','',0, 1, 0, 0),
(10086,'RADIOSTEREOMETRIC ANALYSIS UPPER EXTREMITY EXAM','RADIOSTEREOMETRIC ANALYSIS UPPER EXTREMITY EXAM','0349T','104','','1','0','','','',0, 1, 0, 0),
(10087,'RADIOSTEREOMETRIC ANALYSIS LOWER EXTREMITY EXAM','RADIOSTEREOMETRIC ANALYSIS LOWER EXTREMITY EXAM','0350T','104','','1','0','','','',0, 1, 0, 0),
(10088,'INTRAOP OCT BREAST OR AXILL NODE EACH SPECIMEN','INTRAOP OCT BREAST OR AXILL NODE EACH SPECIMEN','0351T','104','','1','0','','','',0, 1, 0, 0),
(10089,'OCT BREAST OR AXILL NODE SPECIMEN I&R','OCT BREAST OR AXILL NODE SPECIMEN I&R','0352T','104','','1','0','','','',0, 1, 0, 0),
(10090,'OCT OF BREAST SURG CAVITY REAL TIME INTRAOP','OCT OF BREAST SURG CAVITY REAL TIME INTRAOP','0353T','104','','1','0','','','',0, 1, 0, 0),
(10091,'OCT BREAST SURG CAVITY REAL TIME/REFERRED I&R','OCT BREAST SURG CAVITY REAL TIME/REFERRED I&R','0354T','104','','1','0','','','',0, 1, 0, 0),
(10092,'GI TRACT IMAGING INTRALUMINAL COLON WITH I&R','GI TRACT IMAGING INTRALUMINAL COLON WITH I&R','0355T','104','','1','0','','','',0, 1, 0, 0),
(10093,'INSERT DRUG IMPLANT INTO LACRIMAL CANAL FOR IOP','INSERT DRUG IMPLANT INTO LACRIMAL CANAL FOR IOP','0356T','104','','1','0','','','',0, 1, 0, 0),
(10094,'CRYOPRESERVATION IMMATURE OOCYTE(S)','CRYOPRESERVATION IMMATURE OOCYTE(S)','0357T','104','','1','0','','','',0, 1, 0, 0),
(10095,'BIA WHOLE BODY COMPOSITION ASSESSMENT W/I&R','BIA WHOLE BODY COMPOSITION ASSESSMENT W/I&R','0358T','104','','1','0','','','',0, 1, 0, 0),
(10096,'BEHAVIORAL IDENTIFICATION ASSESSMENT','BEHAVIORAL IDENTIFICATION ASSESSMENT','0359T','104','','1','0','','','',0, 1, 0, 0),
(10097,'OBSERVATIONAL BEHAV ASSESSMENT FIRST 30 MIN','OBSERVATIONAL BEHAV ASSESSMENT FIRST 30 MIN','0360T','104','','1','0','','','',0, 1, 0, 0),
(10098,'OBSERVATIONAL BEHAV ASSESSMENT ADDL 30 MIN','OBSERVATIONAL BEHAV ASSESSMENT ADDL 30 MIN','0361T','104','','1','0','','','',0, 1, 0, 0),
(10099,'EXPOSURE BEHAV ASSESSMENT FIRST 30 MIN','EXPOSURE BEHAV ASSESSMENT FIRST 30 MIN','0362T','104','','1','0','','','',0, 1, 0, 0),
(10100,'EXPOSURE BEHAV ASSESSMENT ADDL 30 MIN','EXPOSURE BEHAV ASSESSMENT ADDL 30 MIN','0363T','104','','1','0','','','',0, 1, 0, 0),
(10101,'ADAPTIVE BEHAVIOR TX BY PROTOCOL FIRST 30 MIN','ADAPTIVE BEHAVIOR TX BY PROTOCOL FIRST 30 MIN','0364T','104','','1','0','','','',0, 1, 0, 0),
(10102,'ADAPTIVE BEHAVIOR TX BY PROTOCOL ADDL 30 MIN','ADAPTIVE BEHAVIOR TX BY PROTOCOL ADDL 30 MIN','0365T','104','','1','0','','','',0, 1, 0, 0),
(10103,'GROUP BEHAVIOR TREATMENT FIRST 30 MIN','GROUP BEHAVIOR TREATMENT FIRST 30 MIN','0366T','104','','1','0','','','',0, 1, 0, 0),
(10104,'GROUP BEHAVIOR TREATMENT ADDL 30 MIN','GROUP BEHAVIOR TREATMENT ADDL 30 MIN','0367T','104','','1','0','','','',0, 1, 0, 0),
(10105,'BEHAVIOR TX WITH MODIFICATION FIRST 30 MIN','BEHAVIOR TX WITH MODIFICATION FIRST 30 MIN','0368T','104','','1','0','','','',0, 1, 0, 0),
(10106,'BEHAVIOR TREATMENT WITH MODIFICATION ADDL 30 MIN','BEHAVIOR TREATMENT WITH MODIFICATION ADDL 30 MIN','0369T','104','','1','0','','','',0, 1, 0, 0),
(10107,'FAMILY BEHAVIOR TREATMENT GUIDANCE','FAMILY BEHAVIOR TREATMENT GUIDANCE','0370T','104','','1','0','','','',0, 1, 0, 0),
(10108,'MULTIPLE FAMILY GROUP BEHAV TREATMENT GUIDANCE','MULTIPLE FAMILY GROUP BEHAV TREATMENT GUIDANCE','0371T','104','','1','0','','','',0, 1, 0, 0),
(10109,'BEHAVIOR TREATMENT SOCIAL SKILLS TRAINING GROUP','BEHAVIOR TREATMENT SOCIAL SKILLS TRAINING GROUP','0372T','104','','1','0','','','',0, 1, 0, 0),
(10110,'EXPOSURE BEHAVIOR TREATMENT FIRST 60 MIN','EXPOSURE BEHAVIOR TREATMENT FIRST 60 MIN','0373T','104','','1','0','','','',0, 1, 0, 0),
(10111,'EXPOSURE BEHAVIOR TREATMENT ADDL 30 MIN','EXPOSURE BEHAVIOR TREATMENT ADDL 30 MIN','0374T','104','','1','0','','','',0, 1, 0, 0),
(10112,'TOTAL DISC ARTHRP ANT APPR W/DISCECTOMY CRV 3+','TOTAL DISC ARTHRP ANT APPR W/DISCECTOMY CRV 3+','0375T','104','','1','0','','','',0, 1, 0, 0),
(10113,'ANT SEGMENT INSERT DRAIN W/O RESERVOIR EA ADDL','ANT SEGMENT INSERT DRAIN W/O RESERVOIR EA ADDL','0376T','104','','1','0','','','',0, 1, 0, 0),
(10114,'ANOSCOPY W/BULKING AGENT INJ FOR FECAL INCONT','ANOSCOPY W/BULKING AGENT INJ FOR FECAL INCONT','0377T','104','','1','0','','','',0, 1, 0, 0),
(10115,'VISUAL FIELD ASSESSMENT PHYS REVIEW AND REPORT','VISUAL FIELD ASSESSMENT PHYS REVIEW AND REPORT','0378T','104','','1','0','','','',0, 1, 0, 0),
(10116,'VISUAL FIELD ASSESSMENT TECH SUPPORT W/INSTRUCT','VISUAL FIELD ASSESSMENT TECH SUPPORT W/INSTRUCT','0379T','104','','1','0','','','',0, 1, 0, 0),
(10117,'COMP ANIMATION RETINA IMAGE TIME SERIES ANALYSIS','COMP ANIMATION RETINA IMAGE TIME SERIES ANALYSIS','0380T','104','','1','0','','','',0, 1, 0, 0),
(10118,'XTRNL HRT RATE EPI SEIZ UP TO 14 DAYS COMPLETE','XTRNL HRT RATE EPI SEIZ UP TO 14 DAYS COMPLETE','0381T','104','','1','0','','','',0, 1, 0, 0),
(10119,'XTRNL HRT RATE EPI SEIZ UP TO 14 DAYS R&I ONLY','XTRNL HRT RATE EPI SEIZ UP TO 14 DAYS R&I ONLY','0382T','104','','1','0','','','',0, 1, 0, 0),
(10120,'XTRNL HRT RATE EPI SEIZ 15 TO 30 DAYS COMPLETE','XTRNL HRT RATE EPI SEIZ 15 TO 30 DAYS COMPLETE','0383T','104','','1','0','','','',0, 1, 0, 0),
(10121,'XTRNL HRT RATE EPI SEIZ 15 TO 30 DAYS R&I ONLY','XTRNL HRT RATE EPI SEIZ 15 TO 30 DAYS R&I ONLY','0384T','104','','1','0','','','',0, 1, 0, 0),
(10122,'XTRNL HRT RATE EPI SEIZ OVER 30 DAYS COMPLETE','XTRNL HRT RATE EPI SEIZ OVER 30 DAYS COMPLETE','0385T','104','','1','0','','','',0, 1, 0, 0),
(10123,'XTRNL HRT RATE EPI SEIZ OVER 30 DAYS R&I ONLY','XTRNL HRT RATE EPI SEIZ OVER 30 DAYS R&I ONLY','0386T','104','','1','0','','','',0, 1, 0, 0),
(10124,'TRANSCATH INSERT OR REPLACE LEADLESS PM VENTR','TRANSCATH INSERT OR REPLACE LEADLESS PM VENTR','0387T','104','','1','0','','','',0, 1, 0, 0),
(10125,'TRANSCATH REMOVAL LEADLESS PM VENTRICULAR','TRANSCATH REMOVAL LEADLESS PM VENTRICULAR','0388T','104','','1','0','','','',0, 1, 0, 0),
(10126,'PROG DEVICE EVAL IN PERSON LEADLESS PM SYSTEM','PROG DEVICE EVAL IN PERSON LEADLESS PM SYSTEM','0389T','104','','1','0','','','',0, 1, 0, 0),
(10127,'PERI-PROC DEVICE EVAL IN PERS LEADLESS PM SYSTEM','PERI-PROC DEVICE EVAL IN PERS LEADLESS PM SYSTEM','0390T','104','','1','0','','','',0, 1, 0, 0),
(10128,'INTERROG DEVICE EVAL IN PERSON LEADLESS PM SYST','INTERROG DEVICE EVAL IN PERSON LEADLESS PM SYST','0391T','104','','1','0','','','',0, 1, 0, 0),
(10129,'LAPS ESOPHGL SPHINCTER AUGMENT PROC PLACE DEVICE','LAPS ESOPHGL SPHINCTER AUGMENT PROC PLACE DEVICE','0392T','104','','1','0','','','',0, 1, 0, 0),
(10130,'ESOPHGL SPHINCTER AUGMENT DEVICE REMOVAL','ESOPHGL SPHINCTER AUGMENT DEVICE REMOVAL','0393T','104','','1','0','','','',0, 1, 0, 0),
(10131,'HDR ELECTRONIC BRACHYTHERAPY SKIN SURFACE','HDR ELECTRONIC BRACHYTHERAPY SKIN SURFACE','0394T','104','','1','0','','','',0, 1, 0, 0),
(10132,'HDR ELECTRONIC BRACHYTHERAPY NTRSTL/INTRCAV','HDR ELECTRONIC BRACHYTHERAPY NTRSTL/INTRCAV','0395T','104','','1','0','','','',0, 1, 0, 0),
(10133,'INTRAOP KINETIC BALANCE SENSR KNEE RPLCMT ARTHRP','INTRAOP KINETIC BALANCE SENSR KNEE RPLCMT ARTHRP','0396T','104','','1','0','','','',0, 1, 0, 0),
(10134,'ERCP WITH OPTICAL ENDOMICROSCOPY ADD ON','ERCP WITH OPTICAL ENDOMICROSCOPY ADD ON','0397T','104','','1','0','','','',0, 1, 0, 0),
(10135,'MRGFUS STEREOTACTIC ABLATION LESION INTRACRANIAL','MRGFUS STEREOTACTIC ABLATION LESION INTRACRANIAL','0398T','104','','1','0','','','',0, 1, 0, 0),
(10136,'MYOCARDIAL STRAIN IMAGING QUAN ASSMT','MYOCARDIAL STRAIN IMAGING QUAN ASSMT','0399T','104','','1','0','','','',0, 1, 0, 0),
(10137,'MULTI-SPECTRAL DIGITAL SKIN LES ANALYSIS 1-5 LES','MULTI-SPECTRAL DIGITAL SKIN LES ANALYSIS 1-5 LES','0400T','104','','1','0','','','',0, 1, 0, 0),
(10138,'MULTI-SPECTRAL DIGITAL SKIN LES ANALYSIS 6+ LES','MULTI-SPECTRAL DIGITAL SKIN LES ANALYSIS 6+ LES','0401T','104','','1','0','','','',0, 1, 0, 0),
(10139,'COLLAGEN CROSS-LINKING OF CORNEA','COLLAGEN CROSS-LINKING OF CORNEA','0402T','104','','1','0','','','',0, 1, 0, 0),
(10140,'DIABETES PREVENTION PROG STANDARDIZED CURRICULUM','DIABETES PREVENTION PROG STANDARDIZED CURRICULUM','0403T','104','','1','0','','','',0, 1, 0, 0),
(10141,'TRANSCERVICAL UTERINE FIBROID ABLTJ W/US GDN RF','TRANSCERVICAL UTERINE FIBROID ABLTJ W/US GDN RF','0404T','104','','1','0','','','',0, 1, 0, 0),
(10142,'OVERSIGHT CARE OF XTRCORP LIVER ASSIST SYS PAT','OVERSIGHT CARE OF XTRCORP LIVER ASSIST SYS PAT','0405T','104','','1','0','','','',0, 1, 0, 0),
(10143,'NSL NDSC SURG ETHMD SIN PLMT DRUG ELUTNG IMPLNT','NSL NDSC SURG ETHMD SIN PLMT DRUG ELUTNG IMPLNT','0406T','104','','1','0','','','',0, 1, 0, 0),
(10144,'NSL NDSC SURG ETHMD PLMT DRUG ELUTNG IMPLNT W/BX','NSL NDSC SURG ETHMD PLMT DRUG ELUTNG IMPLNT W/BX','0407T','104','','1','0','','','',0, 1, 0, 0),
('10145','PQRS_Special','PQRS_Special','PQRS1','3','','1','0','','','','0','1','0','0'),
('10146','Dressing for one wound','Dressing for one wound','A1','3','','1','0','','','','0','1','0','0'),
('10147','Dressing for two wounds','Dressing for two wounds','A2','3','','1','0','','','','0','1','0','0'),
('10148','Dressing for three wounds','Dressing for three wounds','A3','3','','1','0','','','','0','1','0','0'),
('10149','Dressing for four wounds','Dressing for four wounds','A4','3','','1','0','','','','0','1','0','0'),
('10150','Dressing for five wounds','Dressing for five wounds','A5','3','','1','0','','','','0','1','0','0'),
('10151','Dressing for six wounds','Dressing for six wounds','A6','3','','1','0','','','','0','1','0','0'),
('10152','Dressing for seven wounds','Dressing for seven wounds','A7','3','','1','0','','','','0','1','0','0'),
('10153','Dressing for eight wounds','Dressing for eight wounds','A8','3','','1','0','','','','0','1','0','0'),
('10154','Dressing for nine or more wounds','Dressing for 9 or more wound','A9','3','','1','0','','','','0','1','0','0'),
('10155','Anesthesia services performed personally by anesthesiologist','Anesthesia perf by anesgst','AA','3','','1','0','','','','0','1','0','0'),
('10156','Medical supervision by a physician: more than four concurrent anesthesia procedures','Md supervision; >4 anes proc','AD','3','','1','0','','','','0','1','0','0'),
('10157','Registered dietician','Registered dietician','AE','3','','1','0','','','','0','1','0','0'),
('10158','Specialty physician','Specialty physician','AF','3','','1','0','','','','0','1','0','0'),
('10159','Primary physician','Primary physician','AG','3','','1','0','','','','0','1','0','0'),
('10160','Clinical psychologist','Clinical psychologist','AH','3','','1','0','','','','0','1','0','0'),
('10161','Principal physician of record','Principal physician of rec','AI','3','','1','0','','','','0','1','0','0'),
('10162','Clinical social worker','Clinical social worker','AJ','3','','1','0','','','','0','1','0','0'),
('10163','Non participating physician','Non participating physician','AK','3','','1','0','','','','0','1','0','0'),
('10164','Physician; team member service','Physician; team member svc','AM','3','','1','0','','','','0','1','0','0'),
('10165','Alternate payment method declined by provider of service','Prov declined alt pmt method','AO','3','','1','0','','','','0','1','0','0'),
('10166','Determination of refractive state was not performed in the course of diagnostic ophthalmological examination','No dtmn of refractive state','AP','3','','1','0','','','','0','1','0','0'),
('10167','Physician providing a service in an unlisted health professional shortage area (hpsa)','Physician service hpsa area','AQ','3','','1','0','','','','0','1','0','0'),
('10168','Physician provider services in a physician scarcity area','Physician scarcity area','AR','3','','1','0','','','','0','1','0','0'),
('10169','Physician assistant; nurse practitioner; or clinical nurse specialist services for assistant at surgery','Assistant at surgery service','AS','3','','1','0','','','','0','1','0','0'),
('10170','Acute treatment (this modifier should be used when reporting service 98940; 98941; 98942)','Acute treatment','AT','3','','1','0','','','','0','1','0','0'),
('10171','Item furnished in conjunction with a urological; ostomy; or tracheostomy supply','Uro; ostomy or trach item','AU','3','','1','0','','','','0','1','0','0'),
('10172','Item furnished in conjunction with a prosthetic device; prosthetic or orthotic','Item w prosthetic/orthotic','AV','3','','1','0','','','','0','1','0','0'),
('10173','Item furnished in conjunction with a surgical dressing','Item w a surgical dressing','AW','3','','1','0','','','','0','1','0','0'),
('10174','Item furnished in conjunction with dialysis services','Item w dialysis services','AX','3','','1','0','','','','0','1','0','0'),
('10175','Item or service furnished to an esrd patient that is not for the treatment of esrd','Item/service not for esrd tx','AY','3','','1','0','','','','0','1','0','0'),
('10176','Physician providing a service in a dental health professional shortage area for the purpose of an electronic health record incentive payment','Physician serv in dent hpsa','AZ','3','','1','0','','','','0','1','0','0'),
('10177','Item furnished in conjunction with parenteral enteral nutrition (pen) services','Item w pen services','BA','3','','1','0','','','','0','1','0','0'),
('10178','Special acquisition of blood and blood products','Spec acquisition blood prods','BL','3','','1','0','','','','0','1','0','0'),
('10179','Orally administered nutrition; not by feeding tube','Nutrition oral admin no tube','BO','3','','1','0','','','','0','1','0','0'),
('10180','The beneficiary has been informed of the purchase and rental options and has elected to purchase the item','Bene electd to purchase item','BP','3','','1','0','','','','0','1','0','0'),
('10181','The beneficiary has been informed of the purchase and rental options and has elected to rent the item','Bene elected to rent item','BR','3','','1','0','','','','0','1','0','0'),
('10182','The beneficiary has been informed of the purchase and rental options and after 30 days has not informed the supplier of his/her decision','Bene undecided on purch/rent','BU','3','','1','0','','','','0','1','0','0'),
('10183','Procedure payable only in the inpatient setting when performed emergently on an outpatient who expires prior to admission','Procedure payable inpatient','CA','3','','1','0','','','','0','1','0','0'),
('10184','Service ordered by a renal dialysis facility (rdf) physician as part of the esrd beneficiarys dialysis benefit; is not part of the composite rate; and is separately reimbursable','Esrd bene part a snf-sep pay','CB','3','','1','0','','','','0','1','0','0'),
('10185','Procedure code change (use cc when the procedure code submitted was changed either for administrative reasons or because an incorrect code was filed)','Procedure code change','CC','3','','1','0','','','','0','1','0','0'),
('10186','Amcc test has been ordered by an esrd facility or mcp physician that is part of the composite rate and is not separately billable','Amcc test for esrd or mcp md','CD','3','','1','0','','','','0','1','0','0'),
('10187','Amcc test has been ordered by an esrd facility or mcp physician that is a composite rate test but is beyond the normal frequency covered under the rate and is separately reimbursable based on medical necessity','Med neces amcc tst sep reimb','CE','3','','1','0','','','','0','1','0','0'),
('10188','Amcc test has been ordered by an esrd facility or mcp physician that is not part of the composite rate and is separately billable','Amcc tst not composite rate','CF','3','','1','0','','','','0','1','0','0'),
('10189','Policy criteria applied','Policy criteria applied','CG','3','','1','0','','','','0','1','0','0'),
('10190','0 percent impaired; limited or restricted','0 percent impaired; ltd; res','CH','3','','1','0','','','','0','1','0','0'),
('10191','At least 1 percent but less than 20 percent impaired; limited or restricted','1 to <20 percent impaired','CI','3','','1','0','','','','0','1','0','0'),
('10192','At least 20 percent but less than 40 percent impaired; limited or restricted','20 to <40 percent impaired','CJ','3','','1','0','','','','0','1','0','0'),
('10193','At least 40 percent but less than 60 percent impaired; limited or restricted','40 to <60 percent impaired','CK','3','','1','0','','','','0','1','0','0'),
('10194','At least 60 percent but less than 80 percent impaired; limited or restricted','60 to <80 percent impaired','CL','3','','1','0','','','','0','1','0','0'),
('10195','At least 80 percent but less than 100 percent impaired; limited or restricted','80 to <100 percent impaired','CM','3','','1','0','','','','0','1','0','0'),
('10196','100 percent impaired; limited or restricted','100 percent impaired; ltd','CN','3','','1','0','','','','0','1','0','0'),
('10197','Adjunctive service related to a procedure assigned to a comprehensive ambulatory payment classification (c-apc) procedure; but reported on a different claim','C-apc adjunctive service','CP','3','','1','0','','','','0','1','0','0'),
('10198','Catastrophe/disaster related','Catastrophe/disaster related','CR','3','','1','0','','','','0','1','0','0'),
('10199','Item or service related; in whole or in part; to an illness; injury; or condition that was caused by or exacerbated by the effects; direct or indirect; of the 2010 oil spill in the gulf of mexico; including but not limited to subsequent clean-up activities','Gulf oil 2010 spill related','CS','3','','1','0','','','','0','1','0','0'),
('10200','Computed tomography services furnished using equipment that does not meet each of the attributes of the national electrical manufacturers association (nema) xr-29-2013 standard','Ct does not meet nema standa','CT','3','','1','0','','','','0','1','0','0'),
('10201','Oral health assessment by a licensed health professional other than a dentist','Oral health assess; not dent','DA','3','','1','0','','','','0','1','0','0'),
('10202','Upper left; eyelid','Upper left eyelid','E1','3','','1','0','','','','0','1','0','0'),
('10203','Lower left; eyelid','Lower left eyelid','E2','3','','1','0','','','','0','1','0','0'),
('10204','Upper right; eyelid','Upper right eyelid','E3','3','','1','0','','','','0','1','0','0'),
('10205','Lower right; eyelid','Lower right eyelid','E4','3','','1','0','','','','0','1','0','0'),
('10206','Erythropoetic stimulating agent (esa) administered to treat anemia due to anti-cancer chemotherapy','Esa; anemia; chemo-induced','EA','3','','1','0','','','','0','1','0','0'),
('10207','Erythropoetic stimulating agent (esa) administered to treat anemia due to anti-cancer radiotherapy','Esa; anemia; radio-induced','EB','3','','1','0','','','','0','1','0','0'),
('10208','Erythropoetic stimulating agent (esa) administered to treat anemia not due to anti-cancer radiotherapy or anti-cancer chemotherapy','Esa; anemia; non-chemo/radio','EC','3','','1','0','','','','0','1','0','0'),
('10209','Hematocrit level has exceeded 39% (or hemoglobin level has exceeded 13.0 g/dl) for 3 or more consecutive billing cycles immediately prior to and including the current cycle','Hct>39% or hgb>13g>=3 cycle','ED','3','','1','0','','','','0','1','0','0'),
('10210','Hematocrit level has not exceeded 39% (or hemoglobin level has not exceeded 13.0 g/dl) for 3 or more consecutive billing cycles immediately prior to and including the current cycle','Hct>39% or hgb>13g<3 cycle','EE','3','','1','0','','','','0','1','0','0'),
('10211','Subsequent claims for a defined course of therapy; e.g.; epo; sodium hyaluronate; infliximab','Subsequent claim','EJ','3','','1','0','','','','0','1','0','0'),
('10212','Emergency reserve supply (for esrd benefit only)','Emer reserve supply (esrd)','EM','3','','1','0','','','','0','1','0','0'),
('10213','Service provided as part of medicaid early periodic screening diagnosis and treatment (epsdt) program','Medicaid epsdt program svc','EP','3','','1','0','','','','0','1','0','0'),
('10214','Emergency services','Emergency services','ET','3','','1','0','','','','0','1','0','0'),
('10215','Expatriate beneficiary','Expatriate beneficiary','EX','3','','1','0','','','','0','1','0','0'),
('10216','No physician or other licensed health care provider order for this item or service','No md order for item/service','EY','3','','1','0','','','','0','1','0','0'),
('10217','Left hand; second digit','Left hand; second digit','F1','3','','1','0','','','','0','1','0','0'),
('10218','Left hand; third digit','Left hand; third digit','F2','3','','1','0','','','','0','1','0','0'),
('10219','Left hand; fourth digit','Left hand; fourth digit','F3','3','','1','0','','','','0','1','0','0'),
('10220','Left hand; fifth digit','Left hand; fifth digit','F4','3','','1','0','','','','0','1','0','0'),
('10221','Right hand; thumb','Right hand; thumb','F5','3','','1','0','','','','0','1','0','0'),
('10222','Right hand; second digit','Right hand; second digit','F6','3','','1','0','','','','0','1','0','0'),
('10223','Right hand; third digit','Right hand; third digit','F7','3','','1','0','','','','0','1','0','0'),
('10224','Right hand; fourth digit','Right hand; fourth digit','F8','3','','1','0','','','','0','1','0','0'),
('10225','Right hand; fifth digit','Right hand; fifth digit','F9','3','','1','0','','','','0','1','0','0'),
('10226','Left hand; thumb','Left hand; thumb','FA','3','','1','0','','','','0','1','0','0'),
('10227','Item provided without cost to provider; supplier or practitioner; or full credit received for replaced device (examples; but not limited to; covered under warranty; replaced due to defect; free samples)','Item provided without cost','FB','3','','1','0','','','','0','1','0','0'),
('10228','Partial credit received for replaced device','Part credit; replaced device','FC','3','','1','0','','','','0','1','0','0'),
('10229','Service provided as part of family planning program','Svc part of family plan pgm','FP','3','','1','0','','','','0','1','0','0'),
('10230','X-ray taken using film','X-ray taken using film','FX','3','','1','0','','','','0','1','0','0'),
('10231','Most recent urr reading of less than 60','Urr reading of less than 60','G1','3','','1','0','','','','0','1','0','0'),
('10232','Most recent urr reading of 60 to 64.9','Urr reading of 60 to 64.9','G2','3','','1','0','','','','0','1','0','0'),
('10233','Most recent urr reading of 65 to 69.9','Urr  reading of 65 to 69.9','G3','3','','1','0','','','','0','1','0','0'),
('10234','Most recent urr reading of 70 to 74.9','Urr reading of 70 to 74.9','G4','3','','1','0','','','','0','1','0','0'),
('10235','Most recent urr reading of 75 or greater','Urr reading of 75 or greater','G5','3','','1','0','','','','0','1','0','0'),
('10236','Esrd patient for whom less than six dialysis sessions have been provided in a month','Esrd patient <6 dialysis/mth','G6','3','','1','0','','','','0','1','0','0'),
('10237','Pregnancy resulted from rape or incest or pregnancy certified by physician as life threatening','Payment limits do not apply','G7','3','','1','0','','','','0','1','0','0'),
('10238','Monitored anesthesia care (mac) for deep complex; complicated; or markedly invasive surgical procedure','Monitored anesthesia care','G8','3','','1','0','','','','0','1','0','0'),
('10239','Monitored anesthesia care for patient who has history of severe cardio-pulmonary condition','Mac for at risk patient','G9','3','','1','0','','','','0','1','0','0'),
('10240','Waiver of liability statement issued as required by payer policy; individual case','Liability waiver ind case','GA','3','','1','0','','','','0','1','0','0'),
('10241','Claim being re-submitted for payment because it is no longer covered under a global payment demonstration','Claim resubmitted','GB','3','','1','0','','','','0','1','0','0'),
('10242','This service has been performed in part by a resident under the direction of a teaching physician','Resident/teaching phys serv','GC','3','','1','0','','','','0','1','0','0'),
('10243','Units of service exceeds medically unlikely edit value and represents reasonable and necessary services','Unit of service > mue value','GD','3','','1','0','','','','0','1','0','0'),
('10244','This service has been performed by a resident without the presence of a teaching physician under the primary care exception','Resident prim care exception','GE','3','','1','0','','','','0','1','0','0'),
('10245','Non-physician (e.g. nurse practitioner (np); certified registered nurse anesthetist (crna); certified registered nurse (crn); clinical nurse specialist (cns); physician assistant (pa)) services in a critical access hospital','Nonphysician serv c a hosp','GF','3','','1','0','','','','0','1','0','0'),
('10246','Performance and payment of a screening mammogram and diagnostic mammogram on the same patient; same day','Payment screen mam + diagmam','GG','3','','1','0','','','','0','1','0','0'),
('10247','Diagnostic mammogram converted from screening mammogram on same day','Diag mammo to screening mamo','GH','3','','1','0','','','','0','1','0','0'),
('10248','''opt out'' physician or practitioner emergency or urgent service','Opt out provider of er srvc','GJ','3','','1','0','','','','0','1','0','0'),
('10249','Reasonable and necessary item/service associated with a ga or gz modifier','Actual item/service ordered','GK','3','','1','0','','','','0','1','0','0'),
('10250','Medically unnecessary upgrade provided instead of non-upgraded item; no charge; no advance beneficiary notice (abn)','Upgraded item; no charge','GL','3','','1','0','','','','0','1','0','0'),
('10251','Multiple patients on one ambulance trip','Multiple transports','GM','3','','1','0','','','','0','1','0','0'),
('10252','Services delivered under an outpatient speech language pathology plan of care','Op speech language service','GN','3','','1','0','','','','0','1','0','0'),
('10253','Services delivered under an outpatient occupational therapy plan of care','Op occupational therapy serv','GO','3','','1','0','','','','0','1','0','0'),
('10254','Services delivered under an outpatient physical therapy plan of care','Op pt services','GP','3','','1','0','','','','0','1','0','0'),
('10255','Via asynchronous telecommunications system','Telehealth store and forward','GQ','3','','1','0','','','','0','1','0','0'),
('10256','This service was performed in whole or in part by a resident in a department of veterans affairs medical center or clinic; supervised in accordance with va policy','Service by va resident','GR','3','','1','0','','','','0','1','0','0'),
('10257','Dosage of erythropoietin stimulating agent has been reduced and maintained in response to hematocrit or hemoglobin level','Epo/darbepoietin reduced 25%','GS','3','','1','0','','','','0','1','0','0'),
('10258','Via interactive audio and video telecommunication systems','Interactivetelecommunication','GT','3','','1','0','','','','0','1','0','0'),
('10259','Waiver of liability statement issued as required by payer policy; routine notice','Liability waiver rout notice','GU','3','','1','0','','','','0','1','0','0'),
('10260','Attending physician not employed or paid under arrangement by the patients hospice provider','Attending phys not hospice','GV','3','','1','0','','','','0','1','0','0'),
('10261','Service not related to the hospice patients terminal condition','Service unrelated to term co','GW','3','','1','0','','','','0','1','0','0'),
('10262','Notice of liability issued; voluntary under payer policy','Voluntary liability notice','GX','3','','1','0','','','','0','1','0','0'),
('10263','Item or service statutorily excluded; does not meet the definition of any medicare benefit or; for non-medicare insurers; is not a contract benefit','Statutorily excluded','GY','3','','1','0','','','','0','1','0','0'),
('10264','Item or service expected to be denied as not reasonable and necessary','Not reasonable and necessary','GZ','3','','1','0','','','','0','1','0','0'),
('10265','Court-ordered','Court-ordered','H9','3','','1','0','','','','0','1','0','0'),
('10266','Child/adolescent program','Child/adolescent program','HA','3','','1','0','','','','0','1','0','0'),
('10267','Adult program; non geriatric','Adult program non-geriatric','HB','3','','1','0','','','','0','1','0','0'),
('10268','Adult program; geriatric','Adult program geriatric','HC','3','','1','0','','','','0','1','0','0'),
('10269','Pregnant/parenting womens program','Pregnant/parenting program','HD','3','','1','0','','','','0','1','0','0'),
('10270','Mental health program','Mental health program','HE','3','','1','0','','','','0','1','0','0'),
('10271','Substance abuse program','Substance abuse program','HF','3','','1','0','','','','0','1','0','0'),
('10272','Opioid addiction treatment program','Opioid addiction tx program','HG','3','','1','0','','','','0','1','0','0'),
('10273','Integrated mental health/substance abuse program','Mental hlth/substance abs pr','HH','3','','1','0','','','','0','1','0','0'),
('10274','Integrated mental health and intellectual disability/developmental disabilities program','Men hlth intel/dev disab pgm','HI','3','','1','0','','','','0','1','0','0'),
('10275','Employee assistance program','Employee assistance program','HJ','3','','1','0','','','','0','1','0','0'),
('10276','Specialized mental health programs for high-risk populations','Spec hgh rsk mntl hlth pop p','HK','3','','1','0','','','','0','1','0','0'),
('10277','Intern','Intern','HL','3','','1','0','','','','0','1','0','0'),
('10278','Less than bachelor degree level','Less than bachelor degree lv','HM','3','','1','0','','','','0','1','0','0'),
('10279','Bachelors degree level','Bachelors degree level','HN','3','','1','0','','','','0','1','0','0'),
('10280','Masters degree level','Masters degree level','HO','3','','1','0','','','','0','1','0','0'),
('10281','Doctoral level','Doctoral level','HP','3','','1','0','','','','0','1','0','0'),
('10282','Group setting','Group setting','HQ','3','','1','0','','','','0','1','0','0'),
('10283','Family/couple with client present','Family/couple w client prsnt','HR','3','','1','0','','','','0','1','0','0'),
('10284','Family/couple without client present','Family/couple w/o client prs','HS','3','','1','0','','','','0','1','0','0'),
('10285','Multi-disciplinary team','Multi-disciplinary team','HT','3','','1','0','','','','0','1','0','0'),
('10286','Funded by child welfare agency','Child welfare agency funded','HU','3','','1','0','','','','0','1','0','0'),
('10287','Funded state addictions agency','Funded state addiction agncy','HV','3','','1','0','','','','0','1','0','0'),
('10288','Funded by state mental health agency','State mntl hlth agncy funded','HW','3','','1','0','','','','0','1','0','0'),
('10289','Funded by county/local agency','County/local agency funded','HX','3','','1','0','','','','0','1','0','0'),
('10290','Funded by juvenile justice agency','Funded by juvenile justice','HY','3','','1','0','','','','0','1','0','0'),
('10291','Funded by criminal justice agency','Criminal justice agncy fund','HZ','3','','1','0','','','','0','1','0','0'),
('10292','Competitive acquisition program no-pay submission for a prescription number','Cap no-pay for prescript num','J1','3','','1','0','','','','0','1','0','0'),
('10293','Competitive acquisition program; restocking of emergency drugs after emergency administration','Cap restock of emerg drugs','J2','3','','1','0','','','','0','1','0','0'),
('10294','Competitive acquisition program (cap); drug not available through cap as written; reimbursed under average sales price methodology','Cap drug unavail thru cap','J3','3','','1','0','','','','0','1','0','0'),
('10295','Dmepos item subject to dmepos competitive bidding program that is furnished by a hospital upon discharge','Dmepos comp bid furn by hosp','J4','3','','1','0','','','','0','1','0','0'),
('10296','Administered intravenously','Administered intravenously','JA','3','','1','0','','','','0','1','0','0'),
('10297','Administered subcutaneously','Administered subcutaneously','JB','3','','1','0','','','','0','1','0','0'),
('10298','Skin substitute used as a graft','Skin substitute graft','JC','3','','1','0','','','','0','1','0','0'),
('10299','Skin substitute not used as a graft','Skin sub not used as a graft','JD','3','','1','0','','','','0','1','0','0'),
('10300','Administered via dialysate','Administered via dialysate','JE','3','','1','0','','','','0','1','0','0'),
('10301','Compounded drug','Compounded drug','JF','3','','1','0','','','','0','1','0','0'),
('10302','Drug amount discarded/not administered to any patient','Discarded drug not administe','JW','3','','1','0','','','','0','1','0','0'),
('10303','Lower extremity prosthesis functional level 0 - does not have the ability or potential to ambulate or transfer safely with or without assistance and a prosthesis does not enhance their quality of life or mobility.','Lwr ext prost functnl lvl 0','K0','3','','1','0','','','','0','1','0','0'),
('10304','Lower extremity prosthesis functional level 1 - has the ability or potential to use a prosthesis for transfers or ambulation on level surfaces at fixed cadence. typical of the limited and unlimited household ambulator.','Lwr ext prost functnl lvl 1','K1','3','','1','0','','','','0','1','0','0'),
('10305','Lower extremity prosthesis functional level 2 - has the ability or potential for ambulation with the ability to traverse low level environmental barriers such as curbs; stairs or uneven surfaces.  typical of the limited community ambulator.','Lwr ext prost functnl lvl 2','K2','3','','1','0','','','','0','1','0','0'),
('10306','Lower extremity prosthesis functional level 3 - has the ability or potential for ambulation with variable cadence.  typical of the community ambulator who has the ability to transverse most environmental barriers and may have vocational; therapeutic; or exercise activity that demands prosthetic utilization beyond simple locomotion.','Lwr ext prost functnl lvl 3','K3','3','','1','0','','','','0','1','0','0'),
('10307','Lower extremity prosthesis functional level 4 - has the ability or potential for prosthetic ambulation that exceeds the basic ambulation skills; exhibiting high impact; stress; or energy levels; typical of the prosthetic demands of the child; active adult; or athlete.','Lwr ext prost functnl lvl 4','K4','3','','1','0','','','','0','1','0','0'),
('10308','Add on option/accessory for wheelchair','Wheelchair add-on option/acc','KA','3','','1','0','','','','0','1','0','0'),
('10309','Beneficiary requested upgrade for abn; more than 4 modifiers identified on claim','>4 modifiers on claim','KB','3','','1','0','','','','0','1','0','0'),
('10310','Replacement of special power wheelchair interface','Repl special pwr wc intrface','KC','3','','1','0','','','','0','1','0','0'),
('10311','Drug or biological infused through dme','Drug/biological dme infused','KD','3','','1','0','','','','0','1','0','0'),
('10312','Bid under round one of the dmepos competitive bidding program for use with non-competitive bid base equipment','Bid under round 1 dmepos cb','KE','3','','1','0','','','','0','1','0','0'),
('10313','Item designated by fda as class iii device','Fda class iii device','KF','3','','1','0','','','','0','1','0','0'),
('10314','Dmepos item subject to dmepos competitive bidding program number 1','Dmepos comp bid prgm no 1','KG','3','','1','0','','','','0','1','0','0'),
('10315','Dmepos item; initial claim; purchase or first month rental','Dmepos ini clm; pur/1 mo rnt','KH','3','','1','0','','','','0','1','0','0'),
('10316','Dmepos item; second or third month rental','Dmepos 2nd or 3rd mo rental','KI','3','','1','0','','','','0','1','0','0'),
('10317','Dmepos item; parenteral enteral nutrition (pen) pump or capped rental; months four to fifteen','Dmepos pen pmp or 4-15mo rnt','KJ','3','','1','0','','','','0','1','0','0'),
('10318','Dmepos item subject to dmepos competitive bidding program number 2','Dmepos comp bid prgm no 2','KK','3','','1','0','','','','0','1','0','0'),
('10319','Dmepos item delivered via mail','Dmepos mailorder comp bid','KL','3','','1','0','','','','0','1','0','0'),
('10320','Replacement of facial prosthesis including new impression/moulage','Rplc facial prosth new imp','KM','3','','1','0','','','','0','1','0','0'),
('10321','Replacement of facial prosthesis using previous master model','Rplc facial prosth old mod','KN','3','','1','0','','','','0','1','0','0'),
('10322','Single drug unit dose formulation','Single drug unit dose form','KO','3','','1','0','','','','0','1','0','0'),
('10323','First drug of a multiple drug unit dose formulation','First drug of multi drug u d','KP','3','','1','0','','','','0','1','0','0'),
('10324','Second or subsequent drug of a multiple drug unit dose formulation','2nd/subsqnt drg multi drg ud','KQ','3','','1','0','','','','0','1','0','0'),
('10325','Rental item; billing for partial month','Rental item partial month','KR','3','','1','0','','','','0','1','0','0'),
('10326','Glucose monitor supply for diabetic beneficiary not treated with insulin','Glucose monitor supply','KS','3','','1','0','','','','0','1','0','0'),
('10327','Beneficiary resides in a competitive bidding area and travels outside that competitive bidding area and receives a competitive bid item','Item from noncontract supply','KT','3','','1','0','','','','0','1','0','0'),
('10328','Dmepos item subject to dmepos competitive bidding program number 3','Dmepos comp bid prgm no 3','KU','3','','1','0','','','','0','1','0','0'),
('10329','Dmepos item subject to dmepos competitive bidding program that is furnished as part of a professional service','Dmepos item; profession serv','KV','3','','1','0','','','','0','1','0','0'),
('10330','Dmepos item subject to dmepos competitive bidding program number 4','Dmepos comp bid prgm no 4','KW','3','','1','0','','','','0','1','0','0'),
('10331','Requirements specified in the medical policy have been met','Documentation on file','KX','3','','1','0','','','','0','1','0','0'),
('10332','Dmepos item subject to dmepos competitive bidding program number 5','Dmepos comp bid prgm no 5','KY','3','','1','0','','','','0','1','0','0'),
('10333','New coverage not implemented by managed care','New cov not implement by m+c','KZ','3','','1','0','','','','0','1','0','0'),
('10334','Provider attestation that the hospital laboratory test(s) is not packaged under the hospital opps','Separately payable lab test','L1','3','','1','0','','','','0','1','0','0'),
('10335','Left circumflex coronary artery','Lft circum coronary artery','LC','3','','1','0','','','','0','1','0','0'),
('10336','Left anterior descending coronary artery','Left ant des coronary artery','LD','3','','1','0','','','','0','1','0','0'),
('10337','Lease/rental (use the ll modifier when dme equipment rental is to be applied against the purchase price)','Lease/rental (appld to pur)','LL','3','','1','0','','','','0','1','0','0'),
('10338','Left main coronary artery','Left main coronary artery','LM','3','','1','0','','','','0','1','0','0'),
('10339','Laboratory round trip','Laboratory round trip','LR','3','','1','0','','','','0','1','0','0'),
('10340','Fda-monitored intraocular lens implant','Fda-monitored iol implant','LS','3','','1','0','','','','0','1','0','0'),
('10341','Left side (used to identify procedures performed on the left side of the body)','Left side','LT','3','','1','0','','','','0','1','0','0'),
('10342','Medicare secondary payer (msp)','Medicare secondary payer','M2','3','','1','0','','','','0','1','0','0'),
('10343','Six month maintenance and servicing fee for reasonable and necessary parts and labor which are not covered under any manufacturer or supplier warranty','6-mo maint/svc fee parts/lbr','MS','3','','1','0','','','','0','1','0','0'),
('10344','Nebulizer system; any type; fda-cleared for use with specific drug','Drug specific nebulizer','NB','3','','1','0','','','','0','1','0','0'),
('10345','New when rented (use the nr modifier when dme which was new at the time of rental is subsequently purchased)','New when rented','NR','3','','1','0','','','','0','1','0','0'),
('10346','New equipment','New equipment','NU','3','','1','0','','','','0','1','0','0'),
('10347','A normal healthy patient','Normal healthy patient','P1','3','','1','0','','','','0','1','0','0'),
('10348','A patient with mild systemic disease','Patient w/mild syst disease','P2','3','','1','0','','','','0','1','0','0'),
('10349','A patient with severe systemic disease','Patient w/severe sys disease','P3','3','','1','0','','','','0','1','0','0'),
('10350','A patient with severe systemic disease that is a constant threat to life','Pt w/sev sys dis threat life','P4','3','','1','0','','','','0','1','0','0'),
('10351','A moribund patient who is not expected to survive without the operation','Pt not expect surv w/o oper','P5','3','','1','0','','','','0','1','0','0'),
('10352','A declared brain-dead patient whose organs are being removed for donor purposes','Brain-dead pt organs removed','P6','3','','1','0','','','','0','1','0','0'),
('10353','Surgical or other invasive procedure on wrong body part','Surgery; wrong body part','PA','3','','1','0','','','','0','1','0','0'),
('10354','Surgical or other invasive procedure on wrong patient','Surgery; wrong patient','PB','3','','1','0','','','','0','1','0','0'),
('10355','Wrong surgery or other invasive procedure on patient','Wrong surgery on patient','PC','3','','1','0','','','','0','1','0','0'),
('10356','Diagnostic or related non diagnostic item or service provided in a wholly owned or operated entity to a patient who is admitted as an inpatient within 3 days','Inp admit w/in 3 days','PD','3','','1','0','','','','0','1','0','0'),
('10357','Positron emission tomography (pet) or pet/computed tomography (ct) to inform the initial treatment strategy of tumors that are biopsy proven or strongly suspected of being cancerous based on other diagnostic testing','Pet tumor init tx strat','PI','3','','1','0','','','','0','1','0','0'),
('10358','Progressive addition lenses','Progressive addition lenses','PL','3','','1','0','','','','0','1','0','0'),
('10359','Post mortem','Post mortem','PM','3','','1','0','','','','0','1','0','0'),
('10360','Non-excepted service provided at an off-campus; outpatient; provider-based department of a hospital','Non-excepted off-campus svc','PN','3','','1','0','','','','0','1','0','0'),
('10361','Excepted service provided at an off-campus; outpatient; provider-based department of a hospital','Excepted off-campus service','PO','3','','1','0','','','','0','1','0','0'),
('10362','Positron emission tomography (pet) or pet/computed tomography (ct) to inform the subsequent treatment strategy of cancerous tumors when the beneficiarys treating physician determines that the pet study is needed to inform subsequent anti-tumor strategy','Pet tumor subsq tx strategy','PS','3','','1','0','','','','0','1','0','0'),
('10363','Colorectal cancer screening test; converted to diagnostic test or other procedure','Clrctal screen to diagn','PT','3','','1','0','','','','0','1','0','0'),
('10364','Investigational clinical service provided in a clinical research study that is in an approved clinical research study','Invest clinical research','Q0','3','','1','0','','','','0','1','0','0'),
('10365','Routine clinical service provided in a clinical research study that is in an approved clinical research study','Routine clinical research','Q1','3','','1','0','','','','0','1','0','0'),
('10366','Demonstration procedure/service','Demo procedure; service','Q2','3','','1','0','','','','0','1','0','0'),
('10367','Live kidney donor surgery and related services','Live donor surgery/services','Q3','3','','1','0','','','','0','1','0','0'),
('10368','Service for ordering/referring physician qualifies as a service exemption','Svc exempt - ordrg/rfrng md','Q4','3','','1','0','','','','0','1','0','0'),
('10369','Service furnished by a substitute physician under a reciprocal billing arrangement','Subst md svc; recip bill arr','Q5','3','','1','0','','','','0','1','0','0'),
('10370','Service furnished by a locum tenens physician','Locum tenens md service','Q6','3','','1','0','','','','0','1','0','0'),
('10371','One class a finding','One class a finding','Q7','3','','1','0','','','','0','1','0','0'),
('10372','Two class b findings','Two class b findings','Q8','3','','1','0','','','','0','1','0','0'),
('10373','One class b and two class c findings','1 class b & 2 class c fndngs','Q9','3','','1','0','','','','0','1','0','0'),
('10374','Single channel monitoring','Single channel monitoring','QC','3','','1','0','','','','0','1','0','0'),
('10375','Recording and storage in solid state memory by a digital recorder','Rcrdg/strg in sld st memory','QD','3','','1','0','','','','0','1','0','0'),
('10376','Prescribed amount of oxygen is less than 1 liter per minute (lpm)','Prescribed oxygen < 1 lpm','QE','3','','1','0','','','','0','1','0','0'),
('10377','Prescribed amount of oxygen exceeds 4 liters per minute (lpm) and portable oxygen is prescribed','Prscrbd oxygen >4 lpm & port','QF','3','','1','0','','','','0','1','0','0'),
('10378','Prescribed amount of oxygen is greater than 4 liters per minute(lpm)','Prescribed oxygen > 4 lpm','QG','3','','1','0','','','','0','1','0','0'),
('10379','Oxygen conserving device is being used with an oxygen delivery system','Oxygen cnsrvg dvc w del sys','QH','3','','1','0','','','','0','1','0','0'),
('10380','Services/items provided to a prisoner or patient in state or local custody; however the state or local government; as applicable; meets the requirements in 42 cfr 411.4 (b)','Patient in state/locl custod','QJ','3','','1','0','','','','0','1','0','0'),
('10381','Medical direction of two; three; or four concurrent anesthesia procedures involving qualified individuals','Med dir 2-4 cncrnt anes proc','QK','3','','1','0','','','','0','1','0','0'),
('10382','Patient pronounced dead after ambulance called','Patient died after amb call','QL','3','','1','0','','','','0','1','0','0'),
('10383','Ambulance service provided under arrangement by a provider of services','Ambulance arr by provider','QM','3','','1','0','','','','0','1','0','0'),
('10384','Ambulance service furnished directly by a provider of services','Ambulance furn by provider','QN','3','','1','0','','','','0','1','0','0'),
('10385','Documentation is on file showing that the laboratory test(s) was ordered individually or ordered as a cpt-recognized panel other than automated profile codes 80002-80019; g0058; g0059; and g0060.','Individually ordered lab tst','QP','3','','1','0','','','','0','1','0','0'),
('10386','Monitored anesthesia care service','Monitored anesthesia care','QS','3','','1','0','','','','0','1','0','0'),
('10387','Recording and storage on tape by an analog tape recorder','Rcrdg/strg tape analog recdr','QT','3','','1','0','','','','0','1','0','0'),
('10388','Clia waived test','Clia waived test','QW','3','','1','0','','','','0','1','0','0'),
('10389','Crna service: with medical direction by a physician','Crna svc w/ md med direction','QX','3','','1','0','','','','0','1','0','0'),
('10390','Medical direction of one certified registered nurse anesthetist (crna) by an anesthesiologist','Medically directed crna','QY','3','','1','0','','','','0','1','0','0'),
('10391','Crna service: without medical direction by a physician','Crna svc w/o med dir by md','QZ','3','','1','0','','','','0','1','0','0'),
('10392','Replacement of a dme; orthotic or prosthetic item','Replacement of dme item','RA','3','','1','0','','','','0','1','0','0'),
('10393','Replacement of a part of a dme; orthotic or prosthetic item furnished as part of a repair','Replacement part; dme item','RB','3','','1','0','','','','0','1','0','0'),
('10394','Right coronary artery','Right coronary artery','RC','3','','1','0','','','','0','1','0','0'),
('10395','Drug provided to beneficiary; but not administered ''incident-to''','Drug admin not incident-to','RD','3','','1','0','','','','0','1','0','0'),
('10396','Furnished in full compliance with fda-mandated risk evaluation and mitigation strategy (rems)','Furnish full compliance rems','RE','3','','1','0','','','','0','1','0','0'),
('10397','Ramus intermedius coronary artery','Ramus intermedius cor artery','RI','3','','1','0','','','','0','1','0','0'),
('10398','Rental (use the rr modifier when dme is to be rented)','Rental (dme)','RR','3','','1','0','','','','0','1','0','0'),
('10399','Right side (used to identify procedures performed on the right side of the body)','Right side','RT','3','','1','0','','','','0','1','0','0'),
('10400','Nurse practitioner rendering service in collaboration with a physician','Nurse practitioner w physici','SA','3','','1','0','','','','0','1','0','0'),
('10401','Nurse midwife','Nurse midwife','SB','3','','1','0','','','','0','1','0','0'),
('10402','Medically necessary service or supply','Medically necessary serv/sup','SC','3','','1','0','','','','0','1','0','0'),
('10403','Services provided by registered nurse with specialized; highly technical home infusion training','Serv by home infusion rn','SD','3','','1','0','','','','0','1','0','0'),
('10404','State and/or federally-funded programs/services','State/fed funded program/ser','SE','3','','1','0','','','','0','1','0','0'),
('10405','Second opinion ordered by a professional review organization (pro) per section 9401; p.l. 99-272 (100% reimbursement - no medicare deductible or coinsurance)','2nd opinion ordered by pro','SF','3','','1','0','','','','0','1','0','0'),
('10406','Ambulatory surgical center (asc) facility service','Asc facility service','SG','3','','1','0','','','','0','1','0','0'),
('10407','Second concurrently administered infusion therapy','2nd concurrent infusion ther','SH','3','','1','0','','','','0','1','0','0'),
('10408','Third or more concurrently administered infusion therapy','3rd concurrent infusion ther','SJ','3','','1','0','','','','0','1','0','0'),
('10409','Member of high risk population (use only with codes for immunization)','High risk population','SK','3','','1','0','','','','0','1','0','0'),
('10410','State supplied vaccine','State supplied vaccine','SL','3','','1','0','','','','0','1','0','0'),
('10411','Second surgical opinion','Second opinion','SM','3','','1','0','','','','0','1','0','0'),
('10412','Third surgical opinion','Third opinion','SN','3','','1','0','','','','0','1','0','0'),
('10413','Item ordered by home health','Item ordered by home health','SQ','3','','1','0','','','','0','1','0','0'),
('10414','Home infusion services provided in the infusion suite of the iv therapy provider','Hit in infusion suite','SS','3','','1','0','','','','0','1','0','0'),
('10415','Related to trauma or injury','Related to trauma or injury','ST','3','','1','0','','','','0','1','0','0'),
('10416','Procedure performed in physicians office (to denote use of facility and equipment)','Performed in phys office','SU','3','','1','0','','','','0','1','0','0'),
('10417','Pharmaceuticals delivered to patients home but not utilized','Drugs delivered not used','SV','3','','1','0','','','','0','1','0','0'),
('10418','Services provided by a certified diabetic educator','Serv by cert diab educator','SW','3','','1','0','','','','0','1','0','0'),
('10419','Persons who are in close contact with member of high-risk population (use only with codes for immunization)','Contact w/high-risk pop','SY','3','','1','0','','','','0','1','0','0'),
('10420','Habilitative services','Habilitative services','SZ','3','','1','0','','','','0','1','0','0'),
('10421','Left foot; second digit','Left foot; second digit','T1','3','','1','0','','','','0','1','0','0'),
('10422','Left foot; third digit','Left foot; third digit','T2','3','','1','0','','','','0','1','0','0'),
('10423','Left foot; fourth digit','Left foot; fourth digit','T3','3','','1','0','','','','0','1','0','0'),
('10424','Left foot; fifth digit','Left foot; fifth digit','T4','3','','1','0','','','','0','1','0','0'),
('10425','Right foot; great toe','Right foot; great toe','T5','3','','1','0','','','','0','1','0','0'),
('10426','Right foot; second digit','Right foot; second digit','T6','3','','1','0','','','','0','1','0','0'),
('10427','Right foot; third digit','Right foot; third digit','T7','3','','1','0','','','','0','1','0','0'),
('10428','Right foot; fourth digit','Right foot; fourth digit','T8','3','','1','0','','','','0','1','0','0'),
('10429','Right foot; fifth digit','Right foot; fifth digit','T9','3','','1','0','','','','0','1','0','0'),
('10430','Left foot; great toe','Left foot; great toe','TA','3','','1','0','','','','0','1','0','0'),
('10431','Technical component; under certain circumstances; a charge may be made for the technical component alone;  under those circumstances the technical component charge is identified by adding modifier tc to the usual procedure number; technical component charges are institutional charges and not billed separately by physicians; however; portable x-ray suppliers only bill for technical component and should utilize modifier tc; the charge data from portable x-ray suppliers will then be used to build customary and prevailing profiles','Technical component','TC','3','','1','0','','','','0','1','0','0'),
('10432','Rn','Rn','TD','3','','1','0','','','','0','1','0','0'),
('10433','Lpn/lvn','Lpn/lvn','TE','3','','1','0','','','','0','1','0','0'),
('10434','Intermediate level of care','Intermediate level of care','TF','3','','1','0','','','','0','1','0','0'),
('10435','Complex/high tech level of care','Complex/high tech level care','TG','3','','1','0','','','','0','1','0','0'),
('10436','Obstetrical treatment/services; prenatal or postpartum','Ob tx/srvcs prenatl/postpart','TH','3','','1','0','','','','0','1','0','0'),
('10437','Program group; child and/or adolescent','Child/adolescent program gp','TJ','3','','1','0','','','','0','1','0','0'),
('10438','Extra patient or passenger; non-ambulance','Extra patient or passenger','TK','3','','1','0','','','','0','1','0','0'),
('10439','Early intervention/individualized family service plan (ifsp)','Early intervention ifsp','TL','3','','1','0','','','','0','1','0','0'),
('10440','Individualized education program (iep)','Individualized ed prgrm(iep)','TM','3','','1','0','','','','0','1','0','0'),
('10441','Rural/outside providers customary service area','Rural/out of service area','TN','3','','1','0','','','','0','1','0','0'),
('10442','Medical transport; unloaded vehicle','Med transprt unloaded vehicl','TP','3','','1','0','','','','0','1','0','0'),
('10443','Basic life support transport by a volunteer ambulance provider','Bls by volunteer amb providr','TQ','3','','1','0','','','','0','1','0','0'),
('10444','School-based individualized education program (iep) services provided outside the public school district responsible for the student','School-based iep out of dist','TR','3','','1','0','','','','0','1','0','0'),
('10445','Follow-up service','Follow-up service','TS','3','','1','0','','','','0','1','0','0'),
('10446','Individualized service provided to more than one patient in same setting','Additional patient','TT','3','','1','0','','','','0','1','0','0'),
('10447','Special payment rate; overtime','Overtime payment rate','TU','3','','1','0','','','','0','1','0','0'),
('10448','Special payment rates; holidays/weekends','Holiday/weekend payment rate','TV','3','','1','0','','','','0','1','0','0'),
('10449','Back-up equipment','Back-up equipment','TW','3','','1','0','','','','0','1','0','0'),
('10450','Medicaid level of care 1; as defined by each state','M/caid care lev 1 state def','U1','3','','1','0','','','','0','1','0','0'),
('10451','Medicaid level of care 2; as defined by each state','M/caid care lev 2 state def','U2','3','','1','0','','','','0','1','0','0'),
('10452','Medicaid level of care 3; as defined by each state','M/caid care lev 3 state def','U3','3','','1','0','','','','0','1','0','0'),
('10453','Medicaid level of care 4; as defined by each state','M/caid care lev 4 state def','U4','3','','1','0','','','','0','1','0','0'),
('10454','Medicaid level of care 5; as defined by each state','M/caid care lev 5 state def','U5','3','','1','0','','','','0','1','0','0'),
('10455','Medicaid level of care 6; as defined by each state','M/caid care lev 6 state def','U6','3','','1','0','','','','0','1','0','0'),
('10456','Medicaid level of care 7; as defined by each state','M/caid care lev 7 state def','U7','3','','1','0','','','','0','1','0','0'),
('10457','Medicaid level of care 8; as defined by each state','M/caid care lev 8 state def','U8','3','','1','0','','','','0','1','0','0'),
('10458','Medicaid level of care 9; as defined by each state','M/caid care lev 9 state def','U9','3','','1','0','','','','0','1','0','0'),
('10459','Medicaid level of care 10; as defined by each state','M/caid care lev 10 state def','UA','3','','1','0','','','','0','1','0','0'),
('10460','Medicaid level of care 11; as defined by each state','M/caid care lev 11 state def','UB','3','','1','0','','','','0','1','0','0'),
('10461','Medicaid level of care 12; as defined by each state','M/caid care lev 12 state def','UC','3','','1','0','','','','0','1','0','0'),
('10462','Medicaid level of care 13; as defined by each state','M/caid care lev 13 state def','UD','3','','1','0','','','','0','1','0','0'),
('10463','Used durable medical equipment','Used durable med equipment','UE','3','','1','0','','','','0','1','0','0'),
('10464','Services provided in the morning','Services provided; morning','UF','3','','1','0','','','','0','1','0','0'),
('10465','Services provided in the afternoon','Services provided; afternoon','UG','3','','1','0','','','','0','1','0','0'),
('10466','Services provided in the evening','Services provided; evening','UH','3','','1','0','','','','0','1','0','0'),
('10467','Services provided at night','Services provided; night','UJ','3','','1','0','','','','0','1','0','0'),
('10468','Services provided on behalf of the client to someone other than the client (collateral relationship)','Svc on behalf client-collat','UK','3','','1','0','','','','0','1','0','0'),
('10469','Two patients served','Two patients served','UN','3','','1','0','','','','0','1','0','0'),
('10470','Three patients served','Three patients served','UP','3','','1','0','','','','0','1','0','0'),
('10471','Four patients served','Four patients served','UQ','3','','1','0','','','','0','1','0','0'),
('10472','Five patients served','Five patients served','UR','3','','1','0','','','','0','1','0','0'),
('10473','Six or more patients served','Six or more patients served','US','3','','1','0','','','','0','1','0','0'),
('10474','Demonstration modifier 1','Demonstration modifier 1','V1','3','','1','0','','','','0','1','0','0'),
('10475','Demonstration modifier 2','Demonstration modifier 2','V2','3','','1','0','','','','0','1','0','0'),
('10476','Demonstration modifier 3','Demonstration modifier 3','V3','3','','1','0','','','','0','1','0','0'),
('10477','Vascular catheter (alone or with any other vascular access)','Vascular catheter','V5','3','','1','0','','','','0','1','0','0'),
('10478','Arteriovenous graft (or other vascular access not including a vascular catheter)','Arteriovenous graft','V6','3','','1','0','','','','0','1','0','0'),
('10479','Arteriovenous fistula only (in use with two needles)','Arteriovenous fistula','V7','3','','1','0','','','','0','1','0','0'),
('10480','Infection present','Infection present','V8','3','','1','0','','','','0','1','0','0'),
('10481','No infection present','No infection present','V9','3','','1','0','','','','0','1','0','0'),
('10482','Aphakic patient','Aphakic patient','VP','3','','1','0','','','','0','1','0','0'),
('10483','Separate encounter; a service that is distinct because it occurred during a separate encounter','Separate encounter','XE','3','','1','0','','','','0','1','0','0'),
('10484','Separate practitioner; a service that is distinct because it was performed by a different practitioner','Separate practitioner','XP','3','','1','0','','','','0','1','0','0'),
('10485','Separate structure; a service that is distinct because it was performed on a separate organ/structure','Separate organ/structure','XS','3','','1','0','','','','0','1','0','0'),
('10486','Unusual non-overlapping service; the use of a service that is distinct because it does not overlap usual components of the main service','Unusual separate service','XU','3','','1','0','','','','0','1','0','0'),
('10487','Novartis/sandoz','Novartis/sandoz','ZA','3','','1','0','','','','0','1','0','0'),
('10488','Pfizer/hospira','Pfizer/hospira','ZB','3','','1','0','','','','0','1','0','0'),
('10489','Ambulance service; outside state per mile; transport (medicaid only)','Outside state ambulance serv','A0021','3','','1','0','','','','0','1','0','0'),
('10490','Non-emergency transportation; per mile - vehicle provided by volunteer (individual or organization); with no vested interest','Noninterest escort in non er','A0080','3','','1','0','','','','0','1','0','0'),
('10491','Non-emergency transportation; per mile - vehicle provided by individual (family member; self; neighbor) with vested interest','Interest escort in non er','A0090','3','','1','0','','','','0','1','0','0'),
('10492','Non-emergency transportation; taxi','Nonemergency transport taxi','A0100','3','','1','0','','','','0','1','0','0'),
('10493','Non-emergency transportation and bus; intra or inter state carrier','Nonemergency transport bus','A0110','3','','1','0','','','','0','1','0','0'),
('10494','Non-emergency transportation: mini-bus; mountain area transports; or other transportation systems','Noner transport mini-bus','A0120','3','','1','0','','','','0','1','0','0'),
('10495','Non-emergency transportation: wheelchair van','Noner transport wheelch van','A0130','3','','1','0','','','','0','1','0','0'),
('10496','Non-emergency transportation and air travel (private or commercial) intra or inter state','Nonemergency transport air','A0140','3','','1','0','','','','0','1','0','0'),
('10497','Non-emergency transportation: per mile - case worker or social worker','Noner transport case worker','A0160','3','','1','0','','','','0','1','0','0'),
('10498','Transportation ancillary: parking fees; tolls; other','Transport parking fees/tolls','A0170','3','','1','0','','','','0','1','0','0'),
('10499','Non-emergency transportation: ancillary: lodging-recipient','Noner transport lodgng recip','A0180','3','','1','0','','','','0','1','0','0'),
('10500','Non-emergency transportation: ancillary: meals-recipient','Noner transport meals recip','A0190','3','','1','0','','','','0','1','0','0'),
('10501','Non-emergency transportation: ancillary: lodging escort','Noner transport lodgng escrt','A0200','3','','1','0','','','','0','1','0','0'),
('10502','Non-emergency transportation: ancillary: meals-escort','Noner transport meals escort','A0210','3','','1','0','','','','0','1','0','0'),
('10503','Ambulance service; neonatal transport; base rate; emergency transport; one way','Neonatal emergency transport','A0225','3','','1','0','','','','0','1','0','0'),
('10504','Bls mileage (per mile)','Basic life support mileage','A0380','3','','1','0','','','','0','1','0','0'),
('10505','Bls routine disposable supplies','Basic support routine suppls','A0382','3','','1','0','','','','0','1','0','0'),
('10506','Bls specialized service disposable supplies; defibrillation (used by als ambulances and bls ambulances in jurisdictions where defibrillation is permitted in bls ambulances)','Bls defibrillation supplies','A0384','3','','1','0','','','','0','1','0','0'),
('10507','Als mileage (per mile)','Advanced life support mileag','A0390','3','','1','0','','','','0','1','0','0'),
('10508','Als specialized service disposable supplies; defibrillation (to be used only in jurisdictions where defibrillation cannot be performed in bls ambulances)','Als defibrillation supplies','A0392','3','','1','0','','','','0','1','0','0'),
('10509','Als specialized service disposable supplies; iv drug therapy','Als iv drug therapy supplies','A0394','3','','1','0','','','','0','1','0','0'),
('10510','Als specialized service disposable supplies; esophageal intubation','Als esophageal intub suppls','A0396','3','','1','0','','','','0','1','0','0'),
('10511','Als routine disposable supplies','Als routine disposble suppls','A0398','3','','1','0','','','','0','1','0','0'),
('10512','Ambulance waiting time (als or bls); one half (1/2) hour increments','Ambulance waiting 1/2 hr','A0420','3','','1','0','','','','0','1','0','0'),
('10513','Ambulance (als or bls) oxygen and oxygen supplies; life sustaining situation','Ambulance 02 life sustaining','A0422','3','','1','0','','','','0','1','0','0'),
('10514','Extra ambulance attendant; ground (als or bls) or air (fixed or rotary winged); (requires medical review)','Extra ambulance attendant','A0424','3','','1','0','','','','0','1','0','0'),
('10515','Ground mileage; per statute mile','Ground mileage','A0425','3','','1','0','','','','0','1','0','0'),
('10516','Ambulance service; advanced life support; non-emergency transport; level 1 (als 1)','Als 1','A0426','3','','1','0','','','','0','1','0','0'),
('10517','Ambulance service; advanced life support; emergency transport; level 1 (als 1 - emergency)','Als1-emergency','A0427','3','','1','0','','','','0','1','0','0'),
('10518','Ambulance service; basic life support; non-emergency transport; (bls)','Bls','A0428','3','','1','0','','','','0','1','0','0'),
('10519','Ambulance service; basic life support; emergency transport (bls-emergency)','Bls-emergency','A0429','3','','1','0','','','','0','1','0','0'),
('10520','Ambulance service; conventional air services; transport; one way (fixed wing)','Fixed wing air transport','A0430','3','','1','0','','','','0','1','0','0'),
('10521','Ambulance service; conventional air services; transport; one way (rotary wing)','Rotary wing air transport','A0431','3','','1','0','','','','0','1','0','0'),
('10522','Paramedic intercept (pi); rural area; transport furnished by a volunteer ambulance company which is prohibited by state law from billing third party payers','Pi volunteer ambulance co','A0432','3','','1','0','','','','0','1','0','0'),
('10523','Advanced life support; level 2 (als 2)','Als 2','A0433','3','','1','0','','','','0','1','0','0'),
('10524','Specialty care transport (sct)','Specialty care transport','A0434','3','','1','0','','','','0','1','0','0'),
('10525','Fixed wing air mileage; per statute mile','Fixed wing air mileage','A0435','3','','1','0','','','','0','1','0','0'),
('10526','Rotary wing air mileage; per statute mile','Rotary wing air mileage','A0436','3','','1','0','','','','0','1','0','0'),
('10527','Noncovered ambulance mileage; per mile (e.g.; for miles traveled beyond closest appropriate facility)','Noncovered ambulance mileage','A0888','3','','1','0','','','','0','1','0','0'),
('10528','Ambulance response and treatment; no transport','Ambulance response/treatment','A0998','3','','1','0','','','','0','1','0','0'),
('10529','Unlisted ambulance service','Unlisted ambulance service','A0999','3','','1','0','','','','0','1','0','0'),
('10530','Syringe with needle; sterile; 1 cc or less; each','1 cc sterile syringe&needle','A4206','3','','1','0','','','','0','1','0','0'),
('10531','Syringe with needle; sterile 2 cc; each','2 cc sterile syringe&needle','A4207','3','','1','0','','','','0','1','0','0'),
('10532','Syringe with needle; sterile 3 cc; each','3 cc sterile syringe&needle','A4208','3','','1','0','','','','0','1','0','0'),
('10533','Syringe with needle; sterile 5 cc or greater; each','5+ cc sterile syringe&needle','A4209','3','','1','0','','','','0','1','0','0'),
('10534','Needle-free injection device; each','Nonneedle injection device','A4210','3','','1','0','','','','0','1','0','0'),
('10535','Supplies for self-administered injections','Supp for self-adm injections','A4211','3','','1','0','','','','0','1','0','0'),
('10536','Non-coring needle or stylet with or without catheter','Non coring needle or stylet','A4212','3','','1','0','','','','0','1','0','0'),
('10537','Syringe; sterile; 20 cc or greater; each','20+ cc syringe only','A4213','3','','1','0','','','','0','1','0','0'),
('10538','Needle; sterile; any size; each','Sterile needle','A4215','3','','1','0','','','','0','1','0','0'),
('10539','Sterile water; saline and/or dextrose; diluent/flush; 10 ml','Sterile water/saline; 10 ml','A4216','3','','1','0','','','','0','1','0','0'),
('10540','Sterile water/saline; 500 ml','Sterile water/saline; 500 ml','A4217','3','','1','0','','','','0','1','0','0'),
('10541','Sterile saline or water; metered dose dispenser; 10 ml','Sterile saline or water','A4218','3','','1','0','','','','0','1','0','0'),
('10542','Refill kit for implantable infusion pump','Infusion pump refill kit','A4220','3','','1','0','','','','0','1','0','0'),
('10543','Supplies for maintenance of non-insulin drug infusion catheter; per week (list drugs  separately)','Supp non-insulin inf cath/wk','A4221','3','','1','0','','','','0','1','0','0'),
('10544','Infusion supplies for external drug infusion pump; per cassette or bag (list drugs separately)','Infusion supplies with pump','A4222','3','','1','0','','','','0','1','0','0'),
('10545','Infusion supplies not used with external infusion pump; per cassette or bag (list drugs separately)','Infusion supplies w/o pump','A4223','3','','1','0','','','','0','1','0','0'),
('10546','Supplies for maintenance of insulin infusion catheter; per week','Supply insulin inf cath/wk','A4224','3','','1','0','','','','0','1','0','0'),
('10547','Supplies for external insulin infusion pump; syringe type cartridge; sterile; each','Sup/ext insulin inf pump syr','A4225','3','','1','0','','','','0','1','0','0'),
('10548','Infusion set for external insulin pump; non needle cannula type','Infus insulin pump non needl','A4230','3','','1','0','','','','0','1','0','0'),
('10549','Infusion set for external insulin pump; needle type','Infusion insulin pump needle','A4231','3','','1','0','','','','0','1','0','0'),
('10550','Syringe with needle for external insulin pump; sterile; 3 cc','Syringe w/needle insulin 3cc','A4232','3','','1','0','','','','0','1','0','0'),
('10551','Replacement battery; alkaline (other than j cell); for use with medically necessary home blood glucose monitor owned by patient; each','Alkalin batt for glucose mon','A4233','3','','1','0','','','','0','1','0','0'),
('10552','Replacement battery; alkaline; j cell; for use with medically necessary home blood glucose monitor owned by patient; each','J-cell batt for glucose mon','A4234','3','','1','0','','','','0','1','0','0'),
('10553','Replacement battery; lithium; for use with medically necessary home blood glucose monitor owned by patient; each','Lithium batt for glucose mon','A4235','3','','1','0','','','','0','1','0','0'),
('10554','Replacement battery; silver oxide; for use with medically necessary home blood glucose monitor owned by patient; each','Silvr oxide batt glucose mon','A4236','3','','1','0','','','','0','1','0','0'),
('10555','Alcohol or peroxide; per pint','Alcohol or peroxide per pint','A4244','3','','1','0','','','','0','1','0','0'),
('10556','Alcohol wipes; per box','Alcohol wipes per box','A4245','3','','1','0','','','','0','1','0','0'),
('10557','Betadine or phisohex solution; per pint','Betadine/phisohex solution','A4246','3','','1','0','','','','0','1','0','0'),
('10558','Betadine or iodine swabs/wipes; per box','Betadine/iodine swabs/wipes','A4247','3','','1','0','','','','0','1','0','0'),
('10559','Chlorhexidine containing antiseptic; 1 ml','Chlorhexidine antisept','A4248','3','','1','0','','','','0','1','0','0'),
('10560','Urine test or reagent strips or tablets (100 tablets or strips)','Urine reagent strips/tablets','A4250','3','','1','0','','','','0','1','0','0'),
('10561','Blood ketone test or reagent strip; each','Blood ketone test or strip','A4252','3','','1','0','','','','0','1','0','0'),
('10562','Blood glucose test or reagent strips for home blood glucose monitor; per 50 strips','Blood glucose/reagent strips','A4253','3','','1','0','','','','0','1','0','0'),
('10563','Platforms for home blood glucose monitor; 50 per box','Glucose monitor platforms','A4255','3','','1','0','','','','0','1','0','0'),
('10564','Normal; low and high calibrator solution / chips','Calibrator solution/chips','A4256','3','','1','0','','','','0','1','0','0'),
('10565','Replacement lens shield cartridge for use with laser skin piercing device; each','Replace lensshield cartridge','A4257','3','','1','0','','','','0','1','0','0'),
('10566','Spring-powered device for lancet; each','Lancet device each','A4258','3','','1','0','','','','0','1','0','0'),
('10567','Lancets; per box of 100','Lancets per box','A4259','3','','1','0','','','','0','1','0','0'),
('10568','Cervical cap for contraceptive use','Cervical cap contraceptive','A4261','3','','1','0','','','','0','1','0','0'),
('10569','Temporary; absorbable lacrimal duct implant; each','Temporary tear duct plug','A4262','3','','1','0','','','','0','1','0','0'),
('10570','Permanent; long term; non-dissolvable lacrimal duct implant; each','Permanent tear duct plug','A4263','3','','1','0','','','','0','1','0','0'),
('10571','Permanent implantable contraceptive intratubal occlusion device(s) and delivery system','Intratubal occlusion device','A4264','3','','1','0','','','','0','1','0','0'),
('10572','Paraffin; per pound','Paraffin','A4265','3','','1','0','','','','0','1','0','0'),
('10573','Diaphragm for contraceptive use','Diaphragm','A4266','3','','1','0','','','','0','1','0','0'),
('10574','Contraceptive supply; condom; male; each','Male condom','A4267','3','','1','0','','','','0','1','0','0'),
('10575','Contraceptive supply; condom; female; each','Female condom','A4268','3','','1','0','','','','0','1','0','0'),
('10576','Contraceptive supply; spermicide (e.g.; foam; gel); each','Spermicide','A4269','3','','1','0','','','','0','1','0','0'),
('10577','Disposable endoscope sheath; each','Disposable endoscope sheath','A4270','3','','1','0','','','','0','1','0','0'),
('10578','Adhesive skin support attachment for use with external breast prosthesis; each','Brst prsths adhsv attchmnt','A4280','3','','1','0','','','','0','1','0','0'),
('10579','Tubing for breast pump; replacement','Replacement breastpump tube','A4281','3','','1','0','','','','0','1','0','0'),
('10580','Adapter for breast pump; replacement','Replacement breastpump adpt','A4282','3','','1','0','','','','0','1','0','0'),
('10581','Cap for breast pump bottle; replacement','Replacement breastpump cap','A4283','3','','1','0','','','','0','1','0','0'),
('10582','Breast shield and splash protector for use with breast pump; replacement','Replcmnt breast pump shield','A4284','3','','1','0','','','','0','1','0','0'),
('10583','Polycarbonate bottle for use with breast pump; replacement','Replcmnt breast pump bottle','A4285','3','','1','0','','','','0','1','0','0'),
('10584','Locking ring for breast pump; replacement','Replcmnt breastpump lok ring','A4286','3','','1','0','','','','0','1','0','0'),
('10585','Sacral nerve stimulation test lead; each','Sacral nerve stim test lead','A4290','3','','1','0','','','','0','1','0','0'),
('10586','Implantable access catheter; (e.g.; venous; arterial; epidural subarachnoid; or peritoneal; etc.) external access','Cath impl vasc access portal','A4300','3','','1','0','','','','0','1','0','0'),
('10587','Implantable access total catheter; port/reservoir (e.g.; venous; arterial; epidural; subarachnoid; peritoneal; etc.)','Implantable access syst perc','A4301','3','','1','0','','','','0','1','0','0'),
('10588','Disposable drug delivery system; flow rate of 50 ml or greater per hour','Drug delivery system >=50 ml','A4305','3','','1','0','','','','0','1','0','0'),
('10589','Disposable drug delivery system; flow rate of less than 50 ml per hour','Drug delivery system <=50 ml','A4306','3','','1','0','','','','0','1','0','0'),
('10590','Insertion tray without drainage bag and without catheter (accessories only)','Insert tray w/o bag/cath','A4310','3','','1','0','','','','0','1','0','0'),
('10591','Insertion tray without drainage bag with indwelling catheter; foley type; two-way latex with coating (teflon; silicone; silicone elastomer or hydrophilic; etc.)','Catheter w/o bag 2-way latex','A4311','3','','1','0','','','','0','1','0','0'),
('10592','Insertion tray without drainage bag with indwelling catheter; foley type; two-way; all silicone','Cath w/o bag 2-way silicone','A4312','3','','1','0','','','','0','1','0','0'),
('10593','Insertion tray without drainage bag with indwelling catheter; foley type; three-way; for continuous irrigation','Catheter w/bag 3-way','A4313','3','','1','0','','','','0','1','0','0'),
('10594','Insertion tray with drainage bag with indwelling catheter; foley type; two-way latex with coating (teflon; silicone; silicone elastomer or hydrophilic; etc.)','Cath w/drainage 2-way latex','A4314','3','','1','0','','','','0','1','0','0'),
('10595','Insertion tray with drainage bag with indwelling catheter; foley type; two-way; all silicone','Cath w/drainage 2-way silcne','A4315','3','','1','0','','','','0','1','0','0'),
('10596','Insertion tray with drainage bag with indwelling catheter; foley type; three-way; for continuous irrigation','Cath w/drainage 3-way','A4316','3','','1','0','','','','0','1','0','0'),
('10597','Irrigation tray with bulb or piston syringe; any purpose','Irrigation tray','A4320','3','','1','0','','','','0','1','0','0'),
('10598','Therapeutic agent for urinary catheter irrigation','Cath therapeutic irrig agent','A4321','3','','1','0','','','','0','1','0','0'),
('10599','Irrigation syringe; bulb or piston; each','Irrigation syringe','A4322','3','','1','0','','','','0','1','0','0'),
('10600','Male external catheter with integral collection chamber; any type; each','Male external catheter','A4326','3','','1','0','','','','0','1','0','0'),
('10601','Female external urinary collection device; meatal cup; each','Fem urinary collect dev cup','A4327','3','','1','0','','','','0','1','0','0'),
('10602','Female external urinary collection device; pouch; each','Fem urinary collect pouch','A4328','3','','1','0','','','','0','1','0','0'),
('10603','Perianal fecal collection pouch with adhesive; each','Stool collection pouch','A4330','3','','1','0','','','','0','1','0','0'),
('10604','Extension drainage tubing; any type; any length; with connector/adaptor; for use with urinary leg bag or urostomy pouch; each','Extension drainage tubing','A4331','3','','1','0','','','','0','1','0','0'),
('10605','Lubricant; individual sterile packet; each','Lube sterile packet','A4332','3','','1','0','','','','0','1','0','0'),
('10606','Urinary catheter anchoring device; adhesive skin attachment; each','Urinary cath anchor device','A4333','3','','1','0','','','','0','1','0','0'),
('10607','Urinary catheter anchoring device; leg strap; each','Urinary cath leg strap','A4334','3','','1','0','','','','0','1','0','0'),
('10608','Incontinence supply; miscellaneous','Incontinence supply','A4335','3','','1','0','','','','0','1','0','0'),
('10609','Incontinence supply; urethral insert; any type; each','Urethral insert','A4336','3','','1','0','','','','0','1','0','0'),
('10610','Incontinence supply; rectal insert; any type; each','Incontinent rectal insert','A4337','3','','1','0','','','','0','1','0','0'),
('10611','Indwelling catheter; foley type; two-way latex with coating (teflon; silicone; silicone elastomer; or hydrophilic; etc.); each','Indwelling catheter latex','A4338','3','','1','0','','','','0','1','0','0'),
('10612','Indwelling catheter; specialty type; (e.g.; coude; mushroom; wing; etc.); each','Indwelling catheter special','A4340','3','','1','0','','','','0','1','0','0'),
('10613','Indwelling catheter; foley type; two-way; all silicone; each','Cath indw foley 2 way silicn','A4344','3','','1','0','','','','0','1','0','0'),
('10614','Indwelling catheter; foley type; three way for continuous irrigation; each','Cath indw foley 3 way','A4346','3','','1','0','','','','0','1','0','0'),
('10615','Male external catheter; with or without adhesive; disposable; each','Disposable male external cat','A4349','3','','1','0','','','','0','1','0','0'),
('10616','Intermittent urinary catheter; straight tip; with or without coating (teflon; silicone; silicone elastomer; or hydrophilic; etc.); each','Straight tip urine catheter','A4351','3','','1','0','','','','0','1','0','0'),
('10617','Intermittent urinary catheter; coude (curved) tip; with or without coating (teflon; silicone; silicone elastomeric; or hydrophilic; etc.); each','Coude tip urinary catheter','A4352','3','','1','0','','','','0','1','0','0'),
('10618','Intermittent urinary catheter; with insertion supplies','Intermittent urinary cath','A4353','3','','1','0','','','','0','1','0','0'),
('10619','Insertion tray with drainage bag but without catheter','Cath insertion tray w/bag','A4354','3','','1','0','','','','0','1','0','0'),
('10620','Irrigation tubing set for continuous bladder irrigation through a three-way indwelling foley catheter; each','Bladder irrigation tubing','A4355','3','','1','0','','','','0','1','0','0'),
('10621','External urethral clamp or compression device (not to be used for catheter clamp); each','Ext ureth clmp or compr dvc','A4356','3','','1','0','','','','0','1','0','0'),
('10622','Bedside drainage bag; day or night; with or without anti-reflux device; with or without tube; each','Bedside drainage bag','A4357','3','','1','0','','','','0','1','0','0'),
('10623','Urinary drainage bag; leg or abdomen; vinyl; with or without tube; with straps; each','Urinary leg or abdomen bag','A4358','3','','1','0','','','','0','1','0','0'),
('10624','Disposable external urethral clamp or compression device; with pad and/or pouch; each','Disposable ext urethral dev','A4360','3','','1','0','','','','0','1','0','0'),
('10625','Ostomy faceplate; each','Ostomy face plate','A4361','3','','1','0','','','','0','1','0','0'),
('10626','Skin barrier; solid; 4 x 4 or equivalent; each','Solid skin barrier','A4362','3','','1','0','','','','0','1','0','0'),
('10627','Ostomy clamp; any type; replacement only; each','Ostomy clamp; replacement','A4363','3','','1','0','','','','0','1','0','0'),
('10628','Adhesive; liquid or equal; any type; per oz','Adhesive; liquid or equal','A4364','3','','1','0','','','','0','1','0','0'),
('10629','Ostomy vent; any type; each','Ostomy vent','A4366','3','','1','0','','','','0','1','0','0'),
('10630','Ostomy belt; each','Ostomy belt','A4367','3','','1','0','','','','0','1','0','0'),
('10631','Ostomy filter; any type; each','Ostomy filter','A4368','3','','1','0','','','','0','1','0','0'),
('10632','Ostomy skin barrier; liquid (spray; brush; etc.); per oz','Skin barrier liquid per oz','A4369','3','','1','0','','','','0','1','0','0'),
('10633','Ostomy skin barrier; powder; per oz','Skin barrier powder per oz','A4371','3','','1','0','','','','0','1','0','0'),
('10634','Ostomy skin barrier; solid 4 x 4 or equivalent; standard wear; with built-in convexity; each','Skin barrier solid 4x4 equiv','A4372','3','','1','0','','','','0','1','0','0'),
('10635','Ostomy skin barrier; with flange (solid; flexible or accordion); with built-in convexity; any size; each','Skin barrier with flange','A4373','3','','1','0','','','','0','1','0','0'),
('10636','Ostomy pouch; drainable; with faceplate attached; plastic; each','Drainable plastic pch w fcpl','A4375','3','','1','0','','','','0','1','0','0'),
('10637','Ostomy pouch; drainable; with faceplate attached; rubber; each','Drainable rubber pch w fcplt','A4376','3','','1','0','','','','0','1','0','0'),
('10638','Ostomy pouch; drainable; for use on faceplate; plastic; each','Drainable plstic pch w/o fp','A4377','3','','1','0','','','','0','1','0','0'),
('10639','Ostomy pouch; drainable; for use on faceplate; rubber; each','Drainable rubber pch w/o fp','A4378','3','','1','0','','','','0','1','0','0'),
('10640','Ostomy pouch; urinary; with faceplate attached; plastic; each','Urinary plastic pouch w fcpl','A4379','3','','1','0','','','','0','1','0','0'),
('10641','Ostomy pouch; urinary; with faceplate attached; rubber; each','Urinary rubber pouch w fcplt','A4380','3','','1','0','','','','0','1','0','0'),
('10642','Ostomy pouch; urinary; for use on faceplate; plastic; each','Urinary plastic pouch w/o fp','A4381','3','','1','0','','','','0','1','0','0'),
('10643','Ostomy pouch; urinary; for use on faceplate; heavy plastic; each','Urinary hvy plstc pch w/o fp','A4382','3','','1','0','','','','0','1','0','0'),
('10644','Ostomy pouch; urinary; for use on faceplate; rubber; each','Urinary rubber pouch w/o fp','A4383','3','','1','0','','','','0','1','0','0'),
('10645','Ostomy faceplate equivalent; silicone ring; each','Ostomy faceplt/silicone ring','A4384','3','','1','0','','','','0','1','0','0'),
('10646','Ostomy skin barrier; solid 4 x 4 or equivalent; extended wear; without built-in convexity; each','Ost skn barrier sld ext wear','A4385','3','','1','0','','','','0','1','0','0'),
('10647','Ostomy pouch; closed; with barrier attached; with built-in convexity (1 piece); each','Ost clsd pouch w att st barr','A4387','3','','1','0','','','','0','1','0','0'),
('10648','Ostomy pouch; drainable; with extended wear barrier attached; (1 piece); each','Drainable pch w ex wear barr','A4388','3','','1','0','','','','0','1','0','0'),
('10649','Ostomy pouch; drainable; with barrier attached; with built-in convexity (1 piece); each','Drainable pch w st wear barr','A4389','3','','1','0','','','','0','1','0','0'),
('10650','Ostomy pouch; drainable; with extended wear barrier attached; with built-in convexity (1 piece); each','Drainable pch ex wear convex','A4390','3','','1','0','','','','0','1','0','0'),
('10651','Ostomy pouch; urinary; with extended wear barrier attached (1 piece); each','Urinary pouch w ex wear barr','A4391','3','','1','0','','','','0','1','0','0'),
('10652','Ostomy pouch; urinary; with standard wear barrier attached; with built-in convexity (1 piece); each','Urinary pouch w st wear barr','A4392','3','','1','0','','','','0','1','0','0'),
('10653','Ostomy pouch; urinary; with extended wear barrier attached; with built-in convexity (1 piece); each','Urine pch w ex wear bar conv','A4393','3','','1','0','','','','0','1','0','0'),
('10654','Ostomy deodorant; with or without lubricant; for use in ostomy pouch; per fluid ounce','Ostomy pouch liq deodorant','A4394','3','','1','0','','','','0','1','0','0'),
('10655','Ostomy deodorant for use in ostomy pouch; solid; per tablet','Ostomy pouch solid deodorant','A4395','3','','1','0','','','','0','1','0','0'),
('10656','Ostomy belt with peristomal hernia support','Peristomal hernia supprt blt','A4396','3','','1','0','','','','0','1','0','0'),
('10657','Irrigation supply; sleeve; each','Irrigation supply sleeve','A4397','3','','1','0','','','','0','1','0','0'),
('10658','Ostomy irrigation supply; bag; each','Ostomy irrigation bag','A4398','3','','1','0','','','','0','1','0','0'),
('10659','Ostomy irrigation supply; cone/catheter; with or without brush','Ostomy irrig cone/cath w brs','A4399','3','','1','0','','','','0','1','0','0'),
('10660','Ostomy irrigation set','Ostomy irrigation set','A4400','3','','1','0','','','','0','1','0','0'),
('10661','Lubricant; per ounce','Lubricant per ounce','A4402','3','','1','0','','','','0','1','0','0'),
('10662','Ostomy ring; each','Ostomy ring each','A4404','3','','1','0','','','','0','1','0','0'),
('10663','Ostomy skin barrier; non-pectin based; paste; per ounce','Nonpectin based ostomy paste','A4405','3','','1','0','','','','0','1','0','0'),
('10664','Ostomy skin barrier; pectin-based; paste; per ounce','Pectin based ostomy paste','A4406','3','','1','0','','','','0','1','0','0'),
('10665','Ostomy skin barrier; with flange (solid; flexible; or accordion); extended wear; with built-in convexity; 4 x 4 inches or smaller; each','Ext wear ost skn barr <=4sq''','A4407','3','','1','0','','','','0','1','0','0'),
('10666','Ostomy skin barrier; with flange (solid; flexible or accordion); extended wear; with built-in convexity; larger than 4 x 4 inches; each','Ext wear ost skn barr >4sq''','A4408','3','','1','0','','','','0','1','0','0'),
('10667','Ostomy skin barrier; with flange (solid; flexible or accordion); extended wear; without built-in convexity; 4 x 4 inches or smaller; each','Ost skn barr convex <=4 sq i','A4409','3','','1','0','','','','0','1','0','0'),
('10668','Ostomy skin barrier; with flange (solid; flexible or accordion); extended wear; without built-in convexity; larger than 4 x 4 inches; each','Ost skn barr extnd >4 sq','A4410','3','','1','0','','','','0','1','0','0'),
('10669','Ostomy skin barrier; solid 4 x 4 or equivalent; extended wear; with built-in convexity; each','Ost skn barr extnd =4sq','A4411','3','','1','0','','','','0','1','0','0'),
('10670','Ostomy pouch; drainable; high output; for use on a barrier with flange (2 piece system); without filter; each','Ost pouch drain high output','A4412','3','','1','0','','','','0','1','0','0'),
('10671','Ostomy pouch; drainable; high output; for use on a barrier with flange (2 piece system); with filter; each','2 pc drainable ost pouch','A4413','3','','1','0','','','','0','1','0','0'),
('10672','Ostomy skin barrier; with flange (solid; flexible or accordion); without built-in convexity; 4 x 4 inches or smaller; each','Ost sknbar w/o conv<=4 sq in','A4414','3','','1','0','','','','0','1','0','0'),
('10673','Ostomy skin barrier; with flange (solid; flexible or accordion); without built-in convexity; larger than 4 x 4 inches; each','Ost skn barr w/o conv >4 sqi','A4415','3','','1','0','','','','0','1','0','0'),
('10674','Ostomy pouch; closed; with barrier attached; with filter (1 piece); each','Ost pch clsd w barrier/filtr','A4416','3','','1','0','','','','0','1','0','0'),
('10675','Ostomy pouch; closed; with barrier attached; with built-in convexity; with filter (1 piece); each','Ost pch w bar/bltinconv/fltr','A4417','3','','1','0','','','','0','1','0','0'),
('10676','Ostomy pouch; closed; without barrier attached; with filter (1 piece); each','Ost pch clsd w/o bar w filtr','A4418','3','','1','0','','','','0','1','0','0'),
('10677','Ostomy pouch; closed; for use on barrier with non-locking flange; with filter (2 piece); each','Ost pch for bar w flange/flt','A4419','3','','1','0','','','','0','1','0','0'),
('10678','Ostomy pouch; closed; for use on barrier with locking flange (2 piece); each','Ost pch clsd for bar w lk fl','A4420','3','','1','0','','','','0','1','0','0'),
('10679','Ostomy supply; miscellaneous','Ostomy supply misc','A4421','3','','1','0','','','','0','1','0','0'),
('10680','Ostomy absorbent material (sheet/pad/crystal packet) for use in ostomy pouch to thicken liquid stomal output; each','Ost pouch absorbent material','A4422','3','','1','0','','','','0','1','0','0'),
('10681','Ostomy pouch; closed; for use on barrier with locking flange; with filter (2 piece); each','Ost pch for bar w lk fl/fltr','A4423','3','','1','0','','','','0','1','0','0'),
('10682','Ostomy pouch; drainable; with barrier attached; with filter (1 piece); each','Ost pch drain w bar & filter','A4424','3','','1','0','','','','0','1','0','0'),
('10683','Ostomy pouch; drainable; for use on barrier with non-locking flange; with filter (2 piece system); each','Ost pch drain for barrier fl','A4425','3','','1','0','','','','0','1','0','0'),
('10684','Ostomy pouch; drainable; for use on barrier with locking flange (2 piece system); each','Ost pch drain 2 piece system','A4426','3','','1','0','','','','0','1','0','0'),
('10685','Ostomy pouch; drainable; for use on barrier with locking flange; with filter (2 piece system); each','Ost pch drain/barr lk flng/f','A4427','3','','1','0','','','','0','1','0','0'),
('10686','Ostomy pouch; urinary; with extended wear barrier attached; with faucet-type tap with valve (1 piece); each','Urine ost pouch w faucet/tap','A4428','3','','1','0','','','','0','1','0','0'),
('10687','Ostomy pouch; urinary; with barrier attached; with built-in convexity; with faucet-type tap with valve (1 piece); each','Urine ost pouch w bltinconv','A4429','3','','1','0','','','','0','1','0','0'),
('10688','Ostomy pouch; urinary; with extended wear barrier attached; with built-in convexity; with faucet-type tap with valve (1 piece); each','Ost urine pch w b/bltin conv','A4430','3','','1','0','','','','0','1','0','0'),
('10689','Ostomy pouch; urinary; with barrier attached; with faucet-type tap with valve (1 piece); each','Ost pch urine w barrier/tapv','A4431','3','','1','0','','','','0','1','0','0'),
('10690','Ostomy pouch; urinary; for use on barrier with non-locking flange; with faucet-type tap with valve (2 piece); each','Os pch urine w bar/fange/tap','A4432','3','','1','0','','','','0','1','0','0'),
('10691','Ostomy pouch; urinary; for use on barrier with locking flange (2 piece); each','Urine ost pch bar w lock fln','A4433','3','','1','0','','','','0','1','0','0'),
('10692','Ostomy pouch; urinary; for use on barrier with locking flange; with faucet-type tap with valve (2 piece); each','Ost pch urine w lock flng/ft','A4434','3','','1','0','','','','0','1','0','0'),
('10693','Ostomy pouch; drainable; high output; with extended wear barrier (one-piece system); with or without filter; each','1pc ost pch drain hgh output','A4435','3','','1','0','','','','0','1','0','0'),
('10694','Tape; non-waterproof; per 18 square inches','Non-waterproof tape','A4450','3','','1','0','','','','0','1','0','0'),
('10695','Tape; waterproof; per 18 square inches','Waterproof tape','A4452','3','','1','0','','','','0','1','0','0'),
('10696','Adhesive remover or solvent (for tape; cement or other adhesive); per ounce','Adhesive remover per ounce','A4455','3','','1','0','','','','0','1','0','0'),
('10697','Adhesive remover; wipes; any type; each','Adhesive remover; wipes','A4456','3','','1','0','','','','0','1','0','0'),
('10698','Enema bag with tubing; reusable','Reusable enema bag','A4458','3','','1','0','','','','0','1','0','0'),
('10699','Manual pump-operated enema system; includes balloon; catheter and all accessories; reusable; any type','Manual pump enema; reusable','A4459','3','','1','0','','','','0','1','0','0'),
('10700','Surgical dressing holder; non-reusable; each','Surgicl dress hold non-reuse','A4461','3','','1','0','','','','0','1','0','0'),
('10701','Surgical dressing holder; reusable; each','Surgical dress holder reuse','A4463','3','','1','0','','','','0','1','0','0'),
('10702','Non-elastic binder for extremity','Non-elastic extremity binder','A4465','3','','1','0','','','','0','1','0','0'),
('10703','Garment; belt; sleeve or other covering; elastic or similar stretchable material; any type; each','Elastic garment/covering','A4466','3','','1','0','','','','0','1','0','0'),
('10704','Belt; strap; sleeve; garment; or covering; any type','Belt strap sleev grmnt cover','A4467','3','','1','0','','','','0','1','0','0'),
('10705','Gravlee jet washer','Gravlee jet washer','A4470','3','','1','0','','','','0','1','0','0'),
('10706','Vabra aspirator','Vabra aspirator','A4480','3','','1','0','','','','0','1','0','0'),
('10707','Tracheostoma filter; any type; any size; each','Tracheostoma filter','A4481','3','','1','0','','','','0','1','0','0'),
('10708','Moisture exchanger; disposable; for use with invasive mechanical ventilation','Moisture exchanger','A4483','3','','1','0','','','','0','1','0','0'),
('10709','Surgical stockings above knee length; each','Above knee surgical stocking','A4490','3','','1','0','','','','0','1','0','0'),
('10710','Surgical stockings thigh length; each','Thigh length surg stocking','A4495','3','','1','0','','','','0','1','0','0'),
('10711','Surgical stockings below knee length; each','Below knee surgical stocking','A4500','3','','1','0','','','','0','1','0','0'),
('10712','Surgical stockings full length; each','Full length surg stocking','A4510','3','','1','0','','','','0','1','0','0'),
('10713','Incontinence garment; any type; (e.g.; brief; diaper); each','Incontinence garment anytype','A4520','3','','1','0','','','','0','1','0','0'),
('10714','Surgical trays','Surgical trays','A4550','3','','1','0','','','','0','1','0','0'),
('10715','Non-disposable underpads; all sizes','Nondisp underpads; all sizes','A4553','3','','1','0','','','','0','1','0','0'),
('10716','Disposable underpads; all sizes','Disposable underpads','A4554','3','','1','0','','','','0','1','0','0'),
('10717','Electrode/transducer for use with electrical stimulation device used for cancer treatment; replacement only','Ca tx e-stim electr/transduc','A4555','3','','1','0','','','','0','1','0','0'),
('10718','Electrodes; (e.g.; apnea monitor); per pair','Electrodes; pair','A4556','3','','1','0','','','','0','1','0','0'),
('10719','Lead wires; (e.g.; apnea monitor); per pair','Lead wires; pair','A4557','3','','1','0','','','','0','1','0','0'),
('10720','Conductive gel or paste; for use with electrical device (e.g.; tens; nmes); per oz','Conductive gel or paste','A4558','3','','1','0','','','','0','1','0','0'),
('10721','Coupling gel or paste; for use with ultrasound device; per oz','Coupling gel or paste','A4559','3','','1','0','','','','0','1','0','0'),
('10722','Pessary; rubber; any type','Pessary rubber; any type','A4561','3','','1','0','','','','0','1','0','0'),
('10723','Pessary; non rubber; any type','Pessary; non rubber;any type','A4562','3','','1','0','','','','0','1','0','0'),
('10724','Slings','Slings','A4565','3','','1','0','','','','0','1','0','0'),
('10725','Shoulder sling or vest design; abduction restrainer; with or without swathe control; prefabricated; includes fitting and adjustment','Should sling/vest/abrestrain','A4566','3','','1','0','','','','0','1','0','0'),
('10726','Splint','Splint','A4570','3','','1','0','','','','0','1','0','0'),
('10727','Topical hyperbaric oxygen chamber; disposable','Hyperbaric o2 chamber disps','A4575','3','','1','0','','','','0','1','0','0'),
('10728','Cast supplies (e.g.; plaster)','Cast supplies (plaster)','A4580','3','','1','0','','','','0','1','0','0'),
('10729','Special casting material (e.g.; fiberglass)','Special casting material','A4590','3','','1','0','','','','0','1','0','0'),
('10730','Electrical stimulator supplies; 2 lead; per month; (e.g.; tens; nmes)','Tens suppl 2 lead per month','A4595','3','','1','0','','','','0','1','0','0'),
('10731','Sleeve for intermittent limb compression device; replacement only; each','Sleeve; inter limb comp dev','A4600','3','','1','0','','','','0','1','0','0'),
('10732','Lithium ion battery; rechargeable; for non-prosthetic use; replacement','Lith ion non prosth recharge','A4601','3','','1','0','','','','0','1','0','0'),
('10733','Replacement battery for external infusion pump owned by patient; lithium; 1.5 volt; each','Replace lithium battery 1.5v','A4602','3','','1','0','','','','0','1','0','0'),
('10734','Tubing with integrated heating element for use with positive airway pressure device','Tubing with heating element','A4604','3','','1','0','','','','0','1','0','0'),
('10735','Tracheal suction catheter; closed system; each','Trach suction cath close sys','A4605','3','','1','0','','','','0','1','0','0'),
('10736','Oxygen probe for use with oximeter device; replacement','Oxygen probe used w oximeter','A4606','3','','1','0','','','','0','1','0','0'),
('10737','Transtracheal oxygen catheter; each','Transtracheal oxygen cath','A4608','3','','1','0','','','','0','1','0','0'),
('10738','Battery; heavy duty; replacement for patient owned ventilator','Heavy duty battery','A4611','3','','1','0','','','','0','1','0','0'),
('10739','Battery cables; replacement for patient-owned ventilator','Battery cables','A4612','3','','1','0','','','','0','1','0','0'),
('10740','Battery charger; replacement for patient-owned ventilator','Battery charger','A4613','3','','1','0','','','','0','1','0','0'),
('10741','Peak expiratory flow rate meter; hand held','Hand-held pefr meter','A4614','3','','1','0','','','','0','1','0','0'),
('10742','Cannula; nasal','Cannula nasal','A4615','3','','1','0','','','','0','1','0','0'),
('10743','Tubing (oxygen); per foot','Tubing (oxygen) per foot','A4616','3','','1','0','','','','0','1','0','0'),
('10744','Mouth piece','Mouth piece','A4617','3','','1','0','','','','0','1','0','0'),
('10745','Breathing circuits','Breathing circuits','A4618','3','','1','0','','','','0','1','0','0'),
('10746','Face tent','Face tent','A4619','3','','1','0','','','','0','1','0','0'),
('10747','Variable concentration mask','Variable concentration mask','A4620','3','','1','0','','','','0','1','0','0'),
('10748','Tracheostomy; inner cannula','Tracheostomy inner cannula','A4623','3','','1','0','','','','0','1','0','0'),
('10749','Tracheal suction catheter; any type other than closed system; each','Tracheal suction tube','A4624','3','','1','0','','','','0','1','0','0'),
('10750','Tracheostomy care kit for new tracheostomy','Trach care kit for new trach','A4625','3','','1','0','','','','0','1','0','0'),
('10751','Tracheostomy cleaning brush; each','Tracheostomy cleaning brush','A4626','3','','1','0','','','','0','1','0','0'),
('10752','Spacer; bag or reservoir; with or without mask; for use with metered dose inhaler','Spacer bag/reservoir','A4627','3','','1','0','','','','0','1','0','0'),
('10753','Oropharyngeal suction catheter; each','Oropharyngeal suction cath','A4628','3','','1','0','','','','0','1','0','0'),
('10754','Tracheostomy care kit for established tracheostomy','Tracheostomy care kit','A4629','3','','1','0','','','','0','1','0','0'),
('10755','Replacement batteries; medically necessary; transcutaneous electrical stimulator; owned by patient','Repl bat t.e.n.s. own by pt','A4630','3','','1','0','','','','0','1','0','0'),
('10756','Replacement bulb/lamp for ultraviolet light therapy system; each','Uvl replacement bulb','A4633','3','','1','0','','','','0','1','0','0'),
('10757','Replacement bulb for therapeutic light box; tabletop model','Replacement bulb th lightbox','A4634','3','','1','0','','','','0','1','0','0'),
('10758','Underarm pad; crutch; replacement; each','Underarm crutch pad','A4635','3','','1','0','','','','0','1','0','0'),
('10759','Replacement; handgrip; cane; crutch; or walker; each','Handgrip for cane etc','A4636','3','','1','0','','','','0','1','0','0'),
('10760','Replacement; tip; cane; crutch; walker; each.','Repl tip cane/crutch/walker','A4637','3','','1','0','','','','0','1','0','0'),
('10761','Replacement battery for patient-owned ear pulse generator; each','Repl batt pulse gen sys','A4638','3','','1','0','','','','0','1','0','0'),
('10762','Replacement pad for infrared heating pad system; each','Infrared ht sys replcmnt pad','A4639','3','','1','0','','','','0','1','0','0'),
('10763','Replacement pad for use with medically necessary alternating pressure pad owned by patient','Alternating pressure pad','A4640','3','','1','0','','','','0','1','0','0'),
('10764','Radiopharmaceutical; diagnostic; not otherwise classified','Radiopharm dx agent noc','A4641','3','','1','0','','','','0','1','0','0'),
('10765','Indium in-111 satumomab pendetide; diagnostic; per study dose; up to 6 millicuries','In111 satumomab','A4642','3','','1','0','','','','0','1','0','0'),
('10766','Tissue marker; implantable; any type; each','Implantable tissue marker','A4648','3','','1','0','','','','0','1','0','0'),
('10767','Surgical supply; miscellaneous','Surgical supplies','A4649','3','','1','0','','','','0','1','0','0'),
('10768','Implantable radiation dosimeter; each','Implant radiation dosimeter','A4650','3','','1','0','','','','0','1','0','0'),
('10769','Calibrated microcapillary tube; each','Calibrated microcap tube','A4651','3','','1','0','','','','0','1','0','0'),
('10770','Microcapillary tube sealant','Microcapillary tube sealant','A4652','3','','1','0','','','','0','1','0','0'),
('10771','Peritoneal dialysis catheter anchoring device; belt; each','Pd catheter anchor belt','A4653','3','','1','0','','','','0','1','0','0'),
('10772','Syringe; with or without needle; each','Syringe w/wo needle','A4657','3','','1','0','','','','0','1','0','0'),
('10773','Sphygmomanometer/blood pressure apparatus with cuff and stethoscope','Sphyg/bp app w cuff and stet','A4660','3','','1','0','','','','0','1','0','0'),
('10774','Blood pressure cuff only','Dialysis blood pressure cuff','A4663','3','','1','0','','','','0','1','0','0'),
('10775','Automatic blood pressure monitor','Automatic bp monitor; dial','A4670','3','','1','0','','','','0','1','0','0'),
('10776','Disposable cycler set used with cycler dialysis machine; each','Disposable cycler set','A4671','3','','1','0','','','','0','1','0','0'),
('10777','Drainage extension line; sterile; for dialysis; each','Drainage ext line; dialysis','A4672','3','','1','0','','','','0','1','0','0'),
('10778','Extension line with easy lock connectors; used with dialysis','Ext line w easy lock connect','A4673','3','','1','0','','','','0','1','0','0'),
('10779','Chemicals/antiseptics solution used to clean/sterilize dialysis equipment; per 8 oz','Chem/antisept solution; 8oz','A4674','3','','1','0','','','','0','1','0','0'),
('10780','Activated carbon filter for hemodialysis; each','Activated carbon filter; ea','A4680','3','','1','0','','','','0','1','0','0'),
('10781','Dialyzer (artificial kidneys); all types; all sizes; for hemodialysis; each','Dialyzer; each','A4690','3','','1','0','','','','0','1','0','0'),
('10782','Bicarbonate concentrate; solution; for hemodialysis; per gallon','Bicarbonate conc sol per gal','A4706','3','','1','0','','','','0','1','0','0'),
('10783','Bicarbonate concentrate; powder; for hemodialysis; per packet','Bicarbonate conc pow per pac','A4707','3','','1','0','','','','0','1','0','0'),
('10784','Acetate concentrate solution; for hemodialysis; per gallon','Acetate conc sol per gallon','A4708','3','','1','0','','','','0','1','0','0'),
('10785','Acid concentrate; solution; for hemodialysis; per gallon','Acid conc sol per gallon','A4709','3','','1','0','','','','0','1','0','0'),
('10786','Treated water (deionized; distilled; or reverse osmosis) for peritoneal dialysis; per gallon','Treated water per gallon','A4714','3','','1','0','','','','0','1','0','0'),
('10787','''y set'' tubing for peritoneal dialysis','''y set'' tubing','A4719','3','','1','0','','','','0','1','0','0'),
('10788','Dialysate solution; any concentration of dextrose; fluid volume greater than 249 cc; but less than or equal to 999 cc; for peritoneal dialysis','Dialysat sol fld vol > 249cc','A4720','3','','1','0','','','','0','1','0','0'),
('10789','Dialysate solution; any concentration of dextrose; fluid volume greater than 999 cc but less than or equal to 1999 cc; for peritoneal dialysis','Dialysat sol fld vol > 999cc','A4721','3','','1','0','','','','0','1','0','0'),
('10790','Dialysate solution; any concentration of dextrose; fluid volume greater than 1999 cc but less than or equal to 2999 cc; for peritoneal dialysis','Dialys sol fld vol > 1999cc','A4722','3','','1','0','','','','0','1','0','0'),
('10791','Dialysate solution; any concentration of dextrose; fluid volume greater than 2999 cc but less than or equal to 3999 cc; for peritoneal dialysis','Dialys sol fld vol > 2999cc','A4723','3','','1','0','','','','0','1','0','0'),
('10792','Dialysate solution; any concentration of dextrose; fluid volume greater than 3999 cc but less than or equal to 4999 cc; for peritoneal dialysis','Dialys sol fld vol > 3999cc','A4724','3','','1','0','','','','0','1','0','0'),
('10793','Dialysate solution; any concentration of dextrose; fluid volume greater than 4999 cc but less than or equal to 5999 cc; for peritoneal dialysis','Dialys sol fld vol > 4999cc','A4725','3','','1','0','','','','0','1','0','0'),
('10794','Dialysate solution; any concentration of dextrose; fluid volume greater than 5999 cc; for peritoneal dialysis','Dialys sol fld vol > 5999cc','A4726','3','','1','0','','','','0','1','0','0'),
('10795','Dialysate solution; non-dextrose containing; 500 ml','Dialysate solution; non-dex','A4728','3','','1','0','','','','0','1','0','0'),
('10796','Fistula cannulation set for hemodialysis; each','Fistula cannulation set; ea','A4730','3','','1','0','','','','0','1','0','0'),
('10797','Topical anesthetic; for dialysis; per gram','Topical anesthetic; per gram','A4736','3','','1','0','','','','0','1','0','0'),
('10798','Injectable anesthetic; for dialysis; per 10 ml','Inj anesthetic per 10 ml','A4737','3','','1','0','','','','0','1','0','0'),
('10799','Shunt accessory; for hemodialysis; any type; each','Shunt accessory','A4740','3','','1','0','','','','0','1','0','0'),
('10800','Blood tubing; arterial or venous; for hemodialysis; each','Art or venous blood tubing','A4750','3','','1','0','','','','0','1','0','0'),
('10801','Blood tubing; arterial and venous combined; for hemodialysis; each','Comb art/venous blood tubing','A4755','3','','1','0','','','','0','1','0','0'),
('10802','Dialysate solution test kit; for peritoneal dialysis; any type; each','Dialysate sol test kit; each','A4760','3','','1','0','','','','0','1','0','0'),
('10803','Dialysate concentrate; powder; additive for peritoneal dialysis; per packet','Dialysate conc pow per pack','A4765','3','','1','0','','','','0','1','0','0'),
('10804','Dialysate concentrate; solution; additive for peritoneal dialysis; per 10 ml','Dialysate conc sol add 10 ml','A4766','3','','1','0','','','','0','1','0','0'),
('10805','Blood collection tube; vacuum; for dialysis; per 50','Blood collection tube/vacuum','A4770','3','','1','0','','','','0','1','0','0'),
('10806','Serum clotting time tube; for dialysis; per 50','Serum clotting time tube','A4771','3','','1','0','','','','0','1','0','0'),
('10807','Blood glucose test strips; for dialysis; per 50','Blood glucose test strips','A4772','3','','1','0','','','','0','1','0','0'),
('10808','Occult blood test strips; for dialysis; per 50','Occult blood test strips','A4773','3','','1','0','','','','0','1','0','0'),
('10809','Ammonia test strips; for dialysis; per 50','Ammonia test strips','A4774','3','','1','0','','','','0','1','0','0'),
('10810','Protamine sulfate; for hemodialysis; per 50 mg','Protamine sulfate per 50 mg','A4802','3','','1','0','','','','0','1','0','0'),
('10811','Disposable catheter tips for peritoneal dialysis; per 10','Disposable catheter tips','A4860','3','','1','0','','','','0','1','0','0'),
('10812','Plumbing and/or electrical work for home hemodialysis equipment','Plumb/elec wk hm hemo equip','A4870','3','','1','0','','','','0','1','0','0'),
('10813','Contracts; repair and maintenance; for hemodialysis equipment','Repair/maint cont hemo equip','A4890','3','','1','0','','','','0','1','0','0'),
('10814','Drain bag/bottle; for dialysis; each','Drain bag/bottle','A4911','3','','1','0','','','','0','1','0','0'),
('10815','Miscellaneous dialysis supplies; not otherwise specified','Misc dialysis supplies noc','A4913','3','','1','0','','','','0','1','0','0'),
('10816','Venous pressure clamp; for hemodialysis; each','Venous pressure clamp','A4918','3','','1','0','','','','0','1','0','0'),
('10817','Gloves; non-sterile; per 100','Non-sterile gloves','A4927','3','','1','0','','','','0','1','0','0'),
('10818','Surgical mask; per 20','Surgical mask','A4928','3','','1','0','','','','0','1','0','0'),
('10819','Tourniquet for dialysis; each','Tourniquet for dialysis; ea','A4929','3','','1','0','','','','0','1','0','0'),
('10820','Gloves; sterile; per pair','Sterile; gloves per pair','A4930','3','','1','0','','','','0','1','0','0'),
('10821','Oral thermometer; reusable; any type; each','Reusable oral thermometer','A4931','3','','1','0','','','','0','1','0','0'),
('10822','Rectal thermometer; reusable; any type; each','Reusable rectal thermometer','A4932','3','','1','0','','','','0','1','0','0'),
('10823','Ostomy pouch; closed; with barrier attached (1 piece); each','Pouch clsd w barr attached','A5051','3','','1','0','','','','0','1','0','0'),
('10824','Ostomy pouch; closed; without barrier attached (1 piece); each','Clsd ostomy pouch w/o barr','A5052','3','','1','0','','','','0','1','0','0'),
('10825','Ostomy pouch; closed; for use on faceplate; each','Clsd ostomy pouch faceplate','A5053','3','','1','0','','','','0','1','0','0'),
('10826','Ostomy pouch; closed; for use on barrier with flange (2 piece); each','Clsd ostomy pouch w/flange','A5054','3','','1','0','','','','0','1','0','0'),
('10827','Stoma cap','Stoma cap','A5055','3','','1','0','','','','0','1','0','0'),
('10828','Ostomy pouch; drainable; with extended wear barrier attached; with filter; (1 piece); each','1 pc ost pouch w filter','A5056','3','','1','0','','','','0','1','0','0'),
('10829','Ostomy pouch; drainable; with extended wear barrier attached; with built in convexity; with filter; (1 piece); each','1 pc ost pou w built-in conv','A5057','3','','1','0','','','','0','1','0','0'),
('10830','Ostomy pouch; drainable; with barrier attached; (1 piece); each','Pouch drainable w barrier at','A5061','3','','1','0','','','','0','1','0','0'),
('10831','Ostomy pouch; drainable; without barrier attached (1 piece); each','Drnble ostomy pouch w/o barr','A5062','3','','1','0','','','','0','1','0','0'),
('10832','Ostomy pouch; drainable; for use on barrier with flange (2 piece system); each','Drain ostomy pouch w/flange','A5063','3','','1','0','','','','0','1','0','0'),
('10833','Ostomy pouch; urinary; with barrier attached (1 piece); each','Urinary pouch w/barrier','A5071','3','','1','0','','','','0','1','0','0'),
('10834','Ostomy pouch; urinary; without barrier attached (1 piece); each','Urinary pouch w/o barrier','A5072','3','','1','0','','','','0','1','0','0'),
('10835','Ostomy pouch; urinary; for use on barrier with flange (2 piece); each','Urinary pouch on barr w/flng','A5073','3','','1','0','','','','0','1','0','0'),
('10836','Stoma plug or seal; any type','Stoma plug or seal; any type','A5081','3','','1','0','','','','0','1','0','0'),
('10837','Continent device; catheter for continent stoma','Continent stoma catheter','A5082','3','','1','0','','','','0','1','0','0'),
('10838','Continent device; stoma absorptive cover for continent stoma','Stoma absorptive cover','A5083','3','','1','0','','','','0','1','0','0'),
('10839','Ostomy accessory; convex insert','Ostomy accessory convex inse','A5093','3','','1','0','','','','0','1','0','0'),
('10840','Bedside drainage bottle with or without tubing; rigid or expandable; each','Bedside drain btl w/wo tube','A5102','3','','1','0','','','','0','1','0','0'),
('10841','Urinary suspensory with leg bag; with or without tube; each','Urinary suspensory','A5105','3','','1','0','','','','0','1','0','0'),
('10842','Urinary drainage bag; leg or abdomen; latex; with or without tube; with straps; each','Urinary leg bag','A5112','3','','1','0','','','','0','1','0','0'),
('10843','Leg strap; latex; replacement only; per set','Latex leg strap','A5113','3','','1','0','','','','0','1','0','0'),
('10844','Leg strap; foam or fabric; replacement only; per set','Foam/fabric leg strap','A5114','3','','1','0','','','','0','1','0','0'),
('10845','Skin barrier; wipes or swabs; each','Skin barrier; wipe or swab','A5120','3','','1','0','','','','0','1','0','0'),
('10846','Skin barrier; solid; 6 x 6 or equivalent; each','Solid skin barrier 6x6','A5121','3','','1','0','','','','0','1','0','0'),
('10847','Skin barrier; solid; 8 x 8 or equivalent; each','Solid skin barrier 8x8','A5122','3','','1','0','','','','0','1','0','0'),
('10848','Adhesive or non-adhesive; disk or foam pad','Disk/foam pad +or- adhesive','A5126','3','','1','0','','','','0','1','0','0'),
('10849','Appliance cleaner; incontinence and ostomy appliances; per 16 oz.','Appliance cleaner','A5131','3','','1','0','','','','0','1','0','0'),
('10850','Percutaneous catheter/tube anchoring device; adhesive skin attachment','Percutaneous catheter anchor','A5200','3','','1','0','','','','0','1','0','0'),
('10851','For diabetics only; fitting (including follow-up); custom preparation and supply of off-the-shelf depth-inlay shoe manufactured to accommodate multi-density insert(s); per shoe','Diab shoe for density insert','A5500','3','','1','0','','','','0','1','0','0'),
('10852','For diabetics only; fitting (including follow-up); custom preparation and supply of shoe molded from cast(s) of patients foot (custom molded shoe); per shoe','Diabetic custom molded shoe','A5501','3','','1','0','','','','0','1','0','0'),
('10853','For diabetics only; modification (including fitting) of off-the-shelf depth-inlay shoe or custom-molded shoe with roller or rigid rocker bottom; per shoe','Diabetic shoe w/roller/rockr','A5503','3','','1','0','','','','0','1','0','0'),
('10854','For diabetics only; modification (including fitting) of off-the-shelf depth-inlay shoe or custom-molded shoe with wedge(s); per shoe','Diabetic shoe with wedge','A5504','3','','1','0','','','','0','1','0','0'),
('10855','For diabetics only; modification (including fitting) of off-the-shelf depth-inlay shoe or custom-molded shoe with metatarsal bar; per shoe','Diab shoe w/metatarsal bar','A5505','3','','1','0','','','','0','1','0','0'),
('10856','For diabetics only; modification (including fitting) of off-the-shelf depth-inlay shoe or custom-molded shoe with off-set heel(s); per shoe','Diabetic shoe w/off set heel','A5506','3','','1','0','','','','0','1','0','0'),
('10857','For diabetics only; not otherwise specified modification (including fitting) of off-the-shelf depth-inlay shoe or custom-molded shoe; per shoe','Modification diabetic shoe','A5507','3','','1','0','','','','0','1','0','0'),
('10858','For diabetics only; deluxe feature of off-the-shelf depth-inlay shoe or custom-molded shoe; per shoe','Diabetic deluxe shoe','A5508','3','','1','0','','','','0','1','0','0'),
('10859','For diabetics only; direct formed; compression molded to patients foot without external heat source; multiple-density insert(s) prefabricated; per shoe','Compression form shoe insert','A5510','3','','1','0','','','','0','1','0','0'),
('10860','For diabetics only; multiple density insert; direct formed; molded to foot after external heat source of 230 degrees fahrenheit or higher; total contact with patients foot; including arch; base layer minimum of 1/4 inch material of shore a 35 durometer or 3/16 inch material of shore a 40 durometer (or higher); prefabricated; each','Multi den insert direct form','A5512','3','','1','0','','','','0','1','0','0'),
('10861','For diabetics only; multiple density insert; custom molded from model of patients foot; total contact with patients foot; including arch; base layer minimum of 3/16 inch material of shore a 35 durometer or higher); includes arch filler and other shaping material; custom fabricated; each','Multi den insert custom mold','A5513','3','','1','0','','','','0','1','0','0'),
('10862','Non-contact wound warming wound cover for use with the non-contact wound warming device and warming card','Wound warming wound cover','A6000','3','','1','0','','','','0','1','0','0'),
('10863','Collagen based wound filler; dry form; sterile; per gram of collagen','Collagen based wound filler','A6010','3','','1','0','','','','0','1','0','0'),
('10864','Collagen based wound filler; gel/paste; per gram of collagen','Collagen gel/paste wound fil','A6011','3','','1','0','','','','0','1','0','0'),
('10865','Collagen dressing; sterile; size 16 sq. in. or less; each','Collagen dressing <=16 sq in','A6021','3','','1','0','','','','0','1','0','0'),
('10866','Collagen dressing; sterile; size more than 16 sq. in. but less than or equal to 48 sq. in.; each','Collagen drsg>16<=48 sq in','A6022','3','','1','0','','','','0','1','0','0'),
('10867','Collagen dressing; sterile; size more than 48 sq. in.; each','Collagen dressing >48 sq in','A6023','3','','1','0','','','','0','1','0','0'),
('10868','Collagen dressing wound filler; sterile; per 6 inches','Collagen dsg wound filler','A6024','3','','1','0','','','','0','1','0','0'),
('10869','Gel sheet for dermal or epidermal application; (e.g.; silicone; hydrogel; other); each','Silicone gel sheet; each','A6025','3','','1','0','','','','0','1','0','0'),
('10870','Wound pouch; each','Wound pouch each','A6154','3','','1','0','','','','0','1','0','0'),
('10871','Alginate or other fiber gelling dressing; wound cover; sterile; pad size 16 sq. in. or less; each dressing','Alginate dressing <=16 sq in','A6196','3','','1','0','','','','0','1','0','0'),
('10872','Alginate or other fiber gelling dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; each dressing','Alginate drsg >16 <=48 sq in','A6197','3','','1','0','','','','0','1','0','0'),
('10873','Alginate or other fiber gelling dressing; wound cover; sterile; pad size more than 48 sq. in.; each dressing','Alginate dressing > 48 sq in','A6198','3','','1','0','','','','0','1','0','0'),
('10874','Alginate or other fiber gelling dressing; wound filler; sterile; per 6 inches','Alginate drsg wound filler','A6199','3','','1','0','','','','0','1','0','0'),
('10875','Composite dressing; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Composite drsg <= 16 sq in','A6203','3','','1','0','','','','0','1','0','0'),
('10876','Composite dressing; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Composite drsg >16<=48 sq in','A6204','3','','1','0','','','','0','1','0','0'),
('10877','Composite dressing; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Composite drsg > 48 sq in','A6205','3','','1','0','','','','0','1','0','0'),
('10878','Contact layer; sterile; 16 sq. in. or less; each dressing','Contact layer <= 16 sq in','A6206','3','','1','0','','','','0','1','0','0'),
('10879','Contact layer; sterile; more than 16 sq. in. but less than or equal to 48 sq. in.; each dressing','Contact layer >16<= 48 sq in','A6207','3','','1','0','','','','0','1','0','0'),
('10880','Contact layer; sterile; more than 48 sq. in.; each dressing','Contact layer > 48 sq in','A6208','3','','1','0','','','','0','1','0','0'),
('10881','Foam dressing; wound cover; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Foam drsg <=16 sq in w/o bdr','A6209','3','','1','0','','','','0','1','0','0'),
('10882','Foam dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Foam drg >16<=48 sq in w/o b','A6210','3','','1','0','','','','0','1','0','0'),
('10883','Foam dressing; wound cover; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Foam drg > 48 sq in w/o brdr','A6211','3','','1','0','','','','0','1','0','0'),
('10884','Foam dressing; wound cover; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Foam drg <=16 sq in w/border','A6212','3','','1','0','','','','0','1','0','0'),
('10885','Foam dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Foam drg >16<=48 sq in w/bdr','A6213','3','','1','0','','','','0','1','0','0'),
('10886','Foam dressing; wound cover; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Foam drg > 48 sq in w/border','A6214','3','','1','0','','','','0','1','0','0'),
('10887','Foam dressing; wound filler; sterile; per gram','Foam dressing wound filler','A6215','3','','1','0','','','','0','1','0','0'),
('10888','Gauze; non-impregnated; non-sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Non-sterile gauze<=16 sq in','A6216','3','','1','0','','','','0','1','0','0'),
('10889','Gauze; non-impregnated; non-sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Non-sterile gauze>16<=48 sq','A6217','3','','1','0','','','','0','1','0','0'),
('10890','Gauze; non-impregnated; non-sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Non-sterile gauze > 48 sq in','A6218','3','','1','0','','','','0','1','0','0'),
('10891','Gauze; non-impregnated; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Gauze <= 16 sq in w/border','A6219','3','','1','0','','','','0','1','0','0'),
('10892','Gauze; non-impregnated; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Gauze >16 <=48 sq in w/bordr','A6220','3','','1','0','','','','0','1','0','0'),
('10893','Gauze; non-impregnated; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Gauze > 48 sq in w/border','A6221','3','','1','0','','','','0','1','0','0'),
('10894','Gauze; impregnated with other than water; normal saline; or hydrogel; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Gauze <=16 in no w/sal w/o b','A6222','3','','1','0','','','','0','1','0','0'),
('10895','Gauze; impregnated with other than water; normal saline; or hydrogel; sterile; pad size more than 16 sq. in.; but less than or equal to 48 sq. in.; without adhesive border; each dressing','Gauze >16<=48 no w/sal w/o b','A6223','3','','1','0','','','','0','1','0','0'),
('10896','Gauze; impregnated with other than water; normal saline; or hydrogel; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Gauze > 48 in no w/sal w/o b','A6224','3','','1','0','','','','0','1','0','0'),
('10897','Gauze; impregnated; water or normal saline; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Gauze <= 16 sq in water/sal','A6228','3','','1','0','','','','0','1','0','0'),
('10898','Gauze; impregnated; water or normal saline; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Gauze >16<=48 sq in watr/sal','A6229','3','','1','0','','','','0','1','0','0'),
('10899','Gauze; impregnated; water or normal saline; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Gauze > 48 sq in water/salne','A6230','3','','1','0','','','','0','1','0','0'),
('10900','Gauze; impregnated; hydrogel; for direct wound contact; sterile; pad size 16 sq. in. or less; each dressing','Hydrogel dsg<=16 sq in','A6231','3','','1','0','','','','0','1','0','0'),
('10901','Gauze; impregnated; hydrogel; for direct wound contact; sterile; pad size greater than 16 sq. in.; but less than or equal to 48 sq. in.; each dressing','Hydrogel dsg>16<=48 sq in','A6232','3','','1','0','','','','0','1','0','0'),
('10902','Gauze; impregnated; hydrogel; for direct wound contact; sterile; pad size more than 48 sq. in.; each dressing','Hydrogel dressing >48 sq in','A6233','3','','1','0','','','','0','1','0','0'),
('10903','Hydrocolloid dressing; wound cover; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Hydrocolld drg <=16 w/o bdr','A6234','3','','1','0','','','','0','1','0','0'),
('10904','Hydrocolloid dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Hydrocolld drg >16<=48 w/o b','A6235','3','','1','0','','','','0','1','0','0'),
('10905','Hydrocolloid dressing; wound cover; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Hydrocolld drg > 48 in w/o b','A6236','3','','1','0','','','','0','1','0','0'),
('10906','Hydrocolloid dressing; wound cover; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Hydrocolld drg <=16 in w/bdr','A6237','3','','1','0','','','','0','1','0','0'),
('10907','Hydrocolloid dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Hydrocolld drg >16<=48 w/bdr','A6238','3','','1','0','','','','0','1','0','0'),
('10908','Hydrocolloid dressing; wound cover; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Hydrocolld drg > 48 in w/bdr','A6239','3','','1','0','','','','0','1','0','0'),
('10909','Hydrocolloid dressing; wound filler; paste; sterile; per ounce','Hydrocolld drg filler paste','A6240','3','','1','0','','','','0','1','0','0'),
('10910','Hydrocolloid dressing; wound filler; dry form; sterile; per gram','Hydrocolloid drg filler dry','A6241','3','','1','0','','','','0','1','0','0'),
('10911','Hydrogel dressing; wound cover; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Hydrogel drg <=16 in w/o bdr','A6242','3','','1','0','','','','0','1','0','0'),
('10912','Hydrogel dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Hydrogel drg >16<=48 w/o bdr','A6243','3','','1','0','','','','0','1','0','0'),
('10913','Hydrogel dressing; wound cover; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Hydrogel drg >48 in w/o bdr','A6244','3','','1','0','','','','0','1','0','0'),
('10914','Hydrogel dressing; wound cover; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Hydrogel drg <= 16 in w/bdr','A6245','3','','1','0','','','','0','1','0','0'),
('10915','Hydrogel dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Hydrogel drg >16<=48 in w/b','A6246','3','','1','0','','','','0','1','0','0'),
('10916','Hydrogel dressing; wound cover; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Hydrogel drg > 48 sq in w/b','A6247','3','','1','0','','','','0','1','0','0'),
('10917','Hydrogel dressing; wound filler; gel; per fluid ounce','Hydrogel drsg gel filler','A6248','3','','1','0','','','','0','1','0','0'),
('10918','Skin sealants; protectants; moisturizers; ointments; any type; any size','Skin seal protect moisturizr','A6250','3','','1','0','','','','0','1','0','0'),
('10919','Specialty absorptive dressing; wound cover; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Absorpt drg <=16 sq in w/o b','A6251','3','','1','0','','','','0','1','0','0'),
('10920','Specialty absorptive dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; without adhesive border; each dressing','Absorpt drg >16 <=48 w/o bdr','A6252','3','','1','0','','','','0','1','0','0'),
('10921','Specialty absorptive dressing; wound cover; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Absorpt drg > 48 sq in w/o b','A6253','3','','1','0','','','','0','1','0','0'),
('10922','Specialty absorptive dressing; wound cover; sterile; pad size 16 sq. in. or less; with any size adhesive border; each dressing','Absorpt drg <=16 sq in w/bdr','A6254','3','','1','0','','','','0','1','0','0'),
('10923','Specialty absorptive dressing; wound cover; sterile; pad size more than 16 sq. in. but less than or equal to 48 sq. in.; with any size adhesive border; each dressing','Absorpt drg >16<=48 in w/bdr','A6255','3','','1','0','','','','0','1','0','0'),
('10924','Specialty absorptive dressing; wound cover; sterile; pad size more than 48 sq. in.; with any size adhesive border; each dressing','Absorpt drg > 48 sq in w/bdr','A6256','3','','1','0','','','','0','1','0','0'),
('10925','Transparent film; sterile; 16 sq. in. or less; each dressing','Transparent film <= 16 sq in','A6257','3','','1','0','','','','0','1','0','0'),
('10926','Transparent film; sterile; more than 16 sq. in. but less than or equal to 48 sq. in.; each dressing','Transparent film >16<=48 in','A6258','3','','1','0','','','','0','1','0','0'),
('10927','Transparent film; sterile; more than 48 sq. in.; each dressing','Transparent film > 48 sq in','A6259','3','','1','0','','','','0','1','0','0'),
('10928','Wound cleansers; any type; any size','Wound cleanser any type/size','A6260','3','','1','0','','','','0','1','0','0'),
('10929','Wound filler; gel/paste; per fluid ounce; not otherwise specified','Wound filler gel/paste /oz','A6261','3','','1','0','','','','0','1','0','0'),
('10930','Wound filler; dry form; per gram; not otherwise specified','Wound filler dry form / gram','A6262','3','','1','0','','','','0','1','0','0'),
('10931','Gauze; impregnated; other than water; normal saline; or zinc paste; sterile; any width; per linear yard','Impreg gauze no h20/sal/yard','A6266','3','','1','0','','','','0','1','0','0'),
('10932','Gauze; non-impregnated; sterile; pad size 16 sq. in. or less; without adhesive border; each dressing','Sterile gauze <= 16 sq in','A6402','3','','1','0','','','','0','1','0','0'),
('10933','Gauze; non-impregnated; sterile; pad size more than 16 sq. in. less than or equal to 48 sq. in.; without adhesive border; each dressing','Sterile gauze>16 <= 48 sq in','A6403','3','','1','0','','','','0','1','0','0'),
('10934','Gauze; non-impregnated; sterile; pad size more than 48 sq. in.; without adhesive border; each dressing','Sterile gauze > 48 sq in','A6404','3','','1','0','','','','0','1','0','0'),
('10935','Packing strips; non-impregnated; sterile; up to 2 inches in width; per linear yard','Packing strips; non-impreg','A6407','3','','1','0','','','','0','1','0','0'),
('10936','Eye pad; sterile; each','Sterile eye pad','A6410','3','','1','0','','','','0','1','0','0'),
('10937','Eye pad; non-sterile; each','Non-sterile eye pad','A6411','3','','1','0','','','','0','1','0','0'),
('10938','Eye patch; occlusive; each','Occlusive eye patch','A6412','3','','1','0','','','','0','1','0','0'),
('10939','Adhesive bandage; first-aid type; any size; each','Adhesive bandage; first-aid','A6413','3','','1','0','','','','0','1','0','0'),
('10940','Padding bandage; non-elastic; non-woven/non-knitted; width greater than or equal to three inches and less than five inches; per yard','Pad band w>=3'' <5''/yd','A6441','3','','1','0','','','','0','1','0','0'),
('10941','Conforming bandage; non-elastic; knitted/woven; non-sterile; width less than three inches; per yard','Conform band n/s w<3''/yd','A6442','3','','1','0','','','','0','1','0','0'),
('10942','Conforming bandage; non-elastic; knitted/woven; non-sterile; width greater than or equal to three inches and less than five inches; per yard','Conform band n/s w>=3''<5''/yd','A6443','3','','1','0','','','','0','1','0','0'),
('10943','Conforming bandage; non-elastic; knitted/woven; non-sterile; width greater than or equal to 5 inches; per yard','Conform band n/s w>=5''/yd','A6444','3','','1','0','','','','0','1','0','0'),
('10944','Conforming bandage; non-elastic; knitted/woven; sterile; width less than three inches; per yard','Conform band s w <3''/yd','A6445','3','','1','0','','','','0','1','0','0'),
('10945','Conforming bandage; non-elastic; knitted/woven; sterile; width greater than or equal to three inches and less than five inches; per yard','Conform band s w>=3'' <5''/yd','A6446','3','','1','0','','','','0','1','0','0'),
('10946','Conforming bandage; non-elastic; knitted/woven; sterile; width greater than or equal to five inches; per yard','Conform band s w >=5''/yd','A6447','3','','1','0','','','','0','1','0','0'),
('10947','Light compression bandage; elastic; knitted/woven; width less than three inches; per yard','Lt compres band <3''/yd','A6448','3','','1','0','','','','0','1','0','0'),
('10948','Light compression bandage; elastic; knitted/woven; width greater than or equal to three inches and less than five inches; per yard','Lt compres band >=3'' <5''/yd','A6449','3','','1','0','','','','0','1','0','0'),
('10949','Light compression bandage; elastic; knitted/woven; width greater than or equal to five inches; per yard','Lt compres band >=5''/yd','A6450','3','','1','0','','','','0','1','0','0'),
('10950','Moderate compression bandage; elastic; knitted/woven; load resistance of 1.25 to 1.34 foot pounds at 50% maximum stretch; width greater than or equal to three inches and less than five inches; per yard','Mod compres band w>=3''<5''/yd','A6451','3','','1','0','','','','0','1','0','0'),
('10951','High compression bandage; elastic; knitted/woven; load resistance greater than or equal to 1.35 foot pounds at 50% maximum stretch; width greater than or equal to three inches and less than five inches; per yard','High compres band w>=3''<5''yd','A6452','3','','1','0','','','','0','1','0','0'),
('10952','Self-adherent bandage; elastic; non-knitted/non-woven; width less than three inches; per yard','Self-adher band w <3''/yd','A6453','3','','1','0','','','','0','1','0','0'),
('10953','Self-adherent bandage; elastic; non-knitted/non-woven; width greater than or equal to three inches and less than five inches; per yard','Self-adher band w>=3'' <5''/yd','A6454','3','','1','0','','','','0','1','0','0'),
('10954','Self-adherent bandage; elastic; non-knitted/non-woven; width greater than or equal to five inches; per yard','Self-adher band >=5''/yd','A6455','3','','1','0','','','','0','1','0','0'),
('10955','Zinc paste impregnated bandage; non-elastic; knitted/woven; width greater than or equal to three inches and less than five inches; per yard','Zinc paste band w >=3''<5''/yd','A6456','3','','1','0','','','','0','1','0','0'),
('10956','Tubular dressing with or without elastic; any width; per linear yard','Tubular dressing','A6457','3','','1','0','','','','0','1','0','0'),
('10957','Compression burn garment; bodysuit (head to foot); custom fabricated','Compres burngarment bodysuit','A6501','3','','1','0','','','','0','1','0','0'),
('10958','Compression burn garment; chin strap; custom fabricated','Compres burngarment chinstrp','A6502','3','','1','0','','','','0','1','0','0'),
('10959','Compression burn garment; facial hood; custom fabricated','Compres burngarment facehood','A6503','3','','1','0','','','','0','1','0','0'),
('10960','Compression burn garment; glove to wrist; custom fabricated','Cmprsburngarment glove-wrist','A6504','3','','1','0','','','','0','1','0','0'),
('10961','Compression burn garment; glove to elbow; custom fabricated','Cmprsburngarment glove-elbow','A6505','3','','1','0','','','','0','1','0','0'),
('10962','Compression burn garment; glove to axilla; custom fabricated','Cmprsburngrmnt glove-axilla','A6506','3','','1','0','','','','0','1','0','0'),
('10963','Compression burn garment; foot to knee length; custom fabricated','Cmprs burngarment foot-knee','A6507','3','','1','0','','','','0','1','0','0'),
('10964','Compression burn garment; foot to thigh length; custom fabricated','Cmprs burngarment foot-thigh','A6508','3','','1','0','','','','0','1','0','0'),
('10965','Compression burn garment; upper trunk to waist including arm openings (vest); custom fabricated','Compres burn garment jacket','A6509','3','','1','0','','','','0','1','0','0'),
('10966','Compression burn garment; trunk; including arms down to leg openings (leotard); custom fabricated','Compres burn garment leotard','A6510','3','','1','0','','','','0','1','0','0'),
('10967','Compression burn garment; lower trunk including leg openings (panty); custom fabricated','Compres burn garment panty','A6511','3','','1','0','','','','0','1','0','0'),
('10968','Compression burn garment; not otherwise classified','Compres burn garment; noc','A6512','3','','1','0','','','','0','1','0','0'),
('10969','Compression burn mask; face and/or neck; plastic or equal; custom fabricated','Compress burn mask face/neck','A6513','3','','1','0','','','','0','1','0','0'),
('10970','Gradient compression stocking; below knee; 18-30 mmhg; each','Compression stocking bk18-30','A6530','3','','1','0','','','','0','1','0','0'),
('10971','Gradient compression stocking; below knee; 30-40 mmhg; each','Compression stocking bk30-40','A6531','3','','1','0','','','','0','1','0','0'),
('10972','Gradient compression stocking; below knee; 40-50 mmhg; each','Compression stocking bk40-50','A6532','3','','1','0','','','','0','1','0','0'),
('10973','Gradient compression stocking; thigh length; 18-30 mmhg; each','Gc stocking thighlngth 18-30','A6533','3','','1','0','','','','0','1','0','0'),
('10974','Gradient compression stocking; thigh length; 30-40 mmhg; each','Gc stocking thighlngth 30-40','A6534','3','','1','0','','','','0','1','0','0'),
('10975','Gradient compression stocking; thigh length; 40-50 mmhg; each','Gc stocking thighlngth 40-50','A6535','3','','1','0','','','','0','1','0','0'),
('10976','Gradient compression stocking; full length/chap style; 18-30 mmhg; each','Gc stocking full lngth 18-30','A6536','3','','1','0','','','','0','1','0','0'),
('10977','Gradient compression stocking; full length/chap style; 30-40 mmhg; each','Gc stocking full lngth 30-40','A6537','3','','1','0','','','','0','1','0','0'),
('10978','Gradient compression stocking; full length/chap style; 40-50 mmhg; each','Gc stocking full lngth 40-50','A6538','3','','1','0','','','','0','1','0','0'),
('10979','Gradient compression stocking; waist length; 18-30 mmhg; each','Gc stocking waistlngth 18-30','A6539','3','','1','0','','','','0','1','0','0'),
('10980','Gradient compression stocking; waist length; 30-40 mmhg; each','Gc stocking waistlngth 30-40','A6540','3','','1','0','','','','0','1','0','0'),
('10981','Gradient compression stocking; waist length; 40-50 mmhg; each','Gc stocking waistlngth 40-50','A6541','3','','1','0','','','','0','1','0','0'),
('10982','Gradient compression stocking; garter belt','Gc stocking garter belt','A6544','3','','1','0','','','','0','1','0','0'),
('10983','Gradient compression wrap; non-elastic; below knee; 30-50 mm hg; each','Grad comp non-elastic bk','A6545','3','','1','0','','','','0','1','0','0'),
('10984','Gradient compression stocking/sleeve; not otherwise specified','G compression stocking','A6549','3','','1','0','','','','0','1','0','0'),
('10985','Wound care set; for negative pressure wound therapy electrical pump; includes all supplies and accessories','Neg pres wound ther drsg set','A6550','3','','1','0','','','','0','1','0','0'),
('10986','Canister; disposable; used with suction pump; each','Disposable canister for pump','A7000','3','','1','0','','','','0','1','0','0'),
('10987','Canister; non-disposable; used with suction pump; each','Nondisposable pump canister','A7001','3','','1','0','','','','0','1','0','0'),
('10988','Tubing; used with suction pump; each','Tubing used w suction pump','A7002','3','','1','0','','','','0','1','0','0'),
('10989','Administration set; with small volume nonfiltered pneumatic nebulizer; disposable','Nebulizer administration set','A7003','3','','1','0','','','','0','1','0','0'),
('10990','Small volume nonfiltered pneumatic nebulizer; disposable','Disposable nebulizer sml vol','A7004','3','','1','0','','','','0','1','0','0'),
('10991','Administration set; with small volume nonfiltered pneumatic nebulizer; non-disposable','Nondisposable nebulizer set','A7005','3','','1','0','','','','0','1','0','0'),
('10992','Administration set; with small volume filtered pneumatic nebulizer','Filtered nebulizer admin set','A7006','3','','1','0','','','','0','1','0','0'),
('10993','Large volume nebulizer; disposable; unfilled; used with aerosol compressor','Lg vol nebulizer disposable','A7007','3','','1','0','','','','0','1','0','0'),
('10994','Large volume nebulizer; disposable; prefilled; used with aerosol compressor','Disposable nebulizer prefill','A7008','3','','1','0','','','','0','1','0','0'),
('10995','Reservoir bottle; non-disposable; used with large volume ultrasonic nebulizer','Nebulizer reservoir bottle','A7009','3','','1','0','','','','0','1','0','0'),
('10996','Corrugated tubing; disposable; used with large volume nebulizer; 100 feet','Disposable corrugated tubing','A7010','3','','1','0','','','','0','1','0','0'),
('10997','Corrugated tubing; non-disposable; used with large volume nebulizer; 10 feet','Nondispos corrugated tubing','A7011','3','','1','0','','','','0','1','0','0'),
('10998','Water collection device; used with large volume nebulizer','Nebulizer water collec devic','A7012','3','','1','0','','','','0','1','0','0'),
('10999','Filter; disposable; used with aerosol compressor or ultrasonic generator','Disposable compressor filter','A7013','3','','1','0','','','','0','1','0','0'),
('11000','Filter; nondisposable; used with aerosol compressor or ultrasonic generator','Compressor nondispos filter','A7014','3','','1','0','','','','0','1','0','0'),
('11001','Aerosol mask; used with dme nebulizer','Aerosol mask used w nebulize','A7015','3','','1','0','','','','0','1','0','0'),
('11002','Dome and mouthpiece; used with small volume ultrasonic nebulizer','Nebulizer dome & mouthpiece','A7016','3','','1','0','','','','0','1','0','0'),
('11003','Nebulizer; durable; glass or autoclavable plastic; bottle type; not used with oxygen','Nebulizer not used w oxygen','A7017','3','','1','0','','','','0','1','0','0'),
('11004','Water; distilled; used with large volume nebulizer; 1000 ml','Water distilled w/nebulizer','A7018','3','','1','0','','','','0','1','0','0'),
('11005','Interface for cough stimulating device; includes all components; replacement only','Interface; cough stim device','A7020','3','','1','0','','','','0','1','0','0'),
('11006','High frequency chest wall oscillation system vest; replacement for use with patient owned equipment; each','Replace chest compress vest','A7025','3','','1','0','','','','0','1','0','0'),
('11007','High frequency chest wall oscillation system hose; replacement for use with patient owned equipment; each','Replace chst cmprss sys hose','A7026','3','','1','0','','','','0','1','0','0'),
('11008','Combination oral/nasal mask; used with continuous positive airway pressure device; each','Combination oral/nasal mask','A7027','3','','1','0','','','','0','1','0','0'),
('11009','Oral cushion for combination oral/nasal mask; replacement only; each','Repl oral cushion combo mask','A7028','3','','1','0','','','','0','1','0','0'),
('11010','Nasal pillows for combination oral/nasal mask; replacement only; pair','Repl nasal pillow comb mask','A7029','3','','1','0','','','','0','1','0','0'),
('11011','Full face mask used with positive airway pressure device; each','Cpap full face mask','A7030','3','','1','0','','','','0','1','0','0'),
('11012','Face mask interface; replacement for full face mask; each','Replacement facemask interfa','A7031','3','','1','0','','','','0','1','0','0'),
('11013','Cushion for use on nasal mask interface; replacement only; each','Replacement nasal cushion','A7032','3','','1','0','','','','0','1','0','0'),
('11014','Pillow for use on nasal cannula type interface; replacement only; pair','Replacement nasal pillows','A7033','3','','1','0','','','','0','1','0','0'),
('11015','Nasal interface (mask or cannula type) used with positive airway pressure device; with or without head strap','Nasal application device','A7034','3','','1','0','','','','0','1','0','0'),
('11016','Headgear used with positive airway pressure device','Pos airway press headgear','A7035','3','','1','0','','','','0','1','0','0'),
('11017','Chinstrap used with positive airway pressure device','Pos airway press chinstrap','A7036','3','','1','0','','','','0','1','0','0'),
('11018','Tubing used with positive airway pressure device','Pos airway pressure tubing','A7037','3','','1','0','','','','0','1','0','0'),
('11019','Filter; disposable; used with positive airway pressure device','Pos airway pressure filter','A7038','3','','1','0','','','','0','1','0','0'),
('11020','Filter; non disposable; used with positive airway pressure device','Filter; non disposable w pap','A7039','3','','1','0','','','','0','1','0','0'),
('11021','One way chest drain valve','One way chest drain valve','A7040','3','','1','0','','','','0','1','0','0'),
('11022','Water seal drainage container and tubing for use with implanted chest tube','Water seal drain container','A7041','3','','1','0','','','','0','1','0','0'),
('11023','Implanted pleural catheter; each','Implanted pleural catheter','A7042','3','','1','0','','','','0','1','0','0'),
('11024','Vacuum drainage bottle and tubing for use with implanted catheter','Vacuum drainagebottle/tubing','A7043','3','','1','0','','','','0','1','0','0'),
('11025','Oral interface used with positive airway pressure device; each','Pap oral interface','A7044','3','','1','0','','','','0','1','0','0'),
('11026','Exhalation port with or without swivel used with accessories for positive airway devices; replacement only','Repl exhalation port for pap','A7045','3','','1','0','','','','0','1','0','0'),
('11027','Water chamber for humidifier; used with positive airway pressure device; replacement; each','Repl water chamber; pap dev','A7046','3','','1','0','','','','0','1','0','0'),
('11028','Oral interface used with respiratory suction pump; each','Resp suction oral interface','A7047','3','','1','0','','','','0','1','0','0'),
('11029','Vacuum drainage collection unit and tubing kit; including all supplies needed for collection unit change; for use with implanted catheter; each','Vacuum drain bottle/tube kit','A7048','3','','1','0','','','','0','1','0','0'),
('11030','Tracheostoma valve; including diaphragm; each','Tracheostoma valve w diaphra','A7501','3','','1','0','','','','0','1','0','0'),
('11031','Replacement diaphragm/faceplate for tracheostoma valve; each','Replacement diaphragm/fplate','A7502','3','','1','0','','','','0','1','0','0'),
('11032','Filter holder or filter cap; reusable; for use in a tracheostoma heat and moisture exchange system; each','Hmes filter holder or cap','A7503','3','','1','0','','','','0','1','0','0'),
('11033','Filter for use in a tracheostoma heat and moisture exchange system; each','Tracheostoma hmes filter','A7504','3','','1','0','','','','0','1','0','0'),
('11034','Housing; reusable without adhesive; for use in a heat and moisture exchange system and/or with a tracheostoma valve; each','Hmes or trach valve housing','A7505','3','','1','0','','','','0','1','0','0'),
('11035','Adhesive disc for use in a heat and moisture exchange system and/or with tracheostoma valve; any type each','Hmes/trachvalve adhesivedisk','A7506','3','','1','0','','','','0','1','0','0'),
('11036','Filter holder and integrated filter without adhesive; for use in a tracheostoma heat and moisture exchange system; each','Integrated filter & holder','A7507','3','','1','0','','','','0','1','0','0'),
('11037','Housing and integrated adhesive; for use in a tracheostoma heat and moisture exchange system and/or with a tracheostoma valve; each','Housing & integrated adhesiv','A7508','3','','1','0','','','','0','1','0','0'),
('11038','Filter holder and integrated filter housing; and adhesive; for use as a tracheostoma heat and moisture exchange system; each','Heat & moisture exchange sys','A7509','3','','1','0','','','','0','1','0','0'),
('11039','Tracheostomy/laryngectomy tube; non-cuffed; polyvinylchloride (pvc); silicone or equal; each','Trach/laryn tube non-cuffed','A7520','3','','1','0','','','','0','1','0','0'),
('11040','Tracheostomy/laryngectomy tube; cuffed; polyvinylchloride (pvc); silicone or equal; each','Trach/laryn tube cuffed','A7521','3','','1','0','','','','0','1','0','0'),
('11041','Tracheostomy/laryngectomy tube; stainless steel or equal (sterilizable and reusable); each','Trach/laryn tube stainless','A7522','3','','1','0','','','','0','1','0','0'),
('11042','Tracheostomy shower protector; each','Tracheostomy shower protect','A7523','3','','1','0','','','','0','1','0','0'),
('11043','Tracheostoma stent/stud/button; each','Tracheostoma stent/stud/bttn','A7524','3','','1','0','','','','0','1','0','0'),
('11044','Tracheostomy mask; each','Tracheostomy mask','A7525','3','','1','0','','','','0','1','0','0'),
('11045','Tracheostomy tube collar/holder; each','Tracheostomy tube collar','A7526','3','','1','0','','','','0','1','0','0'),
('11046','Tracheostomy/laryngectomy tube plug/stop; each','Trach/laryn tube plug/stop','A7527','3','','1','0','','','','0','1','0','0'),
('11047','Helmet; protective; soft; prefabricated; includes all components and accessories','Soft protect helmet prefab','A8000','3','','1','0','','','','0','1','0','0'),
('11048','Helmet; protective; hard; prefabricated; includes all components and accessories','Hard protect helmet prefab','A8001','3','','1','0','','','','0','1','0','0'),
('11049','Helmet; protective; soft; custom fabricated; includes all components and accessories','Soft protect helmet custom','A8002','3','','1','0','','','','0','1','0','0'),
('11050','Helmet; protective; hard; custom fabricated; includes all components and accessories','Hard protect helmet custom','A8003','3','','1','0','','','','0','1','0','0'),
('11051','Soft interface for helmet; replacement only','Repl soft interface; helmet','A8004','3','','1','0','','','','0','1','0','0'),
('11052','Non-prescription drugs','Misc/exper non-prescript dru','A9150','3','','1','0','','','','0','1','0','0'),
('11053','Single vitamin/mineral/trace element; oral; per dose; not otherwise specified','Single vitamin nos','A9152','3','','1','0','','','','0','1','0','0'),
('11054','Multiple vitamins; with or without minerals and trace elements; oral; per dose; not otherwise specified','Multi-vitamin nos','A9153','3','','1','0','','','','0','1','0','0'),
('11055','Artificial saliva; 30 ml','Artificial saliva','A9155','3','','1','0','','','','0','1','0','0'),
('11056','Pediculosis (lice infestation) treatment; topical; for administration by patient/caretaker','Lice treatment; topical','A9180','3','','1','0','','','','0','1','0','0'),
('11057','Non-covered item or service','Non-covered item or service','A9270','3','','1','0','','','','0','1','0','0'),
('11058','Wound suction; disposable; includes dressing; all accessories and components; any type; each','Disp wound suct; drsg/access','A9272','3','','1','0','','','','0','1','0','0'),
('11059','Hot water bottle; ice cap or collar; heat and/or cold wrap; any type','Hot/cold h2obot/cap/col/wrap','A9273','3','','1','0','','','','0','1','0','0'),
('11060','External ambulatory insulin delivery system; disposable; each; includes all supplies and accessories','Ext amb insulin delivery sys','A9274','3','','1','0','','','','0','1','0','0'),
('11061','Home glucose disposable monitor; includes test strips','Disp home glucose monitor','A9275','3','','1','0','','','','0','1','0','0'),
('11062','Sensor; invasive (e.g.; subcutaneous); disposable; for use with interstitial continuous glucose monitoring system; one unit = 1 day supply','Disposable sensor; cgm sys','A9276','3','','1','0','','','','0','1','0','0'),
('11063','Transmitter; external; for use with interstitial continuous glucose monitoring system','External transmitter; cgm','A9277','3','','1','0','','','','0','1','0','0'),
('11064','Receiver (monitor); external; for use with interstitial continuous glucose monitoring system','External receiver; cgm sys','A9278','3','','1','0','','','','0','1','0','0'),
('11065','Monitoring feature/device; stand-alone or integrated; any type; includes all accessories; components and electronics; not otherwise classified','Monitoring feature/devicenoc','A9279','3','','1','0','','','','0','1','0','0'),
('11066','Alert or alarm device; not otherwise classified','Alert device; noc','A9280','3','','1','0','','','','0','1','0','0'),
('11067','Reaching/grabbing device; any type; any length; each','Reaching/grabbing device','A9281','3','','1','0','','','','0','1','0','0'),
('11068','Wig; any type; each','Wig any type','A9282','3','','1','0','','','','0','1','0','0'),
('11069','Foot pressure off loading/supportive device; any type; each','Foot press off load supp dev','A9283','3','','1','0','','','','0','1','0','0'),
('11070','Spirometer; non-electronic; includes all accessories','Non-electronic spirometer','A9284','3','','1','0','','','','0','1','0','0'),
('11071','Inversion/eversion correction device','Inversion eversion cor devic','A9285','3','','1','0','','','','0','1','0','0'),
('11072','Hygienic item or device; disposable or non-disposable; any type; each','Any hygienic item; device','A9286','3','','1','0','','','','0','1','0','0'),
('11073','Exercise equipment','Exercise equipment','A9300','3','','1','0','','','','0','1','0','0'),
('11074','Technetium tc-99m sestamibi; diagnostic; per study dose','Tc99m sestamibi','A9500','3','','1','0','','','','0','1','0','0'),
('11075','Technetium tc-99m teboroxime; diagnostic; per study dose','Technetium tc-99m teboroxime','A9501','3','','1','0','','','','0','1','0','0'),
('11076','Technetium tc-99m tetrofosmin; diagnostic; per study dose','Tc99m tetrofosmin','A9502','3','','1','0','','','','0','1','0','0'),
('11077','Technetium tc-99m medronate; diagnostic; per study dose; up to 30 millicuries','Tc99m medronate','A9503','3','','1','0','','','','0','1','0','0'),
('11078','Technetium tc-99m apcitide; diagnostic; per study dose; up to 20 millicuries','Tc99m apcitide','A9504','3','','1','0','','','','0','1','0','0'),
('11079','Thallium tl-201 thallous chloride; diagnostic; per millicurie','Tl201 thallium','A9505','3','','1','0','','','','0','1','0','0'),
('11080','Indium in-111 capromab pendetide; diagnostic; per study dose; up to 10 millicuries','In111 capromab','A9507','3','','1','0','','','','0','1','0','0'),
('11081','Iodine i-131 iobenguane sulfate; diagnostic; per 0.5 millicurie','I131 iodobenguate; dx','A9508','3','','1','0','','','','0','1','0','0'),
('11082','Iodine i-123 sodium iodide; diagnostic; per millicurie','Iodine i-123 sod iodide mil','A9509','3','','1','0','','','','0','1','0','0'),
('11083','Technetium tc-99m disofenin; diagnostic; per study dose; up to 15 millicuries','Tc99m disofenin','A9510','3','','1','0','','','','0','1','0','0'),
('11084','Technetium tc-99m pertechnetate; diagnostic; per millicurie','Tc99m pertechnetate','A9512','3','','1','0','','','','0','1','0','0'),
('11085','Choline c-11; diagnostic; per study dose up to 20 millicuries','Choline c-11','A9515','3','','1','0','','','','0','1','0','0'),
('11086','Iodine i-123 sodium iodide; diagnostic; per 100 microcuries; up to 999 microcuries','Iodine i-123 sod iodide mic','A9516','3','','1','0','','','','0','1','0','0'),
('11087','Iodine i-131 sodium iodide capsule(s); therapeutic; per millicurie','I131 iodide cap; rx','A9517','3','','1','0','','','','0','1','0','0'),
('11088','Technetium tc-99m tilmanocept; diagnostic; up to 0.5 millicuries','Tc99 tilmanocept diag 0.5mci','A9520','3','','1','0','','','','0','1','0','0'),
('11089','Technetium tc-99m exametazime; diagnostic; per study dose; up to 25 millicuries','Tc99m exametazime','A9521','3','','1','0','','','','0','1','0','0'),
('11090','Iodine i-131 iodinated serum albumin; diagnostic; per 5 microcuries','I131 serum albumin; dx','A9524','3','','1','0','','','','0','1','0','0'),
('11091','Nitrogen n-13 ammonia; diagnostic; per study dose; up to 40 millicuries','Nitrogen n-13 ammonia','A9526','3','','1','0','','','','0','1','0','0'),
('11092','Iodine i-125; sodium iodide solution; therapeutic; per millicurie','Iodine i-125 sodium iodide','A9527','3','','1','0','','','','0','1','0','0'),
('11093','Iodine i-131 sodium iodide capsule(s); diagnostic; per millicurie','Iodine i-131 iodide cap; dx','A9528','3','','1','0','','','','0','1','0','0'),
('11094','Iodine i-131 sodium iodide solution; diagnostic; per millicurie','I131 iodide sol; dx','A9529','3','','1','0','','','','0','1','0','0'),
('11095','Iodine i-131 sodium iodide solution; therapeutic; per millicurie','I131 iodide sol; rx','A9530','3','','1','0','','','','0','1','0','0'),
('11096','Iodine i-131 sodium iodide; diagnostic; per microcurie (up to 100 microcuries)','I131 max 100uci','A9531','3','','1','0','','','','0','1','0','0'),
('11097','Iodine i-125 serum albumin; diagnostic; per 5 microcuries','I125 serum albumin; dx','A9532','3','','1','0','','','','0','1','0','0'),
('11098','Technetium tc-99m depreotide; diagnostic; per study dose; up to 35 millicuries','Tc99m depreotide','A9536','3','','1','0','','','','0','1','0','0'),
('11099','Technetium tc-99m mebrofenin; diagnostic; per study dose; up to 15 millicuries','Tc99m mebrofenin','A9537','3','','1','0','','','','0','1','0','0'),
('11100','Technetium tc-99m pyrophosphate; diagnostic; per study dose; up to 25 millicuries','Tc99m pyrophosphate','A9538','3','','1','0','','','','0','1','0','0'),
('11101','Technetium tc-99m pentetate; diagnostic; per study dose; up to 25 millicuries','Tc99m pentetate','A9539','3','','1','0','','','','0','1','0','0'),
('11102','Technetium tc-99m macroaggregated albumin; diagnostic; per study dose; up to 10 millicuries','Tc99m maa','A9540','3','','1','0','','','','0','1','0','0'),
('11103','Technetium tc-99m sulfur colloid; diagnostic; per study dose; up to 20 millicuries','Tc99m sulfur colloid','A9541','3','','1','0','','','','0','1','0','0'),
('11104','Indium in-111 ibritumomab tiuxetan; diagnostic; per study dose; up to 5 millicuries','In111 ibritumomab; dx','A9542','3','','1','0','','','','0','1','0','0'),
('11105','Yttrium y-90 ibritumomab tiuxetan; therapeutic; per treatment dose; up to 40 millicuries','Y90 ibritumomab; rx','A9543','3','','1','0','','','','0','1','0','0'),
('11106','Iodine i-131 tositumomab; diagnostic; per study dose','I131 tositumomab; dx','A9544','3','','1','0','','','','0','1','0','0'),
('11107','Iodine i-131 tositumomab; therapeutic; per treatment dose','I131 tositumomab; rx','A9545','3','','1','0','','','','0','1','0','0'),
('11108','Cobalt co-57/58; cyanocobalamin; diagnostic; per study dose; up to 1 microcurie','Co57/58','A9546','3','','1','0','','','','0','1','0','0'),
('11109','Indium in-111 oxyquinoline; diagnostic; per 0.5 millicurie','In111 oxyquinoline','A9547','3','','1','0','','','','0','1','0','0'),
('11110','Indium in-111 pentetate; diagnostic; per 0.5 millicurie','In111 pentetate','A9548','3','','1','0','','','','0','1','0','0'),
('11111','Technetium tc-99m sodium gluceptate; diagnostic; per study dose; up to 25 millicurie','Tc99m gluceptate','A9550','3','','1','0','','','','0','1','0','0'),
('11112','Technetium tc-99m succimer; diagnostic; per study dose; up to 10 millicuries','Tc99m succimer','A9551','3','','1','0','','','','0','1','0','0'),
('11113','Fluorodeoxyglucose f-18 fdg; diagnostic; per study dose; up to 45 millicuries','F18 fdg','A9552','3','','1','0','','','','0','1','0','0'),
('11114','Chromium cr-51 sodium chromate; diagnostic; per study dose; up to 250 microcuries','Cr51 chromate','A9553','3','','1','0','','','','0','1','0','0'),
('11115','Iodine i-125 sodium iothalamate; diagnostic; per study dose; up to 10 microcuries','I125 iothalamate; dx','A9554','3','','1','0','','','','0','1','0','0'),
('11116','Rubidium rb-82; diagnostic; per study dose; up to 60 millicuries','Rb82 rubidium','A9555','3','','1','0','','','','0','1','0','0'),
('11117','Gallium ga-67 citrate; diagnostic; per millicurie','Ga67 gallium','A9556','3','','1','0','','','','0','1','0','0'),
('11118','Technetium tc-99m bicisate; diagnostic; per study dose; up to 25 millicuries','Tc99m bicisate','A9557','3','','1','0','','','','0','1','0','0'),
('11119','Xenon xe-133 gas; diagnostic; per 10 millicuries','Xe133 xenon 10mci','A9558','3','','1','0','','','','0','1','0','0'),
('11120','Cobalt co-57 cyanocobalamin; oral; diagnostic; per study dose; up to 1 microcurie','Co57 cyano','A9559','3','','1','0','','','','0','1','0','0'),
('11121','Technetium tc-99m labeled red blood cells; diagnostic; per study dose; up to 30 millicuries','Tc99m labeled rbc','A9560','3','','1','0','','','','0','1','0','0'),
('11122','Technetium tc-99m oxidronate; diagnostic; per study dose; up to 30 millicuries','Tc99m oxidronate','A9561','3','','1','0','','','','0','1','0','0'),
('11123','Technetium tc-99m mertiatide; diagnostic; per study dose; up to 15 millicuries','Tc99m mertiatide','A9562','3','','1','0','','','','0','1','0','0'),
('11124','Sodium phosphate p-32; therapeutic; per millicurie','P32 na phosphate','A9563','3','','1','0','','','','0','1','0','0'),
('11125','Chromic phosphate p-32 suspension; therapeutic; per millicurie','P32 chromic phosphate','A9564','3','','1','0','','','','0','1','0','0'),
('11126','Technetium tc-99m fanolesomab; diagnostic; per study dose; up to 25 millicuries','Tc99m fanolesomab','A9566','3','','1','0','','','','0','1','0','0'),
('11127','Technetium tc-99m pentetate; diagnostic; aerosol; per study dose; up to 75 millicuries','Technetium tc-99m aerosol','A9567','3','','1','0','','','','0','1','0','0'),
('11128','Technetium tc-99m arcitumomab; diagnostic; per study dose; up to 45 millicuries','Technetium tc99m arcitumomab','A9568','3','','1','0','','','','0','1','0','0'),
('11129','Technetium tc-99m exametazime labeled autologous white blood cells; diagnostic; per study dose','Technetium tc-99m auto wbc','A9569','3','','1','0','','','','0','1','0','0'),
('11130','Indium in-111 labeled autologous white blood cells; diagnostic; per study dose','Indium in-111 auto wbc','A9570','3','','1','0','','','','0','1','0','0'),
('11131','Indium in-111 labeled autologous platelets; diagnostic; per study dose','Indium in-111 auto platelet','A9571','3','','1','0','','','','0','1','0','0'),
('11132','Indium in-111 pentetreotide; diagnostic; per study dose; up to 6 millicuries','Indium in-111 pentetreotide','A9572','3','','1','0','','','','0','1','0','0'),
('11133','Injection; gadoterate meglumine; 0.1 ml','Inj gadoterate meglumi 0.1ml','A9575','3','','1','0','','','','0','1','0','0'),
('11134','Injection; gadoteridol; (prohance multipack); per ml','Inj prohance multipack','A9576','3','','1','0','','','','0','1','0','0'),
('11135','Injection; gadobenate dimeglumine (multihance); per ml','Inj multihance','A9577','3','','1','0','','','','0','1','0','0'),
('11136','Injection; gadobenate dimeglumine (multihance multipack); per ml','Inj multihance multipack','A9578','3','','1','0','','','','0','1','0','0'),
('11137','Injection; gadolinium-based magnetic resonance contrast agent; not otherwise specified (nos); per ml','Gad-base mr contrast nos;1ml','A9579','3','','1','0','','','','0','1','0','0'),
('11138','Sodium fluoride f-18; diagnostic; per study dose; up to 30 millicuries','Sodium fluoride f-18','A9580','3','','1','0','','','','0','1','0','0'),
('11139','Injection; gadoxetate disodium; 1 ml','Gadoxetate disodium inj','A9581','3','','1','0','','','','0','1','0','0'),
('11140','Iodine i-123 iobenguane; diagnostic; per study dose; up to 15 millicuries','Iodine i-123 iobenguane','A9582','3','','1','0','','','','0','1','0','0'),
('11141','Injection; gadofosveset trisodium; 1 ml','Gadofosveset trisodium inj','A9583','3','','1','0','','','','0','1','0','0'),
('11142','Iodine 1-123 ioflupane; diagnostic; per study dose; up to 5 millicuries','Iodine i-123 ioflupane','A9584','3','','1','0','','','','0','1','0','0'),
('11143','Injection; gadobutrol; 0.1 ml','Gadobutrol injection','A9585','3','','1','0','','','','0','1','0','0'),
('11144','Florbetapir f18; diagnostic; per study dose; up to 10 millicuries','Florbetapir f18','A9586','3','','1','0','','','','0','1','0','0'),
('11145','Gallium ga-68; dotatate; diagnostic; 0.1 millicurie','Gallium ga-68','A9587','3','','1','0','','','','0','1','0','0'),
('11146','Fluciclovine f-18; diagnostic; 1 millicurie','Fluciclovine f-18','A9588','3','','1','0','','','','0','1','0','0'),
('11147','Positron emission tomography radiopharmaceutical; diagnostic; for tumor identification; not otherwise classified','Pet; dx; for tumor id; noc','A9597','3','','1','0','','','','0','1','0','0'),
('11148','Positron emission tomography radiopharmaceutical; diagnostic; for non-tumor identification; not otherwise classified','Pet dx for non-tumor id; noc','A9598','3','','1','0','','','','0','1','0','0'),
('11149','Radiopharmaceutical; diagnostic; for beta-amyloid positron emission tomography (pet) imaging; per study dose; not otherwise specified','Radioph dx b amyloid pet nos','A9599','3','','1','0','','','','0','1','0','0'),
('11150','Strontium sr-89 chloride; therapeutic; per millicurie','Sr89 strontium','A9600','3','','1','0','','','','0','1','0','0'),
('11151','Samarium sm-153 lexidronam; therapeutic; per treatment dose; up to 150 millicuries','Sm 153 lexidronam','A9604','3','','1','0','','','','0','1','0','0'),
('11152','Radium ra-223 dichloride; therapeutic; per microcurie','Radium ra223 dichloride ther','A9606','3','','1','0','','','','0','1','0','0'),
('11153','Non-radioactive contrast imaging material; not otherwise classified; per study','Non-rad contrast materialnoc','A9698','3','','1','0','','','','0','1','0','0'),
('11154','Radiopharmaceutical; therapeutic; not otherwise classified','Radiopharm rx agent noc','A9699','3','','1','0','','','','0','1','0','0'),
('11155','Supply of injectable contrast material for use in echocardiography; per study','Echocardiography contrast','A9700','3','','1','0','','','','0','1','0','0'),
('11156','Miscellaneous dme supply; accessory; and/or service component of another hcpcs code','Supply/accessory/service','A9900','3','','1','0','','','','0','1','0','0'),
('11157','Dme delivery; set up; and/or dispensing service component of another hcpcs code','Delivery/set up/dispensing','A9901','3','','1','0','','','','0','1','0','0'),
('11158','Miscellaneous dme supply or accessory; not otherwise specified','Dme supply or accessory; nos','A9999','3','','1','0','','','','0','1','0','0'),
('11159','Enteral feeding supply kit; syringe fed; per day; includes but not limited to feeding/flushing syringe; administration set tubing; dressings; tape','Enter feed supkit syr by day','B4034','3','','1','0','','','','0','1','0','0'),
('11160','Enteral feeding supply kit; pump fed; per day; includes but not limited to feeding/flushing syringe; administration set tubing; dressings; tape','Enteral feed supp pump per d','B4035','3','','1','0','','','','0','1','0','0'),
('11161','Enteral feeding supply kit; gravity fed; per day; includes but not limited to feeding/flushing syringe; administration set tubing; dressings; tape','Enteral feed sup kit grav by','B4036','3','','1','0','','','','0','1','0','0'),
('11162','Nasogastric tubing with stylet','Enteral ng tubing w/ stylet','B4081','3','','1','0','','','','0','1','0','0'),
('11163','Nasogastric tubing without stylet','Enteral ng tubing w/o stylet','B4082','3','','1','0','','','','0','1','0','0'),
('11164','Stomach tube - levine type','Enteral stomach tube levine','B4083','3','','1','0','','','','0','1','0','0'),
('11165','Gastrostomy/jejunostomy tube; standard; any material; any type; each','Gastro/jejuno tube; std','B4087','3','','1','0','','','','0','1','0','0'),
('11166','Gastrostomy/jejunostomy tube; low-profile; any material; any type; each','Gastro/jejuno tube; low-pro','B4088','3','','1','0','','','','0','1','0','0'),
('11167','Food thickener; administered orally; per ounce','Food thickener oral','B4100','3','','1','0','','','','0','1','0','0'),
('11168','Enteral formula; for adults; used to replace fluids and electrolytes (e.g.; clear liquids); 500 ml = 1 unit','Ef adult fluids and electro','B4102','3','','1','0','','','','0','1','0','0'),
('11169','Enteral formula; for pediatrics; used to replace fluids and electrolytes (e.g.; clear liquids); 500 ml = 1 unit','Ef ped fluid and electrolyte','B4103','3','','1','0','','','','0','1','0','0'),
('11170','Additive for enteral formula (e.g.; fiber)','Additive for enteral formula','B4104','3','','1','0','','','','0','1','0','0'),
('11171','Enteral formula; manufactured blenderized natural foods with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef blenderized foods','B4149','3','','1','0','','','','0','1','0','0'),
('11172','Enteral formula; nutritionally complete with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef complet w/intact nutrient','B4150','3','','1','0','','','','0','1','0','0'),
('11173','Enteral formula; nutritionally complete; calorically dense (equal to or greater than 1.5 kcal/ml) with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef calorie dense>/=1.5kcal','B4152','3','','1','0','','','','0','1','0','0'),
('11174','Enteral formula; nutritionally complete; hydrolyzed proteins (amino acids and peptide chain); includes fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef hydrolyzed/amino acids','B4153','3','','1','0','','','','0','1','0','0'),
('11175','Enteral formula; nutritionally complete; for special metabolic needs; excludes inherited disease of metabolism; includes altered composition of proteins; fats; carbohydrates; vitamins and/or minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef spec metabolic noninherit','B4154','3','','1','0','','','','0','1','0','0'),
('11176','Enteral formula; nutritionally incomplete/modular nutrients; includes specific nutrients; carbohydrates (e.g.; glucose polymers); proteins/amino acids (e.g.; glutamine; arginine); fat (e.g.; medium chain triglycerides) or combination; administered through an enteral feeding tube; 100 calories = 1 unit','Ef incomplete/modular','B4155','3','','1','0','','','','0','1','0','0'),
('11177','Enteral formula; nutritionally complete; for special metabolic needs for inherited disease of metabolism; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef special metabolic inherit','B4157','3','','1','0','','','','0','1','0','0'),
('11178','Enteral formula; for pediatrics; nutritionally complete with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber and/or iron; administered through an enteral feeding tube; 100 calories = 1 unit','Ef ped complete intact nut','B4158','3','','1','0','','','','0','1','0','0'),
('11179','Enteral formula; for pediatrics; nutritionally complete soy based with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber and/or iron; administered through an enteral feeding tube; 100 calories = 1 unit','Ef ped complete soy based','B4159','3','','1','0','','','','0','1','0','0'),
('11180','Enteral formula; for pediatrics; nutritionally complete calorically dense (equal to or greater than 0.7 kcal/ml) with intact nutrients; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef ped caloric dense>/=0.7kc','B4160','3','','1','0','','','','0','1','0','0'),
('11181','Enteral formula; for pediatrics; hydrolyzed/amino acids and peptide chain proteins; includes fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef ped hydrolyzed/amino acid','B4161','3','','1','0','','','','0','1','0','0'),
('11182','Enteral formula; for pediatrics; special metabolic needs for inherited disease of metabolism; includes proteins; fats; carbohydrates; vitamins and minerals; may include fiber; administered through an enteral feeding tube; 100 calories = 1 unit','Ef ped specmetabolic inherit','B4162','3','','1','0','','','','0','1','0','0'),
('11183','Parenteral nutrition solution: carbohydrates (dextrose); 50% or less (500 ml = 1 unit) - home mix','Parenteral 50% dextrose solu','B4164','3','','1','0','','','','0','1','0','0'),
('11184','Parenteral nutrition solution; amino acid; 3.5%; (500 ml = 1 unit) - home mix','Parenteral sol amino acid 3.','B4168','3','','1','0','','','','0','1','0','0'),
('11185','Parenteral nutrition solution; amino acid; 5.5% through 7%; (500 ml = 1 unit) - home mix','Parenteral sol amino acid 5.','B4172','3','','1','0','','','','0','1','0','0'),
('11186','Parenteral nutrition solution; amino acid; 7% through 8.5%; (500 ml = 1 unit) - home mix','Parenteral sol amino acid 7-','B4176','3','','1','0','','','','0','1','0','0'),
('11187','Parenteral nutrition solution: amino acid; greater than 8.5% (500 ml = 1 unit) - home mix','Parenteral sol amino acid >','B4178','3','','1','0','','','','0','1','0','0'),
('11188','Parenteral nutrition solution; carbohydrates (dextrose); greater than 50% (500 ml = 1 unit) - home mix','Parenteral sol carb > 50%','B4180','3','','1','0','','','','0','1','0','0'),
('11189','Parenteral nutrition solution; per 10 grams lipids','Parenteral sol 10 gm lipids','B4185','3','','1','0','','','','0','1','0','0'),
('11190','Parenteral nutrition solution; compounded amino acid and carbohydrates with electrolytes; trace elements; and vitamins; including preparation; any strength; 10 to 51 grams of protein - premix','Parenteral sol amino acid &','B4189','3','','1','0','','','','0','1','0','0'),
('11191','Parenteral nutrition solution; compounded amino acid and carbohydrates with electrolytes; trace elements; and vitamins; including preparation; any strength; 52 to 73 grams of protein - premix','Parenteral sol 52-73 gm prot','B4193','3','','1','0','','','','0','1','0','0'),
('11192','Parenteral nutrition solution; compounded amino acid and carbohydrates with electrolytes; trace elements and vitamins; including preparation; any strength; 74 to 100 grams of protein - premix','Parenteral sol 74-100 gm pro','B4197','3','','1','0','','','','0','1','0','0'),
('11193','Parenteral nutrition solution; compounded amino acid and carbohydrates with electrolytes; trace elements and vitamins; including preparation; any strength; over 100 grams of protein - premix','Parenteral sol > 100gm prote','B4199','3','','1','0','','','','0','1','0','0'),
('11194','Parenteral nutrition; additives (vitamins; trace elements; heparin; electrolytes); home mix; per day','Parenteral nutrition additiv','B4216','3','','1','0','','','','0','1','0','0'),
('11195','Parenteral nutrition supply kit; premix; per day','Parenteral supply kit premix','B4220','3','','1','0','','','','0','1','0','0'),
('11196','Parenteral nutrition supply kit; home mix; per day','Parenteral supply kit homemi','B4222','3','','1','0','','','','0','1','0','0'),
('11197','Parenteral nutrition administration kit; per day','Parenteral administration ki','B4224','3','','1','0','','','','0','1','0','0'),
('11198','Parenteral nutrition solution compounded amino acid and carbohydrates with electrolytes; trace elements; and vitamins; including preparation; any strength; renal-aminosyn-rf; nephramine; renamine-premix','Parenteral sol renal-amirosy','B5000','3','','1','0','','','','0','1','0','0'),
('11199','Parenteral nutrition solution compounded amino acid and carbohydrates with electrolytes; trace elements; and vitamins; including preparation; any strength; hepatic; hepatamine-premix','Parenteral solution hepatic','B5100','3','','1','0','','','','0','1','0','0'),
('11200','Parenteral nutrition solution compounded amino acid and carbohydrates with electrolytes; trace elements; and vitamins; including preparation; any strength; stress-branch chain amino acids-freamine-hbc-premix','Parenteral sol hepatic fream','B5200','3','','1','0','','','','0','1','0','0'),
('11201','Enteral nutrition infusion pump - without alarm','Enter infusion pump w/o alrm','B9000','3','','1','0','','','','0','1','0','0'),
('11202','Enteral nutrition infusion pump; any type','Enter nutr inf pump any type','B9002','3','','1','0','','','','0','1','0','0'),
('11203','Parenteral nutrition infusion pump; portable','Parenteral infus pump portab','B9004','3','','1','0','','','','0','1','0','0'),
('11204','Parenteral nutrition infusion pump; stationary','Parenteral infus pump statio','B9006','3','','1','0','','','','0','1','0','0'),
('11205','Noc for enteral supplies','Enteral supp not otherwise c','B9998','3','','1','0','','','','0','1','0','0'),
('11206','Noc for parenteral supplies','Parenteral supp not othrws c','B9999','3','','1','0','','','','0','1','0','0'),
('11207','Technetium tc 99m tilmanocept; diagnostic; up to 0.5 millicuries','Tc 99m tilmanocept','C1204','3','','1','0','','','','0','1','0','0'),
('11208','Hyperbaric oxygen under pressure; full body chamber; per 30 minute interval','Hyperbaric oxygen','C1300','3','','1','0','','','','0','1','0','0'),
('11209','Anchor/screw for opposing bone-to-bone or soft tissue-to-bone (implantable)','Anchor/screw bn/bn;tis/bn','C1713','3','','1','0','','','','0','1','0','0'),
('11210','Catheter; transluminal atherectomy; directional','Cath; trans atherectomy; dir','C1714','3','','1','0','','','','0','1','0','0'),
('11211','Brachytherapy needle','Brachytherapy needle','C1715','3','','1','0','','','','0','1','0','0'),
('11212','Brachytherapy source; non-stranded; gold-198; per source','Brachytx; non-str; gold-198','C1716','3','','1','0','','','','0','1','0','0'),
('11213','Brachytherapy source; non-stranded; high dose rate iridium-192; per source','Brachytx; non-str;hdr ir-192','C1717','3','','1','0','','','','0','1','0','0'),
('11214','Brachytherapy source; non-stranded; non-high dose rate iridium-192; per source','Brachytx; ns; non-hdrir-192','C1719','3','','1','0','','','','0','1','0','0'),
('11215','Cardioverter-defibrillator; dual chamber (implantable)','Aicd; dual chamber','C1721','3','','1','0','','','','0','1','0','0'),
('11216','Cardioverter-defibrillator; single chamber (implantable)','Aicd; single chamber','C1722','3','','1','0','','','','0','1','0','0'),
('11217','Catheter; transluminal atherectomy; rotational','Cath; trans atherec;rotation','C1724','3','','1','0','','','','0','1','0','0'),
('11218','Catheter; transluminal angioplasty; non-laser (may include guidance; infusion/perfusion capability)','Cath; translumin non-laser','C1725','3','','1','0','','','','0','1','0','0'),
('11219','Catheter; balloon dilatation; non-vascular','Cath; bal dil; non-vascular','C1726','3','','1','0','','','','0','1','0','0'),
('11220','Catheter; balloon tissue dissector; non-vascular (insertable)','Cath; bal tis dis; non-vas','C1727','3','','1','0','','','','0','1','0','0'),
('11221','Catheter; brachytherapy seed administration','Cath; brachytx seed adm','C1728','3','','1','0','','','','0','1','0','0'),
('11222','Catheter; drainage','Cath; drainage','C1729','3','','1','0','','','','0','1','0','0'),
('11223','Catheter; electrophysiology; diagnostic; other than 3d mapping (19 or fewer electrodes)','Cath; ep; 19 or few elect','C1730','3','','1','0','','','','0','1','0','0'),
('11224','Catheter; electrophysiology; diagnostic; other than 3d mapping (20 or more electrodes)','Cath; ep; 20 or more elec','C1731','3','','1','0','','','','0','1','0','0'),
('11225','Catheter; electrophysiology; diagnostic/ablation; 3d or vector mapping','Cath; ep; diag/abl; 3d/vect','C1732','3','','1','0','','','','0','1','0','0'),
('11226','Catheter; electrophysiology; diagnostic/ablation; other than 3d or vector mapping; other than cool-tip','Cath; ep; othr than cool-tip','C1733','3','','1','0','','','','0','1','0','0'),
('11227','Endoscope; retrograde imaging/illumination colonoscope device (implantable)','Endo; colon; retro imaging','C1749','3','','1','0','','','','0','1','0','0'),
('11228','Catheter; hemodialysis/peritoneal; long-term','Cath; hemodialysis;long-term','C1750','3','','1','0','','','','0','1','0','0'),
('11229','Catheter; infusion; inserted peripherally; centrally or midline (other than hemodialysis)','Cath; inf; per/cent/midline','C1751','3','','1','0','','','','0','1','0','0'),
('11230','Catheter; hemodialysis/peritoneal; short-term','Cath;hemodialysis;short-term','C1752','3','','1','0','','','','0','1','0','0'),
('11231','Catheter; intravascular ultrasound','Cath; intravas ultrasound','C1753','3','','1','0','','','','0','1','0','0'),
('11232','Catheter; intradiscal','Catheter; intradiscal','C1754','3','','1','0','','','','0','1','0','0'),
('11233','Catheter; intraspinal','Catheter; intraspinal','C1755','3','','1','0','','','','0','1','0','0'),
('11234','Catheter; pacing; transesophageal','Cath; pacing; transesoph','C1756','3','','1','0','','','','0','1','0','0'),
('11235','Catheter; thrombectomy/embolectomy','Cath; thrombectomy/embolect','C1757','3','','1','0','','','','0','1','0','0'),
('11236','Catheter; ureteral','Catheter; ureteral','C1758','3','','1','0','','','','0','1','0','0'),
('11237','Catheter; intracardiac echocardiography','Cath; intra echocardiography','C1759','3','','1','0','','','','0','1','0','0'),
('11238','Closure device; vascular (implantable/insertable)','Closure dev; vasc','C1760','3','','1','0','','','','0','1','0','0'),
('11239','Connective tissue; human (includes fascia lata)','Conn tiss; human(inc fascia)','C1762','3','','1','0','','','','0','1','0','0'),
('11240','Connective tissue; non-human (includes synthetic)','Conn tiss; non-human','C1763','3','','1','0','','','','0','1','0','0'),
('11241','Event recorder; cardiac (implantable)','Event recorder; cardiac','C1764','3','','1','0','','','','0','1','0','0'),
('11242','Adhesion barrier','Adhesion barrier','C1765','3','','1','0','','','','0','1','0','0'),
('11243','Introducer/sheath; guiding; intracardiac electrophysiological; steerable; other than peel-away','Intro/sheath;strble;non-peel','C1766','3','','1','0','','','','0','1','0','0'),
('11244','Generator; neurostimulator (implantable); non-rechargeable','Generator; neuro non-recharg','C1767','3','','1','0','','','','0','1','0','0'),
('11245','Graft; vascular','Graft; vascular','C1768','3','','1','0','','','','0','1','0','0'),
('11246','Guide wire','Guide wire','C1769','3','','1','0','','','','0','1','0','0'),
('11247','Imaging coil; magnetic resonance (insertable)','Imaging coil; mr; insertable','C1770','3','','1','0','','','','0','1','0','0'),
('11248','Repair device; urinary; incontinence; with sling graft','Rep dev; urinary; w/sling','C1771','3','','1','0','','','','0','1','0','0'),
('11249','Infusion pump; programmable (implantable)','Infusion pump; programmable','C1772','3','','1','0','','','','0','1','0','0'),
('11250','Retrieval device; insertable (used to retrieve fractured medical devices)','Ret dev; insertable','C1773','3','','1','0','','','','0','1','0','0'),
('11251','Joint device (implantable)','Joint device (implantable)','C1776','3','','1','0','','','','0','1','0','0'),
('11252','Lead; cardioverter-defibrillator; endocardial single coil (implantable)','Lead; aicd; endo single coil','C1777','3','','1','0','','','','0','1','0','0'),
('11253','Lead; neurostimulator (implantable)','Lead; neurostimulator','C1778','3','','1','0','','','','0','1','0','0'),
('11254','Lead; pacemaker; transvenous vdd single pass','Lead; pmkr; transvenous vdd','C1779','3','','1','0','','','','0','1','0','0'),
('11255','Lens; intraocular (new technology)','Lens; intraocular (new tech)','C1780','3','','1','0','','','','0','1','0','0'),
('11256','Mesh (implantable)','Mesh (implantable)','C1781','3','','1','0','','','','0','1','0','0'),
('11257','Morcellator','Morcellator','C1782','3','','1','0','','','','0','1','0','0'),
('11258','Ocular implant; aqueous drainage assist device','Ocular imp; aqueous drain de','C1783','3','','1','0','','','','0','1','0','0'),
('11259','Ocular device; intraoperative; detached retina','Ocular dev; intraop; det ret','C1784','3','','1','0','','','','0','1','0','0'),
('11260','Pacemaker; dual chamber; rate-responsive (implantable)','Pmkr; dual; rate-resp','C1785','3','','1','0','','','','0','1','0','0'),
('11261','Pacemaker; single chamber; rate-responsive (implantable)','Pmkr; single; rate-resp','C1786','3','','1','0','','','','0','1','0','0'),
('11262','Patient programmer; neurostimulator','Patient progr; neurostim','C1787','3','','1','0','','','','0','1','0','0'),
('11263','Port; indwelling (implantable)','Port; indwelling; imp','C1788','3','','1','0','','','','0','1','0','0'),
('11264','Prosthesis; breast (implantable)','Prosthesis; breast; imp','C1789','3','','1','0','','','','0','1','0','0'),
('11265','Prosthesis; penile; inflatable','Prosthesis; penile; inflatab','C1813','3','','1','0','','','','0','1','0','0'),
('11266','Retinal tamponade device; silicone oil','Retinal tamp; silicone oil','C1814','3','','1','0','','','','0','1','0','0'),
('11267','Prosthesis; urinary sphincter (implantable)','Pros; urinary sph; imp','C1815','3','','1','0','','','','0','1','0','0'),
('11268','Receiver and/or transmitter; neurostimulator (implantable)','Receiver/transmitter; neuro','C1816','3','','1','0','','','','0','1','0','0'),
('11269','Septal defect implant system; intracardiac','Septal defect imp sys','C1817','3','','1','0','','','','0','1','0','0'),
('11270','Integrated keratoprosthesis','Integrated keratoprosthesis','C1818','3','','1','0','','','','0','1','0','0'),
('11271','Surgical tissue localization and excision device (implantable)','Tissue localization-excision','C1819','3','','1','0','','','','0','1','0','0'),
('11272','Generator; neurostimulator (implantable); with rechargeable battery and charging system','Generator neuro rechg bat sy','C1820','3','','1','0','','','','0','1','0','0'),
('11273','Interspinous process distraction device (implantable)','Interspinous implant','C1821','3','','1','0','','','','0','1','0','0'),
('11274','Generator; neurostimulator (implantable); high frequency; with rechargeable battery and charging system','Gen; neuro; hf; rechg bat','C1822','3','','1','0','','','','0','1','0','0'),
('11275','Powered bone marrow biopsy needle','Power bone marrow bx needle','C1830','3','','1','0','','','','0','1','0','0'),
('11276','Lens; intraocular (telescopic)','Telescopic intraocular lens','C1840','3','','1','0','','','','0','1','0','0'),
('11277','Retinal prosthesis; includes all internal and external components','Retinal prosth int/ext comp','C1841','3','','1','0','','','','0','1','0','0'),
('11278','Stent; coated/covered; with delivery system','Stent; coated/cov w/del sys','C1874','3','','1','0','','','','0','1','0','0'),
('11279','Stent; coated/covered; without delivery system','Stent; coated/cov w/o del sy','C1875','3','','1','0','','','','0','1','0','0'),
('11280','Stent; non-coated/non-covered; with delivery system','Stent; non-coa/non-cov w/del','C1876','3','','1','0','','','','0','1','0','0'),
('11281','Stent; non-coated/non-covered; without delivery system','Stent; non-coat/cov w/o del','C1877','3','','1','0','','','','0','1','0','0'),
('11282','Material for vocal cord medialization; synthetic (implantable)','Matrl for vocal cord','C1878','3','','1','0','','','','0','1','0','0'),
('11283','Tissue marker (implantable)','Tissue marker; implantable','C1879','3','','1','0','','','','0','1','0','0'),
('11284','Vena cava filter','Vena cava filter','C1880','3','','1','0','','','','0','1','0','0'),
('11285','Dialysis access system (implantable)','Dialysis access system','C1881','3','','1','0','','','','0','1','0','0'),
('11286','Cardioverter-defibrillator; other than single or dual chamber (implantable)','Aicd; other than sing/dual','C1882','3','','1','0','','','','0','1','0','0'),
('11287','Adapter/extension; pacing lead or neurostimulator lead (implantable)','Adapt/ext; pacing/neuro lead','C1883','3','','1','0','','','','0','1','0','0'),
('11288','Embolization protective system','Embolization protect syst','C1884','3','','1','0','','','','0','1','0','0'),
('11289','Catheter; transluminal angioplasty; laser','Cath; translumin angio laser','C1885','3','','1','0','','','','0','1','0','0'),
('11290','Catheter; extravascular tissue ablation; any modality (insertable)','Catheter; ablation','C1886','3','','1','0','','','','0','1','0','0'),
('11291','Catheter; guiding (may include infusion/perfusion capability)','Catheter; guiding','C1887','3','','1','0','','','','0','1','0','0'),
('11292','Catheter; ablation; non-cardiac; endovascular (implantable)','Endovas non-cardiac abl cath','C1888','3','','1','0','','','','0','1','0','0'),
('11293','Implantable/insertable device for device intensive procedure; not otherwise classified','Implant/insert device; noc','C1889','3','','1','0','','','','0','1','0','0'),
('11294','Infusion pump; non-programmable; permanent (implantable)','Infusion pump;non-prog; perm','C1891','3','','1','0','','','','0','1','0','0'),
('11295','Introducer/sheath; guiding; intracardiac electrophysiological; fixed-curve; peel-away','Intro/sheath;fixed;peel-away','C1892','3','','1','0','','','','0','1','0','0'),
('11296','Introducer/sheath; guiding; intracardiac electrophysiological; fixed-curve; other than peel-away','Intro/sheath; fixed;non-peel','C1893','3','','1','0','','','','0','1','0','0'),
('11297','Introducer/sheath; other than guiding; other than intracardiac electrophysiological; non-laser','Intro/sheath; non-laser','C1894','3','','1','0','','','','0','1','0','0'),
('11298','Lead; cardioverter-defibrillator; endocardial dual coil (implantable)','Lead; aicd; endo dual coil','C1895','3','','1','0','','','','0','1','0','0'),
('11299','Lead; cardioverter-defibrillator; other than endocardial single or dual coil (implantable)','Lead; aicd; non sing/dual','C1896','3','','1','0','','','','0','1','0','0'),
('11300','Lead; neurostimulator test kit (implantable)','Lead; neurostim test kit','C1897','3','','1','0','','','','0','1','0','0'),
('11301','Lead; pacemaker; other than transvenous vdd single pass','Lead; pmkr; other than trans','C1898','3','','1','0','','','','0','1','0','0'),
('11302','Lead; pacemaker/cardioverter-defibrillator combination (implantable)','Lead; pmkr/aicd combination','C1899','3','','1','0','','','','0','1','0','0'),
('11303','Lead; left ventricular coronary venous system','Lead; coronary venous','C1900','3','','1','0','','','','0','1','0','0'),
('11304','Lung biopsy plug with delivery system','Lung bx plug w/del sys','C2613','3','','1','0','','','','0','1','0','0'),
('11305','Probe; percutaneous lumbar discectomy','Probe; perc lumb disc','C2614','3','','1','0','','','','0','1','0','0'),
('11306','Sealant; pulmonary; liquid','Sealant; pulmonary; liquid','C2615','3','','1','0','','','','0','1','0','0'),
('11307','Brachytherapy source; non-stranded; yttrium-90; per source','Brachytx; non-str;yttrium-90','C2616','3','','1','0','','','','0','1','0','0'),
('11308','Stent; non-coronary; temporary; without delivery system','Stent; non-cor; tem w/o del','C2617','3','','1','0','','','','0','1','0','0'),
('11309','Probe/needle; cryoablation','Probe/needle; cryo','C2618','3','','1','0','','','','0','1','0','0'),
('11310','Pacemaker; dual chamber; non rate-responsive (implantable)','Pmkr; dual; non rate-resp','C2619','3','','1','0','','','','0','1','0','0'),
('11311','Pacemaker; single chamber; non rate-responsive (implantable)','Pmkr; single; non rate-resp','C2620','3','','1','0','','','','0','1','0','0'),
('11312','Pacemaker; other than single or dual chamber (implantable)','Pmkr; other than sing/dual','C2621','3','','1','0','','','','0','1','0','0'),
('11313','Prosthesis; penile; non-inflatable','Prosthesis; penile; non-inf','C2622','3','','1','0','','','','0','1','0','0'),
('11314','Catheter; transluminal angioplasty; drug-coated; non-laser','Cath; translumin; drug-coat','C2623','3','','1','0','','','','0','1','0','0'),
('11315','Implantable wireless pulmonary artery pressure sensor with delivery catheter; including all system components','Wireless pressure sensor','C2624','3','','1','0','','','','0','1','0','0'),
('11316','Stent; non-coronary; temporary; with delivery system','Stent; non-cor; tem w/del sy','C2625','3','','1','0','','','','0','1','0','0'),
('11317','Infusion pump; non-programmable; temporary (implantable)','Infusion pump; non-prog;temp','C2626','3','','1','0','','','','0','1','0','0'),
('11318','Catheter; suprapubic/cystoscopic','Cath; suprapubic/cystoscopic','C2627','3','','1','0','','','','0','1','0','0'),
('11319','Catheter; occlusion','Catheter; occlusion','C2628','3','','1','0','','','','0','1','0','0'),
('11320','Introducer/sheath; other than guiding; other than intracardiac electrophysiological; laser','Intro/sheath; laser','C2629','3','','1','0','','','','0','1','0','0'),
('11321','Catheter; electrophysiology; diagnostic/ablation; other than 3d or vector mapping; cool-tip','Cath; ep; cool-tip','C2630','3','','1','0','','','','0','1','0','0'),
('11322','Repair device; urinary; incontinence; without sling graft','Rep dev; urinary; w/o sling','C2631','3','','1','0','','','','0','1','0','0'),
('11323','Brachytherapy source; non-stranded; high activity; iodine-125; greater than 1.01 mci (nist); per source','Brachytx; non-str; ha; i-125','C2634','3','','1','0','','','','0','1','0','0'),
('11324','Brachytherapy source; non-stranded; high activity; palladium-103; greater than 2.2 mci (nist); per source','Brachytx; non-str; ha; p-103','C2635','3','','1','0','','','','0','1','0','0'),
('11325','Brachytherapy linear source; non-stranded; palladium-103; per 1 mm','Brachy linear; non-str;p-103','C2636','3','','1','0','','','','0','1','0','0'),
('11326','Brachytherapy source; non-stranded; ytterbium-169; per source','Brachy;non-str;ytterbium-169','C2637','3','','1','0','','','','0','1','0','0'),
('11327','Brachytherapy source; stranded; iodine-125; per source','Brachytx; stranded; i-125','C2638','3','','1','0','','','','0','1','0','0'),
('11328','Brachytherapy source; non-stranded; iodine-125; per source','Brachytx; non-stranded;i-125','C2639','3','','1','0','','','','0','1','0','0'),
('11329','Brachytherapy source; stranded; palladium-103; per source','Brachytx; stranded; p-103','C2640','3','','1','0','','','','0','1','0','0'),
('11330','Brachytherapy source; non-stranded; palladium-103; per source','Brachytx; non-stranded;p-103','C2641','3','','1','0','','','','0','1','0','0'),
('11331','Brachytherapy source; stranded; cesium-131; per source','Brachytx; stranded; c-131','C2642','3','','1','0','','','','0','1','0','0'),
('11332','Brachytherapy source; non-stranded; cesium-131; per source','Brachytx; non-stranded;c-131','C2643','3','','1','0','','','','0','1','0','0'),
('11333','Brachytherapy source; cesium-131 chloride solution; per millicurie','Brachytx cesium-131 chloride','C2644','3','','1','0','','','','0','1','0','0'),
('11334','Brachytherapy planar source; palladium-103; per square millimeter','Brachytx planar; p-103','C2645','3','','1','0','','','','0','1','0','0'),
('11335','Brachytherapy source; stranded; not otherwise specified; per source','Brachytx; stranded; nos','C2698','3','','1','0','','','','0','1','0','0'),
('11336','Brachytherapy source; non-stranded; not otherwise specified; per source','Brachytx; non-stranded; nos','C2699','3','','1','0','','','','0','1','0','0'),
('11337','Application of low cost skin substitute graft to trunk; arms; legs; total wound surface area up to 100 sq cm; first 25 sq cm or less wound surface area','Low cost skin substitute app','C5271','3','','1','0','','','','0','1','0','0'),
('11338','Application of low cost skin substitute graft to trunk; arms; legs; total wound surface area up to 100 sq cm; each additional 25 sq cm wound surface area; or part thereof (list separately in addition to code for primary procedure)','Low cost skin substitute app','C5272','3','','1','0','','','','0','1','0','0'),
('11339','Application of low cost skin substitute graft to trunk; arms; legs; total wound surface area greater than or equal to 100 sq cm; first 100 sq cm wound surface area; or 1% of body area of infants and children','Low cost skin substitute app','C5273','3','','1','0','','','','0','1','0','0'),
('11340','Application of low cost skin substitute graft to trunk; arms; legs; total wound surface area greater than or equal to 100 sq cm; each additional 100 sq cm wound surface area; or part thereof; or each additional 1% of body area of infants and children; or part thereof (list separately in addition to code for primary procedure)','Low cost skin substitute app','C5274','3','','1','0','','','','0','1','0','0'),
('11341','Application of low cost skin substitute graft to face; scalp; eyelids; mouth; neck; ears; orbits; genitalia; hands; feet; and/or multiple digits; total wound surface area up to 100 sq cm; first 25 sq cm or less wound surface area','Low cost skin substitute app','C5275','3','','1','0','','','','0','1','0','0'),
('11342','Application of low cost skin substitute graft to face; scalp; eyelids; mouth; neck; ears; orbits; genitalia; hands; feet; and/or multiple digits; total wound surface area up to 100 sq cm; each additional 25 sq cm wound surface area; or part thereof (list separately in addition to code for primary procedure)','Low cost skin substitute app','C5276','3','','1','0','','','','0','1','0','0'),
('11343','Application of low cost skin substitute graft to face; scalp; eyelids; mouth; neck; ears; orbits; genitalia; hands; feet; and/or multiple digits; total wound surface area greater than or equal to 100 sq cm; first 100 sq cm wound surface area; or 1% of body area of infants and children','Low cost skin substitute app','C5277','3','','1','0','','','','0','1','0','0'),
('11344','Application of low cost skin substitute graft to face; scalp; eyelids; mouth; neck; ears; orbits; genitalia; hands; feet; and/or multiple digits; total wound surface area greater than or equal to 100 sq cm; each additional 100 sq cm wound surface area; or part thereof; or each additional 1% of body area of infants and children; or part thereof (list separately in addition to code for primary procedure)','Low cost skin substitute app','C5278','3','','1','0','','','','0','1','0','0'),
('11345','Magnetic resonance angiography with contrast; abdomen','Mra w/cont; abd','C8900','3','','1','0','','','','0','1','0','0'),
('11346','Magnetic resonance angiography without contrast; abdomen','Mra w/o cont; abd','C8901','3','','1','0','','','','0','1','0','0'),
('11347','Magnetic resonance angiography without contrast followed by with contrast; abdomen','Mra w/o fol w/cont; abd','C8902','3','','1','0','','','','0','1','0','0'),
('11348','Magnetic resonance imaging with contrast; breast; unilateral','Mri w/cont; breast;  uni','C8903','3','','1','0','','','','0','1','0','0'),
('11349','Magnetic resonance imaging without contrast; breast; unilateral','Mri w/o cont; breast; uni','C8904','3','','1','0','','','','0','1','0','0'),
('11350','Magnetic resonance imaging without contrast followed by with contrast; breast; unilateral','Mri w/o fol w/cont; brst; un','C8905','3','','1','0','','','','0','1','0','0'),
('11351','Magnetic resonance imaging with contrast; breast; bilateral','Mri w/cont; breast;  bi','C8906','3','','1','0','','','','0','1','0','0'),
('11352','Magnetic resonance imaging without contrast; breast; bilateral','Mri w/o cont; breast; bi','C8907','3','','1','0','','','','0','1','0','0'),
('11353','Magnetic resonance imaging without contrast followed by with contrast; breast; bilateral','Mri w/o fol w/cont; breast;','C8908','3','','1','0','','','','0','1','0','0'),
('11354','Magnetic resonance angiography with contrast; chest (excluding myocardium)','Mra w/cont; chest','C8909','3','','1','0','','','','0','1','0','0'),
('11355','Magnetic resonance angiography without contrast; chest (excluding myocardium)','Mra w/o cont; chest','C8910','3','','1','0','','','','0','1','0','0'),
('11356','Magnetic resonance angiography without contrast followed by with contrast; chest (excluding myocardium)','Mra w/o fol w/cont; chest','C8911','3','','1','0','','','','0','1','0','0'),
('11357','Magnetic resonance angiography with contrast; lower extremity','Mra w/cont; lwr ext','C8912','3','','1','0','','','','0','1','0','0'),
('11358','Magnetic resonance angiography without contrast; lower extremity','Mra w/o cont; lwr ext','C8913','3','','1','0','','','','0','1','0','0'),
('11359','Magnetic resonance angiography without contrast followed by with contrast; lower extremity','Mra w/o fol w/cont; lwr ext','C8914','3','','1','0','','','','0','1','0','0'),
('11360','Magnetic resonance angiography with contrast; pelvis','Mra w/cont; pelvis','C8918','3','','1','0','','','','0','1','0','0'),
('11361','Magnetic resonance angiography without contrast; pelvis','Mra w/o cont; pelvis','C8919','3','','1','0','','','','0','1','0','0'),
('11362','Magnetic resonance angiography without contrast followed by with contrast; pelvis','Mra w/o fol w/cont; pelvis','C8920','3','','1','0','','','','0','1','0','0'),
('11363','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; for congenital cardiac anomalies; complete','Tte w or w/o fol w/cont; com','C8921','3','','1','0','','','','0','1','0','0'),
('11364','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; for congenital cardiac anomalies; follow-up or limited study','Tte w or w/o fol w/cont; f/u','C8922','3','','1','0','','','','0','1','0','0'),
('11365','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; real-time with image documentation (2d); includes m-mode recording; when performed; complete; without spectral or color doppler echocardiography','2d tte w or w/o fol w/con;co','C8923','3','','1','0','','','','0','1','0','0'),
('11366','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; real-time with image documentation (2d); includes m-mode recording; when performed; follow-up or limited study','2d tte w or w/o fol w/con;fu','C8924','3','','1','0','','','','0','1','0','0'),
('11367','Transesophageal echocardiography (tee) with contrast; or without contrast followed by with contrast; real time with image documentation (2d) (with or without m-mode recording); including probe placement; image acquisition; interpretation and report','2d tee w or w/o fol w/con;in','C8925','3','','1','0','','','','0','1','0','0'),
('11368','Transesophageal echocardiography (tee) with contrast; or without contrast followed by with contrast; for congenital cardiac anomalies; including probe placement; image acquisition; interpretation and report','Tee w or w/o fol w/cont;cong','C8926','3','','1','0','','','','0','1','0','0'),
('11369','Transesophageal echocardiography (tee) with contrast; or without contrast followed by with contrast; for monitoring purposes; including probe placement; real time 2-dimensional image acquisition and interpretation leading to ongoing (continuous) assessment of (dynamically changing) cardiac pumping function and to therapeutic measures on an immediate time basis','Tee w or w/o fol w/cont; mon','C8927','3','','1','0','','','','0','1','0','0'),
('11370','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; real-time with image documentation (2d); includes m-mode recording; when performed; during rest and cardiovascular stress test using treadmill; bicycle exercise and/or pharmacologically induced stress; with interpretation and report','Tte w or w/o fol w/con;stres','C8928','3','','1','0','','','','0','1','0','0'),
('11371','Transthoracic echocardiography with contrast; or without contrast followed by with contrast; real-time with image documentation (2d); includes m-mode recording; when performed; complete; with spectral doppler echocardiography; and with color flow doppler echocardiography','Tte w or wo fol wcon;doppler','C8929','3','','1','0','','','','0','1','0','0'),
('11372','Transthoracic echocardiography; with contrast; or without contrast followed by with contrast; real-time with image documentation (2d); includes m-mode recording; when performed; during rest and cardiovascular stress test using treadmill; bicycle exercise and/or pharmacologically induced stress; with interpretation and report; including performance of continuous electrocardiographic monitoring; with physician supervision','Tte w or w/o contr; cont ecg','C8930','3','','1','0','','','','0','1','0','0'),
('11373','Magnetic resonance angiography with contrast; spinal canal and contents','Mra; w/dye; spinal canal','C8931','3','','1','0','','','','0','1','0','0'),
('11374','Magnetic resonance angiography without contrast; spinal canal and contents','Mra; w/o dye; spinal canal','C8932','3','','1','0','','','','0','1','0','0'),
('11375','Magnetic resonance angiography without contrast followed by with contrast; spinal canal and contents','Mra; w/o&w/dye; spinal canal','C8933','3','','1','0','','','','0','1','0','0'),
('11376','Magnetic resonance angiography with contrast; upper extremity','Mra; w/dye; upper extremity','C8934','3','','1','0','','','','0','1','0','0'),
('11377','Magnetic resonance angiography without contrast; upper extremity','Mra; w/o dye; upper extr','C8935','3','','1','0','','','','0','1','0','0'),
('11378','Magnetic resonance angiography without contrast followed by with contrast; upper extremity','Mra; w/o&w/dye; upper extr','C8936','3','','1','0','','','','0','1','0','0'),
('11379','Intravenous infusion for therapy/diagnosis; initiation of prolonged infusion (more than 8 hours); requiring use of portable or implantable pump','Prolonged iv inf; req pump','C8957','3','','1','0','','','','0','1','0','0'),
('11380','Injection; obinutuzumab; 10 mg','Injection; obinutuzumab','C9021','3','','1','0','','','','0','1','0','0'),
('11381','Injection; elosulfase alfa; 1mg','Injection; elosulfase alfa','C9022','3','','1','0','','','','0','1','0','0'),
('11382','Injection; testosterone undecanoate; 1 mg','Inj testosterone undecanoate','C9023','3','','1','0','','','','0','1','0','0'),
('11383','Injection; ramucirumab; 5 mg','Injection; ramucirumab','C9025','3','','1','0','','','','0','1','0','0'),
('11384','Injection; vedolizumab; 1 mg','Injection; vedolizumab','C9026','3','','1','0','','','','0','1','0','0'),
('11385','Injection; pembrolizumab; 1 mg','Injection; pembrolizumab','C9027','3','','1','0','','','','0','1','0','0'),
('11386','Injection; pantoprazole sodium; per vial','Inj pantoprazole sodium; via','C9113','3','','1','0','','','','0','1','0','0'),
('11387','Injection; argatroban; per 5 mg','Injection; argatroban','C9121','3','','1','0','','','','0','1','0','0'),
('11388','Injection; immune globulin (bivigam); 500 mg','Injection; ivig bivigam','C9130','3','','1','0','','','','0','1','0','0'),
('11389','Injection; ado-trastuzumab emtansine; 1 mg','In ado-trastuzumab emtansine','C9131','3','','1','0','','','','0','1','0','0'),
('11390','Prothrombin complex concentrate (human); kcentra; per i.u. of factor ix activity','Kcentra; per i.u.','C9132','3','','1','0','','','','0','1','0','0'),
('11391','Factor ix (antihemophilic factor; recombinant); rixubis; per i.u.','Factor ix recombinant','C9133','3','','1','0','','','','0','1','0','0'),
('11392','Factor xiii (antihemophilic factor; recombinant); tretten; per 10 i.u.','Factor xiii a-subunit recomb','C9134','3','','1','0','','','','0','1','0','0'),
('11393','Factor ix (antihemophilic factor; recombinant); alprolix; per i.u.','Factor ix (alprolix)','C9135','3','','1','0','','','','0','1','0','0'),
('11394','Injection; factor viii; fc fusion protein; (recombinant); per i.u.','Factor viii (eloctate)','C9136','3','','1','0','','','','0','1','0','0'),
('11395','Injection; factor viii (antihemophilic factor; recombinant) pegylated; 1 i.u.','Adynovate factor viii recom','C9137','3','','1','0','','','','0','1','0','0'),
('11396','Injection; factor viii (antihemophilic factor; recombinant) (nuwiq); 1 i.u.','Nuwiq factor viii recomb','C9138','3','','1','0','','','','0','1','0','0'),
('11397','Injection; factor ix; albumin fusion protein (recombinant); idelvion; 1 i.u.','Idelvion; 1 i.u.','C9139','3','','1','0','','','','0','1','0','0'),
('11398','Injection; factor viii (antihemophilic factor; recombinant) (afstyla); 1 i.u.','Afstyla factor viii recomb','C9140','3','','1','0','','','','0','1','0','0'),
('11399','Injection; clevidipine butyrate; 1 mg','Inj; clevidipine butyrate','C9248','3','','1','0','','','','0','1','0','0'),
('11400','Human plasma fibrin sealant; vapor-heated; solvent-detergent (artiss); 2 ml','Artiss fibrin sealant','C9250','3','','1','0','','','','0','1','0','0'),
('11401','Injection; lacosamide; 1 mg','Injection; lacosamide','C9254','3','','1','0','','','','0','1','0','0'),
('11402','Injection; bevacizumab; 0.25 mg','Bevacizumab injection','C9257','3','','1','0','','','','0','1','0','0'),
('11403','Injection; hexaminolevulinate hydrochloride; 100 mg; per study dose','Hexaminolevulinate hcl','C9275','3','','1','0','','','','0','1','0','0'),
('11404','Lidocaine 70 mg/tetracaine 70 mg; per patch','Patch; lidocaine/tetracaine','C9285','3','','1','0','','','','0','1','0','0'),
('11405','Injection; bupivacaine liposome; 1 mg','Inj; bupivacaine liposome','C9290','3','','1','0','','','','0','1','0','0'),
('11406','Injection; pertuzumab; 10 mg','Injection; pertuzumab','C9292','3','','1','0','','','','0','1','0','0'),
('11407','Injection; glucarpidase; 10 units','Injection; glucarpidase','C9293','3','','1','0','','','','0','1','0','0'),
('11408','Injection; taliglucerase alfa; 10 units','Inj; taliglucerase alfa','C9294','3','','1','0','','','','0','1','0','0'),
('11409','Injection; carfilzomib; 1 mg','Injection; carfilzomib','C9295','3','','1','0','','','','0','1','0','0'),
('11410','Injection; ziv-aflibercept; 1 mg','Injection; ziv-aflibercept','C9296','3','','1','0','','','','0','1','0','0'),
('11411','Injection; omacetaxine mepesuccinate; 0.01 mg','Omacetaxine mepesuccinate','C9297','3','','1','0','','','','0','1','0','0'),
('11412','Injection; ocriplasmin; 0.125 mg','Injection; ocriplasmin','C9298','3','','1','0','','','','0','1','0','0'),
('11413','Puraply; and puraply antimicrobial; any type; per square centimeter','Puraply; puraply antimic','C9349','3','','1','0','','','','0','1','0','0'),
('11414','Microporous collagen implantable tube (neuragen nerve guide); per centimeter length','Neuragen nerve guide; per cm','C9352','3','','1','0','','','','0','1','0','0'),
('11415','Microporous collagen implantable slit tube (neurawrap nerve protector); per centimeter length','Neurawrap nerve protector;cm','C9353','3','','1','0','','','','0','1','0','0'),
('11416','Acellular pericardial tissue matrix of non-human origin (veritas); per square centimeter','Veritas collagen matrix; cm2','C9354','3','','1','0','','','','0','1','0','0'),
('11417','Collagen nerve cuff (neuromatrix); per 0.5 centimeter length','Neuromatrix nerve cuff; cm','C9355','3','','1','0','','','','0','1','0','0'),
('11418','Tendon; porous matrix of cross-linked collagen and glycosaminoglycan matrix (tenoglide tendon protector sheet); per square centimeter','Tenoglide tendon prot; cm2','C9356','3','','1','0','','','','0','1','0','0'),
('11419','Dermal substitute; native; non-denatured collagen; fetal bovine origin (surgimend collagen matrix); per 0.5 square centimeters','Surgimend; fetal','C9358','3','','1','0','','','','0','1','0','0'),
('11420','Porous purified collagen matrix bone void filler (integra mozaik osteoconductive scaffold putty; integra os osteoconductive scaffold putty); per 0.5 cc','Implnt;bon void filler-putty','C9359','3','','1','0','','','','0','1','0','0'),
('11421','Dermal substitute; native; non-denatured collagen; neonatal bovine origin (surgimend collagen matrix); per 0.5 square centimeters','Surgimend; neonatal','C9360','3','','1','0','','','','0','1','0','0'),
('11422','Collagen matrix nerve wrap (neuromend collagen nerve wrap); per 0.5 centimeter length','Neuromend nerve wrap','C9361','3','','1','0','','','','0','1','0','0'),
('11423','Porous purified collagen matrix bone void filler (integra mozaik osteoconductive scaffold strip); per 0.5 cc','Implnt;bon void filler-strip','C9362','3','','1','0','','','','0','1','0','0'),
('11424','Skin substitute; integra meshed bilayer wound matrix; per square centimeter','Integra meshed bil wound mat','C9363','3','','1','0','','','','0','1','0','0'),
('11425','Porcine implant; permacol; per square centimeter','Porcine implant; permacol','C9364','3','','1','0','','','','0','1','0','0'),
('11426','Unclassified drugs or biologicals','Unclassified drugs or biolog','C9399','3','','1','0','','','','0','1','0','0'),
('11427','Injection; ferric carboxymaltose; 1 mg','Inj; ferric carboxymaltose','C9441','3','','1','0','','','','0','1','0','0'),
('11428','Injection; belinostat; 10 mg','Injection; belinostat','C9442','3','','1','0','','','','0','1','0','0'),
('11429','Injection; dalbavancin; 10 mg','Injection; dalbavancin','C9443','3','','1','0','','','','0','1','0','0'),
('11430','Injection; oritavancin; 10 mg','Injection; oritavancin','C9444','3','','1','0','','','','0','1','0','0'),
('11431','Injection; c-1 esterase inhibitor (recombinant); ruconest; 10 units','C-1 esterase; ruconest','C9445','3','','1','0','','','','0','1','0','0'),
('11432','Injection; tedizolid phosphate; 1 mg','Inj; tedizolid phosphate','C9446','3','','1','0','','','','0','1','0','0'),
('11433','Injection; phenylephrine and ketorolac; 4 ml vial','Inj; phenylephrine ketorolac','C9447','3','','1','0','','','','0','1','0','0'),
('11434','Netupitant 300 mg and palonosetron 0.5 mg; oral','Oral netupitant palonosetron','C9448','3','','1','0','','','','0','1','0','0'),
('11435','Injection; blinatumomab; 1 mcg','Inj; blinatumomab','C9449','3','','1','0','','','','0','1','0','0'),
('11436','Injection; fluocinolone acetonide intravitreal implant; 0.01 mg','Fluocinolone acetonide implt','C9450','3','','1','0','','','','0','1','0','0'),
('11437','Injection; peramivir; 1 mg','Injection; peramivir','C9451','3','','1','0','','','','0','1','0','0'),
('11438','Injection; ceftolozane 50 mg and tazobactam 25 mg','Inj; ceftolozane/tazobactam','C9452','3','','1','0','','','','0','1','0','0'),
('11439','Injection; nivolumab; 1 mg','Injection; nivolumab','C9453','3','','1','0','','','','0','1','0','0'),
('11440','Injection; pasireotide long acting; 1 mg','Inj; pasireotide long acting','C9454','3','','1','0','','','','0','1','0','0'),
('11441','Injection; siltuximab; 10 mg','Injection; siltuximab','C9455','3','','1','0','','','','0','1','0','0'),
('11442','Injection; isavuconazonium sulfate; 1 mg','Inj; isavuconazonium sulfate','C9456','3','','1','0','','','','0','1','0','0'),
('11443','Injection; sulfur hexafluoride lipid microsphere; per ml','Lumason contrast agent','C9457','3','','1','0','','','','0','1','0','0'),
('11444','Florbetaben f18; diagnostic; per study dose; up to 8.1 millicuries','Florbetaben f18','C9458','3','','1','0','','','','0','1','0','0'),
('11445','Flutemetamol f18; diagnostic; per study dose; up to 5 millicuries','Flutemetamol f18','C9459','3','','1','0','','','','0','1','0','0'),
('11446','Injection; cangrelor; 1 mg','Injection; cangrelor','C9460','3','','1','0','','','','0','1','0','0'),
('11447','Choline c 11; diagnostic; per study dose','Choline c 11; diagnostic','C9461','3','','1','0','','','','0','1','0','0'),
('11448','Injection; aripiprazole lauroxil; 1 mg','Aripiprazole lauroxil im','C9470','3','','1','0','','','','0','1','0','0'),
('11449','Hyaluronan or derivative; hymovis; for intra-articular injection; 1 mg','Hymovis; 1 mg','C9471','3','','1','0','','','','0','1','0','0'),
('11450','Injection; talimogene laherparepvec; 1 million plaque forming units (pfu)','Inj talimogene laherparepvec','C9472','3','','1','0','','','','0','1','0','0'),
('11451','Injection; mepolizumab; 1 mg','Injection; mepolizumab','C9473','3','','1','0','','','','0','1','0','0'),
('11452','Injection; irinotecan liposome; 1 mg','Inj; irinotecan liposome','C9474','3','','1','0','','','','0','1','0','0'),
('11453','Injection; necitumumab; 1 mg','Injection; necitumumab','C9475','3','','1','0','','','','0','1','0','0'),
('11454','Injection; daratumumab; 10 mg','Injection; daratumumab','C9476','3','','1','0','','','','0','1','0','0'),
('11455','Injection; elotuzumab; 1 mg','Injection; elotuzumab','C9477','3','','1','0','','','','0','1','0','0'),
('11456','Injection; sebelipase alfa; 1 mg','Injection; sebelipase alfa','C9478','3','','1','0','','','','0','1','0','0'),
('11457','Instillation; ciprofloxacin otic suspension; 6 mg','Instill; ciprofloxacin otic','C9479','3','','1','0','','','','0','1','0','0'),
('11458','Injection; trabectedin; 0.1 mg','Injection; trabectedin','C9480','3','','1','0','','','','0','1','0','0'),
('11459','Injection; reslizumab; 1 mg','Injection; reslizumab','C9481','3','','1','0','','','','0','1','0','0'),
('11460','Injection; sotalol hydrochloride; 1 mg','Sotalol hydrochloride iv','C9482','3','','1','0','','','','0','1','0','0'),
('11461','Injection; atezolizumab; 10 mg','Injection; atezolizumab','C9483','3','','1','0','','','','0','1','0','0'),
('11462','Loxapine; inhalation powder; 10 mg','Loxapine; inhalation powder','C9497','3','','1','0','','','','0','1','0','0'),
('11463','Percutaneous transcatheter placement of drug eluting intracoronary stent(s); with coronary angioplasty when performed; single major coronary artery or branch','Perc drug-el cor stent sing','C9600','3','','1','0','','','','0','1','0','0'),
('11464','Percutaneous transcatheter placement of drug-eluting intracoronary stent(s); with coronary angioplasty when performed; each additional branch of a major coronary artery (list separately in addition to code for primary procedure)','Perc drug-el cor stent bran','C9601','3','','1','0','','','','0','1','0','0'),
('11465','Percutaneous transluminal coronary atherectomy; with drug eluting intracoronary stent; with coronary angioplasty when performed; single major coronary artery or branch','Perc d-e cor stent ather s','C9602','3','','1','0','','','','0','1','0','0'),
('11466','Percutaneous transluminal coronary atherectomy; with drug-eluting intracoronary stent; with coronary angioplasty when performed; each additional branch of a major coronary artery (list separately in addition to code for primary procedure)','Perc d-e cor stent ather br','C9603','3','','1','0','','','','0','1','0','0'),
('11467','Percutaneous transluminal revascularization of or through coronary artery bypass graft (internal mammary; free arterial; venous); any combination of drug-eluting intracoronary stent; atherectomy and angioplasty; including distal protection when performed; single vessel','Perc d-e cor revasc t cabg s','C9604','3','','1','0','','','','0','1','0','0'),
('11468','Percutaneous transluminal revascularization of or through coronary artery bypass graft (internal mammary; free arterial; venous); any combination of drug-eluting intracoronary stent; atherectomy and angioplasty; including distal protection when performed; each additional branch subtended by the bypass graft (list separately in addition to code for primary procedure)','Perc d-e cor revasc t cabg b','C9605','3','','1','0','','','','0','1','0','0'),
('11469','Percutaneous transluminal revascularization of acute total/subtotal occlusion during acute myocardial infarction; coronary artery or coronary artery bypass graft; any combination of drug-eluting intracoronary stent; atherectomy and angioplasty; including aspiration thrombectomy when performed; single vessel','Perc d-e cor revasc w ami s','C9606','3','','1','0','','','','0','1','0','0'),
('11470','Percutaneous transluminal revascularization of chronic total occlusion; coronary artery; coronary artery branch; or coronary artery bypass graft; any combination of drug-eluting intracoronary stent; atherectomy and angioplasty; single vessel','Perc d-e cor revasc chro sin','C9607','3','','1','0','','','','0','1','0','0'),
('11471','Percutaneous transluminal revascularization of chronic total occlusion; coronary artery; coronary artery branch; or coronary artery bypass graft; any combination of drug-eluting intracoronary stent; atherectomy and angioplasty; each additional coronary artery; coronary artery branch; or bypass graft (list separately in addition to code for primary procedure)','Perc d-e cor revasc chro add','C9608','3','','1','0','','','','0','1','0','0'),
('11472','Endoscopic full-thickness plication of the stomach using endoscopic plication system (eps); includes endoscopy','Eps stomach plic','C9724','3','','1','0','','','','0','1','0','0'),
('11473','Placement of endorectal intracavitary applicator for high intensity brachytherapy','Place endorectal app','C9725','3','','1','0','','','','0','1','0','0'),
('11474','Placement and removal (if performed) of applicator into breast for intraoperative radiation therapy; add-on to primary breast procedure','Rxt breast appl place/remov','C9726','3','','1','0','','','','0','1','0','0'),
('11475','Insertion of implants into the soft palate; minimum of three implants','Insert palate implants','C9727','3','','1','0','','','','0','1','0','0'),
('11476','Placement of interstitial device(s) for radiation therapy/surgery guidance (e.g.; fiducial markers; dosimeter); for other than the following sites (any approach): abdomen; pelvis; prostate; retroperitoneum; thorax; single or multiple','Place device/marker; non pro','C9728','3','','1','0','','','','0','1','0','0'),
('11477','Non-ophthalmic fluorescent vascular angiography','Non-ophthalmic fva','C9733','3','','1','0','','','','0','1','0','0'),
('11478','Focused ultrasound ablation/therapeutic intervention; other than uterine leiomyomata; with magnetic resonance (mr) guidance','U/s trtmt; not leiomyomata','C9734','3','','1','0','','','','0','1','0','0'),
('11479','Anoscopy; with directed submucosal injection(s); any substance','Anoscopy; submucosal inj','C9735','3','','1','0','','','','0','1','0','0'),
('11480','Laparoscopy; surgical; radiofrequency ablations of uterine fibroid(s); including intraoperative guidance and monitoring; when performed','Lap ablate uteri fibroid rf','C9736','3','','1','0','','','','0','1','0','0'),
('11481','Laparoscopy; surgical; esophageal sphincter augmentation with device (e.g.; magnetic band)','Lap esoph augmentation','C9737','3','','1','0','','','','0','1','0','0'),
('11482','Cystourethroscopy; with insertion of transprostatic implant; 1 to 3 implants','Cystoscopy prostatic imp 1-3','C9739','3','','1','0','','','','0','1','0','0'),
('11483','Cystourethroscopy; with insertion of transprostatic implant; 4 or more implants','Cysto impl 4 or more','C9740','3','','1','0','','','','0','1','0','0'),
('11484','Right heart catheterization with implantation of wireless pressure sensor in the pulmonary artery; including any type of measurement; angiography; imaging supervision; interpretation; and report','Impl pressure sensor w/angio','C9741','3','','1','0','','','','0','1','0','0'),
('11485','Laryngoscopy; flexible fiberoptic; with injection into vocal cord(s); therapeutic; including diagnostic laryngoscopy; if performed','Laryngoscopy with injection','C9742','3','','1','0','','','','0','1','0','0'),
('11486','Injection/implantation of bulking or spacer material (any type) with or without image guidance (not to be used if a more specific code applies)','Bulking/spacer material impl','C9743','3','','1','0','','','','0','1','0','0'),
('11487','Ultrasound; abdominal; with contrast','Abd us w/contrast','C9744','3','','1','0','','','','0','1','0','0'),
('11488','Dermal injection procedure(s) for facial lipodystrophy syndrome (lds) and provision of radiesse or sculptra dermal filler; including all items and supplies','Dermal filler inj px/suppl','C9800','3','','1','0','','','','0','1','0','0'),
('11489','Radiolabeled product provided during a hospital inpatient stay','Inpnt stay radiolabeled item','C9898','3','','1','0','','','','0','1','0','0'),
('11490','Implanted prosthetic device; payable only for inpatients who do not have inpatient coverage','Inpt implant pros dev;no cov','C9899','3','','1','0','','','','0','1','0','0'),
('11491','Cane; includes canes of all materials; adjustable or fixed; with tip','Cane adjust/fixed with tip','E0100','3','','1','0','','','','0','1','0','0'),
('11492','Cane; quad or three prong; includes canes of all materials; adjustable or fixed; with tips','Cane adjust/fixed quad/3 pro','E0105','3','','1','0','','','','0','1','0','0'),
('11493','Crutches; forearm; includes crutches of various materials; adjustable or fixed; pair; complete with tips and handgrips','Crutch forearm pair','E0110','3','','1','0','','','','0','1','0','0'),
('11494','Crutch forearm; includes crutches of various materials; adjustable or fixed; each; with tip and handgrips','Crutch forearm each','E0111','3','','1','0','','','','0','1','0','0'),
('11495','Crutches underarm; wood; adjustable or fixed; pair; with pads; tips and handgrips','Crutch underarm pair wood','E0112','3','','1','0','','','','0','1','0','0'),
('11496','Crutch underarm; wood; adjustable or fixed; each; with pad; tip and handgrip','Crutch underarm each wood','E0113','3','','1','0','','','','0','1','0','0'),
('11497','Crutches underarm; other than wood; adjustable or fixed; pair; with pads; tips and handgrips','Crutch underarm pair no wood','E0114','3','','1','0','','','','0','1','0','0'),
('11498','Crutch; underarm; other than wood; adjustable or fixed; with pad; tip; handgrip; with or without shock absorber; each','Crutch underarm each no wood','E0116','3','','1','0','','','','0','1','0','0'),
('11499','Crutch; underarm; articulating; spring assisted; each','Underarm springassist crutch','E0117','3','','1','0','','','','0','1','0','0'),
('11500','Crutch substitute; lower leg platform; with or without wheels; each','Crutch substitute','E0118','3','','1','0','','','','0','1','0','0'),
('11501','Walker; rigid (pickup); adjustable or fixed height','Walker rigid adjust/fixed ht','E0130','3','','1','0','','','','0','1','0','0'),
('11502','Walker; folding (pickup); adjustable or fixed height','Walker folding adjust/fixed','E0135','3','','1','0','','','','0','1','0','0'),
('11503','Walker; with trunk support; adjustable or fixed height; any type','Walker w trunk support','E0140','3','','1','0','','','','0','1','0','0'),
('11504','Walker; rigid; wheeled; adjustable or fixed height','Rigid wheeled walker adj/fix','E0141','3','','1','0','','','','0','1','0','0'),
('11505','Walker; folding; wheeled; adjustable or fixed height','Walker folding wheeled w/o s','E0143','3','','1','0','','','','0','1','0','0'),
('11506','Walker; enclosed; four sided framed; rigid or folding; wheeled with posterior seat','Enclosed walker w rear seat','E0144','3','','1','0','','','','0','1','0','0'),
('11507','Walker; heavy duty; multiple braking system; variable wheel resistance','Walker variable wheel resist','E0147','3','','1','0','','','','0','1','0','0'),
('11508','Walker; heavy duty; without wheels; rigid or folding; any type; each','Heavyduty walker no wheels','E0148','3','','1','0','','','','0','1','0','0'),
('11509','Walker; heavy duty; wheeled; rigid or folding; any type','Heavy duty wheeled walker','E0149','3','','1','0','','','','0','1','0','0'),
('11510','Platform attachment; forearm crutch; each','Forearm crutch platform atta','E0153','3','','1','0','','','','0','1','0','0'),
('11511','Platform attachment; walker; each','Walker platform attachment','E0154','3','','1','0','','','','0','1','0','0'),
('11512','Wheel attachment; rigid pick-up walker; per pair','Walker wheel attachment;pair','E0155','3','','1','0','','','','0','1','0','0'),
('11513','Seat attachment; walker','Walker seat attachment','E0156','3','','1','0','','','','0','1','0','0'),
('11514','Crutch attachment; walker; each','Walker crutch attachment','E0157','3','','1','0','','','','0','1','0','0'),
('11515','Leg extensions for walker; per set of four (4)','Walker leg extenders set of4','E0158','3','','1','0','','','','0','1','0','0'),
('11516','Brake attachment for wheeled walker; replacement; each','Brake for wheeled walker','E0159','3','','1','0','','','','0','1','0','0'),
('11517','Sitz type bath or equipment; portable; used with or without commode','Sitz type bath or equipment','E0160','3','','1','0','','','','0','1','0','0'),
('11518','Sitz type bath or equipment; portable; used with or without commode; with faucet attachment/s','Sitz bath/equipment w/faucet','E0161','3','','1','0','','','','0','1','0','0'),
('11519','Sitz bath chair','Sitz bath chair','E0162','3','','1','0','','','','0','1','0','0'),
('11520','Commode chair; mobile or stationary; with fixed arms','Commode chair with fixed arm','E0163','3','','1','0','','','','0','1','0','0'),
('11521','Commode chair; mobile or stationary; with detachable arms','Commode chair with detacharm','E0165','3','','1','0','','','','0','1','0','0'),
('11522','Pail or pan for use with commode chair; replacement only','Commode chair pail or pan','E0167','3','','1','0','','','','0','1','0','0'),
('11523','Commode chair; extra wide and/or heavy duty; stationary or mobile; with or without arms; any type; each','Heavyduty/wide commode chair','E0168','3','','1','0','','','','0','1','0','0'),
('11524','Commode chair with integrated seat lift mechanism; electric; any type','Commode chair electric','E0170','3','','1','0','','','','0','1','0','0'),
('11525','Commode chair with integrated seat lift mechanism; non-electric; any type','Commode chair non-electric','E0171','3','','1','0','','','','0','1','0','0'),
('11526','Seat lift mechanism placed over or on top of toilet; any type','Seat lift mechanism toilet','E0172','3','','1','0','','','','0','1','0','0'),
('11527','Foot rest; for use with commode chair; each','Commode chair foot rest','E0175','3','','1','0','','','','0','1','0','0'),
('11528','Powered pressure reducing mattress overlay/pad; alternating; with pump; includes heavy duty','Press pad alternating w/ pum','E0181','3','','1','0','','','','0','1','0','0'),
('11529','Pump for alternating pressure pad; for replacement only','Replace pump; alt press pad','E0182','3','','1','0','','','','0','1','0','0'),
('11530','Dry pressure mattress','Dry pressure mattress','E0184','3','','1','0','','','','0','1','0','0'),
('11531','Gel or gel-like pressure pad for mattress; standard mattress length and width','Gel pressure mattress pad','E0185','3','','1','0','','','','0','1','0','0'),
('11532','Air pressure mattress','Air pressure mattress','E0186','3','','1','0','','','','0','1','0','0'),
('11533','Water pressure mattress','Water pressure mattress','E0187','3','','1','0','','','','0','1','0','0'),
('11534','Synthetic sheepskin pad','Synthetic sheepskin pad','E0188','3','','1','0','','','','0','1','0','0'),
('11535','Lambswool sheepskin pad; any size','Lambswool sheepskin pad','E0189','3','','1','0','','','','0','1','0','0'),
('11536','Positioning cushion/pillow/wedge; any shape or size; includes all components and accessories','Positioning cushion','E0190','3','','1','0','','','','0','1','0','0'),
('11537','Heel or elbow protector; each','Protector heel or elbow','E0191','3','','1','0','','','','0','1','0','0'),
('11538','Powered air flotation bed (low air loss therapy)','Powered air flotation bed','E0193','3','','1','0','','','','0','1','0','0'),
('11539','Air fluidized bed','Air fluidized bed','E0194','3','','1','0','','','','0','1','0','0'),
('11540','Gel pressure mattress','Gel pressure mattress','E0196','3','','1','0','','','','0','1','0','0'),
('11541','Air pressure pad for mattress; standard mattress length and width','Air pressure pad for mattres','E0197','3','','1','0','','','','0','1','0','0'),
('11542','Water pressure pad for mattress; standard mattress length and width','Water pressure pad for mattr','E0198','3','','1','0','','','','0','1','0','0'),
('11543','Dry pressure pad for mattress; standard mattress length and width','Dry pressure pad for mattres','E0199','3','','1','0','','','','0','1','0','0'),
('11544','Heat lamp; without stand (table model); includes bulb; or infrared element','Heat lamp without stand','E0200','3','','1','0','','','','0','1','0','0'),
('11545','Phototherapy (bilirubin) light with photometer','Phototherapy light w/ photom','E0202','3','','1','0','','','','0','1','0','0'),
('11546','Therapeutic lightbox; minimum 10;000 lux; table top model','Therapeutic lightbox tabletp','E0203','3','','1','0','','','','0','1','0','0'),
('11547','Heat lamp; with stand; includes bulb; or infrared element','Heat lamp with stand','E0205','3','','1','0','','','','0','1','0','0'),
('11548','Electric heat pad; standard','Electric heat pad standard','E0210','3','','1','0','','','','0','1','0','0'),
('11549','Electric heat pad; moist','Electric heat pad moist','E0215','3','','1','0','','','','0','1','0','0'),
('11550','Water circulating heat pad with pump','Water circ heat pad w pump','E0217','3','','1','0','','','','0','1','0','0'),
('11551','Water circulating cold pad with pump','Water circ cold pad w pump','E0218','3','','1','0','','','','0','1','0','0'),
('11552','Infrared heating pad system','Infrared heating pad system','E0221','3','','1','0','','','','0','1','0','0'),
('11553','Hydrocollator unit; includes pads','Hydrocollator unit','E0225','3','','1','0','','','','0','1','0','0'),
('11554','Non-contact wound warming device (temperature control unit; ac adapter and power cord) for use with warming card and wound cover','Wound warming device','E0231','3','','1','0','','','','0','1','0','0'),
('11555','Warming card for use with the non contact wound warming device and non contact wound warming wound cover','Warming card for nwt','E0232','3','','1','0','','','','0','1','0','0'),
('11556','Paraffin bath unit; portable (see medical supply code a4265 for paraffin)','Paraffin bath unit portable','E0235','3','','1','0','','','','0','1','0','0'),
('11557','Pump for water circulating pad','Pump for water circulating p','E0236','3','','1','0','','','','0','1','0','0'),
('11558','Hydrocollator unit; portable','Hydrocollator unit portable','E0239','3','','1','0','','','','0','1','0','0'),
('11559','Bath/shower chair; with or without wheels; any size','Bath/shower chair','E0240','3','','1','0','','','','0','1','0','0'),
('11560','Bath tub wall rail; each','Bath tub wall rail','E0241','3','','1','0','','','','0','1','0','0'),
('11561','Bath tub rail; floor base','Bath tub rail floor','E0242','3','','1','0','','','','0','1','0','0'),
('11562','Toilet rail; each','Toilet rail','E0243','3','','1','0','','','','0','1','0','0'),
('11563','Raised toilet seat','Toilet seat raised','E0244','3','','1','0','','','','0','1','0','0'),
('11564','Tub stool or bench','Tub stool or bench','E0245','3','','1','0','','','','0','1','0','0'),
('11565','Transfer tub rail attachment','Transfer tub rail attachment','E0246','3','','1','0','','','','0','1','0','0'),
('11566','Transfer bench for tub or toilet with or without commode opening','Trans bench w/wo comm open','E0247','3','','1','0','','','','0','1','0','0'),
('11567','Transfer bench; heavy duty; for tub or toilet with or without commode opening','Hdtrans bench w/wo comm open','E0248','3','','1','0','','','','0','1','0','0'),
('11568','Pad for water circulating heat unit; for replacement only','Pad water circulating heat u','E0249','3','','1','0','','','','0','1','0','0'),
('11569','Hospital bed; fixed height; with any type side rails; with mattress','Hosp bed fixed ht w/ mattres','E0250','3','','1','0','','','','0','1','0','0'),
('11570','Hospital bed; fixed height; with any type side rails; without mattress','Hosp bed fixd ht w/o mattres','E0251','3','','1','0','','','','0','1','0','0'),
('11571','Hospital bed; variable height; hi-lo; with any type side rails; with mattress','Hospital bed var ht w/ mattr','E0255','3','','1','0','','','','0','1','0','0'),
('11572','Hospital bed; variable height; hi-lo; with any type side rails; without mattress','Hospital bed var ht w/o matt','E0256','3','','1','0','','','','0','1','0','0'),
('11573','Hospital bed; semi-electric (head and foot adjustment); with any type side rails; with mattress','Hosp bed semi-electr w/ matt','E0260','3','','1','0','','','','0','1','0','0'),
('11574','Hospital bed; semi-electric (head and foot adjustment); with any type side rails; without mattress','Hosp bed semi-electr w/o mat','E0261','3','','1','0','','','','0','1','0','0'),
('11575','Hospital bed; total electric (head; foot and height adjustments); with any type side rails; with mattress','Hosp bed total electr w/ mat','E0265','3','','1','0','','','','0','1','0','0'),
('11576','Hospital bed; total electric (head; foot and height adjustments); with any type side rails; without mattress','Hosp bed total elec w/o matt','E0266','3','','1','0','','','','0','1','0','0'),
('11577','Hospital bed; institutional type includes: oscillating; circulating and stryker frame; with mattress','Hospital bed institutional t','E0270','3','','1','0','','','','0','1','0','0'),
('11578','Mattress; innerspring','Mattress innerspring','E0271','3','','1','0','','','','0','1','0','0'),
('11579','Mattress; foam rubber','Mattress foam rubber','E0272','3','','1','0','','','','0','1','0','0'),
('11580','Bed board','Bed board','E0273','3','','1','0','','','','0','1','0','0'),
('11581','Over-bed table','Over-bed table','E0274','3','','1','0','','','','0','1','0','0'),
('11582','Bed pan; standard; metal or plastic','Bed pan standard','E0275','3','','1','0','','','','0','1','0','0'),
('11583','Bed pan; fracture; metal or plastic','Bed pan fracture','E0276','3','','1','0','','','','0','1','0','0'),
('11584','Powered pressure-reducing air mattress','Powered pres-redu air mattrs','E0277','3','','1','0','','','','0','1','0','0'),
('11585','Bed cradle; any type','Bed cradle','E0280','3','','1','0','','','','0','1','0','0'),
('11586','Hospital bed; fixed height; without side rails; with mattress','Hosp bed fx ht w/o rails w/m','E0290','3','','1','0','','','','0','1','0','0'),
('11587','Hospital bed; fixed height; without side rails; without mattress','Hosp bed fx ht w/o rail w/o','E0291','3','','1','0','','','','0','1','0','0'),
('11588','Hospital bed; variable height; hi-lo; without side rails; with mattress','Hosp bed var ht no sr w/matt','E0292','3','','1','0','','','','0','1','0','0'),
('11589','Hospital bed; variable height; hi-lo; without side rails; without mattress','Hosp bed var ht no sr no mat','E0293','3','','1','0','','','','0','1','0','0'),
('11590','Hospital bed; semi-electric (head and foot adjustment); without side rails; with mattress','Hosp bed semi-elect w/ mattr','E0294','3','','1','0','','','','0','1','0','0'),
('11591','Hospital bed; semi-electric (head and foot adjustment); without side rails; without mattress','Hosp bed semi-elect w/o matt','E0295','3','','1','0','','','','0','1','0','0'),
('11592','Hospital bed; total electric (head; foot and height adjustments); without side rails; with mattress','Hosp bed total elect w/ matt','E0296','3','','1','0','','','','0','1','0','0'),
('11593','Hospital bed; total electric (head; foot and height adjustments); without side rails; without mattress','Hosp bed total elect w/o mat','E0297','3','','1','0','','','','0','1','0','0'),
('11594','Pediatric crib; hospital grade; fully enclosed; with or without top enclosure','Enclosed ped crib hosp grade','E0300','3','','1','0','','','','0','1','0','0'),
('11595','Hospital bed; heavy duty; extra wide; with weight capacity greater than 350 pounds; but less than or equal to 600 pounds; with any type side rails; without mattress','Hd hosp bed; 350-600 lbs','E0301','3','','1','0','','','','0','1','0','0'),
('11596','Hospital bed; extra heavy duty; extra wide; with weight capacity greater than 600 pounds; with any type side rails; without mattress','Ex hd hosp bed > 600 lbs','E0302','3','','1','0','','','','0','1','0','0'),
('11597','Hospital bed; heavy duty; extra wide; with weight capacity greater than 350 pounds; but less than or equal to 600 pounds; with any type side rails; with mattress','Hosp bed hvy dty xtra wide','E0303','3','','1','0','','','','0','1','0','0'),
('11598','Hospital bed; extra heavy duty; extra wide; with weight capacity greater than 600 pounds; with any type side rails; with mattress','Hosp bed xtra hvy dty x wide','E0304','3','','1','0','','','','0','1','0','0'),
('11599','Bed side rails; half length','Rails bed side half length','E0305','3','','1','0','','','','0','1','0','0'),
('11600','Bed side rails; full length','Rails bed side full length','E0310','3','','1','0','','','','0','1','0','0'),
('11601','Bed accessory: board; table; or support device; any type','Bed accessory brd/tbl/supprt','E0315','3','','1','0','','','','0','1','0','0'),
('11602','Safety enclosure frame/canopy for use with hospital bed; any type','Bed safety enclosure','E0316','3','','1','0','','','','0','1','0','0'),
('11603','Urinal; male; jug-type; any material','Urinal male jug-type','E0325','3','','1','0','','','','0','1','0','0'),
('11604','Urinal; female; jug-type; any material','Urinal female jug-type','E0326','3','','1','0','','','','0','1','0','0'),
('11605','Hospital bed; pediatric; manual; 360 degree side enclosures; top of headboard; footboard and side rails up to 24 inches above the spring; includes mattress','Ped hospital bed; manual','E0328','3','','1','0','','','','0','1','0','0'),
('11606','Hospital bed; pediatric; electric or semi-electric; 360 degree side enclosures; top of headboard; footboard and side rails up to 24 inches above the spring; includes mattress','Ped hospital bed semi/elect','E0329','3','','1','0','','','','0','1','0','0'),
('11607','Control unit for electronic bowel irrigation/evacuation system','Control unit bowel system','E0350','3','','1','0','','','','0','1','0','0'),
('11608','Disposable pack (water reservoir bag; speculum; valving mechanism and collection bag/box) for use with the electronic bowel irrigation/evacuation system','Disposable pack w/bowel syst','E0352','3','','1','0','','','','0','1','0','0'),
('11609','Air pressure elevator for heel','Air elevator for heel','E0370','3','','1','0','','','','0','1','0','0'),
('11610','Nonpowered advanced pressure reducing overlay for mattress; standard mattress length and width','Nonpower mattress overlay','E0371','3','','1','0','','','','0','1','0','0'),
('11611','Powered air overlay for mattress; standard mattress length and width','Powered air mattress overlay','E0372','3','','1','0','','','','0','1','0','0'),
('11612','Nonpowered advanced pressure reducing mattress','Nonpowered pressure mattress','E0373','3','','1','0','','','','0','1','0','0'),
('11613','Stationary compressed gaseous oxygen system; rental; includes container; contents; regulator; flowmeter; humidifier; nebulizer; cannula or mask; and tubing','Stationary compressed gas 02','E0424','3','','1','0','','','','0','1','0','0'),
('11614','Stationary compressed gas system; purchase; includes regulator; flowmeter; humidifier; nebulizer; cannula or mask; and tubing','Gas system stationary compre','E0425','3','','1','0','','','','0','1','0','0'),
('11615','Portable gaseous oxygen system; purchase; includes regulator; flowmeter; humidifier; cannula or mask; and tubing','Oxygen system gas portable','E0430','3','','1','0','','','','0','1','0','0'),
('11616','Portable gaseous oxygen system; rental; includes portable container; regulator; flowmeter; humidifier; cannula or mask; and tubing','Portable gaseous 02','E0431','3','','1','0','','','','0','1','0','0'),
('11617','Portable liquid oxygen system; rental; home liquefier used to fill portable liquid oxygen containers; includes portable containers; regulator; flowmeter; humidifier; cannula or mask and tubing; with or without supply reservoir and contents gauge','Portable liquid oxygen sys','E0433','3','','1','0','','','','0','1','0','0'),
('11618','Portable liquid oxygen system; rental; includes portable container; supply reservoir; humidifier; flowmeter; refill adaptor; contents gauge; cannula or mask; and tubing','Portable liquid 02','E0434','3','','1','0','','','','0','1','0','0'),
('11619','Portable liquid oxygen system; purchase; includes portable container; supply reservoir; flowmeter; humidifier; contents gauge; cannula or mask; tubing and refill adaptor','Oxygen system liquid portabl','E0435','3','','1','0','','','','0','1','0','0'),
('11620','Stationary liquid oxygen system; rental; includes container; contents; regulator; flowmeter; humidifier; nebulizer; cannula or mask; & tubing','Stationary liquid 02','E0439','3','','1','0','','','','0','1','0','0'),
('11621','Stationary liquid oxygen system; purchase; includes use of reservoir; contents indicator; regulator; flowmeter; humidifier; nebulizer; cannula or mask; and tubing','Oxygen system liquid station','E0440','3','','1','0','','','','0','1','0','0'),
('11622','Stationary oxygen contents; gaseous; 1 months supply = 1 unit','Stationary o2 contents; gas','E0441','3','','1','0','','','','0','1','0','0'),
('11623','Stationary oxygen contents; liquid; 1 months supply = 1 unit','Stationary o2 contents; liq','E0442','3','','1','0','','','','0','1','0','0'),
('11624','Portable oxygen contents; gaseous; 1 months supply = 1 unit','Portable 02 contents; gas','E0443','3','','1','0','','','','0','1','0','0'),
('11625','Portable oxygen contents; liquid; 1 months supply = 1 unit','Portable 02 contents; liquid','E0444','3','','1','0','','','','0','1','0','0'),
('11626','Oximeter device for measuring blood oxygen levels non-invasively','Oximeter non-invasive','E0445','3','','1','0','','','','0','1','0','0'),
('11627','Topical oxygen delivery system; not otherwise specified; includes all supplies and accessories','Topical ox deliver sys; nos','E0446','3','','1','0','','','','0','1','0','0'),
('11628','Volume control ventilator; without pressure support mode; may include pressure control mode; used with invasive interface (e.g.; tracheostomy tube)','Vol control vent invasiv int','E0450','3','','1','0','','','','0','1','0','0'),
('11629','Oxygen tent; excluding croup or pediatric tents','Oxygen tent excl croup/ped t','E0455','3','','1','0','','','','0','1','0','0'),
('11630','Chest shell (cuirass)','Chest shell','E0457','3','','1','0','','','','0','1','0','0'),
('11631','Chest wrap','Chest wrap','E0459','3','','1','0','','','','0','1','0','0'),
('11632','Negative pressure ventilator; portable or stationary','Neg press vent portabl/statn','E0460','3','','1','0','','','','0','1','0','0'),
('11633','Volume control ventilator; without pressure support mode; may include pressure control mode; used with non-invasive interface (e.g.; mask)','Vol control vent noninv int','E0461','3','','1','0','','','','0','1','0','0'),
('11634','Rocking bed with or without side rails','Rocking bed w/ or w/o side r','E0462','3','','1','0','','','','0','1','0','0'),
('11635','Pressure support ventilator with volume control mode; may include pressure control mode; used with invasive interface (e.g.; tracheostomy tube)','Press supp vent invasive int','E0463','3','','1','0','','','','0','1','0','0'),
('11636','Pressure support ventilator with volume control mode; may include pressure control mode; used with non-invasive interface (e.g.; mask)','Press supp vent noninv int','E0464','3','','1','0','','','','0','1','0','0'),
('11637','Home ventilator; any type; used with invasive interface; (e.g.; tracheostomy tube)','Home vent invasive interface','E0465','3','','1','0','','','','0','1','0','0'),
('11638','Home ventilator; any type; used with non-invasive interface; (e.g.; mask; chest shell)','Home vent non-invasive inter','E0466','3','','1','0','','','','0','1','0','0'),
('11639','Respiratory assist device; bi-level pressure capability; without backup rate feature; used with noninvasive interface; e.g.; nasal or facial mask (intermittent assist device with continuous positive airway pressure device)','Rad w/o backup non-inv intfc','E0470','3','','1','0','','','','0','1','0','0'),
('11640','Respiratory assist device; bi-level pressure capability; with back-up rate feature; used with noninvasive interface; e.g.; nasal or facial mask (intermittent assist device with continuous positive airway pressure device)','Rad w/backup non inv intrfc','E0471','3','','1','0','','','','0','1','0','0'),
('11641','Respiratory assist device; bi-level pressure capability; with backup rate feature; used with invasive interface; e.g.; tracheostomy tube (intermittent assist device with continuous positive airway pressure device)','Rad w backup invasive intrfc','E0472','3','','1','0','','','','0','1','0','0'),
('11642','Percussor; electric or pneumatic; home model','Percussor elect/pneum home m','E0480','3','','1','0','','','','0','1','0','0'),
('11643','Intrapulmonary percussive ventilation system and related accessories','Intrpulmnry percuss vent sys','E0481','3','','1','0','','','','0','1','0','0'),
('11644','Cough stimulating device; alternating positive and negative airway pressure','Cough stimulating device','E0482','3','','1','0','','','','0','1','0','0'),
('11645','High frequency chest wall oscillation air-pulse generator system; (includes hoses and vest); each','Chest compression gen system','E0483','3','','1','0','','','','0','1','0','0'),
('11646','Oscillatory positive expiratory pressure device; non-electric; any type; each','Non-elec oscillatory pep dvc','E0484','3','','1','0','','','','0','1','0','0'),
('11647','Oral device/appliance used to reduce upper airway collapsibility; adjustable or non-adjustable; prefabricated; includes fitting and adjustment','Oral device/appliance prefab','E0485','3','','1','0','','','','0','1','0','0'),
('11648','Oral device/appliance used to reduce upper airway collapsibility; adjustable or non-adjustable; custom fabricated; includes fitting and adjustment','Oral device/appliance cusfab','E0486','3','','1','0','','','','0','1','0','0'),
('11649','Spirometer; electronic; includes all accessories','Electronic spirometer','E0487','3','','1','0','','','','0','1','0','0'),
('11650','Ippb machine; all types; with built-in nebulization; manual or automatic valves; internal or external power source','Ippb all types','E0500','3','','1','0','','','','0','1','0','0'),
('11651','Humidifier; durable for extensive supplemental humidification during ippb treatments or oxygen delivery','Humidif extens supple w ippb','E0550','3','','1','0','','','','0','1','0','0'),
('11652','Humidifier; durable; glass or autoclavable plastic bottle type; for use with regulator or flowmeter','Humidifier for use w/ regula','E0555','3','','1','0','','','','0','1','0','0'),
('11653','Humidifier; durable for supplemental humidification during ippb treatment or oxygen delivery','Humidifier supplemental w/ i','E0560','3','','1','0','','','','0','1','0','0'),
('11654','Humidifier; non-heated; used with positive airway pressure device','Humidifier nonheated w pap','E0561','3','','1','0','','','','0','1','0','0'),
('11655','Humidifier; heated; used with positive airway pressure device','Humidifier heated used w pap','E0562','3','','1','0','','','','0','1','0','0'),
('11656','Compressor; air power source for equipment which is not self-contained or cylinder driven','Compressor air power source','E0565','3','','1','0','','','','0','1','0','0'),
('11657','Nebulizer; with compressor','Nebulizer with compression','E0570','3','','1','0','','','','0','1','0','0'),
('11658','Aerosol compressor; adjustable pressure; light duty for intermittent use','Aerosol compressor adjust pr','E0572','3','','1','0','','','','0','1','0','0'),
('11659','Ultrasonic/electronic aerosol generator with small volume nebulizer','Ultrasonic generator w svneb','E0574','3','','1','0','','','','0','1','0','0'),
('11660','Nebulizer; ultrasonic; large volume','Nebulizer ultrasonic','E0575','3','','1','0','','','','0','1','0','0'),
('11661','Nebulizer; durable; glass or autoclavable plastic; bottle type; for use with regulator or flowmeter','Nebulizer for use w/ regulat','E0580','3','','1','0','','','','0','1','0','0'),
('11662','Nebulizer; with compressor and heater','Nebulizer w/ compressor & he','E0585','3','','1','0','','','','0','1','0','0'),
('11663','Respiratory suction pump; home model; portable or stationary; electric','Suction pump portab hom modl','E0600','3','','1','0','','','','0','1','0','0'),
('11664','Continuous positive airway pressure (cpap) device','Cont airway pressure device','E0601','3','','1','0','','','','0','1','0','0'),
('11665','Breast pump; manual; any type','Manual breast pump','E0602','3','','1','0','','','','0','1','0','0'),
('11666','Breast pump; electric (ac and/or dc); any type','Electric breast pump','E0603','3','','1','0','','','','0','1','0','0'),
('11667','Breast pump; hospital grade; electric (ac and / or dc); any type','Hosp grade elec breast pump','E0604','3','','1','0','','','','0','1','0','0'),
('11668','Vaporizer; room type','Vaporizer room type','E0605','3','','1','0','','','','0','1','0','0'),
('11669','Postural drainage board','Drainage board postural','E0606','3','','1','0','','','','0','1','0','0'),
('11670','Home blood glucose monitor','Blood glucose monitor home','E0607','3','','1','0','','','','0','1','0','0'),
('11671','Pacemaker monitor; self-contained; (checks battery depletion; includes audible and visible check systems)','Pacemaker monitr audible/vis','E0610','3','','1','0','','','','0','1','0','0'),
('11672','Pacemaker monitor; self contained; checks battery depletion and other pacemaker components; includes digital/visible check systems','Pacemaker monitr digital/vis','E0615','3','','1','0','','','','0','1','0','0'),
('11673','Implantable cardiac event recorder with memory; activator and programmer','Cardiac event recorder','E0616','3','','1','0','','','','0','1','0','0'),
('11674','External defibrillator with integrated electrocardiogram analysis','Automatic ext defibrillator','E0617','3','','1','0','','','','0','1','0','0'),
('11675','Apnea monitor; without recording feature','Apnea monitor','E0618','3','','1','0','','','','0','1','0','0'),
('11676','Apnea monitor; with recording feature','Apnea monitor w recorder','E0619','3','','1','0','','','','0','1','0','0'),
('11677','Skin piercing device for collection of capillary blood; laser; each','Cap bld skin piercing laser','E0620','3','','1','0','','','','0','1','0','0'),
('11678','Sling or seat; patient lift; canvas or nylon','Patient lift sling or seat','E0621','3','','1','0','','','','0','1','0','0'),
('11679','Patient lift; bathroom or toilet; not otherwise classified','Patient lift bathroom or toi','E0625','3','','1','0','','','','0','1','0','0'),
('11680','Seat lift mechanism; electric; any type','Seat lift mech; electric any','E0627','3','','1','0','','','','0','1','0','0'),
('11681','Separate seat lift mechanism for use with patient owned furniture-electric','Seat lift for pt furn-electr','E0628','3','','1','0','','','','0','1','0','0'),
('11682','Seat lift mechanism; non-electric; any type','Seat lift mech; non-electric','E0629','3','','1','0','','','','0','1','0','0'),
('11683','Patient lift; hydraulic or mechanical; includes any seat; sling; strap(s) or pad(s)','Patient lift hydraulic','E0630','3','','1','0','','','','0','1','0','0'),
('11684','Patient lift; electric with seat or sling','Patient lift electric','E0635','3','','1','0','','','','0','1','0','0'),
('11685','Multipositional patient support system; with integrated lift; patient accessible controls','Pt support & positioning sys','E0636','3','','1','0','','','','0','1','0','0'),
('11686','Combination sit to stand frame/table system; any size including pediatric; with seat lift feature; with or without wheels','Combination sit to stand sys','E0637','3','','1','0','','','','0','1','0','0'),
('11687','Standing frame/table system; one position (e.g.; upright; supine or prone stander); any size including pediatric; with or without wheels','Standing frame sys','E0638','3','','1','0','','','','0','1','0','0'),
('11688','Patient lift; moveable from room to room with disassembly and reassembly; includes all components/accessories','Moveable patient lift system','E0639','3','','1','0','','','','0','1','0','0'),
('11689','Patient lift; fixed system; includes all components/accessories','Fixed patient lift system','E0640','3','','1','0','','','','0','1','0','0'),
('11690','Standing frame/table system; multi-position (e.g.; three-way stander); any size including pediatric; with or without wheels','Multi-position stnd fram sys','E0641','3','','1','0','','','','0','1','0','0'),
('11691','Standing frame/table system; mobile (dynamic stander); any size including pediatric','Dynamic standing frame','E0642','3','','1','0','','','','0','1','0','0'),
('11692','Pneumatic compressor; non-segmental home model','Pneuma compresor non-segment','E0650','3','','1','0','','','','0','1','0','0'),
('11693','Pneumatic compressor; segmental home model without calibrated gradient pressure','Pneum compressor segmental','E0651','3','','1','0','','','','0','1','0','0'),
('11694','Pneumatic compressor; segmental home model with calibrated gradient pressure','Pneum compres w/cal pressure','E0652','3','','1','0','','','','0','1','0','0'),
('11695','Non-segmental pneumatic appliance for use with pneumatic compressor; half arm','Pneumatic appliance half arm','E0655','3','','1','0','','','','0','1','0','0'),
('11696','Segmental pneumatic appliance for use with pneumatic compressor; trunk','Segmental pneumatic trunk','E0656','3','','1','0','','','','0','1','0','0'),
('11697','Segmental pneumatic appliance for use with pneumatic compressor; chest','Segmental pneumatic chest','E0657','3','','1','0','','','','0','1','0','0'),
('11698','Non-segmental pneumatic appliance for use with pneumatic compressor; full leg','Pneumatic appliance full leg','E0660','3','','1','0','','','','0','1','0','0'),
('11699','Non-segmental pneumatic appliance for use with pneumatic compressor; full arm','Pneumatic appliance full arm','E0665','3','','1','0','','','','0','1','0','0'),
('11700','Non-segmental pneumatic appliance for use with pneumatic compressor; half leg','Pneumatic appliance half leg','E0666','3','','1','0','','','','0','1','0','0'),
('11701','Segmental pneumatic appliance for use with pneumatic compressor; full leg','Seg pneumatic appl full leg','E0667','3','','1','0','','','','0','1','0','0'),
('11702','Segmental pneumatic appliance for use with pneumatic compressor; full arm','Seg pneumatic appl full arm','E0668','3','','1','0','','','','0','1','0','0'),
('11703','Segmental pneumatic appliance for use with pneumatic compressor; half leg','Seg pneumatic appli half leg','E0669','3','','1','0','','','','0','1','0','0'),
('11704','Segmental pneumatic appliance for use with pneumatic compressor; integrated; 2 full legs and trunk','Seg pneum int legs/trunk','E0670','3','','1','0','','','','0','1','0','0'),
('11705','Segmental gradient pressure pneumatic appliance; full leg','Pressure pneum appl full leg','E0671','3','','1','0','','','','0','1','0','0'),
('11706','Segmental gradient pressure pneumatic appliance; full arm','Pressure pneum appl full arm','E0672','3','','1','0','','','','0','1','0','0'),
('11707','Segmental gradient pressure pneumatic appliance; half leg','Pressure pneum appl half leg','E0673','3','','1','0','','','','0','1','0','0'),
('11708','Pneumatic compression device; high pressure; rapid inflation/deflation cycle; for arterial insufficiency (unilateral or bilateral system)','Pneumatic compression device','E0675','3','','1','0','','','','0','1','0','0'),
('11709','Intermittent limb compression device (includes all accessories); not otherwise specified','Inter limb compress dev nos','E0676','3','','1','0','','','','0','1','0','0'),
('11710','Ultraviolet light therapy system; includes bulbs/lamps; timer and eye protection; treatment area 2 square feet or less','Uvl pnl 2 sq ft or less','E0691','3','','1','0','','','','0','1','0','0'),
('11711','Ultraviolet light therapy system panel; includes bulbs/lamps; timer and eye protection; 4 foot panel','Uvl sys panel 4 ft','E0692','3','','1','0','','','','0','1','0','0'),
('11712','Ultraviolet light therapy system panel; includes bulbs/lamps; timer and eye protection; 6 foot panel','Uvl sys panel 6 ft','E0693','3','','1','0','','','','0','1','0','0'),
('11713','Ultraviolet multidirectional light therapy system in 6 foot cabinet; includes bulbs/lamps; timer and eye protection','Uvl md cabinet sys 6 ft','E0694','3','','1','0','','','','0','1','0','0'),
('11714','Safety equipment; device or accessory; any type','Safety equipment','E0700','3','','1','0','','','','0','1','0','0'),
('11715','Transfer device; any type; each','Transfer device','E0705','3','','1','0','','','','0','1','0','0'),
('11716','Restraints; any type (body; chest; wrist or ankle)','Restraints any type','E0710','3','','1','0','','','','0','1','0','0'),
('11717','Transcutaneous electrical nerve stimulation (tens) device; two lead; localized stimulation','Tens two lead','E0720','3','','1','0','','','','0','1','0','0'),
('11718','Transcutaneous electrical nerve stimulation (tens) device; four or more leads; for multiple nerve stimulation','Tens four lead','E0730','3','','1','0','','','','0','1','0','0'),
('11719','Form fitting conductive garment for delivery of tens or nmes (with conductive fibers separated from the patients skin by layers of fabric)','Conductive garment for tens/','E0731','3','','1','0','','','','0','1','0','0'),
('11720','Non-implanted pelvic floor electrical stimulator; complete system','Non-implant pelv flr e-stim','E0740','3','','1','0','','','','0','1','0','0'),
('11721','Neuromuscular stimulator for scoliosis','Neuromuscular stim for scoli','E0744','3','','1','0','','','','0','1','0','0'),
('11722','Neuromuscular stimulator; electronic shock unit','Neuromuscular stim for shock','E0745','3','','1','0','','','','0','1','0','0'),
('11723','Electromyography (emg); biofeedback device','Electromyograph biofeedback','E0746','3','','1','0','','','','0','1','0','0'),
('11724','Osteogenesis stimulator; electrical; non-invasive; other than spinal applications','Elec osteogen stim not spine','E0747','3','','1','0','','','','0','1','0','0'),
('11725','Osteogenesis stimulator; electrical; non-invasive; spinal applications','Elec osteogen stim spinal','E0748','3','','1','0','','','','0','1','0','0'),
('11726','Osteogenesis stimulator; electrical; surgically implanted','Elec osteogen stim implanted','E0749','3','','1','0','','','','0','1','0','0'),
('11727','Electronic salivary reflex stimulator (intra-oral/non-invasive)','Electronic salivary reflex s','E0755','3','','1','0','','','','0','1','0','0'),
('11728','Osteogenesis stimulator; low intensity ultrasound; non-invasive','Osteogen ultrasound stimltor','E0760','3','','1','0','','','','0','1','0','0'),
('11729','Non-thermal pulsed high frequency radiowaves; high peak power electromagnetic energy treatment device','Nontherm electromgntc device','E0761','3','','1','0','','','','0','1','0','0'),
('11730','Transcutaneous electrical joint stimulation device system; includes all accessories','Trans elec jt stim dev sys','E0762','3','','1','0','','','','0','1','0','0'),
('11731','Functional neuromuscular stimulation; transcutaneous stimulation of sequential muscle groups of ambulation with computer control; used for walking by spinal cord injured; entire system; after completion of training program','Functional neuromuscularstim','E0764','3','','1','0','','','','0','1','0','0'),
('11732','Fda approved nerve stimulator; with replaceable batteries; for treatment of nausea and vomiting','Nerve stimulator for tx n&v','E0765','3','','1','0','','','','0','1','0','0'),
('11733','Electrical stimulation device used for cancer treatment; includes all accessories; any type','Elec stim cancer treatment','E0766','3','','1','0','','','','0','1','0','0'),
('11734','Electrical stimulation or electromagnetic wound treatment device; not otherwise classified','Electric wound treatment dev','E0769','3','','1','0','','','','0','1','0','0'),
('11735','Functional electrical stimulator; transcutaneous stimulation of nerve and/or muscle groups; any type; complete system; not otherwise specified','Functional electric stim nos','E0770','3','','1','0','','','','0','1','0','0'),
('11736','Iv pole','Iv pole','E0776','3','','1','0','','','','0','1','0','0'),
('11737','Ambulatory infusion pump; mechanical; reusable; for infusion 8 hours or greater','Amb infusion pump mechanical','E0779','3','','1','0','','','','0','1','0','0'),
('11738','Ambulatory infusion pump; mechanical; reusable; for infusion less than 8 hours','Mech amb infusion pump <8hrs','E0780','3','','1','0','','','','0','1','0','0'),
('11739','Ambulatory infusion pump; single or multiple channels; electric or battery operated; with administrative equipment; worn by patient','External ambulatory infus pu','E0781','3','','1','0','','','','0','1','0','0'),
('11740','Infusion pump; implantable; non-programmable (includes all components; e.g.; pump; catheter; connectors; etc.)','Non-programble infusion pump','E0782','3','','1','0','','','','0','1','0','0'),
('11741','Infusion pump system; implantable; programmable (includes all components; e.g.; pump; catheter; connectors; etc.)','Programmable infusion pump','E0783','3','','1','0','','','','0','1','0','0'),
('11742','External ambulatory infusion pump; insulin','Ext amb infusn pump insulin','E0784','3','','1','0','','','','0','1','0','0'),
('11743','Implantable intraspinal (epidural/intrathecal) catheter used with implantable infusion pump; replacement','Replacement impl pump cathet','E0785','3','','1','0','','','','0','1','0','0'),
('11744','Implantable programmable infusion pump; replacement (excludes implantable intraspinal catheter)','Implantable pump replacement','E0786','3','','1','0','','','','0','1','0','0'),
('11745','Parenteral infusion pump; stationary; single or multi-channel','Parenteral infusion pump sta','E0791','3','','1','0','','','','0','1','0','0'),
('11746','Ambulatory traction device; all types; each','Ambulatory traction device','E0830','3','','1','0','','','','0','1','0','0'),
('11747','Traction frame; attached to headboard; cervical traction','Tract frame attach headboard','E0840','3','','1','0','','','','0','1','0','0'),
('11748','Traction equipment; cervical; free-standing stand/frame; pneumatic; applying traction force to other than mandible','Cervical pneum trac equip','E0849','3','','1','0','','','','0','1','0','0'),
('11749','Traction stand; free standing; cervical traction','Traction stand free standing','E0850','3','','1','0','','','','0','1','0','0'),
('11750','Cervical traction equipment not requiring additional stand or frame','Cervical traction equipment','E0855','3','','1','0','','','','0','1','0','0'),
('11751','Cervical traction device; with inflatable air bladder(s)','Cervic collar w air bladders','E0856','3','','1','0','','','','0','1','0','0'),
('11752','Traction equipment; overdoor; cervical','Tract equip cervical tract','E0860','3','','1','0','','','','0','1','0','0'),
('11753','Traction frame; attached to footboard; extremity traction; (e.g.; bucks)','Tract frame attach footboard','E0870','3','','1','0','','','','0','1','0','0'),
('11754','Traction stand; free standing; extremity traction; (e.g.; bucks)','Trac stand free stand extrem','E0880','3','','1','0','','','','0','1','0','0'),
('11755','Traction frame; attached to footboard; pelvic traction','Traction frame attach pelvic','E0890','3','','1','0','','','','0','1','0','0'),
('11756','Traction stand; free standing; pelvic traction; (e.g.; bucks)','Trac stand free stand pelvic','E0900','3','','1','0','','','','0','1','0','0'),
('11757','Trapeze bars; a/k/a patient helper; attached to bed; with grab bar','Trapeze bar attached to bed','E0910','3','','1','0','','','','0','1','0','0'),
('11758','Trapeze bar; heavy duty; for patient weight capacity greater than 250 pounds; attached to bed; with grab bar','Hd trapeze bar attach to bed','E0911','3','','1','0','','','','0','1','0','0'),
('11759','Trapeze bar; heavy duty; for patient weight capacity greater than 250 pounds; free standing; complete with grab bar','Hd trapeze bar free standing','E0912','3','','1','0','','','','0','1','0','0'),
('11760','Fracture frame; attached to bed; includes weights','Fracture frame attached to b','E0920','3','','1','0','','','','0','1','0','0'),
('11761','Fracture frame; free standing; includes weights','Fracture frame free standing','E0930','3','','1','0','','','','0','1','0','0'),
('11762','Continuous passive motion exercise device for use on knee only','Cont pas motion exercise dev','E0935','3','','1','0','','','','0','1','0','0'),
('11763','Continuous passive motion exercise device for use other than knee','Cpm device; other than knee','E0936','3','','1','0','','','','0','1','0','0'),
('11764','Trapeze bar; free standing; complete with grab bar','Trapeze bar free standing','E0940','3','','1','0','','','','0','1','0','0'),
('11765','Gravity assisted traction device; any type','Gravity assisted traction de','E0941','3','','1','0','','','','0','1','0','0'),
('11766','Cervical head harness/halter','Cervical head harness/halter','E0942','3','','1','0','','','','0','1','0','0'),
('11767','Pelvic belt/harness/boot','Pelvic belt/harness/boot','E0944','3','','1','0','','','','0','1','0','0'),
('11768','Extremity belt/harness','Belt/harness extremity','E0945','3','','1','0','','','','0','1','0','0'),
('11769','Fracture; frame; dual with cross bars; attached to bed; (e.g.; balken; 4 poster)','Fracture frame dual w cross','E0946','3','','1','0','','','','0','1','0','0'),
('11770','Fracture frame; attachments for complex pelvic traction','Fracture frame attachmnts pe','E0947','3','','1','0','','','','0','1','0','0'),
('11771','Fracture frame; attachments for complex cervical traction','Fracture frame attachmnts ce','E0948','3','','1','0','','','','0','1','0','0'),
('11772','Wheelchair accessory; tray; each','Tray','E0950','3','','1','0','','','','0','1','0','0'),
('11773','Heel loop/holder; any type; with or without ankle strap; each','Loop heel','E0951','3','','1','0','','','','0','1','0','0'),
('11774','Toe loop/holder; any type; each','Toe loop/holder; each','E0952','3','','1','0','','','','0','1','0','0'),
('11775','Wheelchair accessory; headrest; cushioned; any type; including fixed mounting hardware; each','Cushioned headrest','E0955','3','','1','0','','','','0','1','0','0'),
('11776','Wheelchair accessory; lateral trunk or hip support; any type; including fixed mounting hardware; each','W/c lateral trunk/hip suppor','E0956','3','','1','0','','','','0','1','0','0'),
('11777','Wheelchair accessory; medial thigh support; any type; including fixed mounting hardware; each','W/c medial thigh support','E0957','3','','1','0','','','','0','1','0','0'),
('11778','Manual wheelchair accessory; one-arm drive attachment; each','Whlchr att- conv 1 arm drive','E0958','3','','1','0','','','','0','1','0','0'),
('11779','Manual wheelchair accessory; adapter for amputee; each','Amputee adapter','E0959','3','','1','0','','','','0','1','0','0'),
('11780','Wheelchair accessory; shoulder harness/straps or chest strap; including any type mounting hardware','W/c shoulder harness/straps','E0960','3','','1','0','','','','0','1','0','0'),
('11781','Manual wheelchair accessory; wheel lock brake extension (handle); each','Wheelchair brake extension','E0961','3','','1','0','','','','0','1','0','0'),
('11782','Manual wheelchair accessory; headrest extension; each','Wheelchair head rest extensi','E0966','3','','1','0','','','','0','1','0','0'),
('11783','Manual wheelchair accessory; hand rim with projections; any type; replacement only; each','Man wc rim/projection rep ea','E0967','3','','1','0','','','','0','1','0','0'),
('11784','Commode seat; wheelchair','Wheelchair commode seat','E0968','3','','1','0','','','','0','1','0','0'),
('11785','Narrowing device; wheelchair','Wheelchair narrowing device','E0969','3','','1','0','','','','0','1','0','0'),
('11786','No. 2 footplates; except for elevating leg rest','Wheelchair no. 2 footplates','E0970','3','','1','0','','','','0','1','0','0'),
('11787','Manual wheelchair accessory; anti-tipping device; each','Wheelchair anti-tipping devi','E0971','3','','1','0','','','','0','1','0','0'),
('11788','Wheelchair accessory; adjustable height; detachable armrest; complete assembly; each','W/ch access det adj armrest','E0973','3','','1','0','','','','0','1','0','0'),
('11789','Manual wheelchair accessory; anti-rollback device; each','W/ch access anti-rollback','E0974','3','','1','0','','','','0','1','0','0'),
('11790','Wheelchair accessory; positioning belt/safety belt/pelvic strap; each','W/c acc;saf belt pelv strap','E0978','3','','1','0','','','','0','1','0','0'),
('11791','Safety vest; wheelchair','Wheelchair safety vest','E0980','3','','1','0','','','','0','1','0','0'),
('11792','Wheelchair accessory; seat upholstery; replacement only; each','Seat upholstery; replacement','E0981','3','','1','0','','','','0','1','0','0'),
('11793','Wheelchair accessory; back upholstery; replacement only; each','Back upholstery; replacement','E0982','3','','1','0','','','','0','1','0','0'),
('11794','Manual wheelchair accessory; power add-on to convert manual wheelchair to motorized wheelchair; joystick control','Add pwr joystick','E0983','3','','1','0','','','','0','1','0','0'),
('11795','Manual wheelchair accessory; power add-on to convert manual wheelchair to motorized wheelchair; tiller control','Add pwr tiller','E0984','3','','1','0','','','','0','1','0','0'),
('11796','Wheelchair accessory; seat lift mechanism','W/c seat lift mechanism','E0985','3','','1','0','','','','0','1','0','0'),
('11797','Manual wheelchair accessory; push-rim activated power assist system','Man w/c push-rim powr system','E0986','3','','1','0','','','','0','1','0','0'),
('11798','Manual wheelchair accessory; lever-activated; wheel drive; pair','Lever-activated wheel drive','E0988','3','','1','0','','','','0','1','0','0'),
('11799','Wheelchair accessory; elevating leg rest; complete assembly; each','Wheelchair elevating leg res','E0990','3','','1','0','','','','0','1','0','0'),
('11800','Manual wheelchair accessory; solid seat insert','Wheelchair solid seat insert','E0992','3','','1','0','','','','0','1','0','0'),
('11801','Arm rest; each','Wheelchair arm rest','E0994','3','','1','0','','','','0','1','0','0'),
('11802','Wheelchair accessory; calf rest/pad; replacement only; each','Wc calf rest; pad replacemnt','E0995','3','','1','0','','','','0','1','0','0'),
('11803','Wheelchair accessory; power seating system; tilt only','Pwr seat tilt','E1002','3','','1','0','','','','0','1','0','0'),
('11804','Wheelchair accessory; power seating system; recline only; without shear reduction','Pwr seat recline','E1003','3','','1','0','','','','0','1','0','0'),
('11805','Wheelchair accessory; power seating system; recline only; with mechanical shear reduction','Pwr seat recline mech','E1004','3','','1','0','','','','0','1','0','0'),
('11806','Wheelchair accessory; power seatng system; recline only; with power shear reduction','Pwr seat recline pwr','E1005','3','','1','0','','','','0','1','0','0'),
('11807','Wheelchair accessory; power seating system; combination tilt and recline; without shear reduction','Pwr seat combo w/o shear','E1006','3','','1','0','','','','0','1','0','0'),
('11808','Wheelchair accessory; power seating system; combination tilt and recline; with mechanical shear reduction','Pwr seat combo w/shear','E1007','3','','1','0','','','','0','1','0','0'),
('11809','Wheelchair accessory; power seating system; combination tilt and recline; with power shear reduction','Pwr seat combo pwr shear','E1008','3','','1','0','','','','0','1','0','0'),
('11810','Wheelchair accessory; addition to power seating system; mechanically linked leg elevation system; including pushrod and leg rest; each','Add mech leg elevation','E1009','3','','1','0','','','','0','1','0','0'),
('11811','Wheelchair accessory; addition to power seating system; power leg elevation system; including leg rest; pair','Add pwr leg elevation','E1010','3','','1','0','','','','0','1','0','0'),
('11812','Modification to pediatric size wheelchair; width adjustment package (not to be dispensed with initial chair)','Ped wc modify width adjustm','E1011','3','','1','0','','','','0','1','0','0'),
('11813','Wheelchair accessory; addition to power seating system; center mount power elevating leg rest/platform; complete system; any type; each','Ctr mount pwr elev leg rest','E1012','3','','1','0','','','','0','1','0','0'),
('11814','Reclining back; addition to pediatric size wheelchair','Reclining back add ped w/c','E1014','3','','1','0','','','','0','1','0','0'),
('11815','Shock absorber for manual wheelchair; each','Shock absorber for man w/c','E1015','3','','1','0','','','','0','1','0','0'),
('11816','Shock absorber for power wheelchair; each','Shock absorber for power w/c','E1016','3','','1','0','','','','0','1','0','0'),
('11817','Heavy duty shock absorber for heavy duty or extra heavy duty manual wheelchair; each','Hd shck absrbr for hd man wc','E1017','3','','1','0','','','','0','1','0','0'),
('11818','Heavy duty shock absorber for heavy duty or extra heavy duty power wheelchair; each','Hd shck absrber for hd powwc','E1018','3','','1','0','','','','0','1','0','0'),
('11819','Residual limb support system for wheelchair; any type','Residual limb support system','E1020','3','','1','0','','','','0','1','0','0'),
('11820','Wheelchair accessory; manual swingaway; retractable or removable mounting hardware for joystick; other control interface or positioning accessory','W/c manual swingaway','E1028','3','','1','0','','','','0','1','0','0'),
('11821','Wheelchair accessory; ventilator tray; fixed','W/c vent tray fixed','E1029','3','','1','0','','','','0','1','0','0'),
('11822','Wheelchair accessory; ventilator tray; gimbaled','W/c vent tray gimbaled','E1030','3','','1','0','','','','0','1','0','0'),
('11823','Rollabout chair; any and all types with casters 5'' or greater','Rollabout chair with casters','E1031','3','','1','0','','','','0','1','0','0'),
('11824','Multi-positional patient transfer system; with integrated seat; operated by care giver; patient weight capacity up to and including 300 lbs','Patient transfer system <300','E1035','3','','1','0','','','','0','1','0','0'),
('11825','Multi-positional patient transfer system; extra-wide; with integrated seat; operated by caregiver; patient weight capacity greater than 300 lbs','Patient transfer system >300','E1036','3','','1','0','','','','0','1','0','0'),
('11826','Transport chair; pediatric size','Transport chair; ped size','E1037','3','','1','0','','','','0','1','0','0'),
('11827','Transport chair; adult size; patient weight capacity up to and including 300 pounds','Transport chair pt wt<=300lb','E1038','3','','1','0','','','','0','1','0','0'),
('11828','Transport chair; adult size; heavy duty; patient weight capacity greater than 300 pounds','Transport chair pt wt >300lb','E1039','3','','1','0','','','','0','1','0','0'),
('11829','Fully-reclining wheelchair; fixed full length arms; swing away detachable elevating leg rests','Whelchr fxd full length arms','E1050','3','','1','0','','','','0','1','0','0'),
('11830','Fully-reclining wheelchair; detachable arms; desk or full length; swing away detachable elevating legrests','Wheelchair detachable arms','E1060','3','','1','0','','','','0','1','0','0'),
('11831','Fully-reclining wheelchair; detachable arms (desk or full length) swing away detachable footrest','Wheelchair detachable foot r','E1070','3','','1','0','','','','0','1','0','0'),
('11832','Hemi-wheelchair; fixed full length arms; swing away detachable elevating leg rest','Hemi-wheelchair fixed arms','E1083','3','','1','0','','','','0','1','0','0'),
('11833','Hemi-wheelchair; detachable arms desk or full length arms; swing away detachable elevating leg rests','Hemi-wheelchair detachable a','E1084','3','','1','0','','','','0','1','0','0'),
('11834','Hemi-wheelchair; fixed full length arms; swing away detachable foot rests','Hemi-wheelchair fixed arms','E1085','3','','1','0','','','','0','1','0','0'),
('11835','Hemi-wheelchair detachable arms desk or full length; swing away detachable footrests','Hemi-wheelchair detachable a','E1086','3','','1','0','','','','0','1','0','0'),
('11836','High strength lightweight wheelchair; fixed full length arms; swing away detachable elevating leg rests','Wheelchair lightwt fixed arm','E1087','3','','1','0','','','','0','1','0','0'),
('11837','High strength lightweight wheelchair; detachable arms desk or full length; swing away detachable elevating leg rests','Wheelchair lightweight det a','E1088','3','','1','0','','','','0','1','0','0'),
('11838','High strength lightweight wheelchair; fixed length arms; swing away detachable footrest','Wheelchair lightwt fixed arm','E1089','3','','1','0','','','','0','1','0','0'),
('11839','High strength lightweight wheelchair; detachable arms desk or full length; swing away detachable foot rests','Wheelchair lightweight det a','E1090','3','','1','0','','','','0','1','0','0'),
('11840','Wide heavy duty wheel chair; detachable arms (desk or full length); swing away detachable elevating leg rests','Wheelchair wide w/ leg rests','E1092','3','','1','0','','','','0','1','0','0'),
('11841','Wide heavy duty wheelchair; detachable arms desk or full length arms; swing away detachable footrests','Wheelchair wide w/ foot rest','E1093','3','','1','0','','','','0','1','0','0'),
('11842','Semi-reclining wheelchair; fixed full length arms; swing away detachable elevating leg rests','Whchr s-recl fxd arm leg res','E1100','3','','1','0','','','','0','1','0','0'),
('11843','Semi-reclining wheelchair; detachable arms (desk or full length) elevating leg rest','Wheelchair semi-recl detach','E1110','3','','1','0','','','','0','1','0','0'),
('11844','Standard wheelchair; fixed full length arms; fixed or swing away detachable footrests','Whlchr stand fxd arm ft rest','E1130','3','','1','0','','','','0','1','0','0'),
('11845','Wheelchair; detachable arms; desk or full length; swing away detachable footrests','Wheelchair standard detach a','E1140','3','','1','0','','','','0','1','0','0'),
('11846','Wheelchair; detachable arms; desk or full length swing away detachable elevating legrests','Wheelchair standard w/ leg r','E1150','3','','1','0','','','','0','1','0','0'),
('11847','Wheelchair; fixed full length arms; swing away detachable elevating legrests','Wheelchair fixed arms','E1160','3','','1','0','','','','0','1','0','0'),
('11848','Manual adult size wheelchair; includes tilt in space','Manual adult wc w tiltinspac','E1161','3','','1','0','','','','0','1','0','0'),
('11849','Amputee wheelchair; fixed full length arms; swing away detachable elevating legrests','Whlchr ampu fxd arm leg rest','E1170','3','','1','0','','','','0','1','0','0'),
('11850','Amputee wheelchair; fixed full length arms; without footrests or legrest','Wheelchair amputee w/o leg r','E1171','3','','1','0','','','','0','1','0','0'),
('11851','Amputee wheelchair; detachable arms (desk or full length) without footrests or legrest','Wheelchair amputee detach ar','E1172','3','','1','0','','','','0','1','0','0'),
('11852','Amputee wheelchair; detachable arms (desk or full length) swing away detachable footrests','Wheelchair amputee w/ foot r','E1180','3','','1','0','','','','0','1','0','0'),
('11853','Amputee wheelchair; detachable arms (desk or full length) swing away detachable elevating legrests','Wheelchair amputee w/ leg re','E1190','3','','1','0','','','','0','1','0','0'),
('11854','Heavy duty wheelchair; fixed full length arms; swing away detachable elevating legrests','Wheelchair amputee heavy dut','E1195','3','','1','0','','','','0','1','0','0'),
('11855','Amputee wheelchair; fixed full length arms; swing away detachable footrest','Wheelchair amputee fixed arm','E1200','3','','1','0','','','','0','1','0','0'),
('11856','Wheelchair; specially sized or constructed; (indicate brand name; model number; if any) and justification','Whlchr special size/constrc','E1220','3','','1','0','','','','0','1','0','0'),
('11857','Wheelchair with fixed arm; footrests','Wheelchair spec size w foot','E1221','3','','1','0','','','','0','1','0','0'),
('11858','Wheelchair with fixed arm; elevating legrests','Wheelchair spec size w/ leg','E1222','3','','1','0','','','','0','1','0','0'),
('11859','Wheelchair with detachable arms; footrests','Wheelchair spec size w foot','E1223','3','','1','0','','','','0','1','0','0'),
('11860','Wheelchair with detachable arms; elevating legrests','Wheelchair spec size w/ leg','E1224','3','','1','0','','','','0','1','0','0'),
('11861','Wheelchair accessory; manual semi-reclining back; (recline greater than 15 degrees; but less than 80 degrees); each','Manual semi-reclining back','E1225','3','','1','0','','','','0','1','0','0'),
('11862','Wheelchair accessory; manual fully reclining back; (recline greater than 80 degrees); each','Manual fully reclining back','E1226','3','','1','0','','','','0','1','0','0'),
('11863','Special height arms for wheelchair','Wheelchair spec sz spec ht a','E1227','3','','1','0','','','','0','1','0','0'),
('11864','Special back height for wheelchair','Wheelchair spec sz spec ht b','E1228','3','','1','0','','','','0','1','0','0'),
('11865','Wheelchair; pediatric size; not otherwise specified','Pediatric wheelchair nos','E1229','3','','1','0','','','','0','1','0','0'),
('11866','Power operated vehicle (three or four wheel nonhighway) specify brand name and model number','Power operated vehicle','E1230','3','','1','0','','','','0','1','0','0'),
('11867','Wheelchair; pediatric size; tilt-in-space; rigid; adjustable; with seating system','Rigid ped w/c tilt-in-space','E1231','3','','1','0','','','','0','1','0','0'),
('11868','Wheelchair; pediatric size; tilt-in-space; folding; adjustable; with seating system','Folding ped wc tilt-in-space','E1232','3','','1','0','','','','0','1','0','0'),
('11869','Wheelchair; pediatric size; tilt-in-space; rigid; adjustable; without seating system','Rig ped wc tltnspc w/o seat','E1233','3','','1','0','','','','0','1','0','0'),
('11870','Wheelchair; pediatric size; tilt-in-space; folding; adjustable; without seating system','Fld ped wc tltnspc w/o seat','E1234','3','','1','0','','','','0','1','0','0'),
('11871','Wheelchair; pediatric size; rigid; adjustable; with seating system','Rigid ped wc adjustable','E1235','3','','1','0','','','','0','1','0','0'),
('11872','Wheelchair; pediatric size; folding; adjustable; with seating system','Folding ped wc adjustable','E1236','3','','1','0','','','','0','1','0','0'),
('11873','Wheelchair; pediatric size; rigid; adjustable; without seating system','Rgd ped wc adjstabl w/o seat','E1237','3','','1','0','','','','0','1','0','0'),
('11874','Wheelchair; pediatric size; folding; adjustable; without seating system','Fld ped wc adjstabl w/o seat','E1238','3','','1','0','','','','0','1','0','0'),
('11875','Power wheelchair; pediatric size; not otherwise specified','Ped power wheelchair nos','E1239','3','','1','0','','','','0','1','0','0'),
('11876','Lightweight wheelchair; detachable arms; (desk or full length) swing away detachable; elevating legrest','Whchr litwt det arm leg rest','E1240','3','','1','0','','','','0','1','0','0'),
('11877','Lightweight wheelchair; fixed full length arms; swing away detachable footrest','Wheelchair lightwt fixed arm','E1250','3','','1','0','','','','0','1','0','0'),
('11878','Lightweight wheelchair; detachable arms (desk or full length) swing away detachable footrest','Wheelchair lightwt foot rest','E1260','3','','1','0','','','','0','1','0','0'),
('11879','Lightweight wheelchair; fixed full length arms; swing away detachable elevating legrests','Wheelchair lightweight leg r','E1270','3','','1','0','','','','0','1','0','0'),
('11880','Heavy duty wheelchair; detachable arms (desk or full length) elevating legrests','Whchr h-duty det arm leg res','E1280','3','','1','0','','','','0','1','0','0'),
('11881','Heavy duty wheelchair; fixed full length arms; swing away detachable footrest','Wheelchair heavy duty fixed','E1285','3','','1','0','','','','0','1','0','0'),
('11882','Heavy duty wheelchair; detachable arms (desk or full length) swing away detachable footrest','Wheelchair hvy duty detach a','E1290','3','','1','0','','','','0','1','0','0'),
('11883','Heavy duty wheelchair; fixed full length arms; elevating legrest','Wheelchair heavy duty fixed','E1295','3','','1','0','','','','0','1','0','0'),
('11884','Special wheelchair seat height from floor','Wheelchair special seat heig','E1296','3','','1','0','','','','0','1','0','0'),
('11885','Special wheelchair seat depth; by upholstery','Wheelchair special seat dept','E1297','3','','1','0','','','','0','1','0','0'),
('11886','Special wheelchair seat depth and/or width; by construction','Wheelchair spec seat depth/w','E1298','3','','1','0','','','','0','1','0','0'),
('11887','Whirlpool; portable (overtub type)','Whirlpool portable','E1300','3','','1','0','','','','0','1','0','0'),
('11888','Whirlpool; non-portable (built-in type)','Whirlpool non-portable','E1310','3','','1','0','','','','0','1','0','0'),
('11889','Oxygen accessory; flow regulator capable of positive inspiratory pressure','O2 flow reg pos inspir press','E1352','3','','1','0','','','','0','1','0','0'),
('11890','Regulator','Oxygen supplies regulator','E1353','3','','1','0','','','','0','1','0','0'),
('11891','Oxygen accessory; wheeled cart for portable cylinder or portable concentrator; any type; replacement only; each','Wheeled cart; port cyl/conc','E1354','3','','1','0','','','','0','1','0','0'),
('11892','Stand/rack','Oxygen supplies stand/rack','E1355','3','','1','0','','','','0','1','0','0'),
('11893','Oxygen accessory; battery pack/cartridge for portable concentrator; any type; replacement only; each','Batt pack/cart; port conc','E1356','3','','1','0','','','','0','1','0','0'),
('11894','Oxygen accessory; battery charger for portable concentrator; any type; replacement only; each','Battery charger; port conc','E1357','3','','1','0','','','','0','1','0','0'),
('11895','Oxygen accessory; dc power adapter for portable concentrator; any type; replacement only; each','Dc power adapter; port conc','E1358','3','','1','0','','','','0','1','0','0'),
('11896','Immersion external heater for nebulizer','Oxy suppl heater for nebuliz','E1372','3','','1','0','','','','0','1','0','0'),
('11897','Oxygen concentrator; single delivery port; capable of delivering 85 percent or greater oxygen concentration at the prescribed flow rate','Oxygen concentrator','E1390','3','','1','0','','','','0','1','0','0'),
('11898','Oxygen concentrator; dual delivery port; capable of delivering 85 percent or greater oxygen concentration at the prescribed flow rate; each','Oxygen concentrator; dual','E1391','3','','1','0','','','','0','1','0','0'),
('11899','Portable oxygen concentrator; rental','Portable oxygen concentrator','E1392','3','','1','0','','','','0','1','0','0'),
('11900','Durable medical equipment; miscellaneous','Durable medical equipment mi','E1399','3','','1','0','','','','0','1','0','0'),
('11901','Oxygen and water vapor enriching system with heated delivery','O2/water vapor enrich w/heat','E1405','3','','1','0','','','','0','1','0','0'),
('11902','Oxygen and water vapor enriching system without heated delivery','O2/water vapor enrich w/o he','E1406','3','','1','0','','','','0','1','0','0'),
('11903','Centrifuge; for dialysis','Centrifuge','E1500','3','','1','0','','','','0','1','0','0'),
('11904','Kidney; dialysate delivery syst kidney machine; pump recirculating; air removal syst; flowrate meter; power off; heater and temperature control with alarm; i.v. poles; pressure gauge; concentrate container','Kidney dialysate delivry sys','E1510','3','','1','0','','','','0','1','0','0'),
('11905','Heparin infusion pump for hemodialysis','Heparin infusion pump','E1520','3','','1','0','','','','0','1','0','0'),
('11906','Air bubble detector for hemodialysis; each; replacement','Replacement air bubble detec','E1530','3','','1','0','','','','0','1','0','0'),
('11907','Pressure alarm for hemodialysis; each; replacement','Replacement pressure alarm','E1540','3','','1','0','','','','0','1','0','0'),
('11908','Bath conductivity meter for hemodialysis; each','Bath conductivity meter','E1550','3','','1','0','','','','0','1','0','0'),
('11909','Blood leak detector for hemodialysis; each; replacement','Replace blood leak detector','E1560','3','','1','0','','','','0','1','0','0'),
('11910','Adjustable chair; for esrd patients','Adjustable chair for esrd pt','E1570','3','','1','0','','','','0','1','0','0'),
('11911','Transducer protectors/fluid barriers; for hemodialysis; any size; per 10','Transducer protect/fld bar','E1575','3','','1','0','','','','0','1','0','0'),
('11912','Unipuncture control system for hemodialysis','Unipuncture control system','E1580','3','','1','0','','','','0','1','0','0'),
('11913','Hemodialysis machine','Hemodialysis machine','E1590','3','','1','0','','','','0','1','0','0'),
('11914','Automatic intermittent peritoneal dialysis system','Auto interm peritoneal dialy','E1592','3','','1','0','','','','0','1','0','0'),
('11915','Cycler dialysis machine for peritoneal dialysis','Cycler dialysis machine','E1594','3','','1','0','','','','0','1','0','0'),
('11916','Delivery and/or installation charges for hemodialysis equipment','Deli/install chrg hemo equip','E1600','3','','1','0','','','','0','1','0','0'),
('11917','Reverse osmosis water purification system; for hemodialysis','Reverse osmosis h2o puri sys','E1610','3','','1','0','','','','0','1','0','0'),
('11918','Deionizer water purification system; for hemodialysis','Deionizer h2o puri system','E1615','3','','1','0','','','','0','1','0','0'),
('11919','Blood pump for hemodialysis; replacement','Replacement blood pump','E1620','3','','1','0','','','','0','1','0','0'),
('11920','Water softening system; for hemodialysis','Water softening system','E1625','3','','1','0','','','','0','1','0','0'),
('11921','Reciprocating peritoneal dialysis system','Reciprocating peritoneal dia','E1630','3','','1','0','','','','0','1','0','0'),
('11922','Wearable artificial kidney; each','Wearable artificial kidney','E1632','3','','1','0','','','','0','1','0','0'),
('11923','Peritoneal dialysis clamps; each','Peritoneal dialysis clamp','E1634','3','','1','0','','','','0','1','0','0'),
('11924','Compact (portable) travel hemodialyzer system','Compact travel hemodialyzer','E1635','3','','1','0','','','','0','1','0','0'),
('11925','Sorbent cartridges; for hemodialysis; per 10','Sorbent cartridges per 10','E1636','3','','1','0','','','','0','1','0','0'),
('11926','Hemostats; each','Hemostats for dialysis; each','E1637','3','','1','0','','','','0','1','0','0'),
('11927','Scale; each','Dialysis scale','E1639','3','','1','0','','','','0','1','0','0'),
('11928','Dialysis equipment; not otherwise specified','Dialysis equipment noc','E1699','3','','1','0','','','','0','1','0','0'),
('11929','Jaw motion rehabilitation system','Jaw motion rehab system','E1700','3','','1','0','','','','0','1','0','0'),
('11930','Replacement cushions for jaw motion rehabilitation system; pkg. of 6','Repl cushions for jaw motion','E1701','3','','1','0','','','','0','1','0','0'),
('11931','Replacement measuring scales for jaw motion rehabilitation system; pkg. of 200','Repl measr scales jaw motion','E1702','3','','1','0','','','','0','1','0','0'),
('11932','Dynamic adjustable elbow extension/flexion device; includes soft interface material','Adjust elbow ext/flex device','E1800','3','','1','0','','','','0','1','0','0'),
('11933','Static progressive stretch elbow device; extension and/or flexion; with or without range of motion adjustment; includes all components and accessories','Sps elbow device','E1801','3','','1','0','','','','0','1','0','0'),
('11934','Dynamic adjustable forearm pronation/supination device; includes soft interface material','Adjst forearm pro/sup device','E1802','3','','1','0','','','','0','1','0','0'),
('11935','Dynamic adjustable wrist extension / flexion device; includes soft interface material','Adjust wrist ext/flex device','E1805','3','','1','0','','','','0','1','0','0'),
('11936','Static progressive stretch wrist device; flexion and/or extension; with or without range of motion adjustment; includes all components and accessories','Sps wrist device','E1806','3','','1','0','','','','0','1','0','0'),
('11937','Dynamic adjustable knee extension / flexion device; includes soft interface material','Adjust knee ext/flex device','E1810','3','','1','0','','','','0','1','0','0'),
('11938','Static progressive stretch knee device; extension and/or flexion; with or without range of motion adjustment; includes all components and accessories','Sps knee device','E1811','3','','1','0','','','','0','1','0','0'),
('11939','Dynamic knee; extension/flexion device with active resistance control','Knee ext/flex w act res ctrl','E1812','3','','1','0','','','','0','1','0','0'),
('11940','Dynamic adjustable ankle extension/flexion device; includes soft interface material','Adjust ankle ext/flex device','E1815','3','','1','0','','','','0','1','0','0'),
('11941','Static progressive stretch ankle device; flexion and/or extension; with or without range of motion adjustment; includes all components and accessories','Sps ankle device','E1816','3','','1','0','','','','0','1','0','0'),
('11942','Static progressive stretch forearm pronation / supination device; with or without range of motion adjustment; includes all components and accessories','Sps forearm device','E1818','3','','1','0','','','','0','1','0','0'),
('11943','Replacement soft interface material; dynamic adjustable extension/flexion device','Soft interface material','E1820','3','','1','0','','','','0','1','0','0'),
('11944','Replacement soft interface material/cuffs for bi-directional static progressive stretch device','Replacement interface spsd','E1821','3','','1','0','','','','0','1','0','0'),
('11945','Dynamic adjustable finger extension/flexion device; includes soft interface material','Adjust finger ext/flex devc','E1825','3','','1','0','','','','0','1','0','0'),
('11946','Dynamic adjustable toe extension/flexion device; includes soft interface material','Adjust toe ext/flex device','E1830','3','','1','0','','','','0','1','0','0'),
('11947','Static progressive stretch toe device; extension and/or flexion; with or without range of motion adjustment; includes all components and accessories','Static str toe dev ext/flex','E1831','3','','1','0','','','','0','1','0','0'),
('11948','Dynamic adjustable shoulder flexion / abduction / rotation device; includes soft interface material','Adj shoulder ext/flex device','E1840','3','','1','0','','','','0','1','0','0'),
('11949','Static progressive stretch shoulder device; with or without range of motion adjustment; includes all components and accessories','Static str shldr dev rom adj','E1841','3','','1','0','','','','0','1','0','0'),
('11950','Communication board; non-electronic augmentative or alternative communication device','Aac non-electronic board','E1902','3','','1','0','','','','0','1','0','0'),
('11951','Gastric suction pump; home model; portable or stationary; electric','Gastric suction pump hme mdl','E2000','3','','1','0','','','','0','1','0','0'),
('11952','Blood glucose monitor with integrated voice synthesizer','Bld glucose monitor w voice','E2100','3','','1','0','','','','0','1','0','0'),
('11953','Blood glucose monitor with integrated lancing/blood sample','Bld glucose monitor w lance','E2101','3','','1','0','','','','0','1','0','0'),
('11954','Pulse generator system for tympanic treatment of inner ear endolymphatic fluid','Pulse gen sys tx endolymp fl','E2120','3','','1','0','','','','0','1','0','0'),
('11955','Manual wheelchair accessory; nonstandard seat frame; width greater than or equal to 20 inches and less than 24 inches','Man w/ch acc seat w>=20''<24''','E2201','3','','1','0','','','','0','1','0','0'),
('11956','Manual wheelchair accessory; nonstandard seat frame width; 24-27 inches','Seat width 24-27 in','E2202','3','','1','0','','','','0','1','0','0'),
('11957','Manual wheelchair accessory; nonstandard seat frame depth; 20 to less than 22 inches','Frame depth less than 22 in','E2203','3','','1','0','','','','0','1','0','0'),
('11958','Manual wheelchair accessory; nonstandard seat frame depth; 22 to 25 inches','Frame depth 22 to 25 in','E2204','3','','1','0','','','','0','1','0','0'),
('11959','Manual wheelchair accessory; handrim without projections (includes ergonomic or contoured); any type; replacement only; each','Manual wc accessory; handrim','E2205','3','','1','0','','','','0','1','0','0'),
('11960','Manual wheelchair accessory; wheel lock assembly; complete; replacement only; each','Man wc whl lock comp repl ea','E2206','3','','1','0','','','','0','1','0','0'),
('11961','Wheelchair accessory; crutch and cane holder; each','Crutch and cane holder','E2207','3','','1','0','','','','0','1','0','0'),
('11962','Wheelchair accessory; cylinder tank carrier; each','Cylinder tank carrier','E2208','3','','1','0','','','','0','1','0','0'),
('11963','Accessory; arm trough; with or without hand support; each','Arm trough each','E2209','3','','1','0','','','','0','1','0','0'),
('11964','Wheelchair accessory; bearings; any type; replacement only; each','Wheelchair bearings','E2210','3','','1','0','','','','0','1','0','0'),
('11965','Manual wheelchair accessory; pneumatic propulsion tire; any size; each','Pneumatic propulsion tire','E2211','3','','1','0','','','','0','1','0','0'),
('11966','Manual wheelchair accessory; tube for pneumatic propulsion tire; any size; each','Pneumatic prop tire tube','E2212','3','','1','0','','','','0','1','0','0'),
('11967','Manual wheelchair accessory; insert for pneumatic propulsion tire (removable); any type; any size; each','Pneumatic prop tire insert','E2213','3','','1','0','','','','0','1','0','0'),
('11968','Manual wheelchair accessory; pneumatic caster tire; any size; each','Pneumatic caster tire each','E2214','3','','1','0','','','','0','1','0','0'),
('11969','Manual wheelchair accessory; tube for pneumatic caster tire; any size; each','Pneumatic caster tire tube','E2215','3','','1','0','','','','0','1','0','0'),
('11970','Manual wheelchair accessory; foam filled propulsion tire; any size; each','Foam filled propulsion tire','E2216','3','','1','0','','','','0','1','0','0'),
('11971','Manual wheelchair accessory; foam filled caster tire; any size; each','Foam filled caster tire each','E2217','3','','1','0','','','','0','1','0','0'),
('11972','Manual wheelchair accessory; foam propulsion tire; any size; each','Foam propulsion tire each','E2218','3','','1','0','','','','0','1','0','0'),
('11973','Manual wheelchair accessory; foam caster tire; any size; each','Foam caster tire any size ea','E2219','3','','1','0','','','','0','1','0','0'),
('11974','Manual wheelchair accessory; solid (rubber/plastic) propulsion tire; any size; replacement only; each','Solid propuls tire; repl; ea','E2220','3','','1','0','','','','0','1','0','0'),
('11975','Manual wheelchair accessory; solid (rubber/plastic) caster tire (removable); any size; replacement only; each','Solid caster tire repl; each','E2221','3','','1','0','','','','0','1','0','0'),
('11976','Manual wheelchair accessory; solid (rubber/plastic) caster tire with integrated wheel; any size; replacement only; each','Solid caster integ whl; repl','E2222','3','','1','0','','','','0','1','0','0'),
('11977','Manual wheelchair accessory; propulsion wheel excludes tire; any size; replacement only; each','Propulsion whl excl tire rep','E2224','3','','1','0','','','','0','1','0','0'),
('11978','Manual wheelchair accessory; caster wheel excludes tire; any size; replacement only; each','Caster wheel excludes tire','E2225','3','','1','0','','','','0','1','0','0'),
('11979','Manual wheelchair accessory; caster fork; any size; replacement only; each','Caster fork replacement only','E2226','3','','1','0','','','','0','1','0','0'),
('11980','Manual wheelchair accessory; gear reduction drive wheel; each','Gear reduction drive wheel','E2227','3','','1','0','','','','0','1','0','0'),
('11981','Manual wheelchair accessory; wheel braking system and lock; complete; each','Mwc acc; wheelchair brake','E2228','3','','1','0','','','','0','1','0','0'),
('11982','Manual wheelchair accessory; manual standing system','Manual standing system','E2230','3','','1','0','','','','0','1','0','0'),
('11983','Manual wheelchair accessory; solid seat support base (replaces sling seat); includes any type mounting hardware','Solid seat support base','E2231','3','','1','0','','','','0','1','0','0'),
('11984','Back; planar; for pediatric size wheelchair including fixed attaching hardware','Planar back for ped size wc','E2291','3','','1','0','','','','0','1','0','0'),
('11985','Seat; planar; for pediatric size wheelchair including fixed attaching hardware','Planar seat for ped size wc','E2292','3','','1','0','','','','0','1','0','0'),
('11986','Back; contoured; for pediatric size wheelchair including fixed attaching hardware','Contour back for ped size wc','E2293','3','','1','0','','','','0','1','0','0'),
('11987','Seat; contoured; for pediatric size wheelchair including fixed attaching hardware','Contour seat for ped size wc','E2294','3','','1','0','','','','0','1','0','0'),
('11988','Manual wheelchair accessory; for pediatric size wheelchair; dynamic seating frame; allows coordinated movement of multiple positioning features','Ped dynamic seating frame','E2295','3','','1','0','','','','0','1','0','0'),
('11989','Wheelchair accessory; power seat elevation system; any type','Pwr seat elevation sys','E2300','3','','1','0','','','','0','1','0','0'),
('11990','Wheelchair accessory; power standing system; any type','Pwr standing','E2301','3','','1','0','','','','0','1','0','0'),
('11991','Power wheelchair accessory; electronic connection between wheelchair controller and one power seating system motor; including all related electronics; indicator feature; mechanical function selection switch; and fixed mounting hardware','Electro connect btw control','E2310','3','','1','0','','','','0','1','0','0'),
('11992','Power wheelchair accessory; electronic connection between wheelchair controller and two or more power seating system motors; including all related electronics; indicator feature; mechanical function selection switch; and fixed mounting hardware','Electro connect btw 2 sys','E2311','3','','1','0','','','','0','1','0','0'),
('11993','Power wheelchair accessory; hand or chin control interface; mini-proportional remote joystick; proportional; including fixed mounting hardware','Mini-prop remote joystick','E2312','3','','1','0','','','','0','1','0','0'),
('11994','Power wheelchair accessory; harness for upgrade to expandable controller; including all fasteners; connectors and mounting hardware; each','Pwc harness; expand control','E2313','3','','1','0','','','','0','1','0','0'),
('11995','Power wheelchair accessory; hand control interface; remote joystick; nonproportional; including all related electronics; mechanical stop switch; and fixed mounting hardware','Hand interface joystick','E2321','3','','1','0','','','','0','1','0','0'),
('11996','Power wheelchair accessory; hand control interface; multiple mechanical switches; nonproportional; including all related electronics; mechanical stop switch; and fixed mounting hardware','Mult mech switches','E2322','3','','1','0','','','','0','1','0','0'),
('11997','Power wheelchair accessory; specialty joystick handle for hand control interface; prefabricated','Special joystick handle','E2323','3','','1','0','','','','0','1','0','0'),
('11998','Power wheelchair accessory; chin cup for chin control interface','Chin cup interface','E2324','3','','1','0','','','','0','1','0','0'),
('11999','Power wheelchair accessory; sip and puff interface; nonproportional; including all related electronics; mechanical stop switch; and manual swingaway mounting hardware','Sip and puff interface','E2325','3','','1','0','','','','0','1','0','0'),
('12000','Power wheelchair accessory; breath tube kit for sip and puff interface','Breath tube kit','E2326','3','','1','0','','','','0','1','0','0'),
('12001','Power wheelchair accessory; head control interface; mechanical; proportional; including all related electronics; mechanical direction change switch; and fixed mounting hardware','Head control interface mech','E2327','3','','1','0','','','','0','1','0','0'),
('12002','Power wheelchair accessory; head control or extremity control interface; electronic; proportional; including all related electronics and fixed mounting hardware','Head/extremity control inter','E2328','3','','1','0','','','','0','1','0','0'),
('12003','Power wheelchair accessory; head control interface; contact switch mechanism; nonproportional; including all related electronics; mechanical stop switch; mechanical direction change switch; head array; and fixed mounting hardware','Head control nonproportional','E2329','3','','1','0','','','','0','1','0','0'),
('12004','Power wheelchair accessory; head control interface; proximity switch mechanism; nonproportional; including all related electronics; mechanical stop switch; mechanical direction change switch; head array; and fixed mounting hardware','Head control proximity switc','E2330','3','','1','0','','','','0','1','0','0'),
('12005','Power wheelchair accessory; attendant control; proportional; including all related electronics and fixed mounting hardware','Attendant control','E2331','3','','1','0','','','','0','1','0','0'),
('12006','Power wheelchair accessory; nonstandard seat frame width; 20-23 inches','W/c wdth 20-23 in seat frame','E2340','3','','1','0','','','','0','1','0','0'),
('12007','Power wheelchair accessory; nonstandard seat frame width; 24-27 inches','W/c wdth 24-27 in seat frame','E2341','3','','1','0','','','','0','1','0','0'),
('12008','Power wheelchair accessory; nonstandard seat frame depth; 20 or 21 inches','W/c dpth 20-21 in seat frame','E2342','3','','1','0','','','','0','1','0','0'),
('12009','Power wheelchair accessory; nonstandard seat frame depth; 22-25 inches','W/c dpth 22-25 in seat frame','E2343','3','','1','0','','','','0','1','0','0'),
('12010','Power wheelchair accessory; electronic interface to operate speech generating device using power wheelchair control interface','Electronic sgd interface','E2351','3','','1','0','','','','0','1','0','0'),
('12011','Power wheelchair accessory; group 34 non-sealed lead acid battery; each','Gr 34 nonsealed leadacid','E2358','3','','1','0','','','','0','1','0','0'),
('12012','Power wheelchair accessory; group 34 sealed lead acid battery; each (e.g.; gel cell; absorbed glassmat)','Gr34 sealed leadacid battery','E2359','3','','1','0','','','','0','1','0','0'),
('12013','Power wheelchair accessory; 22nf non-sealed lead acid battery; each','22nf nonsealed leadacid','E2360','3','','1','0','','','','0','1','0','0'),
('12014','Power wheelchair accessory; 22nf sealed lead acid battery; each; (e.g.; gel cell; absorbed glassmat)','22nf sealed leadacid battery','E2361','3','','1','0','','','','0','1','0','0'),
('12015','Power wheelchair accessory; group 24 non-sealed lead acid battery; each','Gr24 nonsealed leadacid','E2362','3','','1','0','','','','0','1','0','0'),
('12016','Power wheelchair accessory; group 24 sealed lead acid battery; each (e.g.; gel cell; absorbed glassmat)','Gr24 sealed leadacid battery','E2363','3','','1','0','','','','0','1','0','0'),
('12017','Power wheelchair accessory; u-1 non-sealed lead acid battery; each','U1nonsealed leadacid battery','E2364','3','','1','0','','','','0','1','0','0'),
('12018','Power wheelchair accessory; u-1 sealed lead acid battery; each (e.g.; gel cell; absorbed glassmat)','U1 sealed leadacid battery','E2365','3','','1','0','','','','0','1','0','0'),
('12019','Power wheelchair accessory; battery charger; single mode; for use with only one battery type; sealed or non-sealed; each','Battery charger; single mode','E2366','3','','1','0','','','','0','1','0','0'),
('12020','Power wheelchair accessory; battery charger; dual mode; for use with either battery type; sealed or non-sealed; each','Battery charger; dual mode','E2367','3','','1','0','','','','0','1','0','0'),
('12021','Power wheelchair component; drive wheel motor; replacement only','Pwr wc drivewheel motor repl','E2368','3','','1','0','','','','0','1','0','0'),
('12022','Power wheelchair component; drive wheel gear box; replacement only','Pwr wc drivewheel gear repl','E2369','3','','1','0','','','','0','1','0','0'),
('12023','Power wheelchair component; integrated drive wheel motor and gear box combination; replacement only','Pwr wc dr wh motor/gear comb','E2370','3','','1','0','','','','0','1','0','0'),
('12024','Power wheelchair accessory; group 27 sealed lead acid battery; (e.g.; gel cell; absorbed glassmat); each','Gr27 sealed leadacid battery','E2371','3','','1','0','','','','0','1','0','0'),
('12025','Power wheelchair accessory; group 27 non-sealed lead acid battery; each','Gr27 non-sealed leadacid','E2372','3','','1','0','','','','0','1','0','0'),
('12026','Power wheelchair accessory; hand or chin control interface; compact remote joystick; proportional; including fixed mounting hardware','Hand/chin ctrl spec joystick','E2373','3','','1','0','','','','0','1','0','0'),
('12027','Power wheelchair accessory; hand or chin control interface; standard remote joystick (not including controller); proportional; including all related electronics and fixed mounting hardware; replacement only','Hand/chin ctrl std joystick','E2374','3','','1','0','','','','0','1','0','0'),
('12028','Power wheelchair accessory; non-expandable controller; including all related electronics and mounting hardware; replacement only','Non-expandable controller','E2375','3','','1','0','','','','0','1','0','0'),
('12029','Power wheelchair accessory; expandable controller; including all related electronics and mounting hardware; replacement only','Expandable controller; repl','E2376','3','','1','0','','','','0','1','0','0'),
('12030','Power wheelchair accessory; expandable controller; including all related electronics and mounting hardware; upgrade provided at initial issue','Expandable controller; initl','E2377','3','','1','0','','','','0','1','0','0'),
('12031','Power wheelchair component; actuator; replacement only','Pw actuator replacement','E2378','3','','1','0','','','','0','1','0','0'),
('12032','Power wheelchair accessory; pneumatic drive wheel tire; any size; replacement only; each','Pneum drive wheel tire','E2381','3','','1','0','','','','0','1','0','0'),
('12033','Power wheelchair accessory; tube for pneumatic drive wheel tire; any size; replacement only; each','Tube; pneum wheel drive tire','E2382','3','','1','0','','','','0','1','0','0'),
('12034','Power wheelchair accessory; insert for pneumatic drive wheel tire (removable); any type; any size; replacement only; each','Insert; pneum wheel drive','E2383','3','','1','0','','','','0','1','0','0'),
('12035','Power wheelchair accessory; pneumatic caster tire; any size; replacement only; each','Pneumatic caster tire','E2384','3','','1','0','','','','0','1','0','0'),
('12036','Power wheelchair accessory; tube for pneumatic caster tire; any size; replacement only; each','Tube; pneumatic caster tire','E2385','3','','1','0','','','','0','1','0','0'),
('12037','Power wheelchair accessory; foam filled drive wheel tire; any size; replacement only; each','Foam filled drive wheel tire','E2386','3','','1','0','','','','0','1','0','0'),
('12038','Power wheelchair accessory; foam filled caster tire; any size; replacement only; each','Foam filled caster tire','E2387','3','','1','0','','','','0','1','0','0'),
('12039','Power wheelchair accessory; foam drive wheel tire; any size; replacement only; each','Foam drive wheel tire','E2388','3','','1','0','','','','0','1','0','0'),
('12040','Power wheelchair accessory; foam caster tire; any size; replacement only; each','Foam caster tire','E2389','3','','1','0','','','','0','1','0','0'),
('12041','Power wheelchair accessory; solid (rubber/plastic) drive wheel tire; any size; replacement only; each','Solid drive wheel tire','E2390','3','','1','0','','','','0','1','0','0'),
('12042','Power wheelchair accessory; solid (rubber/plastic) caster tire (removable); any size; replacement only; each','Solid caster tire','E2391','3','','1','0','','','','0','1','0','0'),
('12043','Power wheelchair accessory; solid (rubber/plastic) caster tire with integrated wheel; any size; replacement only; each','Solid caster tire; integrate','E2392','3','','1','0','','','','0','1','0','0'),
('12044','Power wheelchair accessory; drive wheel excludes tire; any size; replacement only; each','Drive wheel excludes tire','E2394','3','','1','0','','','','0','1','0','0'),
('12045','Power wheelchair accessory; caster wheel excludes tire; any size; replacement only; each','Caster wheel excludes tire','E2395','3','','1','0','','','','0','1','0','0'),
('12046','Power wheelchair accessory; caster fork; any size; replacement only; each','Caster fork','E2396','3','','1','0','','','','0','1','0','0'),
('12047','Power wheelchair accessory; lithium-based battery; each','Pwc acc; lith-based battery','E2397','3','','1','0','','','','0','1','0','0'),
('12048','Negative pressure wound therapy electrical pump; stationary or portable','Neg press wound therapy pump','E2402','3','','1','0','','','','0','1','0','0'),
('12049','Speech generating device; digitized speech; using pre-recorded messages; less than or equal to 8 minutes recording time','Sgd digitized pre-rec <=8min','E2500','3','','1','0','','','','0','1','0','0'),
('12050','Speech generating device; digitized speech; using pre-recorded messages; greater than 8 minutes but less than or equal to 20 minutes recording time','Sgd prerec msg >8min <=20min','E2502','3','','1','0','','','','0','1','0','0'),
('12051','Speech generating device; digitized speech; using pre-recorded messages; greater than 20 minutes but less than or equal to 40 minutes recording time','Sgd prerec msg>20min <=40min','E2504','3','','1','0','','','','0','1','0','0'),
('12052','Speech generating device; digitized speech; using pre-recorded messages; greater than 40 minutes recording time','Sgd prerec msg > 40 min','E2506','3','','1','0','','','','0','1','0','0'),
('12053','Speech generating device; synthesized speech; requiring message formulation by spelling and access by physical contact with the device','Sgd spelling phys contact','E2508','3','','1','0','','','','0','1','0','0'),
('12054','Speech generating device; synthesized speech; permitting multiple methods of message formulation and multiple methods of device access','Sgd w multi methods msg/accs','E2510','3','','1','0','','','','0','1','0','0'),
('12055','Speech generating software program; for personal computer or personal digital assistant','Sgd sftwre prgrm for pc/pda','E2511','3','','1','0','','','','0','1','0','0'),
('12056','Accessory for speech generating device; mounting system','Sgd accessory; mounting sys','E2512','3','','1','0','','','','0','1','0','0'),
('12057','Accessory for speech generating device; not otherwise classified','Sgd accessory noc','E2599','3','','1','0','','','','0','1','0','0'),
('12058','General use wheelchair seat cushion; width less than 22 inches; any depth','Gen w/c cushion wdth < 22 in','E2601','3','','1','0','','','','0','1','0','0'),
('12059','General use wheelchair seat cushion; width 22 inches or greater; any depth','Gen w/c cushion wdth >=22 in','E2602','3','','1','0','','','','0','1','0','0'),
('12060','Skin protection wheelchair seat cushion; width less than 22 inches; any depth','Skin protect wc cus wd <22in','E2603','3','','1','0','','','','0','1','0','0'),
('12061','Skin protection wheelchair seat cushion; width 22 inches or greater; any depth','Skin protect wc cus wd>=22in','E2604','3','','1','0','','','','0','1','0','0'),
('12062','Positioning wheelchair seat cushion; width less than 22 inches; any depth','Position wc cush wdth <22 in','E2605','3','','1','0','','','','0','1','0','0'),
('12063','Positioning wheelchair seat cushion; width 22 inches or greater; any depth','Position wc cush wdth>=22 in','E2606','3','','1','0','','','','0','1','0','0'),
('12064','Skin protection and positioning wheelchair seat cushion; width less than 22 inches; any depth','Skin pro/pos wc cus wd <22in','E2607','3','','1','0','','','','0','1','0','0'),
('12065','Skin protection and positioning wheelchair seat cushion; width 22 inches or greater; any depth','Skin pro/pos wc cus wd>=22in','E2608','3','','1','0','','','','0','1','0','0'),
('12066','Custom fabricated wheelchair seat cushion; any size','Custom fabricate w/c cushion','E2609','3','','1','0','','','','0','1','0','0'),
('12067','Wheelchair seat cushion; powered','Powered w/c cushion','E2610','3','','1','0','','','','0','1','0','0'),
('12068','General use wheelchair back cushion; width less than 22 inches; any height; including any type mounting hardware','Gen use back cush wdth <22in','E2611','3','','1','0','','','','0','1','0','0'),
('12069','General use wheelchair back cushion; width 22 inches or greater; any height; including any type mounting hardware','Gen use back cush wdth>=22in','E2612','3','','1','0','','','','0','1','0','0'),
('12070','Positioning wheelchair back cushion; posterior; width less than 22 inches; any height; including any type mounting hardware','Position back cush wd <22in','E2613','3','','1','0','','','','0','1','0','0'),
('12071','Positioning wheelchair back cushion; posterior; width 22 inches or greater; any height; including any type mounting hardware','Position back cush wd>=22in','E2614','3','','1','0','','','','0','1','0','0'),
('12072','Positioning wheelchair back cushion; posterior-lateral; width less than 22 inches; any height; including any type mounting hardware','Pos back post/lat wdth <22in','E2615','3','','1','0','','','','0','1','0','0'),
('12073','Positioning wheelchair back cushion; posterior-lateral; width 22 inches or greater; any height; including any type mounting hardware','Pos back post/lat wdth>=22in','E2616','3','','1','0','','','','0','1','0','0'),
('12074','Custom fabricated wheelchair back cushion; any size; including any type mounting hardware','Custom fab w/c back cushion','E2617','3','','1','0','','','','0','1','0','0'),
('12075','Replacement cover for wheelchair seat cushion or back cushion; each','Replace cover w/c seat cush','E2619','3','','1','0','','','','0','1','0','0'),
('12076','Positioning wheelchair back cushion; planar back with lateral supports; width less than 22 inches; any height; including any type mounting hardware','Wc planar back cush wd <22in','E2620','3','','1','0','','','','0','1','0','0'),
('12077','Positioning wheelchair back cushion; planar back with lateral supports; width 22 inches or greater; any height; including any type mounting hardware','Wc planar back cush wd>=22in','E2621','3','','1','0','','','','0','1','0','0'),
('12078','Skin protection wheelchair seat cushion; adjustable; width less than 22 inches; any depth','Adj skin pro w/c cus wd<22in','E2622','3','','1','0','','','','0','1','0','0'),
('12079','Skin protection wheelchair seat cushion; adjustable; width 22 inches or greater; any depth','Adj skin pro wc cus wd>=22in','E2623','3','','1','0','','','','0','1','0','0'),
('12080','Skin protection and positioning wheelchair seat cushion; adjustable; width less than 22 inches; any depth','Adj skin pro/pos cus<22in','E2624','3','','1','0','','','','0','1','0','0'),
('12081','Skin protection and positioning wheelchair seat cushion; adjustable; width 22 inches or greater; any depth','Adj skin pro/pos wc cus>=22','E2625','3','','1','0','','','','0','1','0','0'),
('12082','Wheelchair accessory; shoulder elbow; mobile arm support attached to wheelchair; balanced; adjustable','Seo mobile arm sup att to wc','E2626','3','','1','0','','','','0','1','0','0'),
('12083','Wheelchair accessory; shoulder elbow; mobile arm support attached to wheelchair; balanced; adjustable rancho type','Arm supp att to wc rancho ty','E2627','3','','1','0','','','','0','1','0','0'),
('12084','Wheelchair accessory; shoulder elbow; mobile arm support attached to wheelchair; balanced; reclining','Mobile arm supports reclinin','E2628','3','','1','0','','','','0','1','0','0'),
('12085','Wheelchair accessory; shoulder elbow; mobile arm support attached to wheelchair; balanced; friction arm support (friction dampening to proximal and distal joints)','Friction dampening arm supp','E2629','3','','1','0','','','','0','1','0','0'),
('12086','Wheelchair accessory; shoulder elbow; mobile arm support; monosuspension arm and hand support; overhead elbow forearm hand sling support; yoke type suspension support','Monosuspension arm/hand supp','E2630','3','','1','0','','','','0','1','0','0'),
('12087','Wheelchair accessory; addition to mobile arm support; elevating proximal arm','Elevat proximal arm support','E2631','3','','1','0','','','','0','1','0','0'),
('12088','Wheelchair accessory; addition to mobile arm support; offset or lateral rocker arm with elastic balance control','Offset/lat rocker arm w/ela','E2632','3','','1','0','','','','0','1','0','0'),
('12089','Wheelchair accessory; addition to mobile arm support; supinator','Mobile arm support supinator','E2633','3','','1','0','','','','0','1','0','0'),
('12090','Gait trainer; pediatric size; posterior support; includes all accessories and components','Posterior gait trainer','E8000','3','','1','0','','','','0','1','0','0'),
('12091','Gait trainer; pediatric size; upright support; includes all accessories and components','Upright gait trainer','E8001','3','','1','0','','','','0','1','0','0'),
('12092','Gait trainer; pediatric size; anterior support; includes all accessories and components','Anterior gait trainer','E8002','3','','1','0','','','','0','1','0','0'),
('12093','Administration of influenza virus vaccine','Admin influenza virus vac','G0008','3','','1','0','','','','0','1','0','0'),
('12094','Administration of pneumococcal vaccine','Admin pneumococcal vaccine','G0009','3','','1','0','','','','0','1','0','0'),
('12095','Administration of hepatitis b vaccine','Admin hepatitis b vaccine','G0010','3','','1','0','','','','0','1','0','0'),
('12096','Semen analysis; presence and/or motility of sperm excluding huhner','Semen analysis','G0027','3','','1','0','','','','0','1','0','0'),
('12097','Cervical or vaginal cancer screening; pelvic and clinical breast examination','Ca screen;pelvic/breast exam','G0101','3','','1','0','','','','0','1','0','0'),
('12098','Prostate cancer screening; digital rectal examination','Prostate ca screening; dre','G0102','3','','1','0','','','','0','1','0','0'),
('12099','Prostate cancer screening; prostate specific antigen test (psa)','Psa screening','G0103','3','','1','0','','','','0','1','0','0'),
('12100','Colorectal cancer screening; flexible sigmoidoscopy','Ca screen;flexi sigmoidscope','G0104','3','','1','0','','','','0','1','0','0'),
('12101','Colorectal cancer screening; colonoscopy on individual at high risk','Colorectal scrn; hi risk ind','G0105','3','','1','0','','','','0','1','0','0'),
('12102','Colorectal cancer screening; alternative to g0104; screening sigmoidoscopy; barium enema','Colon ca screen;barium enema','G0106','3','','1','0','','','','0','1','0','0'),
('12103','Diabetes outpatient self-management training services; individual; per 30 minutes','Diab manage trn  per indiv','G0108','3','','1','0','','','','0','1','0','0'),
('12104','Diabetes outpatient self-management training services; group session (2 or more); per 30 minutes','Diab manage trn ind/group','G0109','3','','1','0','','','','0','1','0','0'),
('12105','Glaucoma screening for high risk patients furnished by an optometrist or ophthalmologist','Glaucoma scrn hgh risk direc','G0117','3','','1','0','','','','0','1','0','0'),
('12106','Glaucoma screening for high risk patient furnished under the direct supervision of an optometrist or ophthalmologist','Glaucoma scrn hgh risk direc','G0118','3','','1','0','','','','0','1','0','0'),
('12107','Colorectal cancer screening; alternative to g0105; screening colonoscopy; barium enema.','Colon ca scrn; barium enema','G0120','3','','1','0','','','','0','1','0','0'),
('12108','Colorectal cancer screening; colonoscopy on individual not meeting criteria for high risk','Colon ca scrn not hi rsk ind','G0121','3','','1','0','','','','0','1','0','0'),
('12109','Colorectal cancer screening; barium enema','Colon ca scrn; barium enema','G0122','3','','1','0','','','','0','1','0','0'),
('12110','Screening cytopathology; cervical or vaginal (any reporting system); collected in preservative fluid; automated thin layer preparation; screening by cytotechnologist under physician supervision','Screen cerv/vag thin layer','G0123','3','','1','0','','','','0','1','0','0'),
('12111','Screening cytopathology; cervical or vaginal (any reporting system); collected in preservative fluid; automated thin layer preparation; requiring interpretation by physician','Screen c/v thin layer by md','G0124','3','','1','0','','','','0','1','0','0'),
('12112','Trimming of dystrophic nails; any number','Trim nail(s)','G0127','3','','1','0','','','','0','1','0','0'),
('12113','Direct (face-to-face with patient) skilled nursing services of a registered nurse provided in a comprehensive outpatient rehabilitation facility; each 10 minutes beyond the first 5 minutes','Corf skilled nursing service','G0128','3','','1','0','','','','0','1','0','0'),
('12114','Occupational therapy services requiring the skills of a qualified occupational therapist; furnished as a component of a partial hospitalization treatment program; per session (45 minutes or more)','Partial hosp prog service','G0129','3','','1','0','','','','0','1','0','0'),
('12115','Single energy x-ray absorptiometry (sexa) bone density study; one or more sites; appendicular skeleton (peripheral) (e.g.; radius; wrist; heel)','Single energy x-ray study','G0130','3','','1','0','','','','0','1','0','0'),
('12116','Screening cytopathology smears; cervical or vaginal; performed by automated system; with manual rescreening; requiring interpretation by physician','Scr c/v cyto;autosys and md','G0141','3','','1','0','','','','0','1','0','0'),
('12117','Screening cytopathology; cervical or vaginal (any reporting system); collected in preservative fluid; automated thin layer preparation; with manual screening and rescreening by cytotechnologist under physician supervision','Scr c/v cyto;thinlayer;rescr','G0143','3','','1','0','','','','0','1','0','0'),
('12118','Screening cytopathology; cervical or vaginal (any reporting system); collected in preservative fluid; automated thin layer preparation; with screening by automated system; under physician supervision','Scr c/v cyto;thinlayer;rescr','G0144','3','','1','0','','','','0','1','0','0'),
('12119','Screening cytopathology; cervical or vaginal (any reporting system); collected in preservative fluid; automated thin layer preparation; with screening by automated system and manual rescreening under physician supervision','Scr c/v cyto;thinlayer;rescr','G0145','3','','1','0','','','','0','1','0','0'),
('12120','Screening cytopathology smears; cervical or vaginal; performed by automated system under physician supervision','Scr c/v cyto; automated sys','G0147','3','','1','0','','','','0','1','0','0'),
('12121','Screening cytopathology smears; cervical or vaginal; performed by automated system with manual rescreening','Scr c/v cyto; autosys; rescr','G0148','3','','1','0','','','','0','1','0','0'),
('12122','Services performed by a qualified physical therapist in the home health or hospice setting; each 15 minutes','Hhcp-serv of pt;ea 15 min','G0151','3','','1','0','','','','0','1','0','0'),
('12123','Services performed by a qualified occupational therapist in the home health or hospice setting; each 15 minutes','Hhcp-serv of ot;ea 15 min','G0152','3','','1','0','','','','0','1','0','0'),
('12124','Services performed by a qualified speech-language pathologist in the home health or hospice setting; each 15 minutes','Hhcp-svs of s/l path;ea 15mn','G0153','3','','1','0','','','','0','1','0','0'),
('12125','Direct skilled nursing services of a licensed nurse (lpn or rn) in the home health or hospice setting; each 15 minutes','Hhcp-svs of rn;ea 15 min','G0154','3','','1','0','','','','0','1','0','0'),
('12126','Services of clinical social worker in home health or hospice settings; each 15 minutes','Hhcp-svs of csw;ea 15 min','G0155','3','','1','0','','','','0','1','0','0'),
('12127','Services of home health/hospice aide in home health or hospice settings; each 15 minutes','Hhcp-svs of aide;ea 15 min','G0156','3','','1','0','','','','0','1','0','0'),
('12128','Services performed by a qualified physical therapist assistant in the home health or hospice setting; each 15 minutes','Hhc pt assistant ea 15','G0157','3','','1','0','','','','0','1','0','0'),
('12129','Services performed by a qualified occupational therapist assistant in the home health or hospice setting; each 15 minutes','Hhc ot assistant ea 15','G0158','3','','1','0','','','','0','1','0','0'),
('12130','Services performed by a qualified physical therapist; in the home health setting; in the establishment or delivery of a safe and effective physical therapy maintenance program; each 15 minutes','Hhc pt maint ea 15 min','G0159','3','','1','0','','','','0','1','0','0'),
('12131','Services performed by a qualified occupational therapist; in the home health setting; in the establishment or delivery of a safe and effective occupational therapy maintenance program; each 15 minutes','Hhc occup therapy ea 15','G0160','3','','1','0','','','','0','1','0','0'),
('12132','Services performed by a qualified speech-language pathologist; in the home health setting; in the establishment or delivery of a safe and effective speech-language pathology maintenance program; each 15 minutes','Hhc slp ea 15 min','G0161','3','','1','0','','','','0','1','0','0'),
('12133','Skilled services by a registered nurse (rn) for management and evaluation of the plan of care; each 15 minutes (the patients underlying condition or complication requires an rn to ensure that essential non-skilled care achieves its purpose in the home health or hospice setting)','Hhc rn e&m plan svs; 15 min','G0162','3','','1','0','','','','0','1','0','0'),
('12134','Skilled services of a licensed nurse (lpn or rn) for the observation and assessment of the patients condition; each 15 minutes (the change in the patients condition requires skilled nursing personnel to identify and evaluate the patients need for possible modification of treatment in the home health or hospice setting)','Hhc lpn/rn obs/asses ea 15','G0163','3','','1','0','','','','0','1','0','0'),
('12135','Skilled services of a licensed nurse (lpn or rn); in the training and/or education of a patient or family member; in the home health or hospice setting; each 15 minutes','Hhc lis nurse train ea 15','G0164','3','','1','0','','','','0','1','0','0'),
('12136','External counterpulsation; per treatment session','Extrnl counterpulse; per tx','G0166','3','','1','0','','','','0','1','0','0'),
('12137','Wound closure utilizing tissue adhesive(s) only','Wound closure by adhesive','G0168','3','','1','0','','','','0','1','0','0'),
('12138','Linear accelerator based stereotactic radiosurgery; complete course of therapy in one session','Linear acc stereo radsur com','G0173','3','','1','0','','','','0','1','0','0'),
('12139','Scheduled interdisciplinary team conference (minimum of three exclusive of patient care nursing staff) with patient present','Opps service;sched team conf','G0175','3','','1','0','','','','0','1','0','0'),
('12140','Activity therapy; such as music; dance; art or play therapies not for recreation; related to the care and treatment of patients disabling mental health problems; per session (45 minutes or more)','Opps/php;activity therapy','G0176','3','','1','0','','','','0','1','0','0'),
('12141','Training and educational services related to the care and treatment of patients disabling mental health problems per session (45 minutes or more)','Opps/php; train & educ serv','G0177','3','','1','0','','','','0','1','0','0'),
('12142','Physician re-certification for medicare-covered home health services under a home health plan of care (patient not present); including contacts with home health agency and review of reports of patient status required by physicians to affirm the initial implementation of the plan of care that meets patients needs; per re-certification period','Md recertification hha pt','G0179','3','','1','0','','','','0','1','0','0'),
('12143','Physician certification for medicare-covered home health services under a home health plan of care (patient not present); including contacts with home health agency and review of reports of patient status required by physicians to affirm the initial implementation of the plan of care that meets patients needs; per certification period','Md certification hha patient','G0180','3','','1','0','','','','0','1','0','0'),
('12144','Physician supervision of a patient receiving medicare-covered services provided by a participating home health agency (patient not present) requiring complex and multidisciplinary care modalities involving regular physician development and/or revision of care plans; review of subsequent reports of patient status; review of laboratory and other studies; communication (including telephone calls) with other health care professionals involved in the patients care; integration of new information into the medical treatment plan and/or adjustment of medical therapy; within a calendar month; 30 minutes or more','Home health care supervision','G0181','3','','1','0','','','','0','1','0','0'),
('12145','Physician supervision of a patient under a medicare-approved hospice (patient not present) requiring complex and multidisciplinary care modalities involving regular physician development and/or revision of care plans; review of subsequent reports of patient status; review of laboratory and other studies; communication (including telephone calls) with other health care professionals involved in the patients care; integration of new information into the medical treatment plan and/or adjustment of medical therapy; within a calendar month; 30 minutes or more','Hospice care supervision','G0182','3','','1','0','','','','0','1','0','0'),
('12146','Destruction of localized lesion of choroid (for example; choroidal neovascularization); photocoagulation; feeder vessel technique (one or more sessions)','Dstry eye lesn;fdr vssl tech','G0186','3','','1','0','','','','0','1','0','0'),
('12147','Screening mammography; bilateral (2-view study of each breast); including computer-aided detection (cad) when performed','Scr mammo bi incl cad','G0202','3','','1','0','','','','0','1','0','0'),
('12148','Diagnostic mammography; including computer-aided detection (cad) when performed; bilateral','Dx mammo incl cad bi','G0204','3','','1','0','','','','0','1','0','0'),
('12149','Diagnostic mammography; including computer-aided detection (cad) when performed; unilateral','Dx mammo incl cad uni','G0206','3','','1','0','','','','0','1','0','0'),
('12150','Pet imaging whole body; melanoma for non-covered indications','Pet img wholbod melano nonco','G0219','3','','1','0','','','','0','1','0','0'),
('12151','Pet imaging; any site; not otherwise specified','Pet not otherwise specified','G0235','3','','1','0','','','','0','1','0','0'),
('12152','Therapeutic procedures to increase strength or endurance of respiratory muscles; face to face; one on one; each 15 minutes (includes monitoring)','Therapeutic procd strg endur','G0237','3','','1','0','','','','0','1','0','0'),
('12153','Therapeutic procedures to improve respiratory function; other than described by g0237; one on one; face to face; per 15 minutes (includes monitoring)','Oth resp proc; indiv','G0238','3','','1','0','','','','0','1','0','0'),
('12154','Therapeutic procedures to improve respiratory function or increase strength or endurance of respiratory muscles; two or more individuals (includes monitoring)','Oth resp proc; group','G0239','3','','1','0','','','','0','1','0','0'),
('12155','Initial physician evaluation and management of a diabetic patient with diabetic sensory neuropathy resulting in a loss of protective sensation (lops) which must include: (1) the diagnosis of lops; (2) a patient history; (3) a physical examination that consists of at least the following elements: (a) visual inspection of the forefoot; hindfoot and toe web spaces; (b) evaluation of a protective sensation; (c) evaluation of foot structure and biomechanics; (d) evaluation of vascular status and skin integrity; and (e) evaluation and recommendation of footwear and (4) patient education','Initial foot exam pt lops','G0245','3','','1','0','','','','0','1','0','0'),
('12156','Follow-up physician evaluation and management of a diabetic patient with diabetic sensory neuropathy resulting in a loss of protective sensation (lops) to include at least the following: (1) a patient history; (2) a physical examination that includes: (a) visual inspection of the forefoot; hindfoot and toe web spaces; (b) evaluation of protective sensation; (c) evaluation of foot structure and biomechanics; (d) evaluation of vascular status and skin integrity; and (e) evaluation and recommendation of footwear; and (3) patient education','Followup eval of foot pt lop','G0246','3','','1','0','','','','0','1','0','0'),
('12157','Routine foot care by a physician of a diabetic patient with diabetic sensory neuropathy resulting in a loss of protective sensation (lops) to include; the local care of superficial wounds (i.e. superficial to muscle and fascia) and at least the following if present: (1) local care of superficial wounds; (2) debridement of corns and calluses; and (3) trimming and debridement of nails','Routine footcare pt w lops','G0247','3','','1','0','','','','0','1','0','0'),
('12158','Demonstration; prior to initiation of home inr monitoring; for patient with either mechanical heart valve(s); chronic atrial fibrillation; or venous thromboembolism who meets medicare coverage criteria; under the direction of a physician; includes: face-to-face demonstration of use and care of the inr monitor; obtaining at least one blood sample; provision of instructions for reporting home inr test results; and documentation of patients ability to perform testing and report results','Demonstrate use home inr mon','G0248','3','','1','0','','','','0','1','0','0'),
('12159','Provision of test materials and equipment for home inr monitoring of patient with either mechanical heart valve(s); chronic atrial fibrillation; or venous thromboembolism who meets medicare coverage criteria; includes: provision of materials for use in the home and reporting of test results to physician; testing not occurring more frequently than once a week; testing materials; billing units of service include 4 tests','Provide inr test mater/equip','G0249','3','','1','0','','','','0','1','0','0'),
('12160','Physician review; interpretation; and patient management of home inr testing for patient with either mechanical heart valve(s); chronic atrial fibrillation; or venous thromboembolism who meets medicare coverage criteria; testing not occurring more frequently than once a week; billing units of service include 4 tests','Md inr test revie inter mgmt','G0250','3','','1','0','','','','0','1','0','0'),
('12161','Linear accelerator based stereotactic radiosurgery; delivery including collimator changes and custom plugging; fractionated treatment; all lesions; per session; maximum five sessions per course of treatment','Linear acc based stero radio','G0251','3','','1','0','','','','0','1','0','0'),
('12162','Pet imaging; full and partial-ring pet scanners only; for initial diagnosis of breast cancer and/or surgical planning for breast cancer (e.g.; initial staging of axillary lymph nodes)','Pet imaging initial dx','G0252','3','','1','0','','','','0','1','0','0'),
('12163','Current perception threshold/sensory nerve conduction test; (snct) per limb; any nerve','Current percep threshold tst','G0255','3','','1','0','','','','0','1','0','0'),
('12164','Unscheduled or emergency dialysis treatment for an esrd patient in a hospital outpatient department that is not certified as an esrd facility','Unsched dialysis esrd pt hos','G0257','3','','1','0','','','','0','1','0','0'),
('12165','Injection procedure for sacroiliac joint; arthrograpy','Inject for sacroiliac joint','G0259','3','','1','0','','','','0','1','0','0'),
('12166','Injection procedure for sacroiliac joint; provision of anesthetic; steroid and/or other therapeutic agent; with or without arthrography','Inj for sacroiliac jt anesth','G0260','3','','1','0','','','','0','1','0','0'),
('12167','Removal of impacted cerumen (one or both ears) by physician on same date of service as audiologic function testing','Removal of impacted wax md','G0268','3','','1','0','','','','0','1','0','0'),
('12168','Placement of occlusive device into either a venous or arterial access site; post surgical or interventional procedure (e.g.; angioseal plug; vascular plug)','Occlusive device in vein art','G0269','3','','1','0','','','','0','1','0','0'),
('12169','Medical nutrition therapy; reassessment and subsequent intervention(s) following second referral in same year for change in diagnosis; medical condition or treatment regimen (including additional hours needed for renal disease); individual; face to face with the patient; each 15 minutes','Mnt subs tx for change dx','G0270','3','','1','0','','','','0','1','0','0'),
('12170','Medical nutrition therapy; reassessment and subsequent intervention(s) following second referral in same year for change in diagnosis; medical condition; or treatment regimen (including additional hours needed for renal disease); group (2 or more individuals); each 30 minutes','Group mnt 2 or more 30 mins','G0271','3','','1','0','','','','0','1','0','0'),
('12171','Renal angiography; non-selective; one or both kidneys; performed at the same time as cardiac catheterization and/or coronary angiography; includes positioning or placement of any catheter in the abdominal aorta at or near the origins (ostia) of the renal arteries; injection of dye; flush aortogram; production of permanent images; and radiologic supervision and interpretation (list separately in addition to primary procedure)','Renal angio; cardiac cath','G0275','3','','1','0','','','','0','1','0','0'),
('12172','Blinded procedure for lumbar stenosis; percutaneous image-guided lumbar decompression (pild) or placebo-control; performed in an approved coverage with evidence development (ced) clinical trial','Pild/placebo control clin tr','G0276','3','','1','0','','','','0','1','0','0'),
('12173','Hyperbaric oxygen under pressure; full body chamber; per 30 minute interval','Hbot; full body chamber; 30m','G0277','3','','1','0','','','','0','1','0','0'),
('12174','Iliac and/or femoral artery angiography; non-selective; bilateral or ipsilateral to catheter insertion; performed at the same time as cardiac catheterization and/or coronary angiography; includes positioning or placement of the catheter in the distal aorta or ipsilateral femoral or iliac artery; injection of dye; production of permanent images; and radiologic supervision and interpretation (list separately in addition to primary procedure)','Iliac art angio;cardiac cath','G0278','3','','1','0','','','','0','1','0','0'),
('12175','Diagnostic digital breast tomosynthesis; unilateral or bilateral (list separately in addition to g0204 or g0206)','Tomosynthesis; mammo','G0279','3','','1','0','','','','0','1','0','0'),
('12176','Electrical stimulation; (unattended); to one or more areas; for chronic stage iii and stage iv pressure ulcers; arterial ulcers; diabetic ulcers; and venous stasis ulcers not demonstrating measurable signs of healing after 30 days of conventional care; as part of a therapy plan of care','Elec stim unattend for press','G0281','3','','1','0','','','','0','1','0','0'),
('12177','Electrical stimulation; (unattended); to one or more areas; for wound care other than described in g0281','Elect stim wound care not pd','G0282','3','','1','0','','','','0','1','0','0'),
('12178','Electrical stimulation (unattended); to one or more areas for indication(s) other than wound care; as part of a therapy plan of care','Elec stim other than wound','G0283','3','','1','0','','','','0','1','0','0'),
('12179','Reconstruction; computed tomographic angiography of aorta for surgical planning for vascular surgery','Recon; cta for surg plan','G0288','3','','1','0','','','','0','1','0','0'),
('12180','Arthroscopy; knee; surgical; for removal of loose body; foreign body; debridement/shaving of articular cartilage (chondroplasty) at the time of other surgical knee arthroscopy in a different compartment of the same knee','Arthro; loose body + chondro','G0289','3','','1','0','','','','0','1','0','0'),
('12181','Noncovered surgical procedure(s) using conscious sedation; regional; general or spinal anesthesia in a medicare qualifying clinical trial; per day','Non-cov surg proc;clin trial','G0293','3','','1','0','','','','0','1','0','0'),
('12182','Noncovered procedure(s) using either no anesthesia or local anesthesia only; in a medicare qualifying clinical trial; per day','Non-cov proc; clinical trial','G0294','3','','1','0','','','','0','1','0','0'),
('12183','Electromagnetic therapy; to one or more areas; for wound care other than described in g0329 or for other uses','Electromagnetic therapy onc','G0295','3','','1','0','','','','0','1','0','0'),
('12184','Counseling visit to discuss need for lung cancer screening using low dose ct scan (ldct) (service is for eligibility determination and shared decision making)','Visit to determ ldct elig','G0296','3','','1','0','','','','0','1','0','0'),
('12185','Low dose ct scan (ldct) for lung cancer screening','Ldct for lung ca screen','G0297','3','','1','0','','','','0','1','0','0'),
('12186','Direct skilled nursing services of a registered nurse (rn) in the home health or hospice setting; each 15 minutes','Hhs/hospice of rn ea 15 min','G0299','3','','1','0','','','','0','1','0','0'),
('12187','Direct skilled nursing services of a licensed practical nurse (lpn) in the home health or hospice setting; each 15 minutes','Hhs/hospice of lpn ea 15 min','G0300','3','','1','0','','','','0','1','0','0'),
('12188','Pre-operative pulmonary surgery services for preparation for lvrs; complete course of services; to include a minimum of 16 days of services','Pre-op service lvrs complete','G0302','3','','1','0','','','','0','1','0','0'),
('12189','Pre-operative pulmonary surgery services for preparation for lvrs; 10 to 15 days of services','Pre-op service lvrs 10-15dos','G0303','3','','1','0','','','','0','1','0','0'),
('12190','Pre-operative pulmonary surgery services for preparation for lvrs; 1 to 9 days of services','Pre-op service lvrs 1-9 dos','G0304','3','','1','0','','','','0','1','0','0'),
('12191','Post-discharge pulmonary surgery services after lvrs; minimum of 6 days of services','Post op service lvrs min 6','G0305','3','','1','0','','','','0','1','0','0'),
('12192','Complete cbc; automated (hgb; hct; rbc; wbc; without platelet count) and automated wbc differential count','Cbc/diffwbc w/o platelet','G0306','3','','1','0','','','','0','1','0','0'),
('12193','Complete (cbc); automated (hgb; hct; rbc; wbc; without platelet count)','Cbc without platelet','G0307','3','','1','0','','','','0','1','0','0'),
('12194','Colorectal cancer screening; fecal occult blood test; immunoassay; 1-3 simultaneous','Fecal blood scrn immunoassay','G0328','3','','1','0','','','','0','1','0','0'),
('12195','Electromagnetic therapy; to one or more areas for chronic stage iii and stage iv pressure ulcers; arterial ulcers; diabetic ulcers and venous stasis ulcers not demonstrating measurable signs of healing after 30 days of conventional care as part of a therapy plan of care','Electromagntic tx for ulcers','G0329','3','','1','0','','','','0','1','0','0'),
('12196','Pharmacy dispensing fee for inhalation drug(s); initial 30-day supply as a beneficiary','Dispense fee initial 30 day','G0333','3','','1','0','','','','0','1','0','0'),
('12197','Hospice evaluation and counseling services; pre-election','Hospice evaluation preelecti','G0337','3','','1','0','','','','0','1','0','0'),
('12198','Image-guided robotic linear accelerator-based stereotactic radiosurgery; complete course of therapy in one session or first session of fractionated treatment','Robot lin-radsurg com; first','G0339','3','','1','0','','','','0','1','0','0'),
('12199','Image-guided robotic linear accelerator-based stereotactic radiosurgery; delivery including collimator changes and custom plugging; fractionated treatment; all lesions; per session; second through fifth sessions; maximum five sessions per course of treatment','Robt lin-radsurg fractx 2-5','G0340','3','','1','0','','','','0','1','0','0'),
('12200','Percutaneous islet cell transplant; includes portal vein catheterization and infusion','Percutaneous islet celltrans','G0341','3','','1','0','','','','0','1','0','0'),
('12201','Laparoscopy for islet cell transplant; includes portal vein catheterization and infusion','Laparoscopy islet cell trans','G0342','3','','1','0','','','','0','1','0','0'),
('12202','Laparotomy for islet cell transplant; includes portal vein catheterization and infusion','Laparotomy islet cell transp','G0343','3','','1','0','','','','0','1','0','0'),
('12203','Bone marrow aspiration performed with bone marrow biopsy through the same incision on the same date of service','Bone marrow aspirate &biopsy','G0364','3','','1','0','','','','0','1','0','0'),
('12204','Vessel mapping of vessels for hemodialysis access (services for preoperative vessel mapping prior to creation of hemodialysis access using an autogenous hemodialysis conduit; including arterial inflow and venous outflow)','Vessel mapping hemo access','G0365','3','','1','0','','','','0','1','0','0'),
('12205','Physician service required to establish and document the need for a power mobility device','Md service required for pmd','G0372','3','','1','0','','','','0','1','0','0'),
('12206','Hospital observation service; per hour','Hospital observation per hr','G0378','3','','1','0','','','','0','1','0','0'),
('12207','Direct admission of patient for hospital observation care','Direct refer hospital observ','G0379','3','','1','0','','','','0','1','0','0'),
('12208','Level 1 hospital emergency department visit provided in a type b emergency department; (the ed must meet at least one of the following requirements: (1) it is licensed by the state in which it is located under applicable state law as an emergency room or emergency department; (2) it is held out to the public (by name; posted signs; advertising; or other means) as a place that provides care for emergency medical conditions on an urgent basis without requiring a previously scheduled appointment; or (3) during the calendar year immediately preceding the calendar year in which a determination under 42 cfr 489.24 is being made; based on a representative sample of patient visits that occurred during that calendar year; it provides at least one-third of all of its outpatient visits for the treatment of emergency medical conditions on an urgent basis without requiring a previously scheduled appointment)','Lev 1 hosp type b ed visit','G0380','3','','1','0','','','','0','1','0','0'),
('12209','Level 2 hospital emergency department visit provided in a type b emergency department; (the ed must meet at least one of the following requirements: (1) it is licensed by the state in which it is located under applicable state law as an emergency room or emergency department; (2) it is held out to the public (by name; posted signs; advertising; or other means) as a place that provides care for emergency medical conditions on an urgent basis without requiring a previously scheduled appointment; or (3) during the calendar year immediately preceding the calendar year in which a determination under 42 cfr 489.24 is being made; based on a representative sample of patient visits that occurred during that calendar year; it provides at least one-third of all of its outpatient visits for the treatment of emergency medical conditions on an urgent basis without requiring a previously scheduled appointment)','Lev 2 hosp type b ed visit','G0381','3','','1','0','','','','0','1','0','0'),
('12210','Level 3 hospital emergency department visit provided in a type b emergency department; (the ed must meet at least one of the following requirements: (1) it is licensed by the state in which it is located under applicable state law as an emergency room or emergency department; (2) it is held out to the public (by name; posted signs; advertising; or other means) as a place that provides care for emergency medical conditions on an urgent basis without requiring a previously scheduled appointment; or (3) during the calendar year immediately preceding the calendar year in which a determination under 42 cfr 489.24 is being made; based on a representative sample of patient visits that occurred during that calendar year; it provides at least one-third of all of its outpatient visits for the treatment of emergency medical conditions on an urgent basis without requiring a previously scheduled appointment)','Lev 3 hosp type b ed visit','G0382','3','','1','0','','','','0','1','0','0'),
('12211','Level 4 hospital emergency department visit provided in a type b emergency department; (the ed must meet at least one of the following requirements: (1) it is licensed by the state in which it is located under applicable state law as an emergency room or emergency department; (2) it is held out to the public (by name; posted signs; advertising; or other means) as a place that provides care for emergency medical conditions on an urgent basis without requiring a previously scheduled appointment; or (3) during the calendar year immediately preceding the calendar year in which a determination under 42 cfr 489.24 is being made; based on a representative sample of patient visits that occurred during that calendar year; it provides at least one-third of all of its outpatient visits for the treatment of emergency medical conditions on an urgent basis without requiring a previously scheduled appointment)','Lev 4 hosp type b ed visit','G0383','3','','1','0','','','','0','1','0','0'),
('12212','Level 5 hospital emergency department visit provided in a type b emergency department; (the ed must meet at least one of the following requirements: (1) it is licensed by the state in which it is located under applicable state law as an emergency room or emergency department; (2) it is held out to the public (by name; posted signs; advertising; or other means) as a place that provides care for emergency medical conditions on an urgent basis without requiring a previously scheduled appointment; or (3) during the calendar year immediately preceding the calendar year in which a determination under 42 cfr 489.24 is being made; based on a representative sample of patient visits that occurred during that calendar year; it provides at least one-third of all of its outpatient visits for the treatment of emergency medical conditions on an urgent basis without requiring a previously scheduled appointment)','Lev 5 hosp type b ed visit','G0384','3','','1','0','','','','0','1','0','0'),
('12213','Ultrasound b-scan and/or real time with image documentation; for abdominal aortic aneurysm (aaa) screening','Ultrasound exam aaa screen','G0389','3','','1','0','','','','0','1','0','0'),
('12214','Trauma response team associated with hospital critical care service','Trauma respons w/hosp criti','G0390','3','','1','0','','','','0','1','0','0'),
('12215','Alcohol and/or substance (other than tobacco) abuse structured assessment (e.g.; audit; dast); and brief intervention 15 to 30 minutes','Alcohol/subs interv 15-30mn','G0396','3','','1','0','','','','0','1','0','0'),
('12216','Alcohol and/or substance (other than tobacco) abuse structured assessment (e.g.; audit; dast); and intervention; greater than 30 minutes','Alcohol/subs interv >30 min','G0397','3','','1','0','','','','0','1','0','0'),
('12217','Home sleep study test (hst) with type ii portable monitor; unattended; minimum of 7 channels: eeg; eog; emg; ecg/heart rate; airflow; respiratory effort and oxygen saturation','Home sleep test/type 2 porta','G0398','3','','1','0','','','','0','1','0','0'),
('12218','Home sleep test (hst) with type iii portable monitor; unattended; minimum of 4 channels: 2 respiratory movement/airflow; 1 ecg/heart rate and 1 oxygen saturation','Home sleep test/type 3 porta','G0399','3','','1','0','','','','0','1','0','0'),
('12219','Home sleep test (hst) with type iv portable monitor; unattended; minimum of 3 channels','Home sleep test/type 4 porta','G0400','3','','1','0','','','','0','1','0','0'),
('12220','Initial preventive physical examination; face-to-face visit; services limited to new beneficiary during the first 12 months of medicare enrollment','Initial preventive exam','G0402','3','','1','0','','','','0','1','0','0'),
('12221','Electrocardiogram; routine ecg with 12 leads; performed as a screening for the initial preventive physical examination with interpretation and report','Ekg for initial prevent exam','G0403','3','','1','0','','','','0','1','0','0'),
('12222','Electrocardiogram; routine ecg with 12 leads; tracing only; without interpretation and report; performed as a screening for the initial preventive physical examination','Ekg tracing for initial prev','G0404','3','','1','0','','','','0','1','0','0'),
('12223','Electrocardiogram; routine ecg with 12 leads; interpretation and report only; performed as a screening for the initial preventive physical examination','Ekg interpret & report preve','G0405','3','','1','0','','','','0','1','0','0'),
('12224','Follow-up inpatient consultation; limited; physicians typically spend 15 minutes communicating with the patient via telehealth','Inpt/tele follow up 15','G0406','3','','1','0','','','','0','1','0','0'),
('12225','Follow-up inpatient consultation; intermediate; physicians typically spend 25 minutes communicating with the patient via telehealth','Inpt/tele follow up 25','G0407','3','','1','0','','','','0','1','0','0'),
('12226','Follow-up inpatient consultation; complex; physicians typically spend 35 minutes communicating with the patient via telehealth','Inpt/tele follow up 35','G0408','3','','1','0','','','','0','1','0','0'),
('12227','Social work and psychological services; directly relating to and/or furthering the patients rehabilitation goals; each 15 minutes; face-to-face; individual (services provided by a corf-qualified social worker or psychologist in a corf)','Corf related serv 15 mins ea','G0409','3','','1','0','','','','0','1','0','0'),
('12228','Group psychotherapy other than of a multiple-family group; in a partial hospitalization setting; approximately 45 to 50 minutes','Grp psych partial hosp 45-50','G0410','3','','1','0','','','','0','1','0','0'),
('12229','Interactive group psychotherapy; in a partial hospitalization setting; approximately 45 to 50 minutes','Inter active grp psych parti','G0411','3','','1','0','','','','0','1','0','0'),
('12230','Open treatment of iliac spine(s); tuberosity avulsion; or iliac wing fracture(s); unilateral or bilateral for pelvic bone fracture patterns which do not disrupt the pelvic ring includes internal fixation; when performed','Open tx iliac spine uni/bil','G0412','3','','1','0','','','','0','1','0','0'),
('12231','Percutaneous skeletal fixation of posterior pelvic bone fracture and/or dislocation; for fracture patterns which disrupt the pelvic ring; unilateral or bilateral; (includes ilium; sacroiliac joint and/or sacrum)','Pelvic ring fracture uni/bil','G0413','3','','1','0','','','','0','1','0','0'),
('12232','Open treatment of anterior pelvic bone fracture and/or dislocation for fracture patterns which disrupt the pelvic ring; unilateral or bilateral; includes internal fixation when performed (includes pubic symphysis and/or superior/inferior rami)','Pelvic ring fx treat int fix','G0414','3','','1','0','','','','0','1','0','0'),
('12233','Open treatment of posterior pelvic bone fracture and/or dislocation; for fracture patterns which disrupt the pelvic ring; unilateral or bilateral; includes internal fixation; when performed (includes ilium; sacroiliac joint and/or sacrum)','Open tx post pelvic fxcture','G0415','3','','1','0','','','','0','1','0','0'),
('12234','Surgical pathology; gross and microscopic examinations; for prostate needle biopsy; any method','Prostate biopsy; any mthd','G0416','3','','1','0','','','','0','1','0','0'),
('12235','Surgical pathology; gross and microscopic examination; for prostate needle  biopsy; any method; 21-40 specimens','Sat biopsy prostate 21-40','G0417','3','','1','0','','','','0','1','0','0'),
('12236','Surgical pathology; gross and microscopic examination; for prostate needle  biopsy; any method; 41-60 specimens','Sat biopsy prostate 41-60','G0418','3','','1','0','','','','0','1','0','0'),
('12237','Surgical pathology; gross and microscopic examination; for prostate needle  biopsy; any method; >60 specimens','Sat biopsy prostate: >60','G0419','3','','1','0','','','','0','1','0','0'),
('12238','Face-to-face educational services related to the care of chronic kidney disease; individual; per session; per one hour','Ed svc ckd ind per session','G0420','3','','1','0','','','','0','1','0','0'),
('12239','Face-to-face educational services related to the care of chronic kidney disease; group; per session; per one hour','Ed svc ckd grp per session','G0421','3','','1','0','','','','0','1','0','0'),
('12240','Intensive cardiac rehabilitation; with or without continuous ecg monitoring with exercise; per session','Intens cardiac rehab w/exerc','G0422','3','','1','0','','','','0','1','0','0'),
('12241','Intensive cardiac rehabilitation; with or without continuous ecg monitoring; without exercise; per session','Intens cardiac rehab no exer','G0423','3','','1','0','','','','0','1','0','0'),
('12242','Pulmonary rehabilitation; including exercise (includes monitoring); one hour; per session; up to two sessions per day','Pulmonary rehab w exer','G0424','3','','1','0','','','','0','1','0','0'),
('12243','Telehealth consultation; emergency department or initial inpatient; typically 30 minutes communicating with the patient via telehealth','Inpt/ed teleconsult30','G0425','3','','1','0','','','','0','1','0','0'),
('12244','Telehealth consultation; emergency department or initial inpatient; typically 50 minutes communicating with the patient via telehealth','Inpt/ed teleconsult50','G0426','3','','1','0','','','','0','1','0','0'),
('12245','Telehealth consultation; emergency department or initial inpatient; typically 70 minutes or more communicating with the patient via telehealth','Inpt/ed teleconsult70','G0427','3','','1','0','','','','0','1','0','0'),
('12246','Collagen meniscus implant procedure for filling meniscal defects (e.g.; cmi; collagen scaffold; menaflex)','Collagen meniscus implant','G0428','3','','1','0','','','','0','1','0','0'),
('12247','Dermal filler injection(s) for the treatment of facial lipodystrophy syndrome (lds) (e.g.; as a result of highly active antiretroviral therapy)','Dermal filler injection(s)','G0429','3','','1','0','','','','0','1','0','0'),
('12248','Drug screen; qualitative; multiple drug classes by high complexity test method (e.g.; immunoassay; enzyme assay); per patient encounter','Drug screen multiple class','G0431','3','','1','0','','','','0','1','0','0'),
('12249','Infectious agent antibody detection by enzyme immunoassay (eia) technique; hiv-1 and/or hiv-2; screening','Eia hiv-1/hiv-2 screen','G0432','3','','1','0','','','','0','1','0','0'),
('12250','Infectious agent antibody detection by enzyme-linked immunosorbent assay (elisa) technique; hiv-1 and/or hiv-2; screening','Elisa hiv-1/hiv-2 screen','G0433','3','','1','0','','','','0','1','0','0'),
('12251','Drug screen; other than chromatographic; any number of drug classes; by clia waived test or moderate complexity test; per patient encounter','Drug screen multi drug class','G0434','3','','1','0','','','','0','1','0','0'),
('12252','Infectious agent antibody detection by rapid antibody test; hiv-1 and/or hiv-2; screening','Oral hiv-1/hiv-2 screen','G0435','3','','1','0','','','','0','1','0','0'),
('12253','Smoking and tobacco cessation counseling visit for the asymptomatic patient; intermediate; greater than 3 minutes; up to 10 minutes','Tobacco-use counsel 3-10 min','G0436','3','','1','0','','','','0','1','0','0'),
('12254','Smoking and tobacco cessation counseling visit for the asymptomatic patient; intensive; greater than 10 minutes','Tobacco-use counsel>10min','G0437','3','','1','0','','','','0','1','0','0'),
('12255','Annual wellness visit; includes a personalized prevention plan of service (pps); initial visit','Ppps; initial visit','G0438','3','','1','0','','','','0','1','0','0'),
('12256','Annual wellness visit; includes a personalized prevention plan of service (pps); subsequent visit','Ppps; subseq visit','G0439','3','','1','0','','','','0','1','0','0'),
('12257','Annual alcohol misuse screening; 15 minutes','Annual alcohol screen 15 min','G0442','3','','1','0','','','','0','1','0','0'),
('12258','Brief face-to-face behavioral counseling for alcohol misuse; 15 minutes','Brief alcohol misuse counsel','G0443','3','','1','0','','','','0','1','0','0'),
('12259','Annual depression screening; 15 minutes','Depression screen annual','G0444','3','','1','0','','','','0','1','0','0'),
('12260','High intensity behavioral counseling to prevent sexually transmitted infection; face-to-face; individual; includes: education; skills training and guidance on how to change sexual behavior; performed semi-annually; 30 minutes','High inten beh couns std 30m','G0445','3','','1','0','','','','0','1','0','0'),
('12261','Annual; face-to-face intensive behavioral therapy for cardiovascular disease; individual; 15 minutes','Intens behave ther cardio dx','G0446','3','','1','0','','','','0','1','0','0'),
('12262','Face-to-face behavioral counseling for obesity; 15 minutes','Behavior counsel obesity 15m','G0447','3','','1','0','','','','0','1','0','0'),
('12263','Insertion or replacement of a permanent pacing cardioverter-defibrillator system with transvenous lead(s); single or dual chamber with insertion of pacing electrode; cardiac venous system; for left ventricular pacing','Place perm pacing cardiovert','G0448','3','','1','0','','','','0','1','0','0'),
('12264','Development testing; with interpretation and report; per standardized instrument form','Devlopment test interpt&rep','G0451','3','','1','0','','','','0','1','0','0'),
('12265','Molecular pathology procedure; physician interpretation and report','Molecular pathology interpr','G0452','3','','1','0','','','','0','1','0','0'),
('12266','Continuous intraoperative neurophysiology monitoring; from outside the operating room (remote or nearby); per patient; (attention directed exclusively to one patient) each 15 minutes (list in addition to primary procedure)','Cont intraop neuro monitor','G0453','3','','1','0','','','','0','1','0','0'),
('12267','Physician documentation of face-to-face visit for durable medical equipment determination performed by nurse practitioner; physician assistant or clinical nurse specialist','Md document visit by npp','G0454','3','','1','0','','','','0','1','0','0'),
('12268','Preparation with instillation of fecal microbiota by any method; including assessment of donor specimen','Fecal microbiota prep instil','G0455','3','','1','0','','','','0','1','0','0'),
('12269','Negative pressure wound therapy; (e.g. vacuum assisted drainage collection) using a mechanically-powered device; not durable medical equipment; including provision of cartridge and dressing(s); topical application(s); wound assessment; and instructions for ongoing care; per session; total wounds(s) surface area less than or equal to 50 square centimeters','Neg pre wound <=50 sq cm','G0456','3','','1','0','','','','0','1','0','0'),
('12270','Negative pressure wound therapy; (e.g. vacuum assisted drainage collection) using a mechanically-powered device; not durable medical equipment; including provision of cartridge and dressing(s); topical application(s); wound assessment; and instructions for ongoing care; per session; total wounds(s) surface area greater than 50 square centimeters','Neg pres wound >50 sq cm','G0457','3','','1','0','','','','0','1','0','0'),
('12271','Low dose rate (ldr) prostate brachytherapy services; composite rate','Ldr prostate brachy comp rat','G0458','3','','1','0','','','','0','1','0','0'),
('12272','Inpatient telehealth pharmacologic management; including prescription; use; and review of medication with no more than minimal medical psychotherapy','Telehealth inpt pharm mgmt','G0459','3','','1','0','','','','0','1','0','0'),
('12273','Autologous platelet rich plasma for chronic wounds/ulcers; including phlebotomy; centrifugation; and all other preparatory procedures; administration and dressings; per treatment','Autologous prp for ulcers','G0460','3','','1','0','','','','0','1','0','0'),
('12274','Immunohistochemistry or immunocytochemistry; per specimen; first single or multiplex antibody stain','Immunohisto/cyto chem 1st st','G0461','3','','1','0','','','','0','1','0','0'),
('12275','Immunohistochemistry or immunocytochemistry; per specimen; each additional single or multiplex antibody stain (list separately in addition to code for primary procedure)','Immunohisto/cyto chem add','G0462','3','','1','0','','','','0','1','0','0'),
('12276','Hospital outpatient clinic visit for assessment and management of a patient','Hospital outpt clinic visit','G0463','3','','1','0','','','','0','1','0','0'),
('12277','Colorectal cancer screening; stool-based dna and fecal occult hemoglobin (e.g.; kras; ndrg4 and bmp3)','Colorec ca scr; sto bas dna','G0464','3','','1','0','','','','0','1','0','0'),
('12278','Federally qualified health center (fqhc) visit; new patient; a medically-necessary; face-to-face encounter (one-on-one) between a new patient and a fqhc practitioner during which time one or more fqhc services are rendered and includes a typical bundle of medicare-covered services that would be furnished per diem to a patient receiving a fqhc visit','Fqhc visit new patient','G0466','3','','1','0','','','','0','1','0','0'),
('12279','Federally qualified health center (fqhc) visit; established patient; a medically-necessary; face-to-face encounter (one-on-one) between an established patient and a fqhc practitioner during which time one or more fqhc services are rendered and includes a typical bundle of medicare-covered services that would be furnished per diem to a patient receiving a fqhc visit','Fqhc visit; estab pt','G0467','3','','1','0','','','','0','1','0','0'),
('12280','Federally qualified health center (fqhc) visit; ippe or awv; a fqhc visit that includes an initial preventive physical examination (ippe) or annual wellness visit (awv) and includes a typical bundle of medicare-covered services that would be furnished per diem to a patient receiving an ippe or awv','Fqhc visit; ippe or awv','G0468','3','','1','0','','','','0','1','0','0'),
('12281','Federally qualified health center (fqhc) visit; mental health; new patient; a medically-necessary; face-to-face mental health encounter (one-on-one) between a new patient and a fqhc practitioner during which time one or more fqhc services are rendered and includes a typical bundle of medicare-covered services that would be furnished per diem to a patient receiving a mental health visit','Fqhc visit; mh new pt','G0469','3','','1','0','','','','0','1','0','0'),
('12282','Federally qualified health center (fqhc) visit; mental health; established patient; a medically-necessary; face-to-face mental health encounter (one-on-one) between an established patient and a fqhc practitioner during which time one or more fqhc services are rendered and includes a typical bundle of medicare-covered services that would be furnished per diem to a patient receiving a mental health visit','Fqhc visit; mh estab pt','G0470','3','','1','0','','','','0','1','0','0'),
('12283','Collection of venous blood by venipuncture or urine sample by catheterization from an individual in a skilled nursing facility (snf) or by a laboratory on behalf of a home health agency (hha)','Ven blood coll snf/hha','G0471','3','','1','0','','','','0','1','0','0'),
('12284','Hepatitis c antibody screening; for individual at high risk and other covered indication(s)','Hep c screen high risk/other','G0472','3','','1','0','','','','0','1','0','0'),
('12285','Face-to-face behavioral counseling for obesity; group (2-10),; 30 minutes','Group behave couns 2-10','G0473','3','','1','0','','','','0','1','0','0'),
('12286','Hiv antigen/antibody; combination assay; screening','Hiv combination assay','G0475','3','','1','0','','','','0','1','0','0'),
('12287','Infectious agent detection by nucleic acid (dna or rna); human papillomavirus (hpv); high-risk types (e.g.; 16; 18; 31; 33; 35; 39; 45; 51; 52; 56; 58; 59; 68) for cervical cancer screening; must be performed in addition to pap test','Hpv combo assay ca screen','G0476','3','','1','0','','','','0','1','0','0'),
('12288','Drug test(s); presumptive; any number of drug classes; any number of devices or procedures; (e.g.; immunoassay) capable of being read by direct optical observation only (e.g.; dipsticks; cups; cards; cartridges); includes sample validation when performed; per date of service','Drug test presump optical','G0477','3','','1','0','','','','0','1','0','0'),
('12289','Drug test(s); presumptive; any number of drug classes; any number of devices or procedures; (e.g.; immunoassay) read by instrument-assisted direct optical observation (e.g.; dipsticks; cups; cards; cartridges); includes sample validation when performed; per date of service','Drug test presump opt inst','G0478','3','','1','0','','','','0','1','0','0'),
('12290','Drug test(s); presumptive; any number of drug classes; any number of devices or procedures by instrumented chemistry analyzers utilizing immunoassay; enzyme assay; tof; maldi; ldtd; desi; dart; ghpc; gc mass spectrometry); includes sample validation when performed; per date of service','Drug test presump not opt','G0479','3','','1','0','','','','0','1','0','0'),
('12291','Drug test(s); definitive; utilizing drug identification methods able to identify individual drugs and distinguish between structural isomers (but not necessarily stereoisomers); including; but not limited to gc/ms (any type; single or tandem) and lc/ms (any type; single or tandem and excluding immunoassays (e.g.; ia; eia; elisa; emit; fpia) and enzymatic methods (e.g.; alcohol dehydrogenase)); qualitative or quantitative; all sources(s); includes specimen validity testing; per day; 1-7 drug class(es); including metabolite(s) if performed','Drug test def 1-7 classes','G0480','3','','1','0','','','','0','1','0','0'),
('12292','Drug test(s); definitive; utilizing drug identification methods able to identify individual drugs and distinguish between structural isomers (but not necessarily stereoisomers); including; but not limited to gc/ms (any type; single or tandem) and lc/ms (any type; single or tandem and excluding immunoassays (e.g.; ia; eia; elisa; emit; fpia) and enzymatic methods (e.g.; alcohol dehydrogenase)); qualitative or quantitative; all sources(s); includes specimen validity testing; per day; 8-14 drug class(es); including metabolite(s) if performed','Drug test def 8-14 classes','G0481','3','','1','0','','','','0','1','0','0'),
('12293','Drug test(s); definitive; utilizing drug identification methods able to identify individual drugs and distinguish between structural isomers (but not necessarily stereoisomers); including; but not limited to gc/ms (any type; single or tandem) and lc/ms (any type; single or tandem and excluding immunoassays (e.g.; ia; eia; elisa; emit; fpia) and enzymatic methods (e.g.; alcohol dehydrogenase)); qualitative or quantitative; all sources(s); includes specimen validity testing; per day; 15-21 drug class(es); including metabolite(s) if performed','Drug test def 15-21 classes','G0482','3','','1','0','','','','0','1','0','0'),
('12294','Drug test(s); definitive; utilizing drug identification methods able to identify individual drugs and distinguish between structural isomers (but not necessarily stereoisomers); including; but not limited to gc/ms (any type; single or tandem) and lc/ms (any type; single or tandem and excluding immunoassays (e.g.; ia; eia; elisa; emit; fpia) and enzymatic methods (e.g.; alcohol dehydrogenase)); qualitative or quantitative; all sources(s); includes specimen validity testing; per day; 22 or more drug class(es); including metabolite(s) if performed','Drug test def 22+ classes','G0483','3','','1','0','','','','0','1','0','0'),
('12295','Face-to-face home health nursing visit by a rural health clinic (rhc) or federally qualified health center (fqhc) in an area with a shortage of home health agencies;  (services limited to rn or lpn only)','Home visit rn; lpn by rhc/fq','G0490','3','','1','0','','','','0','1','0','0'),
('12296','Dialysis procedure at a medicare certified esrd facility for acute kidney injury without esrd','Dialysis acu kidney no esrd','G0491','3','','1','0','','','','0','1','0','0'),
('12297','Dialysis procedure with single evaluation by a physician or other qualified health care professional  for acute kidney injury without esrd','Md/oth eval acut kid no esrd','G0492','3','','1','0','','','','0','1','0','0'),
('12298','Skilled services of a registered nurse (rn) for the observation and assessment of the patients condition; each 15 minutes (the change in the patients condition requires skilled nursing personnel to identify and evaluate the patients need for possible modification of treatment in the home health or hospice setting)','Rn care ea 15 min hh/hospice','G0493','3','','1','0','','','','0','1','0','0'),
('12299','Skilled services of a licensed practical nurse (lpn) for the observation and assessment of the patients condition; each 15 minutes (the change in the patients condition requires skilled nursing personnel to identify and evaluate the patients need for possible modification of treatment in the home health or hospice setting)','Lpn care ea 15min hh/hospice','G0494','3','','1','0','','','','0','1','0','0'),
('12300','Skilled services of a registered nurse (rn); in the training and/or education of a patient or family member; in the home health or hospice setting; each 15 minutes','Rn care train/edu in hh','G0495','3','','1','0','','','','0','1','0','0'),
('12301','Skilled services of a licensed practical nurse (lpn); in the training and/or education of a patient or family member; in the home health or hospice setting; each 15 minutes','Lpn care train/edu in hh','G0496','3','','1','0','','','','0','1','0','0'),
('12302','Chemotherapy administration; intravenous infusion technique; initiation of infusion in the office/clinic setting using office/clinic pump/supplies; with continuation of the infusion in the community setting (e.g.; home; domiciliary; rest home or assisted living) using a portable pump provided by the office/clinic; includes follow up office/clinic visit at the conclusion of the infusion','Chemo extend iv infus w/pump','G0498','3','','1','0','','','','0','1','0','0'),
('12303','Hepatitis b screening in non-pregnant; high risk individual includes hepatitis b surface antigen (hbsag) followed by a neutralizing confirmatory test for initially reactive results; and antibodies to hbsag (anti-hbs) and hepatitis b core antigen (anti-hbc)','Hepb screen high risk indiv','G0499','3','','1','0','','','','0','1','0','0'),
('12304','Moderate sedation services provided by the same physician or other qualified health care professional performing a gastrointestinal endoscopic service that sedation supports; requiring the presence of an independent trained observer to assist in the monitoring of the patients level of consciousness and physiological status; initial 15 minutes of intra-service time; patient age 5 years or older (additional time may be reported with 99153; as appropriate)','Mod sedat endo service >5yrs','G0500','3','','1','0','','','','0','1','0','0'),
('12305','Resource-intensive services for patients for whom the use of specialized mobility-assistive technology (such as adjustable height chairs or tables; patient lift; and adjustable padded leg supports) is medically necessary and used during the provision of an office/outpatient; evaluation and management  visit (list separately in addition to primary service)','Resource-inten svc during ov','G0501','3','','1','0','','','','0','1','0','0'),
('12306','Initial psychiatric collaborative care management; first 70 minutes in the first calendar month of behavioral health care manager activities; in consultation with a psychiatric consultant; and directed by the treating physician or other qualified health care professional; with the following required elements: outreach to and engagement in treatment of a patient directed by the treating physician or other qualified health care professional; initial assessment of the patient; including administration of validated rating scales; with the development of an individualized treatment plan;  review by the psychiatric consultant with modifications of the plan if recommended;  entering patient in a registry and tracking patient follow-up and progress using the registry; with appropriate documentation; and participation in weekly caseload consultation with the psychiatric consultant; and provision of brief interventions using evidence-based techniques such as behavioral activation; motivational interviewing; and other focused treatment strategies','Init psych care manag; 70min','G0502','3','','1','0','','','','0','1','0','0'),
('12307','Subsequent psychiatric collaborative care management; first 60 minutes in a subsequent month of behavioral health care manager activities; in consultation with a psychiatric consultant; and directed by the treating physician or other qualified health care professional; with the following required elements:  tracking patient follow-up and progress using the registry; with appropriate documentation;  participation in weekly caseload consultation with the psychiatric consultant;  ongoing collaboration with and coordination of the patients mental health care with the treating physician or other qualified health care professional and any other treating mental health providers;  additional review of progress and recommendations for changes in treatment; as indicated; including medications; based on recommendations provided by the psychiatric consultant;  provision of brief interventions using evidence-based techniques such as behavioral activation; motivational interviewing; and other focused treatment strategies;  monitoring of patient outcomes using validated rating scales; and relapse prevention planning with patients as they achieve remission of symptoms and/or other treatment goals and are prepared for discharge from active treatment','Subseq  psych care man;60mi','G0503','3','','1','0','','','','0','1','0','0'),
('12308','Initial or subsequent psychiatric collaborative care management; each additional 30 minutes in a calendar month of behavioral health care manager activities; in consultation with a psychiatric consultant; and directed by the treating physician or other qualified health care professional (list separately in addition to code for primary procedure);  (use g0504 in conjunction with g0502; g0503)','Init/sub psych care add 30 m','G0504','3','','1','0','','','','0','1','0','0'),
('12309','Cognition and functional assessment using standardized instruments with development of recorded care plan for the patient with cognitive impairment; history obtained from patient and/or caregiver; in office or other outpatient setting or home or domiciliary or rest home','Cog/func assessment  outpt','G0505','3','','1','0','','','','0','1','0','0'),
('12310','Comprehensive assessment of and care planning for patients requiring chronic care management services (list separately in addition to primary monthly care management service)','Comp asses care plan ccm svc','G0506','3','','1','0','','','','0','1','0','0'),
('12311','Care management services for behavioral health conditions; at least 20 minutes of clinical staff time; directed by a physician or other qualified health care professional; per calendar month; with the following required elements: initial assessment or follow-up monitoring; including the use of applicable validated rating scales; behavioral health care planning in relation to behavioral/psychiatric health problems; including revision for patients who are not progressing or whose status changes; facilitating and coordinating treatment such as psychotherapy; pharmacotherapy; counseling and/or psychiatric consultation; and continuity of care with a designated member of the care team','Care manage serv minimum 20','G0507','3','','1','0','','','','0','1','0','0'),
('12312','Telehealth consultation; critical care; initial ; physicians typically spend 60 minutes communicating with the patient and providers via telehealth','Crit care telehea consult 60','G0508','3','','1','0','','','','0','1','0','0'),
('12313','Telehealth consultation; critical care; subsequent; physicians typically spend 50 minutes communicating with the patient and providers via telehealth','Crit care telehea consult 50','G0509','3','','1','0','','','','0','1','0','0'),
('12314','Most recent hemoglobin (hgb) level > 12.0 g/dl','Hgb > 12 g/dl','G0908','3','','1','0','','','','0','1','0','0'),
('12315','Hemoglobin level measurement not documented; reason not given','Hbg not doc','G0909','3','','1','0','','','','0','1','0','0'),
('12316','Most recent hemoglobin level <= 12.0 g/dl','Hgb <= 12 g/dl','G0910','3','','1','0','','','','0','1','0','0'),
('12317','Improvement in visual function achieved within 90 days following cataract surgery','Improve visual funct','G0913','3','','1','0','','','','0','1','0','0'),
('12318','Patient care survey was not completed by patient','Survey not complete','G0914','3','','1','0','','','','0','1','0','0'),
('12319','Improvement in visual function not achieved within 90 days following cataract surgery','No improve visual funct','G0915','3','','1','0','','','','0','1','0','0'),
('12320','Satisfaction with care achieved within 90 days following cataract surgery','Satisfy with care','G0916','3','','1','0','','','','0','1','0','0'),
('12321','Patient satisfaction survey was not completed by patient','Satisfy survey not complete','G0917','3','','1','0','','','','0','1','0','0'),
('12322','Satisfaction with care not achieved within 90 days following cataract surgery','No satisfy with care','G0918','3','','1','0','','','','0','1','0','0'),
('12323','Influenza immunization ordered or recommended (to be given at alternate location or alternate provider); vaccine not available at time of visit','Flu immunize not avail','G0919','3','','1','0','','','','0','1','0','0'),
('12324','Type; anatomic location; and activity all documented','Type loc act doc','G0920','3','','1','0','','','','0','1','0','0'),
('12325','Documentation of patient reason(s) for not being able to assess (e.g.; patient refuses endoscopic and/or radiologic assessment)','Doc pt reas no assess','G0921','3','','1','0','','','','0','1','0','0'),
('12326','No documentation of disease type; anatomic location; and activity; reason not given','Type loc act not doc','G0922','3','','1','0','','','','0','1','0','0'),
('12327','Administration and supply of tositumomab; 450 mg','Admin + supply; tositumomab','G3001','3','','1','0','','','','0','1','0','0'),
('12328','Ultrasonic guidance for placement of radiation therapy fields','Echo guidance radiotherapy','G6001','3','','1','0','','','','0','1','0','0'),
('12329','Stereoscopic x-ray guidance for localization of target volume for the delivery of radiation therapy','Stereoscopic x-ray guidance','G6002','3','','1','0','','','','0','1','0','0'),
('12330','Radiation treatment delivery; single treatment area;single port or parallel opposed ports; simple blocks or no blocks: up to 5 mev','Radiation treatment delivery','G6003','3','','1','0','','','','0','1','0','0'),
('12331','Radiation treatment delivery; single treatment area;single port or parallel opposed ports; simple blocks or no blocks: 6-10 mev','Radiation treatment delivery','G6004','3','','1','0','','','','0','1','0','0'),
('12332','Radiation treatment delivery; single treatment area;single port or parallel opposed ports; simple blocks or no blocks: 11-19 mev','Radiation treatment delivery','G6005','3','','1','0','','','','0','1','0','0'),
('12333','Radiation treatment delivery; single treatment area;single port or parallel opposed ports; simple blocks or no blocks: 20 mev or greater','Radiation treatment delivery','G6006','3','','1','0','','','','0','1','0','0'),
('12334','Radiation treatment delivery; 2 separate treatment areas; 3 or more ports on a single treatment area; use of multiple blocks: up to 5 mev','Radiation treatment delivery','G6007','3','','1','0','','','','0','1','0','0'),
('12335','Radiation treatment delivery; 2 separate treatment areas; 3 or more ports on a single treatment area; use of multiple blocks: 6-10 mev','Radiation treatment delivery','G6008','3','','1','0','','','','0','1','0','0'),
('12336','Radiation treatment delivery; 2 separate treatment areas; 3 or more ports on a single treatment area; use of multiple blocks: 11-19 mev','Radiation treatment delivery','G6009','3','','1','0','','','','0','1','0','0'),
('12337','Radiation treatment delivery; 2 separate treatment areas; 3 or more ports on a single treatment area; use of multiple blocks: 20 mev or greater','Radiation treatment delivery','G6010','3','','1','0','','','','0','1','0','0'),
('12338','Radiation treatment delivery;3 or more separate treatment areas; custom blocking; tangential ports; wedges; rotational beam; compensators; electron beam; up to 5 mev','Radiation treatment delivery','G6011','3','','1','0','','','','0','1','0','0'),
('12339','Radiation treatment delivery;3 or more separate treatment areas; custom blocking; tangential ports; wedges; rotational beam; compensators; electron beam; 6-10 mev','Radiation treatment delivery','G6012','3','','1','0','','','','0','1','0','0'),
('12340','Radiation treatment delivery;3 or more separate treatment areas; custom blocking; tangential ports; wedges; rotational beam; compensators; electron beam; 11-19 mev','Radiation treatment delivery','G6013','3','','1','0','','','','0','1','0','0'),
('12341','Radiation treatment delivery;3 or more separate treatment areas; custom blocking; tangential ports; wedges; rotational beam; compensators; electron beam; 20 mev or greater','Radiation treatment delivery','G6014','3','','1','0','','','','0','1','0','0'),
('12342','Intensity modulated treatment delivery; single or multiple fields/arcs;via narrow spatially and temporally modulated beams; binary; dynamic mlc; per treatment session','Radiation tx delivery imrt','G6015','3','','1','0','','','','0','1','0','0'),
('12343','Compensator-based beam modulation treatment delivery of inverse planned treatment using 3 or more high resolution (milled or cast) compensator; convergent beam modulated fields; per treatment session','Delivery comp imrt','G6016','3','','1','0','','','','0','1','0','0'),
('12344','Intra-fraction localization and tracking of target or patient motion during delivery of radiation therapy (eg;3d positional tracking; gating; 3d surface tracking); each fraction of treatment','Intrafraction track motion','G6017','3','','1','0','','','','0','1','0','0'),
('12345','Ileoscopy; through stoma; with transendoscopic stent placement (includes predilation)','Ileoscopy w/stent','G6018','3','','1','0','','','','0','1','0','0'),
('12346','Colonoscopy through stoma; with ablation of tumor(s); polyp(s); or other lesion(s) not amenable to removal by hot biopsy forceps; bipolar cautery or snare technique','Colonoscopy lesion removal','G6019','3','','1','0','','','','0','1','0','0'),
('12347','Colonoscopy through stoma; with transendoscopic stent placement (includes predilation)','Colonoscopy w/stent','G6020','3','','1','0','','','','0','1','0','0'),
('12348','Unlisted procedure; intestine','Unlisted px small intestine','G6021','3','','1','0','','','','0','1','0','0'),
('12349','Sigmoidoscopy; flexible; with ablation of tumor(s); polyp(s); or other lesions(s) not amenable to removal by hot biopsy forceps; bipolar cautery or snare technique','Sigmoidoscopy w/ablate tumr','G6022','3','','1','0','','','','0','1','0','0'),
('12350','Sigmoidoscopy; flexible; with transendoscopic stent placement (includes predilation)','Sigmoidoscopy w/stent','G6023','3','','1','0','','','','0','1','0','0'),
('12351','Colonoscopy; flexible; proximal to splenic flexure; with ablation of tumor(s); polyp(s); or other lesion(s) not amenable to removal by hot biopsy forceps; bipolar cautery or snare technique','Lesion removal colonoscopy','G6024','3','','1','0','','','','0','1','0','0'),
('12352','Colonoscopy; flexible; proximal to splenic flexure; with transendoscopic stent placement (includes predilation)','Colonoscopy w/stent','G6025','3','','1','0','','','','0','1','0','0'),
('12353','Anoscopy; high resolution (hra) (with magnification and chemical agent enhancement); diagnostic; including collection of specimen(s) by brushing or washing when performed','Anoscopy hra w/spec collect','G6027','3','','1','0','','','','0','1','0','0'),
('12354','Anoscopy; high resolution (hra) (with magnification and chemical agent enhancement); with biopsy(ies)','Anoscopy hra w/biopsy','G6028','3','','1','0','','','','0','1','0','0'),
('12355','Amitriptyline','Assay of amitriptyline','G6030','3','','1','0','','','','0','1','0','0'),
('12356','Benzodiazepines','Assay of benzodiazepines','G6031','3','','1','0','','','','0','1','0','0'),
('12357','Desipramine','Assay of desipramine','G6032','3','','1','0','','','','0','1','0','0'),
('12358','Doxepin','Assay of doxepin','G6034','3','','1','0','','','','0','1','0','0'),
('12359','Gold','Assay of gold','G6035','3','','1','0','','','','0','1','0','0'),
('12360','Assay of imipramine','Assay of imipramine','G6036','3','','1','0','','','','0','1','0','0'),
('12361','Nortriptyline','Assay of nortiptyline','G6037','3','','1','0','','','','0','1','0','0'),
('12362','Salicylate','Assay of salicylate','G6038','3','','1','0','','','','0','1','0','0'),
('12363','Acetaminophen','Assay of acetaminophen','G6039','3','','1','0','','','','0','1','0','0'),
('12364','Alcohol (ethanol); any specimen except breath','Assay of ethanol','G6040','3','','1','0','','','','0','1','0','0'),
('12365','Alkaloids; urine; quantitative','Assay of urine alkaloids','G6041','3','','1','0','','','','0','1','0','0'),
('12366','Amphetamine or methamphetamine','Assay of amphetamines','G6042','3','','1','0','','','','0','1','0','0'),
('12367','Barbiturates; not elsewhere specified','Assay of barbiturates','G6043','3','','1','0','','','','0','1','0','0'),
('12368','Cocaine or metabolite','Assay of cocaine','G6044','3','','1','0','','','','0','1','0','0'),
('12369','Dihydrocodeinone','Assay of dihydrocodeinone','G6045','3','','1','0','','','','0','1','0','0'),
('12370','Dihydromorphinone','Assay of dihydromorphinone','G6046','3','','1','0','','','','0','1','0','0'),
('12371','Dihydrotestosterone','Assay of dihydrotestosterone','G6047','3','','1','0','','','','0','1','0','0'),
('12372','Dimethadione','Assay of dimethadione','G6048','3','','1','0','','','','0','1','0','0'),
('12373','Epiandrosterone','Asssay of epiandrosterone','G6049','3','','1','0','','','','0','1','0','0'),
('12374','Ethchlorvynol','Assay of ethchlorvynol','G6050','3','','1','0','','','','0','1','0','0'),
('12375','Flurazepam','Assay of flurazepam','G6051','3','','1','0','','','','0','1','0','0'),
('12376','Meprobamate','Assay of meprobamate','G6052','3','','1','0','','','','0','1','0','0'),
('12377','Methadone','Assay of methadone','G6053','3','','1','0','','','','0','1','0','0'),
('12378','Methsuximide','Assay of methsuximide','G6054','3','','1','0','','','','0','1','0','0'),
('12379','Nicotine','Assay of nicotine','G6055','3','','1','0','','','','0','1','0','0'),
('12380','Opiate(s); drug and metabolites; each procedure','Assay of opiates','G6056','3','','1','0','','','','0','1','0','0'),
('12381','Phenothiazine','Assay of phenothiazine','G6057','3','','1','0','','','','0','1','0','0'),
('12382','Drug confirmation; each procedure','Drug confirmation','G6058','3','','1','0','','','','0','1','0','0'),
('12383','Patient with a diagnosis of major depression documented as being treated with antidepressant medication during the entire 84 day (12 week)  acute treatment phase','Pt treat w/antidepress12wks','G8126','3','','1','0','','','','0','1','0','0'),
('12384','Patient with a diagnosis of major depression not documented as being treated with antidepressant medication during the entire 84 day (12 week) acute treatment phase','Pt not treat w/antidepres12w','G8127','3','','1','0','','','','0','1','0','0'),
('12385','Clinician documented that patient was not an eligible candidate for antidepressant medication during the entire 12 week acute treatment phase measure','Pt inelig for antidepres med','G8128','3','','1','0','','','','0','1','0','0'),
('12386','Left ventricular ejection fraction (lvef) >= 40% or documentation as normal or mildly depressed left ventricular systolic function','Lvef>=40% doc normal or mild','G8395','3','','1','0','','','','0','1','0','0'),
('12387','Left ventricular ejection fraction (lvef) not performed or documented','Lvef not performed','G8396','3','','1','0','','','','0','1','0','0'),
('12388','Dilated macular or fundus exam performed; including documentation of the presence or absence of macular edema and level of severity of retinopathy','Dil macula/fundus exam/w doc','G8397','3','','1','0','','','','0','1','0','0'),
('12389','Dilated macular or fundus exam not performed','Dil macular/fundus not perfo','G8398','3','','1','0','','','','0','1','0','0'),
('12390','Patient with documented results of a central dual-energy x-ray absorptiometry (dxa) ever being performed','Pt w/dxa results document','G8399','3','','1','0','','','','0','1','0','0'),
('12391','Patient with central dual-energy x-ray absorptiometry (dxa) results not documented; reason not given','Pt w/dxa no results doc','G8400','3','','1','0','','','','0','1','0','0'),
('12392','Clinician documented that patient was not an eligible candidate for screening','Pt inelig osteo screen measu','G8401','3','','1','0','','','','0','1','0','0'),
('12393','Lower extremity neurological exam performed and documented','Low extemity neur exam docum','G8404','3','','1','0','','','','0','1','0','0'),
('12394','Lower extremity neurological exam not performed','Low extemity neur not perfor','G8405','3','','1','0','','','','0','1','0','0'),
('12395','Clinician documented that patient was not an eligible candidate for lower extremity neurological exam measure','Pt inelig lower extrem neuro','G8406','3','','1','0','','','','0','1','0','0'),
('12396','Footwear evaluation performed and documented','Eval on foot documented','G8410','3','','1','0','','','','0','1','0','0'),
('12397','Footwear evaluation was not performed','Eval on foot not performed','G8415','3','','1','0','','','','0','1','0','0'),
('12398','Clinician documented that patient was not an eligible candidate for footwear evaluation measure','Pt inelig footwear evaluatio','G8416','3','','1','0','','','','0','1','0','0'),
('12399','Bmi is documented above normal parameters and a follow-up plan is documented','Calc bmi abv up param f/u','G8417','3','','1','0','','','','0','1','0','0'),
('12400','Bmi is documented below normal parameters and a follow-up plan is documented','Calc bmi blw low param f/u','G8418','3','','1','0','','','','0','1','0','0'),
('12401','Bmi documented outside normal parameters; no follow-up plan documented; no reason given','Calc bmi out nrm param nof/u','G8419','3','','1','0','','','','0','1','0','0'),
('12402','Bmi is documented within normal parameters and no follow-up plan is required','Calc bmi norm parameters','G8420','3','','1','0','','','','0','1','0','0'),
('12403','Bmi not documented and no reason is given','Bmi not calculated','G8421','3','','1','0','','','','0','1','0','0'),
('12404','Bmi not documented; documentation the patient is not eligible for bmi calculation','Pt inelig bmi calculation','G8422','3','','1','0','','','','0','1','0','0'),
('12405','Eligible clinician attests to documenting in the medical record they obtained; updated; or reviewed the patients current medications','Docrev cur meds by elig clin','G8427','3','','1','0','','','','0','1','0','0'),
('12406','Current list of medications not documented as obtained; updated; or reviewed by the eligible clinician; reason not given','Cur meds not document','G8428','3','','1','0','','','','0','1','0','0'),
('12407','Eligible clinician attests to documenting in the medical record the patient is not eligible for a current list of medications being obtained; updated; or reviewed by the eligible clinician','Pt inelig med check','G8430','3','','1','0','','','','0','1','0','0'),
('12408','Screening for depression is documented as being positive and a follow-up plan is documented','Pos clin depres scrn f/u doc','G8431','3','','1','0','','','','0','1','0','0'),
('12409','Depression screening not documented; reason not given','Dep scr not doc; rng','G8432','3','','1','0','','','','0','1','0','0'),
('12410','Screening for depression not completed; documented reason','Scr dep not done; doc rsn','G8433','3','','1','0','','','','0','1','0','0'),
('12411','Pain assessment not documented as being performed; documentation the patient is not eligible for a pain assessment using a standardized tool','Pt inelig pain assessment','G8442','3','','1','0','','','','0','1','0','0'),
('12412','Beta-blocker therapy prescribed','Beta-bloc rx pt w/abn lvef','G8450','3','','1','0','','','','0','1','0','0'),
('12413','Beta-blocker therapy for lvef < 40% not prescribed for reasons documented by the clinician (e.g.; low blood pressure; fluid overload; asthma; patients recently treated with an intravenous positive inotropic agent; allergy; intolerance; other medical reasons; patient declined; other patient reasons; or other reasons attributable to the healthcare system)','Pt w/abn lvef inelig b-bloc','G8451','3','','1','0','','','','0','1','0','0'),
('12414','Beta-blocker therapy not prescribed','Pt w/abn lvef b-bloc no rx','G8452','3','','1','0','','','','0','1','0','0'),
('12415','Clinician documented that patient is not an eligible candidate for genotype testing; patient not receiving antiviral treatment for hepatitis c during the measurement period (e.g. genotype test done prior to the reporting period; patient declines; patient not a candidate for antiviral treatment)','Pt inelig geno no antvir tx','G8458','3','','1','0','','','','0','1','0','0'),
('12416','Clinician documented that patient is receiving antiviral treatment for hepatitis c','Doc pt rec antivir treat','G8459','3','','1','0','','','','0','1','0','0'),
('12417','Clinician documented that patient is not an eligible candidate for quantitative rna testing at week 12; patient not receiving antiviral treatment for hepatitis c','Pt inelig rna no antvir tx','G8460','3','','1','0','','','','0','1','0','0'),
('12418','Patient receiving antiviral treatment for hepatitis c during the measurement period','Pt rec antivir treat hep c','G8461','3','','1','0','','','','0','1','0','0'),
('12419','Clinician documented that patient is not an eligible candidate for counseling regarding contraception prior to antiviral treatment; patient not receiving antiviral treatment for hepatitis c','Pt inelig couns no antvir tx','G8462','3','','1','0','','','','0','1','0','0'),
('12420','Patient receiving antiviral treatment for hepatitis c documented','Pt rec antiviral treat doc','G8463','3','','1','0','','','','0','1','0','0'),
('12421','Clinician documented that prostate cancer patient is not an eligible candidate for adjuvant hormonal therapy; low or intermediate risk of recurrence or risk of recurrence not determined','Pt inelig; lo to no dter rsk','G8464','3','','1','0','','','','0','1','0','0'),
('12422','High or very high risk of recurrence of prostate cancer','High risk recurrence pro ca','G8465','3','','1','0','','','','0','1','0','0'),
('12423','Angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy prescribed','Ace/arb thxpy rxd','G8473','3','','1','0','','','','0','1','0','0'),
('12424','Angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy not prescribed for reasons documented by the clinician (e.g.; allergy; intolerance; pregnancy; renal failure due to ace inhibitor; diseases of the aortic or mitral valve; other medical reasons) or (e.g.; patient declined; other patient reasons) or (e.g.; lack of drug availability; other reasons attributable to the health care system)','Ace/arb not rxd; doc reas','G8474','3','','1','0','','','','0','1','0','0'),
('12425','Angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy not prescribed; reason not given','Ace/arb thxpy not rxd','G8475','3','','1','0','','','','0','1','0','0'),
('12426','Most recent blood pressure has a systolic measurement of < 140 mmhg and a diastolic measurement of < 90 mmhg','Bp sys <140 and dias <90','G8476','3','','1','0','','','','0','1','0','0'),
('12427','Most recent blood pressure has a systolic measurement of >= 140 mmhg and/or a diastolic measurement of >= 90 mmhg','Bp sys>=140 and/or dias >=90','G8477','3','','1','0','','','','0','1','0','0'),
('12428','Blood pressure measurement not performed or documented; reason not given','Bp not performed/doc','G8478','3','','1','0','','','','0','1','0','0'),
('12429','Influenza immunization administered or previously received','Flu immunize order/admin','G8482','3','','1','0','','','','0','1','0','0'),
('12430','Influenza immunization was not administered for reasons documented by clinician (e.g.; patient allergy or other medical reasons; patient declined or other patient reasons; vaccine not available or other system reasons)','Flu imm no admin doc rea','G8483','3','','1','0','','','','0','1','0','0'),
('12431','Influenza immunization was not administered; reason not given','Flu immunize no admin','G8484','3','','1','0','','','','0','1','0','0'),
('12432','I intend to report the diabetes mellitus (dm) measures group','Report; diabetes measures','G8485','3','','1','0','','','','0','1','0','0'),
('12433','I intend to report the preventive care measures group','Report; prev care measures','G8486','3','','1','0','','','','0','1','0','0'),
('12434','I intend to report the chronic kidney disease (ckd) measures group','Report ckd measures','G8487','3','','1','0','','','','0','1','0','0'),
('12435','I intend to report the coronary artery disease (cad) measures group','Cad measures grp','G8489','3','','1','0','','','','0','1','0','0'),
('12436','I intend to report the rheumatoid arthritis (ra) measures group','Ra measures grp','G8490','3','','1','0','','','','0','1','0','0'),
('12437','I intend to report the hiv/aids measures group','Hiv/aids measures grp','G8491','3','','1','0','','','','0','1','0','0'),
('12438','I intend to report the perioperative care measures group','Periop care measures grp','G8492','3','','1','0','','','','0','1','0','0'),
('12439','I intend to report the back pain measures group','Back pain measures grp','G8493','3','','1','0','','','','0','1','0','0'),
('12440','All quality actions for the applicable measures in the diabetes mellitus (dm) measures group have been performed for this patient','Dm meas qual act perform','G8494','3','','1','0','','','','0','1','0','0'),
('12441','All quality actions for the applicable measures in the chronic kidney disease (ckd) measures group have been performed for this patient','Ckd meas qual act perform','G8495','3','','1','0','','','','0','1','0','0'),
('12442','All quality actions for the applicable measures in the preventive care measures group have been performed for this patient','Prev care mg qual act perfrm','G8496','3','','1','0','','','','0','1','0','0'),
('12443','All quality actions for the applicable measures in the coronary artery bypass graft (cabg) measures group have been performed for this patient','Cabg meas qual act perform','G8497','3','','1','0','','','','0','1','0','0'),
('12444','All quality actions for the applicable measures in the coronary artery disease (cad) measures group have been performed for this patient','Cad meas qual act perform','G8498','3','','1','0','','','','0','1','0','0'),
('12445','All quality actions for the applicable measures in the rheumatoid arthritis (ra) measures group have been performed for this patient','Ra meas qual act perform','G8499','3','','1','0','','','','0','1','0','0'),
('12446','All quality actions for the applicable measures in the hiv/aids measures group have been performed for this patient','Hiv meas qual act perform','G8500','3','','1','0','','','','0','1','0','0'),
('12447','All quality actions for the applicable measures in the perioperative care measures group have been performed for this patient','Perio meas qual act perform','G8501','3','','1','0','','','','0','1','0','0'),
('12448','All quality actions for the applicable measures in the back pain measures group have been performed for this patient','Back pain mg qual act perfrm','G8502','3','','1','0','','','','0','1','0','0'),
('12449','Patient receiving angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy','Pt rec ace/arb','G8506','3','','1','0','','','','0','1','0','0'),
('12450','Pain assessment documented as positive using a standardized tool; follow-up plan not documented; reason not given','Pos pain assess no f/u doc','G8509','3','','1','0','','','','0','1','0','0'),
('12451','Screening for depression is documented as negative; a follow-up plan is not required','Scr dep neg; no plan reqd','G8510','3','','1','0','','','','0','1','0','0'),
('12452','Screening for depression documented as positive; follow-up plan not documented; reason not given','Scr dep pos; no plan doc rng','G8511','3','','1','0','','','','0','1','0','0'),
('12453','Autogenous av fistula received','Auto av fistula recd','G8530','3','','1','0','','','','0','1','0','0'),
('12454','Clinician documented that patient was not an eligible candidate for autogenous av fistula','Pt inelig; auto av fistula','G8531','3','','1','0','','','','0','1','0','0'),
('12455','Clinician documented that patient received vascular access other than autogenous av fistula; reason not given','No auto av fistula; no reas','G8532','3','','1','0','','','','0','1','0','0'),
('12456','Elder maltreatment screen not documented; documentation that patient not eligible for the elder maltreatment screen','Pt inelig no eld mal scrn','G8535','3','','1','0','','','','0','1','0','0'),
('12457','No documentation of an elder maltreatment screen; reason not given','No doc elder mal scrn','G8536','3','','1','0','','','','0','1','0','0'),
('12458','Functional outcome assessment documented as positive using a standardized tool and a care plan based on identified deficiencies on the date of functional outcome assessment; is documented','Doc funct and care plan','G8539','3','','1','0','','','','0','1','0','0'),
('12459','Functional outcome assessment not documented as being performed; documentation the patient is not eligible for a functional outcome assessment using a standardized tool','Pt inelig funct assess','G8540','3','','1','0','','','','0','1','0','0'),
('12460','Functional outcome assessment using a standardized tool not documented; reason not given','No doc cur funct assess','G8541','3','','1','0','','','','0','1','0','0'),
('12461','Functional outcome assessment using a standardized tool is documented; no functional deficiencies identified; care plan not required','Doc funct no deficiencies','G8542','3','','1','0','','','','0','1','0','0'),
('12462','Documentation of a positive functional outcome assessment using a standardized tool; care plan not documented; reason not given','Cur funct asses; no care pln','G8543','3','','1','0','','','','0','1','0','0'),
('12463','I intend to report the coronary artery bypass graft (cabg) measures group','Cabg measures grp','G8544','3','','1','0','','','','0','1','0','0'),
('12464','I intend to report the hepatitis c measures group','Hepc measures grp','G8545','3','','1','0','','','','0','1','0','0'),
('12465','I intend to report the ischemic vascular disease (ivd) measures group','Ivd measures grp','G8547','3','','1','0','','','','0','1','0','0'),
('12466','I intend to report the heart failure (hf) measures group','Hf measures grp','G8548','3','','1','0','','','','0','1','0','0'),
('12467','All quality actions for the applicable measures in the hepatitis c measures group have been performed for this patient','Hepc mg qual act perform','G8549','3','','1','0','','','','0','1','0','0'),
('12468','All quality actions for the applicable measures in the heart failure (hf) measures group have been performed for this patient','Hf mg qual act perform','G8551','3','','1','0','','','','0','1','0','0'),
('12469','All quality actions for the applicable measures in the ischemic vascular disease (ivd) measures group have been performed for this patient','Ivd mg qual act perform','G8552','3','','1','0','','','','0','1','0','0'),
('12470','Prescription(s) generated and transmitted via a qualified erx system','Prescrip transmit via erx sy','G8553','3','','1','0','','','','0','1','0','0'),
('12471','Referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation','Ref to doc otolog eval','G8556','3','','1','0','','','','0','1','0','0'),
('12472','Patient is not eligible for the referral for otologic evaluation measure','Pt inelig ref otolog eval','G8557','3','','1','0','','','','0','1','0','0'),
('12473','Not referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation; reason not given','No ref to doc otolog eval','G8558','3','','1','0','','','','0','1','0','0'),
('12474','Patient referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation','Pt ref doc oto eval','G8559','3','','1','0','','','','0','1','0','0'),
('12475','Patient has a history of active drainage from the ear within the previous 90 days','Pt hx act drain prev 90 days','G8560','3','','1','0','','','','0','1','0','0'),
('12476','Patient is not eligible for the referral for otologic evaluation for patients with a history of active drainage measure','Pt inelig for ref oto eval','G8561','3','','1','0','','','','0','1','0','0'),
('12477','Patient does not have a history of active drainage from the ear within the previous 90 days','Pt no hx act drain 90 d','G8562','3','','1','0','','','','0','1','0','0'),
('12478','Patient not referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation; reason not given','Pt no ref oto reas no spec','G8563','3','','1','0','','','','0','1','0','0'),
('12479','Patient was referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation; reason not specified)','Pt ref oto eval','G8564','3','','1','0','','','','0','1','0','0'),
('12480','Verification and documentation of sudden or rapidly progressive hearing loss','Ver doc hear loss','G8565','3','','1','0','','','','0','1','0','0'),
('12481','Patient is not eligible for the ''referral for otologic evaluation for sudden or rapidly progressive hearing loss'' measure','Pt inelig ref oto eval','G8566','3','','1','0','','','','0','1','0','0'),
('12482','Patient does not have verification and documentation of sudden or rapidly progressive hearing loss','Pt no doc hear loss','G8567','3','','1','0','','','','0','1','0','0'),
('12483','Patient was not referred to a physician (preferably a physician with training in disorders of the ear) for an otologic evaluation; reason not given','Pt no ref otolo no spec','G8568','3','','1','0','','','','0','1','0','0'),
('12484','Prolonged postoperative intubation (> 24 hrs) required','Prol intubation req','G8569','3','','1','0','','','','0','1','0','0'),
('12485','Prolonged postoperative intubation (> 24 hrs) not required','No prol intub req','G8570','3','','1','0','','','','0','1','0','0'),
('12486','Development of deep sternal wound infection/mediastinitis within 30 days postoperatively','Ster wd ifx 30 d postop','G8571','3','','1','0','','','','0','1','0','0'),
('12487','No deep sternal wound infection/mediastinitis','No ster wd ifx','G8572','3','','1','0','','','','0','1','0','0'),
('12488','Stroke following isolated cabg surgery','Stk cabg','G8573','3','','1','0','','','','0','1','0','0'),
('12489','No stroke following isolated cabg surgery','No strk cabg','G8574','3','','1','0','','','','0','1','0','0'),
('12490','Developed postoperative renal failure or required dialysis','Postop ren fail','G8575','3','','1','0','','','','0','1','0','0'),
('12491','No postoperative renal failure/dialysis not required','No postop ren fail','G8576','3','','1','0','','','','0','1','0','0'),
('12492','Re-exploration required due to mediastinal bleeding with or without tamponade; graft occlusion; valve dysfunction or other cardiac reason','Reop req bld grft oth','G8577','3','','1','0','','','','0','1','0','0'),
('12493','Re-exploration not required due to mediastinal bleeding with or without tamponade; graft occlusion; valve dysfunction or other cardiac reason','No reop req bld grft oth','G8578','3','','1','0','','','','0','1','0','0'),
('12494','Antiplatelet medication at discharge','Antplt med disch','G8579','3','','1','0','','','','0','1','0','0'),
('12495','Antiplatelet medication contraindicated','Antplt med contraind','G8580','3','','1','0','','','','0','1','0','0'),
('12496','No antiplatelet medication at discharge','No antplt med disch','G8581','3','','1','0','','','','0','1','0','0'),
('12497','Beta-blocker at discharge','Bblock disch','G8582','3','','1','0','','','','0','1','0','0'),
('12498','Beta-blocker contraindicated','Bblock contraind','G8583','3','','1','0','','','','0','1','0','0'),
('12499','No beta-blocker at discharge','No bblock disch','G8584','3','','1','0','','','','0','1','0','0'),
('12500','Anti-lipid treatment at discharge','Antilipid treat disch','G8585','3','','1','0','','','','0','1','0','0'),
('12501','Anti-lipid treatment contraindicated','Antlip disch contra','G8586','3','','1','0','','','','0','1','0','0'),
('12502','No anti-lipid treatment at discharge','No antlipid treat disch','G8587','3','','1','0','','','','0','1','0','0'),
('12503','Most recent systolic blood pressure < 140 mmhg','Sys bp <140','G8588','3','','1','0','','','','0','1','0','0'),
('12504','Most recent systolic blood pressure >= 140 mmhg','Sys bp >= 140','G8589','3','','1','0','','','','0','1','0','0'),
('12505','Most recent diastolic blood pressure < 90 mmhg','Dia bp < 90','G8590','3','','1','0','','','','0','1','0','0'),
('12506','Most recent diastolic blood pressure >= 90 mmhg','Dia bp >= 90','G8591','3','','1','0','','','','0','1','0','0'),
('12507','No documentation of blood pressure measurement; reason not given','No bp measure','G8592','3','','1','0','','','','0','1','0','0'),
('12508','Lipid profile results documented and reviewed (must include total cholesterol; hdl-c; triglycerides and calculated ldl-c)','Lipid pn results','G8593','3','','1','0','','','','0','1','0','0'),
('12509','Lipid profile not performed; reason not given','No lipid prof perf','G8594','3','','1','0','','','','0','1','0','0'),
('12510','Most recent ldl-c < 100 mg/dl','Ldl < 100','G8595','3','','1','0','','','','0','1','0','0'),
('12511','Ldl-c was not performed','No ldl perf','G8596','3','','1','0','','','','0','1','0','0'),
('12512','Most recent ldl-c >= 100 mg/dl','Ldl >= 100','G8597','3','','1','0','','','','0','1','0','0'),
('12513','Aspirin or another antiplatelet therapy used','Asa/antiplat ther used','G8598','3','','1','0','','','','0','1','0','0'),
('12514','Aspirin or another antiplatelet therapy not used; reason not given','No asa/antiplat ther use rng','G8599','3','','1','0','','','','0','1','0','0'),
('12515','Iv t-pa initiated within three hours (<= 180 minutes) of time last known well','Tpa initi w/in 3 hrs','G8600','3','','1','0','','','','0','1','0','0'),
('12516','Iv t-pa not initiated within three hours (<= 180 minutes) of time last known well for reasons documented by clinician','No elig tpa init w/in 3 hrs','G8601','3','','1','0','','','','0','1','0','0'),
('12517','Iv t-pa not initiated within three hours (<= 180 minutes) of time last known well; reason not given','No tpa init w/in 3 hrs','G8602','3','','1','0','','','','0','1','0','0'),
('12518','Score on the spoken language comprehension functional communication measure at discharge was higher than at admission','Spok lang comp score','G8603','3','','1','0','','','','0','1','0','0'),
('12519','Score on the spoken language comprehension functional communication measure at discharge was not higher than at admission; reason not given','No high score spok lang','G8604','3','','1','0','','','','0','1','0','0'),
('12520','Patient treated for spoken language comprehension but not scored on the spoken language comprehension functional communication measure either at admission or at discharge','No spok lang comp score','G8605','3','','1','0','','','','0','1','0','0'),
('12521','Score on the attention functional communication measure at discharge was higher than at admission','Attention score','G8606','3','','1','0','','','','0','1','0','0'),
('12522','Score on the attention functional communication measure at discharge was not higher than at admission; reason not given','No high score attention','G8607','3','','1','0','','','','0','1','0','0'),
('12523','Patient treated for attention but not scored on the attention functional communication measure either at admission or at discharge','No attention score','G8608','3','','1','0','','','','0','1','0','0'),
('12524','Score on the memory functional communication measure at discharge was higher than at admission','Memory score','G8609','3','','1','0','','','','0','1','0','0'),
('12525','Score on the memory functional communication measure at discharge was not higher than at admission; reason not given','No high score memory','G8610','3','','1','0','','','','0','1','0','0'),
('12526','Patient treated for memory but not scored on the memory functional communication measure either at admission or at discharge','No memory score','G8611','3','','1','0','','','','0','1','0','0'),
('12527','Score on the motor speech functional communication measure at discharge was higher than at admission','Moto speech score','G8612','3','','1','0','','','','0','1','0','0'),
('12528','Score on the motor speech functional communication measure at discharge was not higher than at admission; reason not given','No high score moto speech','G8613','3','','1','0','','','','0','1','0','0'),
('12529','Patient treated for motor speech but not scored on the motor speech comprehension functional communication measure either at admission or at discharge','No moto speech score','G8614','3','','1','0','','','','0','1','0','0'),
('12530','Score on the reading functional communication measure at discharge was higher than at admission','Reading score','G8615','3','','1','0','','','','0','1','0','0'),
('12531','Score on the reading functional communication measure at discharge was not higher than at admission; reason not given','No high score reading','G8616','3','','1','0','','','','0','1','0','0'),
('12532','Patient treated for reading but not scored on the reading functional communication measure either at admission or at discharge','No reading score','G8617','3','','1','0','','','','0','1','0','0'),
('12533','Score on the spoken language expression functional communication measure at discharge was higher than at admission','Spok lang exp score','G8618','3','','1','0','','','','0','1','0','0'),
('12534','Score on the spoken language expression functional communication measure at discharge was not higher than at admission; reason not given','No high score spok lang exp','G8619','3','','1','0','','','','0','1','0','0'),
('12535','Patient treated for spoken language expression but not scored on the spoken language expression functional communication measure either at admission or at discharge','No spok lang exp score','G8620','3','','1','0','','','','0','1','0','0'),
('12536','Score on the writing functional communication measure at discharge was higher than at admission','Writing score','G8621','3','','1','0','','','','0','1','0','0'),
('12537','Score on the writing functional communication measure at discharge was not higher than at admission; reason not given','No high score writing','G8622','3','','1','0','','','','0','1','0','0'),
('12538','Patient treated for writing but not scored on the writing functional communication measure either at admission or at discharge','No writing score','G8623','3','','1','0','','','','0','1','0','0'),
('12539','Score on the swallowing functional communication measure at discharge was higher than at admission','Swallowing score','G8624','3','','1','0','','','','0','1','0','0'),
('12540','Score on the swallowing functional communication measure at discharge was not higher than at admission; reason not given','No high score swallowing','G8625','3','','1','0','','','','0','1','0','0'),
('12541','Patient treated for swallowing but not scored on the swallowing functional communication measure at admission or at discharge','No swallowing score','G8626','3','','1','0','','','','0','1','0','0'),
('12542','Surgical procedure performed within 30 days following cataract surgery for major complications (e.g.; retained nuclear fragments; endophthalmitis; dislocated or wrong power iol; retinal detachment; or wound dehiscence)','Surg proc w/in 30 days','G8627','3','','1','0','','','','0','1','0','0'),
('12543','Surgical procedure not performed within 30 days following cataract surgery for major complications (e.g.; retained nuclear fragments; endophthalmitis; dislocated or wrong power iol; retinal detachment; or wound dehiscence)','No surg proc w/in 30 days','G8628','3','','1','0','','','','0','1','0','0'),
('12544','Documentation of order for prophylactic parenteral antibiotic to be given within one hour (if fluoroquinolone or vancomycin; two hours) prior to surgical incision (or start of procedure when no incision is required)','Doc antibio order b/4 surg','G8629','3','','1','0','','','','0','1','0','0'),
('12545','Documentation that administration of prophylactic parenteral antibiotics was initiated within one hour (if fluoroquinolone or vancomycin; two hours) prior to surgical incision (or start of procedure when no incision is required); as ordered','Doc antibio given b/4 surg','G8630','3','','1','0','','','','0','1','0','0'),
('12546','Clinician documented that patient was not an eligible candidate for ordering prophylactic parenteral antibiotics to be given within one hour (if fluoroquinolone or vancomycin; two hours) prior to surgical incision (or start of procedure when no incision is required)','Pt no elg 4 order antbi give','G8631','3','','1','0','','','','0','1','0','0'),
('12547','Prophylactic parenteral antibiotics were not ordered to be given or given within one hour (if fluoroquinolone or vancomycin; two hours) prior to the surgical incision (or start of procedure when no incision is required); reason not given','Doc no antibi order b/4 surg','G8632','3','','1','0','','','','0','1','0','0'),
('12548','Pharmacologic therapy (other than minierals/vitamins) for osteoporosis prescribed','Pharm ther osteo rx','G8633','3','','1','0','','','','0','1','0','0'),
('12549','Clinician documented patient not an eligible candidate to receive pharmacologic therapy for osteoporosis','Pt no elg phar ther osteo','G8634','3','','1','0','','','','0','1','0','0'),
('12550','Pharmacologic therapy for osteoporosis was not prescribed; reason not given','No pharm ther osteo rx','G8635','3','','1','0','','','','0','1','0','0'),
('12551','The eligible professional practices in a rural area without sufficient high speed internet access and requests a hardship exemption from the application of the payment adjustment under section 1848(a)(5)(a) of the social security act','Hrdshp rural w/o internet','G8642','3','','1','0','','','','0','1','0','0'),
('12552','The eligible professional practices in an area without sufficient available pharmacies for electronic prescribing and requests a hardship exemption for the application of the payment adjustment under section 1848(a)(5)(a) of the social security act','Hrdshp w/o suff pharm w/erx','G8643','3','','1','0','','','','0','1','0','0'),
('12553','Eligible professional does not have prescribing privileges','Ep no prescribe priv','G8644','3','','1','0','','','','0','1','0','0'),
('12554','I intend to report the asthma measures group','Asthma measures grp','G8645','3','','1','0','','','','0','1','0','0'),
('12555','All quality actions for the applicable measures in the asthma measures group have been performed for this patient','Asthma mg qual act perform','G8646','3','','1','0','','','','0','1','0','0'),
('12556','Risk-adjusted functional status change residual score for the knee successfully calculated and the score was equal to zero (0), or greater than zero (>0),','Fun stat score knee >= 0','G8647','3','','1','0','','','','0','1','0','0'),
('12557','Risk-adjusted functional status change residual score for the knee successfully calculated and the score was less than zero (<0),','Fun stat score knee < 0','G8648','3','','1','0','','','','0','1','0','0'),
('12558','Risk-adjusted functional status change residual scores for the knee not measured because the patient did not complete fotos status survey near discharge; not appropriate','Rafscrs knee no msr; no foto','G8649','3','','1','0','','','','0','1','0','0'),
('12559','Risk-adjusted functional status change residual scores for the knee not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Fun stat score knee not done','G8650','3','','1','0','','','','0','1','0','0'),
('12560','Risk-adjusted functional status change residual score for the hip successfully calculated and the score was equal to zero (0), or greater than zero (>0),','Fun stat score hip >= 0','G8651','3','','1','0','','','','0','1','0','0'),
('12561','Risk-adjusted functional status change residual score for the hip successfully calculated and the score was less than zero (<0),','Fun stat score hip < 0','G8652','3','','1','0','','','','0','1','0','0'),
('12562','Risk-adjusted functional status change residual scores for the hip not measured because the patient did not complete follow up status survey near discharge; patient not appropriate','Rafscrs hip; no msr; no surv','G8653','3','','1','0','','','','0','1','0','0'),
('12563','Risk-adjusted functional status change residual scores for the hip not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Fun stat score hip not done','G8654','3','','1','0','','','','0','1','0','0'),
('12564','Risk-adjusted functional status change residual score for the foot or ankle successfully calculated and the score was equal to zero (0), or greater than zero ( > 0),','Rafscrs ft ank score >=0','G8655','3','','1','0','','','','0','1','0','0'),
('12565','Risk-adjusted functional status change residual score for the foot or ankle successfully calculated and the score was less than zero (< 0),','Rafscrs ft ank score < 0','G8656','3','','1','0','','','','0','1','0','0'),
('12566','Risk-adjusted functional status change residual scores for the foot or ankle not measured because the patient did not complete fotos status survey near discharge; patient not appropriate','Rafscrs foot; no msr/no foto','G8657','3','','1','0','','','','0','1','0','0'),
('12567','Risk-adjusted functional status change residual scores for the foot or ankle not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Rafscrs foot; no msr/no surv','G8658','3','','1','0','','','','0','1','0','0'),
('12568','Risk-adjusted functional status change residual score for the lumbar impairment successfully calculated and the score was equal to zero (0), or greater than zero (> 0),','Rafscrs lumb score >= 0','G8659','3','','1','0','','','','0','1','0','0'),
('12569','Risk-adjusted functional status change residual score for the lumbar impairment successfully calculated and the score was less than zero (< 0),','Rafscrs lumb score < 0','G8660','3','','1','0','','','','0','1','0','0'),
('12570','Risk-adjusted functional status change residual scores for the lumbar impairment not measured because the patient did not complete fotos status survey near discharge; patient not appropriate','Rafscrs lum; no msr/no foto','G8661','3','','1','0','','','','0','1','0','0'),
('12571','Risk-adjusted functional status change residual scores for the lumbar impairment not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Rafscrs lum; no msr/no surv','G8662','3','','1','0','','','','0','1','0','0'),
('12572','Risk-adjusted functional status change residual score for the shoulder successfully calculated and the score was equal to zero (0), or greater than zero (>0),','Fun stat score shdl >=0','G8663','3','','1','0','','','','0','1','0','0'),
('12573','Risk-adjusted functional status change residual score for the shoulder successfully calculated and the score was less than zero (<0),','Fun stat score shdl < 0','G8664','3','','1','0','','','','0','1','0','0'),
('12574','Risk-adjusted functional status change residual scores for the shoulder not measured because the patient did not complete fotos functional status survey near discharge; patient not appropriate','Rafscrs shldr; no msr/foto','G8665','3','','1','0','','','','0','1','0','0'),
('12575','Risk-adjusted functional status change residual scores for the shoulder not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Fun stat score shdl not done','G8666','3','','1','0','','','','0','1','0','0'),
('12576','Risk-adjusted functional status change residual score for the elbow; wrist or hand successfully calculated and the score was equal to zero (0), or greater than zero (>0),','Fun stat score ue >=0','G8667','3','','1','0','','','','0','1','0','0'),
('12577','Risk-adjusted functional status change residual score for the elbow; wrist or hand successfully calculated and the score was less than zero (<0),','Fun stat score ue < 0','G8668','3','','1','0','','','','0','1','0','0'),
('12578','Risk-adjusted functional status change residual scores for the elbow; wrist or hand not measured because the patient did not complete fotos functional follow up status survey near discharge; patient not appropriate','Rafscrs hand; no msr/surv','G8669','3','','1','0','','','','0','1','0','0'),
('12579','Risk-adjusted functional status change residual scores for the elbow; wrist or hand not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Fun stat score ue not done','G8670','3','','1','0','','','','0','1','0','0'),
('12580','Risk-adjusted functional status change residual score for the neck; cranium; mandible; thoracic spine; ribs; or other general orthopaedic impairment successfully calculated and the score was equal to zero (0), or greater than zero (> 0),','Rafscrs neck; score >/=0','G8671','3','','1','0','','','','0','1','0','0'),
('12581','Risk-adjusted functional status change residual score for the neck; cranium; mandible; thoracic spine; ribs; or other general orthopaedic impairment successfully calculated and the score was less than zero (< 0),','Rafscrs neck; score <0','G8672','3','','1','0','','','','0','1','0','0'),
('12582','Risk-adjusted functional status change residual scores for the neck; cranium; mandible; thoracic spine; ribs; or other general orthopaedic impairment not measured because the patient did not complete fotos functional follow up status survey near discharge; patient not appropriate','Rafscrs neck; no msr/no foto','G8673','3','','1','0','','','','0','1','0','0'),
('12583','Risk-adjusted functional status change residual scores for the neck; cranium; mandible; thoracic spine; ribs; or other general orthopaedic impairment not measured because the patient did not complete fotos functional intake on admission and/or follow up status survey near discharge; reason not given','Rafscrs neck; no msr/no foto','G8674','3','','1','0','','','','0','1','0','0'),
('12584','Lvf testing documented as being performed prior to discharge or in the previous 12 months','Lvg test perf','G8682','3','','1','0','','','','0','1','0','0'),
('12585','Lvf testing not performed prior to discharge or in the previous 12 months for a medical or patient documented reason','Pt not elig for lvf test','G8683','3','','1','0','','','','0','1','0','0'),
('12586','Lvf testing not documented as being performed prior to discharge or in the previous 12 months; reason not given','Lvf test not perf','G8685','3','','1','0','','','','0','1','0','0'),
('12587','Left ventricular ejection fraction (lvef) < 40%','Lvef <40%','G8694','3','','1','0','','','','0','1','0','0'),
('12588','Antithrombotic therapy prescribed at discharge','Antithromb thx presc','G8696','3','','1','0','','','','0','1','0','0'),
('12589','Antithrombotic therapy not prescribed for documented reasons (e.g.; patient had stroke during hospital stay; patient expired during inpatient stay; other medical reason(s)); (e.g.; patient left against medical advice; other patient reason(s))','Antithromb no presc doc reas','G8697','3','','1','0','','','','0','1','0','0'),
('12590','Antithrombotic therapy was not prescribed at discharge; reason not given','Antithromb no presc no reas','G8698','3','','1','0','','','','0','1','0','0'),
('12591','Rehabilitation services (occupational; physical or speech) ordered at or prior to discharge','Rehab ordered disch','G8699','3','','1','0','','','','0','1','0','0'),
('12592','Rehabilitation services (occupational; physical or speech) not indicated at or prior to discharge','Rehab not indicated disch','G8700','3','','1','0','','','','0','1','0','0'),
('12593','Rehabilitation services were not ordered; reason not otherwise specified','Rehab not ordered','G8701','3','','1','0','','','','0','1','0','0'),
('12594','Documentation that prophylactic antibiotics were given within 4 hours prior to surgical incision or intraoperatively','Antiobiotics 4 hr prior surg','G8702','3','','1','0','','','','0','1','0','0'),
('12595','Documentation that prophylactic antibiotics were neither given within 4 hours prior to surgical incision nor intraoperatively','Antibiotics not prior surg','G8703','3','','1','0','','','','0','1','0','0'),
('12596','12-lead electrocardiogram (ecg) performed','Ecg performed','G8704','3','','1','0','','','','0','1','0','0'),
('12597','Documentation of medical reason(s) for not performing a 12-lead electrocardiogram (ecg)','Med reas no ecg','G8705','3','','1','0','','','','0','1','0','0'),
('12598','Documentation of patient reason(s) for not performing a 12-lead electrocardiogram (ecg)','Pt reas no ecg','G8706','3','','1','0','','','','0','1','0','0'),
('12599','12-lead electrocardiogram (ecg) not performed; reason not given','Ecg not performed','G8707','3','','1','0','','','','0','1','0','0'),
('12600','Patient not prescribed or dispensed antibiotic','Antibiotic not pres','G8708','3','','1','0','','','','0','1','0','0'),
('12601','Patient prescribed or dispensed antibiotic for documented medical reason(s) (e.g.; intestinal infection; pertussis; bacterial infection; lyme disease; otitis media; acute sinusitis; acute pharyngitis; acute tonsillitis; chronic sinusitis; infection of the pharynx/larynx/tonsils/adenoids; prostatitis; cellulitis; mastoiditis; or bone infections; acute lymphadenitis; impetigo; skin staph infections; pneumonia/gonococcal infections; venereal disease (syphilis; chlamydia; inflammatory diseases (female reproductive organs)); infections of the kidney; cystitis or uti; and acne)','Med reas antibiotic pres','G8709','3','','1','0','','','','0','1','0','0'),
('12602','Patient prescribed or dispensed antibiotic','Pt pres antibiotic','G8710','3','','1','0','','','','0','1','0','0'),
('12603','Prescribed or dispensed antibiotic','Pres antibiotic','G8711','3','','1','0','','','','0','1','0','0'),
('12604','Antibiotic not prescribed or dispensed','Not pres antibiotic','G8712','3','','1','0','','','','0','1','0','0'),
('12605','Spkt/v greater than or equal to 1.2 (single-pool clearance of urea [kt] / volume [v])','Spkt/v great 1.2 kt/v','G8713','3','','1','0','','','','0','1','0','0'),
('12606','Hemodialysis treatment performed exactly three times per week for > 90 days','Hemodialysis 3 times week','G8714','3','','1','0','','','','0','1','0','0'),
('12607','Spkt/v less than 1.2 (single-pool clearance of urea [kt] / volume [v]); reason not given','Less 1.2 kt/v','G8717','3','','1','0','','','','0','1','0','0'),
('12608','Total kt/v greater than or equal to 1.7 per week (total clearance of urea [kt] / volume [v])','Great 1.7 kt/v per week','G8718','3','','1','0','','','','0','1','0','0'),
('12609','Total kt/v less than 1.7 per week (total clearance of urea [kt] / volume [v])','Less 1.7 kt/v per week','G8720','3','','1','0','','','','0','1','0','0'),
('12610','Pt category (primary tumor); pn category (regional lymph nodes); and histologic grade were documented in pathology report','Pt; pn; hist grade doc','G8721','3','','1','0','','','','0','1','0','0'),
('12611','Documentation of medical reason(s) for not including the pt category; the pn category or the histologic grade in the pathology report (e.g.; re-excision without residual tumor; non-carcinomasanal canal)','Med reas pt; pn; not doc','G8722','3','','1','0','','','','0','1','0','0'),
('12612','Specimen site is other than anatomic location of primary tumor','Spec sit not prim tumor','G8723','3','','1','0','','','','0','1','0','0'),
('12613','Pt category; pn category and histologic grade were not documented in the pathology report; reason not given','Pt; pn; hist grade not doc','G8724','3','','1','0','','','','0','1','0','0'),
('12614','Fasting lipid profile performed (triglycerides; ldl-c; hdl-c and total cholesterol)','Lipid profile perf doc','G8725','3','','1','0','','','','0','1','0','0'),
('12615','Clinician has documented reason for not performing fasting lipid profile (e.g.; patient declined; other patient reasons)','Doc reas no lipid profile','G8726','3','','1','0','','','','0','1','0','0'),
('12616','Fasting lipid profile not performed; reason not given','Lipid profile not perf','G8728','3','','1','0','','','','0','1','0','0'),
('12617','Pain assessment documented as positive using a standardized tool and a follow-up plan is documented','Pain doc pos and plan','G8730','3','','1','0','','','','0','1','0','0'),
('12618','Pain assessment using a standardized tool is documented as negative; no follow-up plan required','Pain neg no plan','G8731','3','','1','0','','','','0','1','0','0'),
('12619','No documentation of pain assessment; reason not given','No doc of pain','G8732','3','','1','0','','','','0','1','0','0'),
('12620','Elder maltreatment screen documented as positive and a follow-up plan is documented','Doc pos elder mal scrn plan','G8733','3','','1','0','','','','0','1','0','0'),
('12621','Elder maltreatment screen documented as negative; no follow-up required','Doc neg elder mal no plan','G8734','3','','1','0','','','','0','1','0','0'),
('12622','Elder maltreatment screen documented as positive; follow-up plan not documented; reason not given','Eld mal scrn pos no plan','G8735','3','','1','0','','','','0','1','0','0'),
('12623','Most current ldl-c <100mg/dl','Ldl-c <100mg/dl','G8736','3','','1','0','','','','0','1','0','0'),
('12624','Most current ldl-c >=100mg/dl','Ldl-c >=100mg/dl','G8737','3','','1','0','','','','0','1','0','0'),
('12625','Left ventricular ejection fraction (lvef) < 40% or documentation of severely or moderately depressed left ventricular systolic function','Lvef < 40%','G8738','3','','1','0','','','','0','1','0','0'),
('12626','Left ventricular ejection fraction (lvef) >= 40% or documentation as normal or mildly depressed left ventricular systolic function','Lvef >= 40%','G8739','3','','1','0','','','','0','1','0','0'),
('12627','Left ventricular ejection fraction (lvef) not performed or assessed; reason not given','Lvef not perfrmd','G8740','3','','1','0','','','','0','1','0','0'),
('12628','Patient not treated for spoken language comprehension disorder','Not tx spoken lang','G8741','3','','1','0','','','','0','1','0','0'),
('12629','Patient not treated for attention disorder','Not tx attention','G8742','3','','1','0','','','','0','1','0','0'),
('12630','Patient not treated for memory disorder','Not tx memory','G8743','3','','1','0','','','','0','1','0','0'),
('12631','Patient not treated for motor speech disorder','Not tx motor speech','G8744','3','','1','0','','','','0','1','0','0'),
('12632','Patient not treated for reading disorder','Not tx reading','G8745','3','','1','0','','','','0','1','0','0'),
('12633','Patient not treated for spoken language expression disorder','Not tx spoken lang express','G8746','3','','1','0','','','','0','1','0','0'),
('12634','Patient not treated for writing disorder','Not tx writing','G8747','3','','1','0','','','','0','1','0','0'),
('12635','Patient not treated for swallowing disorder','Not tx swallowing','G8748','3','','1','0','','','','0','1','0','0'),
('12636','Absence of signs of melanoma (cough; dyspnea; tenderness; localized neurologic signs such as weakness; jaundice or any other sign suggesting systemic spread) or absence of symptoms of melanoma (pain; paresthesia; or any other symptom suggesting the possibility of systemic spread of melanoma)','Signs of melanoma absent','G8749','3','','1','0','','','','0','1','0','0'),
('12637','Smoking status and exposure to second hand smoke in the home not assessed; reason not given','Smkg status not assess','G8751','3','','1','0','','','','0','1','0','0'),
('12638','Most recent systolic blood pressure < 140 mmhg','Sys bp less 140','G8752','3','','1','0','','','','0','1','0','0'),
('12639','Most recent systolic blood pressure >= 140 mmhg','Sys bp > or = 140','G8753','3','','1','0','','','','0','1','0','0'),
('12640','Most recent diastolic blood pressure < 90 mmhg','Dias bp less 90','G8754','3','','1','0','','','','0','1','0','0'),
('12641','Most recent diastolic blood pressure >= 90 mmhg','Dias bp > or = 90','G8755','3','','1','0','','','','0','1','0','0'),
('12642','No documentation of blood pressure measurement; reason not given','No bp measure doc','G8756','3','','1','0','','','','0','1','0','0'),
('12643','All quality actions for the applicable measures in the chronic obstructive pulmonary disease (copd) measures group have been performed for this patient','Copd mg qual act perform','G8757','3','','1','0','','','','0','1','0','0'),
('12644','All quality actions for the applicable measures in the inflammatory bowel disease (ibd) measures group have been performed for this patient','Ibd mg qual act perform','G8758','3','','1','0','','','','0','1','0','0'),
('12645','All quality actions for the applicable measures in the sleep apnea measures group have been performed for this patient','Osa mg qual act perform','G8759','3','','1','0','','','','0','1','0','0'),
('12646','All quality actions for the applicable measures in the dementia measures group have been performed for this patient','Dementia mg qual act perform','G8761','3','','1','0','','','','0','1','0','0'),
('12647','All quality actions for the applicable measures in the parkinsons disease measures group have been performed for this patient','Pd mg qual act perform','G8762','3','','1','0','','','','0','1','0','0'),
('12648','All quality actions for the applicable measures in the hypertension (htn) measures group have been performed for this patient','Hyperten mg qual act perform','G8763','3','','1','0','','','','0','1','0','0'),
('12649','All quality actions for the applicable measures in the cardiovascular prevention measures group have bee performed for this patient','Car prev mg qual act perform','G8764','3','','1','0','','','','0','1','0','0'),
('12650','All quality actions for the applicable measures in the cataract measures group have been performed for this patient','Cataract mg qual act perform','G8765','3','','1','0','','','','0','1','0','0'),
('12651','Lipid panel results documented and reviewed (must include total cholesterol; hdl-c; triglycerides and calculated ldl-c)','Lipid panel res doc rev','G8767','3','','1','0','','','','0','1','0','0'),
('12652','Documentation of medical reason(s) for not performing lipid profile (e.g.; patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no lipid profle','G8768','3','','1','0','','','','0','1','0','0'),
('12653','Lipid profile not performed; reason not given','Lipid profile not perform','G8769','3','','1','0','','','','0','1','0','0'),
('12654','Urine protein test result documented and reviewed','Urine protein test doc rev','G8770','3','','1','0','','','','0','1','0','0'),
('12655','Documentation of diagnosis of chronic kidney disease','Doc dx ckd','G8771','3','','1','0','','','','0','1','0','0'),
('12656','Documentation of medical reason(s) for not performing urine protein test (e.g.; patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not cllinically appropriate)','Doc med reas no urine protn','G8772','3','','1','0','','','','0','1','0','0'),
('12657','Urine protein test was not performed; reason not given','No urine protein test','G8773','3','','1','0','','','','0','1','0','0'),
('12658','Serum creatinine test result documented and reviewed','Serum creatinine doc rev','G8774','3','','1','0','','','','0','1','0','0'),
('12659','Documentation of medical reason(s) for not performing serum creatinine test (e.g.; patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no serum crtn','G8775','3','','1','0','','','','0','1','0','0'),
('12660','Serum creatinine test not performed; reason not given','No serum creatinine test','G8776','3','','1','0','','','','0','1','0','0'),
('12661','Diabetes screening test performed','Diabetes screen','G8777','3','','1','0','','','','0','1','0','0'),
('12662','Documentation of medical reason(s) for not performing diabetes screening test (e.g.; patients with a diagnosis of diabetes; or with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no diabete scrn','G8778','3','','1','0','','','','0','1','0','0'),
('12663','Diabetes screening test not performed; reason not given','No diabetes screen','G8779','3','','1','0','','','','0','1','0','0'),
('12664','Counseling for diet and physical activity performed','Counsel diet phys activity','G8780','3','','1','0','','','','0','1','0','0'),
('12665','Documentation of medical reason(s) for patient not receiving counseling for diet and physical activity (e.g.; patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no counsel diet','G8781','3','','1','0','','','','0','1','0','0'),
('12666','Counseling for diet and physical activity not performed; reason not given','No counsel diet phys act','G8782','3','','1','0','','','','0','1','0','0'),
('12667','Normal blood pressure reading documented; follow-up not required','Bp scrn perf rec interval','G8783','3','','1','0','','','','0','1','0','0'),
('12668','Patient not eligible (e.g.; documentation the patient is not eligible due to active diagnosis of hypertension; patient refuses; urgent or emergent situation)','Pt no elig for bp assess','G8784','3','','1','0','','','','0','1','0','0'),
('12669','Blood pressure reading not documented; reason not given','Bp scrn no perf at interval','G8785','3','','1','0','','','','0','1','0','0'),
('12670','Most recent office visit systolic blood pressure <130 mm hg','Systolic <130mmhg','G8790','3','','1','0','','','','0','1','0','0'),
('12671','Most recent office visit systolic blood pressure; 130 to 139 mm hg','Systolic 130-139mmhg','G8791','3','','1','0','','','','0','1','0','0'),
('12672','Most recent office visit systolic blood pressure >=140 mm hg','Systolic >=140mmhg','G8792','3','','1','0','','','','0','1','0','0'),
('12673','Most recent office visit diastolic blood pressure; <80 mm hg','Diastolic <80mmhg','G8793','3','','1','0','','','','0','1','0','0'),
('12674','Most recent office visit diastolic blood pressure; 80 - 89 mm hg','Diastolic 80-89mmhg','G8794','3','','1','0','','','','0','1','0','0'),
('12675','Most recent office visit diastolic blood pressure >=90 mm hg','Diastolic >=90mmhg','G8795','3','','1','0','','','','0','1','0','0'),
('12676','Blood pressure measurement not documented; reason not given','Bp not doc','G8796','3','','1','0','','','','0','1','0','0'),
('12677','Specimen site other than anatomic location of esophagus','Specimen site not esophagus','G8797','3','','1','0','','','','0','1','0','0'),
('12678','Specimen site other than anatomic location of prostate','Specimen site not prostate','G8798','3','','1','0','','','','0','1','0','0'),
('12679','Anticoagulation ordered','Anticoag ordered','G8799','3','','1','0','','','','0','1','0','0'),
('12680','Anticoagulation not ordered for reasons documented by clinician','Doc reas anticoag not order','G8800','3','','1','0','','','','0','1','0','0'),
('12681','Anticoagulation was not ordered; reason not given','Anticoag not ordered','G8801','3','','1','0','','','','0','1','0','0'),
('12682','Performance of trans-abdominal or trans-vaginal ultrasound','Transab or transvag us','G8806','3','','1','0','','','','0','1','0','0'),
('12683','Trans-abdominal or trans-vaginal ultrasound not performed for reasons documented by clinician (e.g.; patient has visited the ed multiple times within 72 hours; patient has a documented intrauterine pregnancy [iup])','Doc reas no us','G8807','3','','1','0','','','','0','1','0','0'),
('12684','Performance of trans-abdominal or trans-vaginal ultrasound not ordered; reason not given (e.g.; patient has visited the ed multiple times with no documentation of a trans-abdominal or trans-vaginal ultrasound within ed or from referring eligible professional)','No transab or transvag us','G8808','3','','1','0','','','','0','1','0','0'),
('12685','Rh-immunoglobulin (rhogam) ordered','Rh-immunoglobulin order','G8809','3','','1','0','','','','0','1','0','0'),
('12686','Rh-immunoglobulin (rhogam) not ordered for reasons documented by clinician (e.g.; patient had prior documented receipt of rhogam within 12 weeks; patient refusal)','Doc reas no rh-immuno','G8810','3','','1','0','','','','0','1','0','0'),
('12687','Documentation rh-immunoglobulin (rhogam) was not ordered; reason not given','No rh-immunoglobulin order','G8811','3','','1','0','','','','0','1','0','0'),
('12688','Patient is not eligible for follow-up cta; duplex; or mra (e.g.; patient death; failure to return for scheduled follow-up exam; planned follow-up study which will meet numerator criteria has not yet occurred at the time of reporting)','Pt not elig cta; duplex; mra','G8812','3','','1','0','','','','0','1','0','0'),
('12689','Follow-up cta; duplex; or mra of the abdomen and pelvis performed','Cta; duplex; mra performed','G8813','3','','1','0','','','','0','1','0','0'),
('12690','Follow-up cta; duplex; or mra of the abdomen and pelvis not performed','No cta; duplex; mra','G8814','3','','1','0','','','','0','1','0','0'),
('12691','Documented reason in the medical records for why the statin therapy was not prescribed (i.e.; lower extremity bypass was for a patient with non-artherosclerotic disease)','Doc reas no statin therapy','G8815','3','','1','0','','','','0','1','0','0'),
('12692','Statin medication prescribed at discharge','Statin med pres at disch','G8816','3','','1','0','','','','0','1','0','0'),
('12693','Statin therapy not prescribed at discharge; reason not given','Doc reas no statin med disch','G8817','3','','1','0','','','','0','1','0','0'),
('12694','Patient discharge to home no later than post-operative day #7','Pt disch to home by day#7','G8818','3','','1','0','','','','0','1','0','0'),
('12695','Patient not discharged to home by post-operative day #7','Pt not disch to home day#7','G8825','3','','1','0','','','','0','1','0','0'),
('12696','Patient discharge to home no later than post-operative day #2 following evar','Pt disch home day #2 evar','G8826','3','','1','0','','','','0','1','0','0'),
('12697','Aneurysm minor diameter <= 5.5 cm for women','Aneurysm <= 5.5cm for women','G8827','3','','1','0','','','','0','1','0','0'),
('12698','Patient not discharged to home by post-operative day #2 following evar','Pt not disch home day#2 evar','G8833','3','','1','0','','','','0','1','0','0'),
('12699','Patient discharged to home no later than post-operative day #2 following cea','Pt disch home day #2 cea','G8834','3','','1','0','','','','0','1','0','0'),
('12700','Asymptomatic patient with no history of any transient ischemic attack or stroke in any carotid or vertebrobasilar territory','Asymptom no trans','G8835','3','','1','0','','','','0','1','0','0'),
('12701','Patient not discharged to home by post-operative day #2 following cea','Not disch home by day #2','G8838','3','','1','0','','','','0','1','0','0'),
('12702','Sleep apnea symptoms assessed; including presence or absence of snoring and daytime sleepiness','Sleep apnea assess','G8839','3','','1','0','','','','0','1','0','0'),
('12703','Documentation of reason(s) for not documenting an assessment of sleep symptoms (e.g.; patient didnt have initial daytime sleepiness; patient visited between initial testing and initiation of therapy)','Doc reas no sleep apnea','G8840','3','','1','0','','','','0','1','0','0'),
('12704','Sleep apnea symptoms not assessed; reason not given','No sleep apnea assess','G8841','3','','1','0','','','','0','1','0','0'),
('12705','Apnea hypopnea index (ahi) or respiratory disturbance index (rdi) measured at the time of initial diagnosis','Ahi or rdi initial dx','G8842','3','','1','0','','','','0','1','0','0'),
('12706','Documentation of reason(s) for not measuring an apnea hypopnea index (ahi) or a respiratory disturbance index (rdi) at the time of initial diagnosis (e.g.; psychiatric disease; dementia; patient declined; financial; insurance coverage; test ordered but not yet completed)','Doc reas no ahi or rdi','G8843','3','','1','0','','','','0','1','0','0'),
('12707','Apnea hypopnea index (ahi) or respiratory disturbance index (rdi) not measured at the time of initial diagnosis; reason not given','No ahi or rdi initial dx','G8844','3','','1','0','','','','0','1','0','0'),
('12708','Positive airway pressure therapy prescribed','Pos airway press prescribed','G8845','3','','1','0','','','','0','1','0','0'),
('12709','Moderate or severe obstructive sleep apnea (apnea hypopnea index (ahi) or respiratory disturbance index (rdi) of 15 or greater)','Mod or severe osa','G8846','3','','1','0','','','','0','1','0','0'),
('12710','Mild obstructive sleep apnea (apnea hypopnea index (ahi) or respiratory disturbance index (rdi) of less than 15)','Mild osa','G8848','3','','1','0','','','','0','1','0','0'),
('12711','Documentation of reason(s) for not prescribing positive airway pressure therapy (e.g.; patient unable to tolerate; alternative therapies use; patient declined; financial; insurance coverage)','Doc reas no pos air press','G8849','3','','1','0','','','','0','1','0','0'),
('12712','Positive airway pressure therapy not prescribed; reason not given','No pap prescribed','G8850','3','','1','0','','','','0','1','0','0'),
('12713','Objective measurement of adherence to positive airway pressure therapy; documented','Adhere pos air press therapy','G8851','3','','1','0','','','','0','1','0','0'),
('12714','Positive airway pressure therapy prescribed','Pos air press prescribe','G8852','3','','1','0','','','','0','1','0','0'),
('12715','Positive airway pressure therapy not prescribed','Pos air press not prescribe','G8853','3','','1','0','','','','0','1','0','0'),
('12716','Documentation of reason(s) for not objectively measuring adherence to positive airway pressure therapy (e.g.; patient didnt bring data from continous positive airway pressure [cpap]; therapy not yet initiated; not available on machine)','Reas no adhere pos air pres','G8854','3','','1','0','','','','0','1','0','0'),
('12717','Objective measurement of adherence to positive airway pressure therapy not performed; reason not given','Pos air press adhere no perf','G8855','3','','1','0','','','','0','1','0','0'),
('12718','Referral to a physician for an otologic evaluation performed','Ref for oto eval','G8856','3','','1','0','','','','0','1','0','0'),
('12719','Patient is not eligible for the referral for otologic evaluation measure (e.g.; patients who are already under the care of a physician for acute or chronic dizziness)','No elig ref for oto eval','G8857','3','','1','0','','','','0','1','0','0'),
('12720','Referral to a physician for an otologic evaluation not performed; reason not given','Not ref for oto eval','G8858','3','','1','0','','','','0','1','0','0'),
('12721','Patient receiving corticosteroids greater than or equal to 10mg/day for 60 or greater consecutive days','Corticosteroids 10mg 60 days','G8859','3','','1','0','','','','0','1','0','0'),
('12722','Patients who have received dose of corticosteroids greater than or equal to 10mg/day for 60 or greater consecutive days','Corticosteroid 10 mg 60 days','G8860','3','','1','0','','','','0','1','0','0'),
('12723','Within the past 2 years; central dual-energy x-ray absorptiometry (dxa) ordered and documented; review of systems and medication history or pharmacologic therapy (other than minerals/vitamins) for osteoporosis prescribed','Dxa ordered for osteo','G8861','3','','1','0','','','','0','1','0','0'),
('12724','Patients not receiving corticosteroids greater than or equal to 10mg/day for 60 or greater consecutive days','No corticostrd 10mg 60 days','G8862','3','','1','0','','','','0','1','0','0'),
('12725','Patients not assessed for risk of bone loss; reason not given','No assess bone loss','G8863','3','','1','0','','','','0','1','0','0'),
('12726','Pneumococcal vaccine administered or previously received','Pneumococcal vaccine admin','G8864','3','','1','0','','','','0','1','0','0'),
('12727','Documentation of medical reason(s) for not administering or previously receiving pneumococcal vaccine (e.g.; patient allergic reaction; potential adverse drug reaction)','Doc med reas no pneumococcal','G8865','3','','1','0','','','','0','1','0','0'),
('12728','Documentation of patient reason(s) for not administering or previously receiving pneumococcal vaccine (e.g.; patient refusal)','Doc pt reas no pneumococcal','G8866','3','','1','0','','','','0','1','0','0'),
('12729','Pneumococcal vaccine not administered or previously received; reason not given','No pneumococcal admin','G8867','3','','1','0','','','','0','1','0','0'),
('12730','Patients receiving a first course of anti-tnf therapy','1st course antitnf','G8868','3','','1','0','','','','0','1','0','0'),
('12731','Patient has documented immunity to hepatitis b and is receiving a first course of anti-tnf therapy','Doc immun hep b 1st antitnf','G8869','3','','1','0','','','','0','1','0','0'),
('12732','Hepatitis b vaccine injection administered or previously received and is receiving a first course of anti-tnf therapy','Hepb admin 1st antitnf','G8870','3','','1','0','','','','0','1','0','0'),
('12733','Patient not receiving a first course of anti-tnf therapy','No 1st antitnf','G8871','3','','1','0','','','','0','1','0','0'),
('12734','Excised tissue evaluated by imaging intraoperatively to confirm successful inclusion of targeted lesion','Intraop image confirm excise','G8872','3','','1','0','','','','0','1','0','0'),
('12735','Patients with needle localization specimens which are not amenable to intraoperative imaging such as mri needle wire localization; or targets which are tentatively identified on mammogram or ultrasound which do not contain a biopsy marker but which can be verified on intraoperative inspection or pathology (e.g.; needle biopsy site where the biopsy marker is remote from the actual biopsy site)','Specimen not intraop image','G8873','3','','1','0','','','','0','1','0','0'),
('12736','Excised tissue not evaluated by imaging intraoperatively to confirm successful inclusion of targeted lesion','Tissue not image intraop','G8874','3','','1','0','','','','0','1','0','0'),
('12737','Clinician diagnosed breast cancer preoperatively by a minimally invasive biopsy method','Breast cancer dx min invsive','G8875','3','','1','0','','','','0','1','0','0'),
('12738','Documentation of reason(s) for not performing minimally invasive biopsy to diagnose breast cancer preoperatively (e.g.; lesion too close to skin; implant; chest wall; etc.; lesion could not be adequately visualized for needle biopsy; patient condition prevents needle biopsy [weight; breast thickness; etc.]; duct excision without imaging abnormality; prophylactic mastectomy; reduction mammoplasty; excisional biopsy performed by another physician)','Doc reas no min inv dx','G8876','3','','1','0','','','','0','1','0','0'),
('12739','Clinician did not attempt to achieve the diagnosis of breast cancer preoperatively by a minimally invasive biopsy method; reason not given','No brst cncr dx min invasive','G8877','3','','1','0','','','','0','1','0','0'),
('12740','Sentinel lymph node biopsy procedure performed','Sent lymph node biopsy','G8878','3','','1','0','','','','0','1','0','0'),
('12741','Clinically node negative (t1n0m0 or t2n0m0), invasive breast cancer','Node neg inv brst cncr','G8879','3','','1','0','','','','0','1','0','0'),
('12742','Documentation of reason(s) sentinel lymph node biopsy not performed (e.g.; reasons could include but not limited to; non-invasive cancer; incidental discovery of breast cancer on prophylactic mastectomy; incidental discovery of breast cancer on reduction mammoplasty; pre-operative biopsy proven lymph node (ln) metastases; inflammatory carcinoma; stage 3 locally advanced cancer; recurrent invasive breast cancer; patient refusal after informed consent)','Doc reas no lymph node biop','G8880','3','','1','0','','','','0','1','0','0'),
('12743','Stage of breast cancer is greater than t1n0m0 or t2n0m0','Brst cncr stage > t1n0m0','G8881','3','','1','0','','','','0','1','0','0'),
('12744','Sentinel lymph node biopsy procedure not performed; reason not given','No sent lymph node biopsy','G8882','3','','1','0','','','','0','1','0','0'),
('12745','Biopsy results reviewed; communicated; tracked and documented','Rev; comm; track; doc biopsy','G8883','3','','1','0','','','','0','1','0','0'),
('12746','Clinician documented reason that patients biopsy results were not reviewed','Doc reas biopsy not review','G8884','3','','1','0','','','','0','1','0','0'),
('12747','Biopsy results not reviewed; communicated; tracked or documented','No rev; comm; track biopsy','G8885','3','','1','0','','','','0','1','0','0'),
('12748','Most recent blood pressure under control','Bp under control','G8886','3','','1','0','','','','0','1','0','0'),
('12749','Documentation of medical reason(s) for most recent blood pressure not being under control (e.g.; patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas bp not control','G8887','3','','1','0','','','','0','1','0','0'),
('12750','Most recent blood pressure not under control; results documented and reviewed','Bp not under control','G8888','3','','1','0','','','','0','1','0','0'),
('12751','No documentation of blood pressure measurement; reason not given','No doc bp','G8889','3','','1','0','','','','0','1','0','0'),
('12752','Most recent ldl-c under control; results documented and reviewed','Ldl-c under control','G8890','3','','1','0','','','','0','1','0','0'),
('12753','Documentation of medical reason(s) for most recent ldl-c not under control (e.g.; patients with palliative goals for for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no ldl-c contrl','G8891','3','','1','0','','','','0','1','0','0'),
('12754','Documentation of medical reason(s) for not performing ldl-c test (e.g. patients with palliative goals or for whom treatment of hypertension with standard treatment goals is not clinically appropriate)','Doc med reas no ldl-c test','G8892','3','','1','0','','','','0','1','0','0'),
('12755','Most recent ldl-c not under control; results documented and reviewed','Ldl-c not under control','G8893','3','','1','0','','','','0','1','0','0'),
('12756','Ldl-c not performed; reason not given','Ldl-c not performed','G8894','3','','1','0','','','','0','1','0','0'),
('12757','Oral aspirin or other antithrombotic therapy prescribed','Antrom prescribe','G8895','3','','1','0','','','','0','1','0','0'),
('12758','Documentation of medical reason(s) for not prescribing oral aspirin or other antthrombotic therapy (e.g.; patient documented to be low risk or patient with terminal illness or treatment of hypertension with standard treatment goals is not clinically appropriate; or for whom risk of aspirin or other antithrombotic therapy exceeds potential benefits such as for individuals whose blood pressure is poorly controlled)','Doc med reas no antihtrom','G8896','3','','1','0','','','','0','1','0','0'),
('12759','Oral aspirin or other antithrombotic therapy was not prescribed; reason not given','Antithrom not prescribe','G8897','3','','1','0','','','','0','1','0','0'),
('12760','I intend to report the chronic obstructive pulmonary disease (copd) measures group','Copd measures group','G8898','3','','1','0','','','','0','1','0','0'),
('12761','I intend to report the inflammatory bowel disease (ibd) measures group','Inflammatory bowel dis mg','G8899','3','','1','0','','','','0','1','0','0'),
('12762','I intend to report the sleep apnea measures group','Obstructive sleep apnea mg','G8900','3','','1','0','','','','0','1','0','0'),
('12763','I intend to report the dementia measures group','Dementia measures group','G8902','3','','1','0','','','','0','1','0','0'),
('12764','I intend to report the parkinsons disease measures group','Parkinsons disease mg','G8903','3','','1','0','','','','0','1','0','0'),
('12765','I intend to report the hypertension (htn) measures group','Hypertension mg','G8904','3','','1','0','','','','0','1','0','0'),
('12766','I intend to report the cardiovascular prevention measures group','Cardiovascular prevention mg','G8905','3','','1','0','','','','0','1','0','0'),
('12767','I intend to report the cataract measures group','Cataract measures group','G8906','3','','1','0','','','','0','1','0','0'),
('12768','Patient documented not to have experienced any of the following events: a burn prior to discharge; a fall within the facility; wrong site/side/patient/procedure/implant event; or a hospital transfer or hospital admission upon discharge from the facility','Pt doc no events on discharg','G8907','3','','1','0','','','','0','1','0','0'),
('12769','Patient documented to have received a burn prior to discharge','Pt doc w burn prior to d/c','G8908','3','','1','0','','','','0','1','0','0'),
('12770','Patient documented not to have received a burn prior to discharge','Pt doc no burn prior to d/c','G8909','3','','1','0','','','','0','1','0','0'),
('12771','Patient documented to have experienced a fall within asc','Pt doc to have fall in asc','G8910','3','','1','0','','','','0','1','0','0'),
('12772','Patient documented not to have experienced a fall within ambulatory surgical center','Pt doc no fall in asc','G8911','3','','1','0','','','','0','1','0','0'),
('12773','Patient documented to have experienced a wrong site; wrong side; wrong patient; wrong procedure or wrong implant event','Pt doc with wrong event','G8912','3','','1','0','','','','0','1','0','0'),
('12774','Patient documented not to have experienced a wrong site; wrong side; wrong patient; wrong procedure or wrong implant event','Pt doc no wrong event','G8913','3','','1','0','','','','0','1','0','0'),
('12775','Patient documented to have experienced a hospital transfer or hospital admission upon discharge from asc','Pt trans to hosp post d/c','G8914','3','','1','0','','','','0','1','0','0'),
('12776','Patient documented not to have experienced a hospital transfer or hospital admission upon discharge from asc','Pt not trans to hosp at d/c','G8915','3','','1','0','','','','0','1','0','0'),
('12777','Patient with preoperative order for iv antibiotic surgical site infection (ssi) prophylaxis; antibiotic initiated on time','Pt w iv ab given on time','G8916','3','','1','0','','','','0','1','0','0'),
('12778','Patient with preoperative order for iv antibiotic surgical site infection (ssi) prophylaxis; antibiotic not initiated on time','Pt w iv ab not given on time','G8917','3','','1','0','','','','0','1','0','0'),
('12779','Patient without preoperative order for iv antibiotic surgical site infection (ssi) prophylaxis','Pt w/o preop order iv ab pro','G8918','3','','1','0','','','','0','1','0','0'),
('12780','Most recent systolic blood pressure < 140 mmhg','Mst rcnt sys bp <140mmg','G8919','3','','1','0','','','','0','1','0','0'),
('12781','Most recent systolic blood pressure >= 140 mmhg','Mst rcnt sys bp >=140mmhg','G8920','3','','1','0','','','','0','1','0','0'),
('12782','Most recent diastolic blood pressure < 90 mmhg','Mst rcnt dia bp <90mmhg','G8921','3','','1','0','','','','0','1','0','0'),
('12783','Most recent diastolic blood pressure >= 90 mmhg','Mst rcnt dia bp >=90mmhg','G8922','3','','1','0','','','','0','1','0','0'),
('12784','Left ventricular ejection fraction (lvef) < 40% or documentation of moderately or severely depressed left ventricular systolic function','Lvef < 40% or lvsd','G8923','3','','1','0','','','','0','1','0','0'),
('12785','Spirometry test results demonstrate fev1/fvc < 70%; fev < 60% predicted and patient has copd symptoms (e.g.; dyspnea; cough/sputum; wheezing)','Spir fev1/fvc<70%;fev<60%','G8924','3','','1','0','','','','0','1','0','0'),
('12786','Spirometry test results demonstrate fev1 >= 60% fev1/fvc >= 70%; predicted or patient does not have copd symptoms','Spir fev1/fvc>=60% & no copd','G8925','3','','1','0','','','','0','1','0','0'),
('12787','Spirometry test not performed or documented; reason not given','Spiro no perf or doc','G8926','3','','1','0','','','','0','1','0','0'),
('12788','Adjuvant chemotherapy referred; prescribed or previously received for ajcc stage iii; colon cancer','Adj chem pres ajcc iii','G8927','3','','1','0','','','','0','1','0','0'),
('12789','Adjuvant chemotherapy not prescribed or previously received; for documented reasons (e.g.; medical co-morbidities; diagnosis date more than 5 years prior to the current visit date; patients diagnosis date is within 120 days of the end of the 12 month reporting period; patients cancer has metastasized; medical contraindication/allergy; poor performance status; other medical reasons; patient refusal; other patient reasons; patient is currently enrolled in a clinical trial that precludes prescription of chemotherapy; other system reasons)','Adj chem not pres rsn spec','G8928','3','','1','0','','','','0','1','0','0'),
('12790','Adjuvant chemotherapy not prescribed or previously received; reason not given','Adj cmo not pres rsn not gvn','G8929','3','','1','0','','','','0','1','0','0'),
('12791','Assessment of depression severity at the initial evaluation','Assess of dep @ initial eval','G8930','3','','1','0','','','','0','1','0','0'),
('12792','Assessment of depression severity not documented; reason not given','Asses of dep not documented','G8931','3','','1','0','','','','0','1','0','0'),
('12793','Suicide risk assessed at the initial evaluation','Suicd rsk assessed init eval','G8932','3','','1','0','','','','0','1','0','0'),
('12794','Suicide risk not assessed at the initial evaluation; reason not given','Suicide risk not assessed','G8933','3','','1','0','','','','0','1','0','0'),
('12795','Left ventricular ejection fraction (lvef) <40% or documentation of moderately or severely depressed left ventricular systolic function','Lvef <40% or dep lv sys fcn','G8934','3','','1','0','','','','0','1','0','0'),
('12796','Clinician prescribed angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy','Rx ace or arb therapy','G8935','3','','1','0','','','','0','1','0','0'),
('12797','Clinician documented that patient was not an eligible candidate for angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy (eg; allergy; intolerance; pregnancy; renal failure due to ace inhibitor; diseases of the aortic or mitral valve; other medical reasons) or (eg; patient declined; other patient reasons) or (eg; lack of drug availability; other reasons attributable to the health care system)','Pt not eligible ace/arb','G8936','3','','1','0','','','','0','1','0','0'),
('12798','Clinician did not prescribe angiotensin converting enzyme (ace) inhibitor or angiotensin receptor blocker (arb) therapy; reason not given','No rx ace/arb therapy','G8937','3','','1','0','','','','0','1','0','0'),
('12799','Bmi is documented as being outside of normal limits; follow-up plan is not documented; documentation the patient is not eligible','Bmi calc; pt no f/u plan elg','G8938','3','','1','0','','','','0','1','0','0'),
('12800','Pain assessment documented as positive; follow-up plan not documented; documentation the patient is not eligible','Pain assess doc; f/u no doc','G8939','3','','1','0','','','','0','1','0','0'),
('12801','Screening for depression documented as positive; a follow-up plan not completed; documented reason','Scr dep pos; no plan done','G8940','3','','1','0','','','','0','1','0','0'),
('12802','Elder maltreatment screen documented as positive; follow-up plan not documented; documentation the patient is not eligible','No doc elder scrn; pt no el','G8941','3','','1','0','','','','0','1','0','0'),
('12803','Functional outcomes assessment using a standardized tool is documented within the previous 30 days and care plan; based on identified deficiencies on the date of the functional outcome assessment; is documented','Doc fcn/care plan w/30 days','G8942','3','','1','0','','','','0','1','0','0'),
('12804','Ldl-c result not present or not within 12 months prior','Ldlc not pres w/i 12 mo prir','G8943','3','','1','0','','','','0','1','0','0'),
('12805','Ajcc melanoma cancer stage 0 through iic melanoma','Ajcc mel cnr stg 0 - iic','G8944','3','','1','0','','','','0','1','0','0'),
('12806','Aneurysm minor diameter <= 6 cm for men','Aneurysm <=6 cm for men','G8945','3','','1','0','','','','0','1','0','0'),
('12807','Minimally invasive biopsy method attempted but not diagnostic of breast cancer (e.g.; high risk lesion of breast such as atypical ductal hyperplasia; lobular neoplasia; atypical lobular hyperplasia; lobular carcinoma in situ; atypical columnar hyperplasia; flat epithelial atypia; radial scar; complex sclerosing lesion; papillary lesion; or any lesion with spindle cells)','Mibm but no dx of breast ca','G8946','3','','1','0','','','','0','1','0','0'),
('12808','One or more neuropsychiatric symptoms','1 or more neuropsych','G8947','3','','1','0','','','','0','1','0','0'),
('12809','No neuropsychiatric symptoms','No neuropsych symptoms','G8948','3','','1','0','','','','0','1','0','0'),
('12810','Documentation of patient reason(s) for patient not receiving counseling for diet and physical activity (e.g.; patient is not willing to discuss diet or exercise interventions to help control blood pressure; or the patient said he/she refused to make these changes)','Doc pt reas on counsel diet','G8949','3','','1','0','','','','0','1','0','0'),
('12811','Pre-hypertensive or hypertensive blood pressure reading documented; and the indicated follow-up is documented','Pre-htn or htn doc; f/u indc','G8950','3','','1','0','','','','0','1','0','0'),
('12812','Pre-hypertensive or hypertensive blood pressure reading documented; indicated follow-up not documented; documentation the patient is not eligible','Pre-htn/htn doc; no pt f/u','G8951','3','','1','0','','','','0','1','0','0'),
('12813','Pre-hypertensive or hypertensive blood pressure reading documented; indicated follow-up not documented; reason not given','Pre-htn/htn; no f/u; not gvn','G8952','3','','1','0','','','','0','1','0','0'),
('12814','All quality actions for the applicable measures in the oncology measures group have been performed for this patient','Oncology mg qual act perform','G8953','3','','1','0','','','','0','1','0','0'),
('12815','Complete and appropriate patient data were reported to a qualified clinical database registry','Pt data rpt qual clin db reg','G8954','3','','1','0','','','','0','1','0','0'),
('12816','Most recent assessment of adequacy of volume management documented','Most recent assess vol mgmt','G8955','3','','1','0','','','','0','1','0','0'),
('12817','Patient receiving maintenance hemodialysis in an outpatient dialysis facility','Pt rcv hedia outpt dyls fac','G8956','3','','1','0','','','','0','1','0','0'),
('12818','Patient not receiving maintenance hemodialysis in an outpatient dialysis facility','Pt no hedia in outpt fac','G8957','3','','1','0','','','','0','1','0','0'),
('12819','Assessment of adequacy of volume management not documented; reason not given','Assess vol mgmt not doc','G8958','3','','1','0','','','','0','1','0','0'),
('12820','Clinician treating major depressive disorder communicates to clinician treating comorbid condition','Clin tx mdd comm to tx clin','G8959','3','','1','0','','','','0','1','0','0'),
('12821','Clinician treating major depressive disorder did not communicate to clinician treating comorbid condition; reason not given','Clin tx mdd not comm','G8960','3','','1','0','','','','0','1','0','0'),
('12822','Cardiac stress imaging test primarily performed on low-risk surgery patient for preoperative evaluation within 30 days preceding this surgery','Csit lowrisk surg pts preop','G8961','3','','1','0','','','','0','1','0','0'),
('12823','Cardiac stress imaging test performed on patient for any reason including those who did not have low risk surgery or test that was performed more than 30 days preceding low risk surgery','Csit on pt any reas 30 days','G8962','3','','1','0','','','','0','1','0','0'),
('12824','Cardiac stress imaging performed primarily for monitoring of asymptomatic patient who had pci within 2 years','Csi per asx pt w/pci 2 yrs','G8963','3','','1','0','','','','0','1','0','0'),
('12825','Cardiac stress imaging test performed primarily for any other reason than monitoring of asymptomatic patient who had pci within 2 years (e.g.; symptomatic patient; patient greater than 2 years since pci; initial evaluation; etc)','Csi any other than pci 2 yr','G8964','3','','1','0','','','','0','1','0','0'),
('12826','Cardiac stress imaging test primarily performed on low chd risk patient for initial detection and risk assessment','Csit perf on low chd rsk','G8965','3','','1','0','','','','0','1','0','0'),
('12827','Cardiac stress imaging test performed on symptomatic or higher than low chd risk patient or for any reason other than initial detection and risk assessment','Csit perf sx or high chd rsk','G8966','3','','1','0','','','','0','1','0','0'),
('12828','Warfarin or another oral anticoagulant that is fda approved prescribed','Wrfrn or oral antigoag pres','G8967','3','','1','0','','','','0','1','0','0'),
('12829','Documentation of medical reason(s) for not prescribing warfarin or another oral anticoagulant that is fda approved for the prevention of thromboembolism (e.g.; allergy; risk of bleeding; other medical reasons)','Doc rsn no warf/anticog pres','G8968','3','','1','0','','','','0','1','0','0'),
('12830','Documentation of patient reason(s) for not prescribing warfarin or another oral anticoagulant that is fda approved (e.g.; economic; social; and/or religious impediments; noncompliance patient refusal; other patient reasons)','Pt rsn no pres wrfrn or othr','G8969','3','','1','0','','','','0','1','0','0'),
('12831','No risk factors or one moderate risk factor for thromboembolism','No rsk fac or 1 mod risk te','G8970','3','','1','0','','','','0','1','0','0'),
('12832','Warfarin or another oral anticoagulant that is fda approved not prescribed; reason not given','Warfrn or othr antcog no rx','G8971','3','','1','0','','','','0','1','0','0'),
('12833','One or more high risk factors for thromboembolism or more than one moderate risk factor for thromboembolism','1>=risk or>= mod risk for te','G8972','3','','1','0','','','','0','1','0','0'),
('12834','Most recent hemoglobin (hgb) level < 10 g/dl','Mst rcnt hbb < 10g/dl','G8973','3','','1','0','','','','0','1','0','0'),
('12835','Hemoglobin level measurement not documented; reason not given','Hgb not doc rns not gvn','G8974','3','','1','0','','','','0','1','0','0'),
('12836','Documentation of medical reason(s) for patient having a hemoglobin level < 10 g/dl (e.g.; patients who have non-renal etiologies of anemia [e.g.; sickle cell anemia or other hemoglobinopathies; hypersplenism; primary bone marrow disease; anemia related to chemotherapy for diagnosis of malignancy; postoperative bleeding; active bloodstream or peritoneal infection]; other medical reasons)','Hgb <10g/dl; med rsn','G8975','3','','1','0','','','','0','1','0','0'),
('12837','Most recent hemoglobin (hgb) level >= 10 g/dl','Hgb >= 10 g/dl','G8976','3','','1','0','','','','0','1','0','0'),
('12838','I intend to report the oncology measures group','Oncology measures grp','G8977','3','','1','0','','','','0','1','0','0'),
('12839','Mobility: walking & moving around functional limitation; current status; at therapy episode outset and at reporting intervals','Mobility current status','G8978','3','','1','0','','','','0','1','0','0'),
('12840','Mobility: walking & moving around functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Mobility goal status','G8979','3','','1','0','','','','0','1','0','0'),
('12841','Mobility: walking & moving around functional limitation; discharge status; at discharge from therapy or to end reporting','Mobility d/c status','G8980','3','','1','0','','','','0','1','0','0'),
('12842','Changing & maintaining body position functional limitation; current status; at therapy episode outset and at reporting intervals','Body pos current status','G8981','3','','1','0','','','','0','1','0','0'),
('12843','Changing & maintaining body position functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Body pos goal status','G8982','3','','1','0','','','','0','1','0','0'),
('12844','Changing & maintaining body position functional limitation; discharge status; at discharge from therapy or to end reporting','Body pos d/c status','G8983','3','','1','0','','','','0','1','0','0'),
('12845','Carrying; moving & handling objects functional limitation; current status; at therapy episode outset and at reporting intervals','Carry current status','G8984','3','','1','0','','','','0','1','0','0'),
('12846','Carrying; moving and handling objects; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Carry goal status','G8985','3','','1','0','','','','0','1','0','0'),
('12847','Carrying; moving & handling objects functional limitation; discharge status; at discharge from therapy or to end reporting','Carry d/c status','G8986','3','','1','0','','','','0','1','0','0'),
('12848','Self care functional limitation; current status; at therapy episode outset and at reporting intervals','Self care current status','G8987','3','','1','0','','','','0','1','0','0'),
('12849','Self care functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Self care goal status','G8988','3','','1','0','','','','0','1','0','0'),
('12850','Self care functional limitation; discharge status; at discharge from therapy or to end reporting','Self care d/c status','G8989','3','','1','0','','','','0','1','0','0'),
('12851','Other physical or occupational therapy primary functional limitation; current status; at therapy episode outset and at reporting intervals','Other pt/ot current status','G8990','3','','1','0','','','','0','1','0','0'),
('12852','Other physical or occupational therapy primary functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Other pt/ot goal status','G8991','3','','1','0','','','','0','1','0','0'),
('12853','Other physical or occupational therapy primary functional limitation; discharge status; at discharge from therapy or to end reporting','Other pt/ot  d/c status','G8992','3','','1','0','','','','0','1','0','0'),
('12854','Other physical or occupational therapy subsequent functional limitation; current status; at therapy episode outset and at reporting intervals','Sub pt/ot current status','G8993','3','','1','0','','','','0','1','0','0'),
('12855','Other physical or occupational therapy subsequent functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Sub pt/ot goal status','G8994','3','','1','0','','','','0','1','0','0'),
('12856','Other physical or occupational therapy subsequent functional limitation; discharge status; at discharge from therapy or to end reporting','Sub pt/ot d/c status','G8995','3','','1','0','','','','0','1','0','0'),
('12857','Swallowing functional limitation; current status at therapy episode outset and at reporting intervals','Swallow current status','G8996','3','','1','0','','','','0','1','0','0'),
('12858','Swallowing functional limitation; projected goal status; at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Swallow goal status','G8997','3','','1','0','','','','0','1','0','0'),
('12859','Swallowing functional limitation; discharge status; at discharge from therapy or to end reporting','Swallow d/c status','G8998','3','','1','0','','','','0','1','0','0'),
('12860','Motor speech functional limitation; current status at therapy episode outset and at reporting intervals','Motor speech current status','G8999','3','','1','0','','','','0','1','0','0'),
('12861','Coordinated care fee; initial rate','Mccd; initial rate','G9001','3','','1','0','','','','0','1','0','0'),
('12862','Coordinated care fee; maintenance rate','Mccd;maintenance rate','G9002','3','','1','0','','','','0','1','0','0'),
('12863','Coordinated care fee; risk adjusted high; initial','Mccd; risk adj hi; initial','G9003','3','','1','0','','','','0','1','0','0'),
('12864','Coordinated care fee; risk adjusted low; initial','Mccd; risk adj lo; initial','G9004','3','','1','0','','','','0','1','0','0'),
('12865','Coordinated care fee; risk adjusted maintenance','Mccd; risk adj; maintenance','G9005','3','','1','0','','','','0','1','0','0'),
('12866','Coordinated care fee; home monitoring','Mccd; home monitoring','G9006','3','','1','0','','','','0','1','0','0'),
('12867','Coordinated care fee; scheduled team conference','Mccd; sch team conf','G9007','3','','1','0','','','','0','1','0','0'),
('12868','Coordinated care fee; physician coordinated care oversight services','Mccd;phys coor-care ovrsght','G9008','3','','1','0','','','','0','1','0','0'),
('12869','Coordinated care fee; risk adjusted maintenance; level 3','Mccd; risk adj; level 3','G9009','3','','1','0','','','','0','1','0','0'),
('12870','Coordinated care fee; risk adjusted maintenance; level 4','Mccd; risk adj; level 4','G9010','3','','1','0','','','','0','1','0','0'),
('12871','Coordinated care fee; risk adjusted maintenance; level 5','Mccd; risk adj; level 5','G9011','3','','1','0','','','','0','1','0','0'),
('12872','Other specified case management service not elsewhere classified','Other specified case mgmt','G9012','3','','1','0','','','','0','1','0','0'),
('12873','Esrd demo basic bundle level i','Esrd demo bundle level i','G9013','3','','1','0','','','','0','1','0','0'),
('12874','Esrd demo expanded bundle including venous access and related services','Esrd demo bundle-level ii','G9014','3','','1','0','','','','0','1','0','0'),
('12875','Smoking cessation counseling; individual; in the absence of or in addition to any other evaluation and management service; per session (6-10 minutes) [demo project code only]','Demo-smoking cessation coun','G9016','3','','1','0','','','','0','1','0','0'),
('12876','Amantadine hydrochloride; oral; per 100 mg (for use in a medicare-approved demonstration project)','Amantadine hcl 100mg oral','G9017','3','','1','0','','','','0','1','0','0'),
('12877','Zanamivir; inhalation powder; administered through inhaler; per 10 mg (for use in a medicare-approved demonstration project)','Zanamivir;inhalation pwd 10m','G9018','3','','1','0','','','','0','1','0','0'),
('12878','Oseltamivir phosphate; oral; per 75 mg (for use in a medicare-approved demonstration project)','Oseltamivir phosphate 75mg','G9019','3','','1','0','','','','0','1','0','0'),
('12879','Rimantadine hydrochloride; oral; per 100 mg (for use in a medicare-approved demonstration project)','Rimantadine hcl 100mg oral','G9020','3','','1','0','','','','0','1','0','0'),
('12880','Amantadine hydrochloride; oral brand; per 100 mg (for use in a medicare-approved demonstration project)','Amantadine hcl oral brand','G9033','3','','1','0','','','','0','1','0','0'),
('12881','Zanamivir; inhalation powder; administered through inhaler; brand; per 10 mg (for use in a medicare-approved demonstration project)','Zanamivir; inh pwdr; brand','G9034','3','','1','0','','','','0','1','0','0'),
('12882','Oseltamivir phosphate; oral; brand; per 75 mg (for use in a medicare-approved demonstration project)','Oseltamivir phosp; brand','G9035','3','','1','0','','','','0','1','0','0'),
('12883','Rimantadine hydrochloride; oral; brand; per 100 mg (for use in a medicare-approved demonstration project)','Rimantadine hcl; brand','G9036','3','','1','0','','','','0','1','0','0'),
('12884','Oncology; primary focus of visit; work-up; evaluation; or staging at the time of cancer diagnosis or recurrence (for use in a medicare-approved demonstration project)','Oncology work-up evaluation','G9050','3','','1','0','','','','0','1','0','0'),
('12885','Oncology; primary focus of visit; treatment decision-making after disease is staged or restaged; discussion of treatment options; supervising/coordinating active cancer directed therapy or managing consequences of cancer directed therapy (for use in a medicare-approved demonstration project)','Oncology tx decision-mgmt','G9051','3','','1','0','','','','0','1','0','0'),
('12886','Oncology; primary focus of visit; surveillance for disease recurrence for patient who has completed definitive cancer-directed therapy and currently lacks evidence of recurrent disease; cancer directed therapy might be considered in the future (for use in a medicare-approved demonstration project)','Onc surveillance for disease','G9052','3','','1','0','','','','0','1','0','0'),
('12887','Oncology; primary focus of visit; expectant management of patient with evidence of cancer for whom no cancer directed therapy is being administered or arranged at present; cancer directed therapy might be considered in the future (for use in a medicare-approved demonstration project)','Onc expectant management pt','G9053','3','','1','0','','','','0','1','0','0'),
('12888','Oncology; primary focus of visit; supervising; coordinating or managing care of patient with terminal cancer or for whom other medical illness prevents further cancer treatment; includes symptom management; end-of-life care planning; management of palliative therapies (for use in a medicare-approved demonstration project)','Onc supervision palliative','G9054','3','','1','0','','','','0','1','0','0'),
('12889','Oncology; primary focus of visit; other; unspecified service not otherwise listed (for use in a medicare-approved demonstration project)','Onc visit unspecified nos','G9055','3','','1','0','','','','0','1','0','0'),
('12890','Oncology; practice guidelines; management adheres to guidelines (for use in a medicare-approved demonstration project)','Onc prac mgmt adheres guide','G9056','3','','1','0','','','','0','1','0','0'),
('12891','Oncology; practice guidelines; management differs from guidelines as a result of patient enrollment in an institutional review board approved clinical trial (for use in a medicare-approved demonstration project)','Onc pract mgmt differs trial','G9057','3','','1','0','','','','0','1','0','0'),
('12892','Oncology; practice guidelines; management differs from guidelines because the treating physician disagrees with guideline recommendations (for use in a medicare-approved demonstration project)','Onc prac mgmt disagree w/gui','G9058','3','','1','0','','','','0','1','0','0'),
('12893','Oncology; practice guidelines; management differs from guidelines because the patient; after being offered treatment consistent with guidelines; has opted for alternative treatment or management; including no treatment (for use in a medicare-approved demonstration project)','Onc prac mgmt pt opt alterna','G9059','3','','1','0','','','','0','1','0','0'),
('12894','Oncology; practice guidelines; management differs from guidelines for reason(s) associated with patient comorbid illness or performance status not factored into guidelines (for use in a medicare-approved demonstration project)','Onc prac mgmt dif pt comorb','G9060','3','','1','0','','','','0','1','0','0'),
('12895','Oncology; practice guidelines; patients condition not addressed by available guidelines (for use in a medicare-approved demonstration project)','Onc prac cond noadd by guide','G9061','3','','1','0','','','','0','1','0','0'),
('12896','Oncology; practice guidelines; management differs from guidelines for other reason(s) not listed (for use in a medicare-approved demonstration project)','Onc prac guide differs nos','G9062','3','','1','0','','','','0','1','0','0'),
('12897','Oncology; disease status; limited to non-small cell lung cancer; extent of disease initially established as stage i (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx nsclc stgi no progres','G9063','3','','1','0','','','','0','1','0','0'),
('12898','Oncology; disease status; limited to non-small cell lung cancer; extent of disease initially established as stage ii (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx nsclc stg2 no progres','G9064','3','','1','0','','','','0','1','0','0'),
('12899','Oncology; disease status; limited to non-small cell lung cancer; extent of disease initially established as stage iii a (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx nsclc stg3a no progre','G9065','3','','1','0','','','','0','1','0','0'),
('12900','Oncology; disease status; limited to non-small cell lung cancer; stage iii b- iv at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx nsclc stg3b-4 metasta','G9066','3','','1','0','','','','0','1','0','0'),
('12901','Oncology; disease status; limited to non-small cell lung cancer; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx nsclc dx unknown nos','G9067','3','','1','0','','','','0','1','0','0'),
('12902','Oncology; disease status; limited to small cell and combined small cell/non-small cell; extent of disease initially established as limited with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx sclc/nsclc limited','G9068','3','','1','0','','','','0','1','0','0'),
('12903','Oncology; disease status; small cell lung cancer; limited to small cell and combined small cell/non-small cell; extensive stage at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx sclc/nsclc ext at dx','G9069','3','','1','0','','','','0','1','0','0'),
('12904','Oncology; disease status; small cell lung cancer; limited to small cell and combined small cell/non-small; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx sclc/nsclc ext unknwn','G9070','3','','1','0','','','','0','1','0','0'),
('12905','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; stage i or stage iia-iib; or t3; n1; m0; and er and/or pr positive; with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx brst stg1-2b hr;nopro','G9071','3','','1','0','','','','0','1','0','0'),
('12906','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; stage i; or stage iia-iib; or t3; n1; m0; and er and pr negative; with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx brst stg1-2 noprogres','G9072','3','','1','0','','','','0','1','0','0'),
('12907','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; stage iiia-iiib; and not t3; n1; m0; and er and/or pr positive; with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx brst stg3-hr; no pro','G9073','3','','1','0','','','','0','1','0','0'),
('12908','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; stage iiia-iiib; and not t3; n1; m0; and er and pr negative; with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx brst stg3-noprogress','G9074','3','','1','0','','','','0','1','0','0'),
('12909','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx brst metastic/ recur','G9075','3','','1','0','','','','0','1','0','0'),
('12910','Oncology; disease status; prostate cancer; limited to adenocarcinoma as predominant cell type; t1-t2c and gleason 2-7 and psa < or equal to 20 at diagnosis with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx prostate t1no progres','G9077','3','','1','0','','','','0','1','0','0'),
('12911','Oncology; disease status; prostate cancer; limited to adenocarcinoma as predominant cell type; t2 or t3a gleason 8-10 or psa > 20 at diagnosis with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx prostate t2no progres','G9078','3','','1','0','','','','0','1','0','0'),
('12912','Oncology; disease status; prostate cancer; limited to adenocarcinoma as predominant cell type; t3b-t4; any n; any t; n1 at diagnosis with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx prostate t3b-t4noprog','G9079','3','','1','0','','','','0','1','0','0'),
('12913','Oncology; disease status; prostate cancer; limited to adenocarcinoma; after initial treatment with rising psa or failure of psa decline (for use in a medicare-approved demonstration project)','Onc dx prostate w/rise psa','G9080','3','','1','0','','','','0','1','0','0'),
('12914','Oncology; disease status; prostate cancer; limited to adenocarcinoma; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx prostate unknwn nos','G9083','3','','1','0','','','','0','1','0','0'),
('12915','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t1-3; n0; m0 with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx colon t1-3;n1-2;no pr','G9084','3','','1','0','','','','0','1','0','0'),
('12916','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t4; n0; m0 with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx colon t4; n0 w/o prog','G9085','3','','1','0','','','','0','1','0','0'),
('12917','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t1-4; n1-2; m0 with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx colon t1-4 no dx prog','G9086','3','','1','0','','','','0','1','0','0'),
('12918','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive with current clinical; radiologic; or biochemical evidence of disease (for use in a medicare-approved demonstration project)','Onc dx colon metas evid dx','G9087','3','','1','0','','','','0','1','0','0'),
('12919','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive without current clinical; radiologic; or biochemical evidence of disease (for use in a medicare-approved demonstration project)','Onc dx colon metas noevid dx','G9088','3','','1','0','','','','0','1','0','0'),
('12920','Oncology; disease status; colon cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx colon extent unknown','G9089','3','','1','0','','','','0','1','0','0'),
('12921','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t1-2; n0; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx rectal t1-2 no progr','G9090','3','','1','0','','','','0','1','0','0'),
('12922','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t3; n0; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx rectal t3 n0 no prog','G9091','3','','1','0','','','','0','1','0','0'),
('12923','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t1-3; n1-2; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence or metastases (for use in a medicare-approved demonstration project)','Onc dx rectal t1-3;n1-2noprg','G9092','3','','1','0','','','','0','1','0','0'),
('12924','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease initially established as t4; any n; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx rectal t4;n;m0 no prg','G9093','3','','1','0','','','','0','1','0','0'),
('12925','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx rectal m1 w/mets prog','G9094','3','','1','0','','','','0','1','0','0'),
('12926','Oncology; disease status; rectal cancer; limited to invasive cancer; adenocarcinoma as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx rectal extent unknwn','G9095','3','','1','0','','','','0','1','0','0'),
('12927','Oncology; disease status; esophageal cancer; limited to adenocarcinoma or squamous cell carcinoma as predominant cell type; extent of disease initially established as t1-t3; n0-n1 or nx (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx esophag t1-t3 noprog','G9096','3','','1','0','','','','0','1','0','0'),
('12928','Oncology; disease status; esophageal cancer; limited to adenocarcinoma or squamous cell carcinoma as predominant cell type; extent of disease initially established as t4; any n; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx esophageal t4 no prog','G9097','3','','1','0','','','','0','1','0','0'),
('12929','Oncology; disease status; esophageal cancer; limited to adenocarcinoma or squamous cell carcinoma as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx esophageal mets recur','G9098','3','','1','0','','','','0','1','0','0'),
('12930','Oncology; disease status; esophageal cancer; limited to adenocarcinoma or squamous cell carcinoma as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx esophageal unknown','G9099','3','','1','0','','','','0','1','0','0'),
('12931','Oncology; disease status; gastric cancer; limited to adenocarcinoma as predominant cell type; post r0 resection (with or without neoadjuvant therapy) with no evidence of disease recurrence; progression; or metastases (for use in a medicare-approved demonstration project)','Onc dx gastric no recurrence','G9100','3','','1','0','','','','0','1','0','0'),
('12932','Oncology; disease status; gastric cancer; limited to adenocarcinoma as predominant cell type; post r1 or r2 resection (with or without neoadjuvant therapy) with no evidence of disease progression; or metastases (for use in a medicare-approved demonstration project)','Onc dx gastric p r1-r2noprog','G9101','3','','1','0','','','','0','1','0','0'),
('12933','Oncology; disease status; gastric cancer; limited to adenocarcinoma as predominant cell type; clinical or pathologic m0; unresectable with no evidence of disease progression; or metastases (for use in a medicare-approved demonstration project)','Onc dx gastric unresectable','G9102','3','','1','0','','','','0','1','0','0'),
('12934','Oncology; disease status; gastric cancer; limited to adenocarcinoma as predominant cell type; clinical or pathologic m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx gastric recurrent','G9103','3','','1','0','','','','0','1','0','0'),
('12935','Oncology; disease status; gastric cancer; limited to adenocarcinoma as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx gastric unknown nos','G9104','3','','1','0','','','','0','1','0','0'),
('12936','Oncology; disease status; pancreatic cancer; limited to adenocarcinoma as predominant cell type; post r0 resection without evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx pancreatc p r0 res no','G9105','3','','1','0','','','','0','1','0','0'),
('12937','Oncology; disease status; pancreatic cancer; limited to adenocarcinoma; post r1 or r2 resection with no evidence of disease progression; or metastases (for use in a medicare-approved demonstration project)','Onc dx pancreatc p r1/r2 no','G9106','3','','1','0','','','','0','1','0','0'),
('12938','Oncology; disease status; pancreatic cancer; limited to adenocarcinoma; unresectable at diagnosis; m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx pancreatic unresectab','G9107','3','','1','0','','','','0','1','0','0'),
('12939','Oncology; disease status; pancreatic cancer; limited to adenocarcinoma; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx pancreatic unknwn nos','G9108','3','','1','0','','','','0','1','0','0'),
('12940','Oncology; disease status; head and neck cancer; limited to cancers of oral cavity; pharynx and larynx with squamous cell as predominant cell type; extent of disease initially established as t1-t2 and n0; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx head/neck t1-t2no prg','G9109','3','','1','0','','','','0','1','0','0'),
('12941','Oncology; disease status; head and neck cancer; limited to cancers of oral cavity; pharynx and larynx with squamous cell as predominant cell type; extent of disease initially established as t3-4 and/or n1-3; m0 (prior to neo-adjuvant therapy; if any) with no evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx head/neck t3-4 noprog','G9110','3','','1','0','','','','0','1','0','0'),
('12942','Oncology; disease status; head and neck cancer; limited to cancers of oral cavity; pharynx and larynx with squamous cell as predominant cell type; m1 at diagnosis; metastatic; locally recurrent; or progressive (for use in a medicare-approved demonstration project)','Onc dx head/neck m1 mets rec','G9111','3','','1','0','','','','0','1','0','0'),
('12943','Oncology; disease status; head and neck cancer; limited to cancers of oral cavity; pharynx and larynx with squamous cell as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx head/neck ext unknown','G9112','3','','1','0','','','','0','1','0','0'),
('12944','Oncology; disease status; ovarian cancer; limited to epithelial cancer; pathologic stage ia-b (grade 1) without evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx ovarian stg1a-b no pr','G9113','3','','1','0','','','','0','1','0','0'),
('12945','Oncology; disease status; ovarian cancer; limited to epithelial cancer; pathologic stage ia-b (grade 2-3); or stage ic (all grades); or stage ii; without evidence of disease progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx ovarian stg1a-b or 2','G9114','3','','1','0','','','','0','1','0','0'),
('12946','Oncology; disease status; ovarian cancer; limited to epithelial cancer; pathologic stage iii-iv; without evidence of progression; recurrence; or metastases (for use in a medicare-approved demonstration project)','Onc dx ovarian stg3/4 noprog','G9115','3','','1','0','','','','0','1','0','0'),
('12947','Oncology; disease status; ovarian cancer; limited to epithelial cancer; evidence of disease progression; or recurrence; and/or platinum resistance (for use in a medicare-approved demonstration project)','Onc dx ovarian recurrence','G9116','3','','1','0','','','','0','1','0','0'),
('12948','Oncology; disease status; ovarian cancer; limited to epithelial cancer; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx ovarian unknown nos','G9117','3','','1','0','','','','0','1','0','0'),
('12949','Oncology; disease status; chronic myelogenous leukemia; limited to philadelphia chromosome positive and/or bcr-abl positive; chronic phase not in hematologic; cytogenetic; or molecular remission (for use in a medicare-approved demonstration project)','Onc dx cml chronic phase','G9123','3','','1','0','','','','0','1','0','0'),
('12950','Oncology; disease status; chronic myelogenous leukemia; limited to philadelphia chromosome positive and/or bcr-abl positive; accelerated phase not in hematologic cytogenetic; or molecular remission (for use in a medicare-approved demonstration project)','Onc dx cml acceler phase','G9124','3','','1','0','','','','0','1','0','0'),
('12951','Oncology; disease status; chronic myelogenous leukemia; limited to philadelphia chromosome positive and/or bcr-abl positive; blast phase not in hematologic; cytogenetic; or molecular remission (for use in a medicare-approved demonstration project)','Onc dx cml blast phase','G9125','3','','1','0','','','','0','1','0','0'),
('12952','Oncology; disease status; chronic myelogenous leukemia; limited to philadelphia chromosome positive and/or bcr-abl positive; in hematologic; cytogenetic; or molecular remission (for use in a medicare-approved demonstration project)','Onc dx cml remission','G9126','3','','1','0','','','','0','1','0','0'),
('12953','Oncology; disease status; limited to multiple myeloma; systemic disease; smoldering; stage i (for use in a medicare-approved demonstration project)','Onc dx multi myeloma stage i','G9128','3','','1','0','','','','0','1','0','0'),
('12954','Oncology; disease status; limited to multiple myeloma; systemic disease; stage ii or higher (for use in a medicare-approved demonstration project)','Onc dx mult myeloma stg2 hig','G9129','3','','1','0','','','','0','1','0','0'),
('12955','Oncology; disease status; limited to multiple myeloma; systemic disease; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx multi myeloma unknown','G9130','3','','1','0','','','','0','1','0','0'),
('12956','Oncology; disease status; invasive female breast cancer (does not include ductal carcinoma in situ); adenocarcinoma as predominant cell type; extent of disease unknown; staging in progress; or not listed (for use in a medicare-approved demonstration project)','Onc dx brst unknown nos','G9131','3','','1','0','','','','0','1','0','0'),
('12957','Oncology; disease status; prostate cancer; limited to adenocarcinoma; hormone-refractory/androgen-independent (e.g.; rising psa on anti-androgen therapy or post-orchiectomy); clinical metastases (for use in a medicare-approved demonstration project)','Onc dx prostate mets no cast','G9132','3','','1','0','','','','0','1','0','0'),
('12958','Oncology; disease status; prostate cancer; limited to adenocarcinoma; hormone-responsive; clinical metastases or m1 at diagnosis (for use in a medicare-approved demonstration project)','Onc dx prostate clinical met','G9133','3','','1','0','','','','0','1','0','0'),
('12959','Oncology; disease status; non-hodgkins lymphoma; any cellular classification; stage i; ii at diagnosis; not relapsed; not refractory (for use in a medicare-approved demonstration project)','Onc nhlstg 1-2 no relap no','G9134','3','','1','0','','','','0','1','0','0'),
('12960','Oncology; disease status; non-hodgkins lymphoma; any cellular classification; stage iii; iv; not relapsed; not refractory (for use in a medicare-approved demonstration project)','Onc dx nhl stg 3-4 not relap','G9135','3','','1','0','','','','0','1','0','0'),
('12961','Oncology; disease status; non-hodgkins lymphoma; transformed from original cellular diagnosis to a second cellular classification (for use in a medicare-approved demonstration project)','Onc dx nhl trans to lg bcell','G9136','3','','1','0','','','','0','1','0','0'),
('12962','Oncology; disease status; non-hodgkins lymphoma; any cellular classification; relapsed/refractory (for use in a medicare-approved demonstration project)','Onc dx nhl relapse/refractor','G9137','3','','1','0','','','','0','1','0','0'),
('12963','Oncology; disease status; non-hodgkins lymphoma; any cellular classification; diagnostic evaluation; stage not determined; evaluation of possible relapse or non-response to therapy; or not listed (for use in a medicare-approved demonstration project)','Onc dx nhl stg unknown','G9138','3','','1','0','','','','0','1','0','0'),
('12964','Oncology; disease status; chronic myelogenous leukemia; limited to philadelphia chromosome positive and/or bcr-abl positive; extent of disease unknown; staging in progress; not listed (for use in a medicare-approved demonstration project)','Onc dx cml dx status unknown','G9139','3','','1','0','','','','0','1','0','0'),
('12965','Frontier extended stay clinic demonstration; for a patient stay in a clinic approved for the cms demonstration project; the following measures should be present: the stay must be equal to or greater than 4 hours; weather or other conditions must prevent transfer or the case falls into a category of monitoring and observation cases that are permitted by the rules of the demonstration; there is a maximum frontier extended stay clinic (fesc) visit of 48 hours; except in the case when weather or other conditions prevent transfer; payment is made on each period up to 4 hours; after the first 4 hours','Frontier extended stay demo','G9140','3','','1','0','','','','0','1','0','0'),
('12966','Warfarin responsiveness testing by genetic technique using any method; any number of specimen(s)','Warfarin respon genetic test','G9143','3','','1','0','','','','0','1','0','0'),
('12967','Outpatient intravenous insulin treatment (oivit) either pulsatile or continuous; by any means; guided by the results of measurements for: respiratory quotient; and/or; urine urea nitrogen (uun); and/or; arterial; venous or capillary glucose; and/or potassium concentration','Outpt iv insulin tx any mea','G9147','3','','1','0','','','','0','1','0','0'),
('12968','National committee for quality assurance - level 1 medical home','Medical home level 1','G9148','3','','1','0','','','','0','1','0','0'),
('12969','National committee for quality assurance - level 2 medical home','Medical home level ii','G9149','3','','1','0','','','','0','1','0','0'),
('12970','National committee for quality assurance - level 3 medical home','Medical home level iii','G9150','3','','1','0','','','','0','1','0','0'),
('12971','Mapcp demonstration - state provided services','Mapcp demo state','G9151','3','','1','0','','','','0','1','0','0'),
('12972','Mapcp demonstration - community health teams','Mapcp demo community','G9152','3','','1','0','','','','0','1','0','0'),
('12973','Mapcp demonstration - physician incentive pool','Mapcp demo physician','G9153','3','','1','0','','','','0','1','0','0'),
('12974','Evaluation for wheelchair requiring face to face visit with physician','Evaluation for wheelchair','G9156','3','','1','0','','','','0','1','0','0'),
('12975','Transesophageal doppler measurement of cardiac output (including probe placement; image acquisition; and interpretation per course of treatment) for monitoring purposes','Transesoph doppl cardiac mon','G9157','3','','1','0','','','','0','1','0','0'),
('12976','Motor speech functional limitation; discharge status; at discharge from therapy or to end reporting','Motor speech d/c status','G9158','3','','1','0','','','','0','1','0','0'),
('12977','Spoken language comprehension functional limitation; current status at therapy episode outset and at reporting intervals','Lang comp current status','G9159','3','','1','0','','','','0','1','0','0'),
('12978','Spoken language comprehension functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Lang comp goal status','G9160','3','','1','0','','','','0','1','0','0'),
('12979','Spoken language comprehension functional limitation; discharge status; at discharge from therapy or to end reporting','Lang comp d/c status','G9161','3','','1','0','','','','0','1','0','0'),
('12980','Spoken language expression functional limitation; current status at therapy episode outset and at reporting intervals','Lang express current status','G9162','3','','1','0','','','','0','1','0','0'),
('12981','Spoken language expression functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Lang express goal status','G9163','3','','1','0','','','','0','1','0','0'),
('12982','Spoken language expression functional limitation; discharge status at discharge from therapy or to end reporting','Lang express d/c status','G9164','3','','1','0','','','','0','1','0','0'),
('12983','Attention functional limitation; current status at therapy episode outset and at reporting intervals','Atten current status','G9165','3','','1','0','','','','0','1','0','0'),
('12984','Attention functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Atten goal status','G9166','3','','1','0','','','','0','1','0','0'),
('12985','Attention functional limitation; discharge status at discharge from therapy or to end reporting','Atten d/c status','G9167','3','','1','0','','','','0','1','0','0'),
('12986','Memory functional limitation; current status at therapy episode outset and at reporting intervals','Memory current status','G9168','3','','1','0','','','','0','1','0','0'),
('12987','Memory functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Memory goal status','G9169','3','','1','0','','','','0','1','0','0'),
('12988','Memory functional limitation; discharge status at discharge from therapy or to end reporting','Memory d/c status','G9170','3','','1','0','','','','0','1','0','0'),
('12989','Voice functional limitation; current status at therapy episode outset and at reporting intervals','Voice current status','G9171','3','','1','0','','','','0','1','0','0'),
('12990','Voice functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Voice goal status','G9172','3','','1','0','','','','0','1','0','0'),
('12991','Voice functional limitation; discharge status at discharge from therapy or to end reporting','Voice d/c status','G9173','3','','1','0','','','','0','1','0','0'),
('12992','Other speech language pathology functional limitation; current status at therapy episode outset and at reporting intervals','Speech lang current status','G9174','3','','1','0','','','','0','1','0','0'),
('12993','Other speech language pathology functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Speech lang goal status','G9175','3','','1','0','','','','0','1','0','0'),
('12994','Other speech language pathology functional limitation; discharge status at discharge from therapy or to end reporting','Speech lang d/c status','G9176','3','','1','0','','','','0','1','0','0'),
('12995','Motor speech functional limitation; projected goal status at therapy episode outset; at reporting intervals; and at discharge or to end reporting','Motor speech goal status','G9186','3','','1','0','','','','0','1','0','0'),
('12996','Bundled payments for care improvement initiative home visit for patient assessment performed by a qualified health care professional for individuals not considered homebound including; but not limited to; assessment of safety; falls; clinical status; fluid status; medication reconciliation/management; patient compliance with orders/plan of care; performance of activities of daily living; appropriateness of care setting; (for use only in the meidcare-approved bundled payments for care improvement initiative); may not be billed for a 30-day period covered by a transitional care management code','Bpci home visit','G9187','3','','1','0','','','','0','1','0','0'),
('12997','Beta-blocker therapy not prescribed; reason not given','Beta not given no reason','G9188','3','','1','0','','','','0','1','0','0'),
('12998','Beta-blocker therapy prescribed or currently being taken','Beta pres or already taking','G9189','3','','1','0','','','','0','1','0','0'),
('12999','Documentation of medical reason(s) for not prescribing beta-blocker therapy (eg; allergy; intolerance; other medical reasons)','Medical reason for no beta','G9190','3','','1','0','','','','0','1','0','0'),
('13000','Documentation of patient reason(s) for not prescribing beta-blocker therapy (eg; patient declined; other patient reasons)','Pt reason for no beta','G9191','3','','1','0','','','','0','1','0','0'),
('13001','Documentation of system reason(s) for not prescribing beta-blocker therapy (eg; other reasons attributable to the health care system)','System reason for no beta','G9192','3','','1','0','','','','0','1','0','0'),
('13002','Clinician documented that patient with a diagnosis of major depression was not an eligible candidate for antidepressant medication treatment or patient did not have a diagnosis of major depression','Doc not eligible for dep med','G9193','3','','1','0','','','','0','1','0','0'),
('13003','Patient with a diagnosis of major depression documented as being treated with antidepressant medication during the entire 180 day (6 month) continuation treatment phase','Mdd pt treated for 180d','G9194','3','','1','0','','','','0','1','0','0'),
('13004','Patient with a diagnosis of major depression not documented as being treated with antidepressant medication during the entire 180 day (6 months) continuation treatment phase','Mdd pt not treated for 180d','G9195','3','','1','0','','','','0','1','0','0'),
('13005','Documentation of medical reason(s) for not ordering a first or second generation cephalosporin for antimicrobial prophylaxis (e.g.; patients enrolled in clinical trials; patients with documented infection prior to surgical procedure of interest; patients who were receiving antibiotics more than 24 hours prior to surgery [except colon surgery patients taking oral prophylactic antibiotics]; patients who were receiving antibiotics within 24 hours prior to arrival [except colon surgery patients taking oral prophylactic antibiotics]; other medical reason(s))','Med reason for no ceph','G9196','3','','1','0','','','','0','1','0','0'),
('13006','Documentation of order for first or second generation cephalosporin for antimicrobial prophylaxis','Order for ceph','G9197','3','','1','0','','','','0','1','0','0'),
('13007','Order for first or second generation cephalosporin for antimicrobial prophylaxis was not documented; reason not given','No order for ceph no reason','G9198','3','','1','0','','','','0','1','0','0'),
('13008','Venous thromboembolism (vte) prophylaxis not administered the day of or the day after hospital admission for documented reasons (eg; patient is ambulatory; patient expired during inpatient stay; patient already on warfarin or another anticoagulant; other medical reason(s) or eg; patient left against medical advice; other patient reason(s))','Doc reason for no vte','G9199','3','','1','0','','','','0','1','0','0'),
('13009','Venous thromboembolism (vte) prophylaxis was not administered the day of or the day after hospital admission; reason not given','No reason for no vte','G9200','3','','1','0','','','','0','1','0','0'),
('13010','Venous thromboembolism (vte) prophylaxis administered the day of or the day after hospital admission','Vte given upon admission','G9201','3','','1','0','','','','0','1','0','0'),
('13011','Patients with a positive hepatitis c antibody test','Hep c aby pos','G9202','3','','1','0','','','','0','1','0','0'),
('13012','Rna testing for hepatitis c documented as performed within 12 months prior to initiation of antiviral treatment for hepatitis c','Hep c rna done prior to med','G9203','3','','1','0','','','','0','1','0','0'),
('13013','Rna testing for hepatitis c was not documented as performed within 12 months prior to initiation of antiviral treatment for hepatitis c; reason not given','No reason for no hep c rna','G9204','3','','1','0','','','','0','1','0','0'),
('13014','Patient starting antiviral treatmentfor hepatitis c during the measurement period','Hep c antiviral started','G9205','3','','1','0','','','','0','1','0','0'),
('13015','Patient starting antiviral treatment for hepatitis c during the measurement period','Hep c therapy started','G9206','3','','1','0','','','','0','1','0','0'),
('13016','Hepatitis c genotype testing documented as performed within 12 months prior to initiation of antiviral treatment for hepatitis c','Hep c genotype prior to med','G9207','3','','1','0','','','','0','1','0','0'),
('13017','Hepatitis c genotype testing was not documented as performed within 12 months prior to initiation of antiviral treatment for hepatitis c; reason not given','No reason for no hep c geno','G9208','3','','1','0','','','','0','1','0','0'),
('13018','Hepatitis c quantitative rna testing documented as performed between 4-12 weeks after the initiation of antiviral treatment','Hep c rna 4to12 wk after med','G9209','3','','1','0','','','','0','1','0','0'),
('13019','Hepatitis c quantitative rna testing not performed between 4-12 weeks after the initiation of antiviral treatment for documented reason(s) (e.g.; patients whose treatment was discontinued during the testing period prior to testing; other medical reasons; patient declined; other patient reasons)','No hepc rna after med docrsn','G9210','3','','1','0','','','','0','1','0','0'),
('13020','Hepatitis c quantitative rna testing was not documented as performed between 4-12 weeks after the initiation of antiviral treatment; reason not given','No hepc rna after med no rsn','G9211','3','','1','0','','','','0','1','0','0'),
('13021','Dsm-ivtm criteria for major depressive disorder documented at the initial evaluation','Doc of dsm-iv init eval','G9212','3','','1','0','','','','0','1','0','0'),
('13022','Dsm-iv-tr criteria for major depressive disorder not documented at the initial evaluation; reason not otherwise specified','No doc of dsm-iv','G9213','3','','1','0','','','','0','1','0','0'),
('13023','Cd4+ cell count or cd4+ cell percentage results documented','Cd4 count documented','G9214','3','','1','0','','','','0','1','0','0'),
('13024','Cd4+ cell count or percentage not documented as performed; reason not given','No cd4 count no reason','G9215','3','','1','0','','','','0','1','0','0'),
('13025','Pcp prophylaxis was not prescribed at time of diagnosis of hiv; reason not given','No pcp proph at dx no reason','G9216','3','','1','0','','','','0','1','0','0'),
('13026','Pcp prophylaxis was not prescribed within 3 months of low cd4+ cell count below 200 cells/mm3; reason not given','No pcp proph low cd4 norsn','G9217','3','','1','0','','','','0','1','0','0'),
('13027','Pcp prophylaxis was not prescribed within 3 months oflow cd4+ cell count below 500 cells/mm3 or a cd4 percentage below 15%; reason not given','No pcp prop low at cd4 norsn','G9218','3','','1','0','','','','0','1','0','0'),
('13028','Pneumocystis jiroveci pneumonia prophylaxis not prescribed within 3 months of low cd4+ cell count below 200 cells/mm3 for medical reason (i.e.; patients cd4+ cell count above threshold within 3 months after cd4+ cell count below threshold; indicating that the patients cd4+ levels are within an acceptable range and the patient does not require pcp prophylaxis)','No oder pjp for med reason','G9219','3','','1','0','','','','0','1','0','0'),
('13029','Pneumocystis jiroveci pneumonia prophylaxis not prescribed within 3 months of low cd4+ cell count below 500 cells/mm3 or a cd4 percentage below 15% for medical reason (i.e.; patients cd4+ cell count above threshold within 3 months after cd4+ cell count below threshold; indicating that the patients cd4+ levels are within an acceptable range and the patient does not require pcp prophylaxis)','No order for pjp for medrsn','G9220','3','','1','0','','','','0','1','0','0'),
('13030','Pneumocystis jiroveci pneumonia prophlaxis prescribed','Pjp proph prescribed','G9221','3','','1','0','','','','0','1','0','0'),
('13031','Pneumocystis jiroveci pneumonia prophylaxis prescribed wthin 3 months of low cd4+ cell count below 200 cells/mm3','Pjp proph ordered low cd4','G9222','3','','1','0','','','','0','1','0','0'),
('13032','Pneumocystis jiroveci pneumonia prophylaxis prescribed within 3 months of low cd4+ cell count below 500 cells/mm3 or a cd4 percentage below 15%','Pjp proph ordered cd4 low','G9223','3','','1','0','','','','0','1','0','0'),
('13033','Documentation of medical reason for not performing foot exam (e.g.; patient with bilateral foot/leg amputation)','Medrsn no foot exam','G9224','3','','1','0','','','','0','1','0','0'),
('13034','Foot exam was not performed; reason not given','Norsn no foot exam','G9225','3','','1','0','','','','0','1','0','0'),
('13035','Foot examination performed (includes examination through visual inspection; sensory exam with 10-g monofilament plus testing any one of the following: vibration using 128-hz tuning fork; pinprick sensation; ankle reflexes; or vibration perception threshold; and pulse exam;  report when all of the 3 components are completed)','3 comp foot exam completed','G9226','3','','1','0','','','','0','1','0','0'),
('13036','Functional outcome assessment documented; care plan not documented; documentation the patient is not eligible for a care plan','Docrsn no care plan','G9227','3','','1','0','','','','0','1','0','0'),
('13037','Chlamydia; gonorrhea and syphilis screening results documented (report when results are present for all of the 3 screenings)','Gc chl syp documented','G9228','3','','1','0','','','','0','1','0','0'),
('13038','Chlamydia; gonorrhea; and syphilis screening results not documented (patient refusal is the only allowed exception)','Ptrsn no gc chl syp test','G9229','3','','1','0','','','','0','1','0','0'),
('13039','Chlamydia; gonorrhea; and syphilis not screened; reason not given','Norsn for gc chl syp test','G9230','3','','1','0','','','','0','1','0','0'),
('13040','Documentation of end stage renal disease (esrd); dialysis; renal transplant before or during the measurement period or pregnancy during the measurement period','Doc esrd dia trans preg','G9231','3','','1','0','','','','0','1','0','0'),
('13041','Clinician treating major depressive disorder did not communicate to clinician treating comorbid condition for specified patient reason (e.g.; patient is unable to communicate the diagnosis of a comorbid condition; the patient is unwilling to communicate the diagnosis of a comorbid condition; or the patient is unaware of the comorbid condition; or any other specified patient reason)','Ptrsn no comm comorbid','G9232','3','','1','0','','','','0','1','0','0'),
('13042','All quality actions for the applicable measures in the total knee replacement measures group have been performed for this patient','Tkr composite','G9233','3','','1','0','','','','0','1','0','0'),
('13043','I intend to report the total knee replacement measures group','Tkr intent','G9234','3','','1','0','','','','0','1','0','0'),
('13044','All quality actions for the applicable measures in the general surgery measures group have been performed for this patient','Gs mg composite','G9235','3','','1','0','','','','0','1','0','0'),
('13045','All quality actions for the applicable measures in the optimizing patient exposure to ionizing radiation measures group have been performed for this patient','Op rad mg composite','G9236','3','','1','0','','','','0','1','0','0'),
('13046','I intend to report the general surgery measures group','Gs mg intent','G9237','3','','1','0','','','','0','1','0','0'),
('13047','I intend to report the optimizing patient exposure to ionizing radiation measures group','Op rad mg intent','G9238','3','','1','0','','','','0','1','0','0'),
('13048','Documentation of reasons for patient initiaiting maintenance hemodialysis with a catheter as the mode of vascular access (e.g.; patient has a maturing avf/avg; time-limited trial of hemodialysis; other medical reasons; patient declined avf/avg; other patient reasons; patient followed by reporting nephrologist for fewer than 90 days; other system reasons)','Doc rsn hemod & cath acc','G9239','3','','1','0','','','','0','1','0','0'),
('13049','Patient whose mode of vascular access is a catheter at the time maintenance hemodialysis is initiated','Doc pt w cath maint dia','G9240','3','','1','0','','','','0','1','0','0'),
('13050','Patient whose mode of vascular access is not a catheter at the time maintenance hemodialysis is initiated','Doc pt w out cath maint dia','G9241','3','','1','0','','','','0','1','0','0'),
('13051','Documentation of viral load equal to or greater than 200 copies/ml or viral load not performed','Doc viral load >=200','G9242','3','','1','0','','','','0','1','0','0'),
('13052','Documentation of viral load less than 200 copies/ml','Doc viral load <200','G9243','3','','1','0','','','','0','1','0','0'),
('13053','Antiretroviral thereapy not prescribed','Antiviral not ordered','G9244','3','','1','0','','','','0','1','0','0'),
('13054','Antiretroviral therapy prescribed','Antiviral ordered','G9245','3','','1','0','','','','0','1','0','0'),
('13055','Patient did not have at least one medical visit in each 6 month period of the 24 month measurement period; with a minimum of 60 days between medical visits','No med visit in 24mo','G9246','3','','1','0','','','','0','1','0','0'),
('13056','Patient had at least one medical visit in each 6 month period of the 24 month measurement period; with a minimum of 60 days between medical visits','1 med visit in 24mo','G9247','3','','1','0','','','','0','1','0','0'),
('13057','Patient did not have a medical visit in the last 6 months','No med visit 6mo','G9248','3','','1','0','','','','0','1','0','0'),
('13058','Patient had a medical visit in the last 6 months','Med visit w in 6mo','G9249','3','','1','0','','','','0','1','0','0'),
('13059','Documentation of patient pain brought to a comfortable level within 48 hours from initial assessment','Doc of pain comfort 48hr','G9250','3','','1','0','','','','0','1','0','0'),
('13060','Documentation of patient with pain not brought to a comfortable level within 48 hours from initial assessment','Doc no pain comfort 48hr','G9251','3','','1','0','','','','0','1','0','0'),
('13061','Adenoma(s) or other neoplasm detected during screening colonoscopy','Neo detect scrn colo','G9252','3','','1','0','','','','0','1','0','0'),
('13062','Adenoma(s) or other neoplasm not detected during screening colonoscopy','No neo detect scrn colo','G9253','3','','1','0','','','','0','1','0','0'),
('13063','Documentation of patient discharged to home later than post-operative day 2 following cas','Doc pt dischg >2d','G9254','3','','1','0','','','','0','1','0','0'),
('13064','Documentation of patient discharged to home no later than post operative day 2 following cas','Doc pt dischg <=2d','G9255','3','','1','0','','','','0','1','0','0'),
('13065','Documentation of patient death following cas','Doc death after cas','G9256','3','','1','0','','','','0','1','0','0'),
('13066','Documentation of patient stroke following cas','Doc stroke after cas','G9257','3','','1','0','','','','0','1','0','0'),
('13067','Documentation of patient stroke following cea','Doc stroke after cea','G9258','3','','1','0','','','','0','1','0','0'),
('13068','Documentation of patient survival and absence of stroke following cas','Doc surv no stroke after cas','G9259','3','','1','0','','','','0','1','0','0'),
('13069','Documentation of patient death following cea','Doc death after cea','G9260','3','','1','0','','','','0','1','0','0'),
('13070','Documentation of patient survival and absence of stroke following cea','Doc surv no stroke after cea','G9261','3','','1','0','','','','0','1','0','0'),
('13071','Documentation of patient death in the hospital following endovascular aaa repair','Doc death in hosp aaa repair','G9262','3','','1','0','','','','0','1','0','0'),
('13072','Documentation of patient survival in the hospital following endovascular aaa repair','Doc surv in hosp aaa repair','G9263','3','','1','0','','','','0','1','0','0'),
('13073','Documentation of patient receiving maintenance hemodialysis for greater than or equal to 90 days with a catheter for documented reasons (e.g.; other medical reasons; patient declined avf/avg; other patient reasons)','Doc rsn hemod w/cath >=90d','G9264','3','','1','0','','','','0','1','0','0'),
('13074','Patient receiving maintenance hemodialysis for greater than or equal to 90 days with a catheter as the mode of vascular access','Doc cath >90d for maint dia','G9265','3','','1','0','','','','0','1','0','0'),
('13075','Patient receiving maintenance hemodialysis for greater than or equal to 90 days without a catheter as the mode of vascular access','Norsn pt cath >=90d','G9266','3','','1','0','','','','0','1','0','0'),
('13076','Documentation of patient with one or more complications or mortality within 30 days','Doc comp or mort w in 30d','G9267','3','','1','0','','','','0','1','0','0'),
('13077','Documentation of patient with one or more complications within 90 days','Doc comp or mort w in 90d','G9268','3','','1','0','','','','0','1','0','0'),
('13078','Documentation of patient without one or more complications and without mortality within 30 days','Doc no comp or mort w in 30d','G9269','3','','1','0','','','','0','1','0','0'),
('13079','Documentation of patient without one or more complications within 90 days','Doc no comp or mort w in 90d','G9270','3','','1','0','','','','0','1','0','0'),
('13080','Ldl value < 100','Ldl under 100','G9271','3','','1','0','','','','0','1','0','0'),
('13081','Ldl value >= 100','Ldl 100 and over','G9272','3','','1','0','','','','0','1','0','0'),
('13082','Blood pressure has a systolic value of < 140 and a diastolic value of < 90','Sys<140 and dia<90','G9273','3','','1','0','','','','0','1','0','0'),
('13083','Blood pressure has a systolic value of =140 and a diastolic value of = 90 or systolic value < 140 and diastolic value = 90 or systolic value = 140 and diastolic value < 90','Bp out of nrml limits','G9274','3','','1','0','','','','0','1','0','0'),
('13084','Documentation that patient is a current non-tobacco user','Doc of non tobacco user','G9275','3','','1','0','','','','0','1','0','0'),
('13085','Documentation that patient is a current tobacco user','Doc of tobacco user','G9276','3','','1','0','','','','0','1','0','0'),
('13086','Documentation that the patient is on daily aspirin or anti-platelet or has documentation of a valid contraindication or exception to aspirin/anti-platelet; contraindications/exceptions include anti-coagulant use; allergy to aspirin or anti-platelets; history of gastrointestinal bleed and bleeding disorder; additionally; the following exceptions documented by the physician as a reason for not taking daily aspirin or anti-platelet are acceptable (use of non-steroidal anti-inflammatory agents; documented risk for drug interaction; uncontrolled hypertension defined as >180 systolic or >110 diastolic or gastroesophageal reflux)','Doc daily aspirin or contra','G9277','3','','1','0','','','','0','1','0','0'),
('13087','Documentation that the patient is not on daily aspirin or anti-platelet regimen','Doc no daily aspirin','G9278','3','','1','0','','','','0','1','0','0'),
('13088','Pneumococcal screening performed and documentation of vaccination received prior to discharge','Pne scrn done doc vac done','G9279','3','','1','0','','','','0','1','0','0'),
('13089','Pneumococcal vaccination not administered prior to discharge; reason not specified','Pne not given norsn','G9280','3','','1','0','','','','0','1','0','0'),
('13090','Screening performed and documentation that vaccination not indicated/patient refusal','Pne scrn done doc not ind','G9281','3','','1','0','','','','0','1','0','0'),
('13091','Documentation of medical reason(s) for not reporting the histological type or nsclc-nos classification with an explanation (e.g.; biopsy taken for other purposes in a patient with a history of non-small cell lung cancer or other documented medical reasons)','Doc medrsn no histo type','G9282','3','','1','0','','','','0','1','0','0'),
('13092','Non small cell lung cancer biopsy and cytology specimen report documents classification into specific histologic type or classified as nsclc-nos with an explanation','Hist type doc on report','G9283','3','','1','0','','','','0','1','0','0'),
('13093','Non small cell lung cancer biopsy and cytology specimen report does not document classification into specific histologic type or classified as nsclc-nos with an explanation','No hist type doc on report','G9284','3','','1','0','','','','0','1','0','0'),
('13094','Specimen site other than anatomic location of lung or is not classified as non small cell lung cancer','Site not small cell lung ca','G9285','3','','1','0','','','','0','1','0','0'),
('13095','Antibiotic regimen prescribed within 10 days after onset of symptoms','Antibio rx w in 10d of sympt','G9286','3','','1','0','','','','0','1','0','0'),
('13096','Antibiotic regimen not prescribed within 10 days after onset of symptoms','No antibio w in 10d of sympt','G9287','3','','1','0','','','','0','1','0','0'),
('13097','Documentation of medical reason(s) for not reporting the histological type or nsclc-nos classification with an explanation (e.g.; a solitary fibrous tumor in a person with a history of non-small cell carcinoma or other documented medical reasons)','Doc medrsn no hist type rpt','G9288','3','','1','0','','','','0','1','0','0'),
('13098','Non small cell lung cancer biopsy and cytology specimen report documents classification into specific histologic type or classified as nsclc-nos with an explanation','Doc type nsm lung ca','G9289','3','','1','0','','','','0','1','0','0'),
('13099','Non small cell lung cancer biopsy and cytology specimen report does not document classification into specific histologic type or classified as nsclc-nos with an explanation','No doc type nsm lung ca','G9290','3','','1','0','','','','0','1','0','0'),
('13100','Specimen site other than anatomic location of lung; is not classified as non small cell lung cancer or classified as nsclc-nos','Not nsm lung ca','G9291','3','','1','0','','','','0','1','0','0'),
('13101','Documentation of medical reason(s) for not reporting pt category and a statement on thickness and ulceration and for pt1; mitotic rate (e.g.; negative skin biopsies in a patient with a history of melanoma or other documented medical reasons)','Medrsn no pt category','G9292','3','','1','0','','','','0','1','0','0'),
('13102','Pathology report does not include the pt category and a statement on thickness and ulceration and for pt1; mitotic rate','No pt category on report','G9293','3','','1','0','','','','0','1','0','0'),
('13103','Pathology report includes the pt category and a statement on thickness and ulceration and for pt1; mitotic rate','Pt cat and thck on report','G9294','3','','1','0','','','','0','1','0','0'),
('13104','Specimen site other than anatomic cutaneous location','Non cutaneous loc','G9295','3','','1','0','','','','0','1','0','0'),
('13105','Patients with documented shared decision-making including discussion of conservative (non-surgical) therapy (e.g.; nsaids; analgesics; weight loss; exercise; injections) prior to the procedure','Doc share dec prior proc','G9296','3','','1','0','','','','0','1','0','0'),
('13106','Shared decision-making including discussion of conservative (non-surgical) therapy (e.g.; nsaids; analgesics; weight loss; exercise; injections) prior to the procedure; not documented; reason not given','No doc share dec prior proc','G9297','3','','1','0','','','','0','1','0','0'),
('13107','Patients who are evaluated for venous thromboembolic and cardiovascular risk factors within 30 days prior to the procedure (e.g.; history of dvt; pe; mi; arrhythmia and stroke)','Eval risk vte card 30d prior','G9298','3','','1','0','','','','0','1','0','0'),
('13108','Patients who are not evaluated for venous thromboembolic and cardiovascular risk factors within 30 days prior to the procedure including (e.g.; history of dvt; pe; mi; arrhythmia and stroke; reason not given)','No eval riskk vte card prior','G9299','3','','1','0','','','','0','1','0','0'),
('13109','Documentation of medical reason(s) for not completely infusing the prophylactic antibiotic prior to the inflation of the proximal tourniquet (e.g.; a tourniquet was not used)','Doc medrsn no compl antibio','G9300','3','','1','0','','','','0','1','0','0'),
('13110','Patients who had the prophylactic antibiotic completely infused prior to the inflation of the proximal tourniquet','Doc compl inf antibio','G9301','3','','1','0','','','','0','1','0','0'),
('13111','Prophylactic antibiotic not completely infused prior to the inflation of the proximal tourniquet; reason not given','Norsn incomp inf antibio','G9302','3','','1','0','','','','0','1','0','0'),
('13112','Operative report does not identify the prosthetic implant specifications including the prosthetic implant manufacturer; the brand name of the prosthetic implant and the size of each prosthetic implant; reason not given','Norsn no pros info op rpt','G9303','3','','1','0','','','','0','1','0','0'),
('13113','Operative report identifies the prosthetic implant specifications including the prosthetic implant manufacturer; the brand name of the prosthetic implant and the size of each prosthetic implant','Pros info op rpt','G9304','3','','1','0','','','','0','1','0','0'),
('13114','Intervention for presence of leak of endoluminal contents through an anastomosis not required','No interv req for leak','G9305','3','','1','0','','','','0','1','0','0'),
('13115','Intervention for presence of leak of endoluminal contents through an anastomosis required','Interv req for leak','G9306','3','','1','0','','','','0','1','0','0'),
('13116','No return to the operating room for a surgical procedure; for complications of the principal operative procedure; within 30 days of the principal operative procedure','No ret for surg w in 30d','G9307','3','','1','0','','','','0','1','0','0'),
('13117','Unplanned return to the operating room for a surgical procedure; for complications of the principal operative procedure; within 30 days of the principal operative procedure','Unpl ret or w/compl w/in 30d','G9308','3','','1','0','','','','0','1','0','0'),
('13118','No unplanned hospital readmission within 30 days of principal procedure','No unplnd hosp readm in 30d','G9309','3','','1','0','','','','0','1','0','0'),
('13119','Unplanned hospital readmission within 30 days of principal procedure','Unplnd hosp readm in 30d','G9310','3','','1','0','','','','0','1','0','0'),
('13120','No surgical site infection','No surg site infection','G9311','3','','1','0','','','','0','1','0','0'),
('13121','Surgical site infection','Surgical site infection','G9312','3','','1','0','','','','0','1','0','0'),
('13122','Amoxicillin; with or without clavulanate; not prescribed as first line antibiotic at the time of diagnosis for documented reason (eg; cystic fibrosis; immotile cilia disorders; ciliary dyskinesia; immune deficiency; prior history of sinus surgery within the past 12 months; and anatomic abnormalities; such as deviated nasal septum; resistant organisms; allergy to medication; recurrent sinusitis; chronic sinusitis; or other reasons)','Docrsn not first line amox','G9313','3','','1','0','','','','0','1','0','0'),
('13123','Amoxicillin; with or without clavulanate; not prescribed as first line antibiotic at the time of diagnosis; reason not given','Norsn not first line amox','G9314','3','','1','0','','','','0','1','0','0'),
('13124','Documentation amoxicillin; with or without clavulanate; prescribed as a first line antibiotic at the time of diagnosis','Doc first line amox','G9315','3','','1','0','','','','0','1','0','0'),
('13125','Documentation of patient-specific risk assessment with a risk calculator based on multi-institutional clinical data; the specific risk calculator used; and communication of risk assessment from risk calculator with the patient or family','Doc comm risk calc','G9316','3','','1','0','','','','0','1','0','0'),
('13126','Documentation of patient-specific risk assessment with a risk calculator based on multi-institutional clinical data; the specific risk calculator used; and communication of risk assessment from risk calculator with the patient or family not completed','No doc comm risk calc','G9317','3','','1','0','','','','0','1','0','0'),
('13127','Imaging study named according to standardized nomenclature','Image std nomenclature','G9318','3','','1','0','','','','0','1','0','0'),
('13128','Imaging study not named according to standardized nomenclature; reason not given','Image not std nomenclature','G9319','3','','1','0','','','','0','1','0','0'),
('13129','Documentation of medical reason(s) for not naming ct studies according to a standardized nomenclature provided (eg; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','Medrsn no std nomenclature','G9320','3','','1','0','','','','0','1','0','0'),
('13130','Count of previous ct (any type of ct) and cardiac nuclear medicine (myocardial perfusion) studies documented in the 12-month period prior to the current study','Doc count of ct in 12mo','G9321','3','','1','0','','','','0','1','0','0'),
('13131','Count of previous ct and cardiac nuclear medicine (myocardial perfusion) studies not documented in the 12-month period prior to the current study; reason not given','No doc count of ct in 12mo','G9322','3','','1','0','','','','0','1','0','0'),
('13132','Documentation of medical reason(s) for not counting previous ct and cardiac nuclear medicine (myocardial perfusion) studies (eg; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','Mdrsn no doc cnt of ct','G9323','3','','1','0','','','','0','1','0','0'),
('13133','All necessary data elements not included; reason not given','Not all data norsn','G9324','3','','1','0','','','','0','1','0','0'),
('13134','Ct studies not reported to a radiation dose index registry due to medical reasons (eg; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','Medrsn no ct rpt to reg','G9325','3','','1','0','','','','0','1','0','0'),
('13135','Ct studies performed not reported to a radiation dose index registry that is capable of collecting at a minimum all necessary data elements; reason not given','Ct done no rad ds index; nrg','G9326','3','','1','0','','','','0','1','0','0'),
('13136','Ct studies performed reported to a radiation dose index registry that is capable of collecting at a minimum all necessary data elements','Ct done rad ds index','G9327','3','','1','0','','','','0','1','0','0'),
('13137','Dicom format image data availability not documented in final report due to medical reasons (eg; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','Medrsn no dicom format doc','G9328','3','','1','0','','','','0','1','0','0'),
('13138','Dicom format image data available to non-affiliated external healthcare facilities or entities on a secure; media free; reciprocally searchable basis with patient authorization for at least a 12-month period after the study not documented in final report; reason not given','Norsn no dicom format doc','G9329','3','','1','0','','','','0','1','0','0'),
('13139','Final report documented that dicom format image data available to non-affiliated external healthcare facilities or entities on a secure; media free; reciprocally searchable basis with patient authorization for at least a 12-month period after the study','Dicom format doc on rpt','G9340','3','','1','0','','','','0','1','0','0'),
('13140','Search conducted for prior patient ct studies completed at non-affiliated external healthcare facilities or entities within the past 12-months and are available through a secure; authorized; media-free; shared archive prior to an imaging study being performed','Srch for ct w in 12 mos','G9341','3','','1','0','','','','0','1','0','0'),
('13141','Search not conducted prior to an imaging study being performed for prior patient ct studies completed at non-affiliated external healthcare facilities or entities within the past 12-months and are available through a secure; authorized; media-free; shared archive; reason not given','No srch for ct in 12mo norsn','G9342','3','','1','0','','','','0','1','0','0'),
('13142','Due to medical reasons; search not conducted for dicom format images for prior patient ct imaging studies completed at non-affiliated external healthcare facilities or entities within the past 12 months that are available through a secure; authorized; media-free; shared archive (e.g.; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','Medrsn no dicom srch','G9343','3','','1','0','','','','0','1','0','0'),
('13143','Due to system reasons search not conducted for dicom format images for prior patient ct imaging studies completed at non-affiliated external healthcare facilities or entities within the past 12 months that are available through a secure; authorized; media-free; shared archive (e.g.; non-affiliated external healthcare facilities or entities does not have archival abilities through a shared archival system)','Sysrsn no dicom srch','G9344','3','','1','0','','','','0','1','0','0'),
('13144','Follow-up recommendations documented according to recommended guidelines for incidentally detected pulmonary nodules (e.g.; follow-up ct imaging studies needed or that no follow-up is needed) based at a minimum on nodule size and patient risk factors','Follow up pulm nod','G9345','3','','1','0','','','','0','1','0','0'),
('13145','Follow-up recommendations not documented according to recommended guidelines for incidentally detected pulmonary nodules due to medical reasons (e.g.; patients with known malignant disease; patients with unexplained fever; ct studies performed for radiation treatment planning or image-guided radiation treatment delivery)','No follow up pulm nod','G9346','3','','1','0','','','','0','1','0','0'),
('13146','Follow-up recommendations not documented according to recommended guidelines for incidentally detected pulmonary nodules; reason not given','No follow up pulm nod norsn','G9347','3','','1','0','','','','0','1','0','0'),
('13147','Ct scan of the paranasal sinuses ordered at the time of diagnosis for documented reasons (eg; persons with sinusitis symptoms lasting at least 7 to 10 days; antibiotic resistance; immunocompromised; recurrent sinusitis; acute frontal sinusitis; acute sphenoid sinusitis; periorbital cellulitis; or other medical)','Docrsn no sinus ct dx','G9348','3','','1','0','','','','0','1','0','0'),
('13148','Documentation of a ct scan of the paranasal sinuses ordered at the time of diagnosis or received within 28 days after date of diagnosis','Doc sinus ct 28d','G9349','3','','1','0','','','','0','1','0','0'),
('13149','Ct scan of the paranasal sinuses not ordered at the time of diagnosis or received within 28 days after date of diagnosis','No doc sinus ct 28d or dx','G9350','3','','1','0','','','','0','1','0','0'),
('13150','More than one ct scan of the paranasal sinuses ordered or received within 90 days after diagnosis','Doc >1 sinus ct w 90d dx','G9351','3','','1','0','','','','0','1','0','0'),
('13151','More than one ct scan of the paranasal sinuses ordered or received within 90 days after the date of diagnosis; reason not given','Not >1 sinus ct w 90d dx','G9352','3','','1','0','','','','0','1','0','0'),
('13152','More than one ct scan of the paranasal sinuses ordered or received within 90 days after the date of diagnosis for documented reasons (eg; patients with complications; second ct obtained prior to surgery; other medical reasons)','Medrsn >1 sinus ct w 90d dx','G9353','3','','1','0','','','','0','1','0','0'),
('13153','One ct scan or no ct scan of the paranasal sinuses ordered within 90 days after the date of diagnosis','1 or no ct sinus w/in 90d dx','G9354','3','','1','0','','','','0','1','0','0'),
('13154','Elective delivery or early induction not performed','No early ind/delivery','G9355','3','','1','0','','','','0','1','0','0'),
('13155','Elective delivery or early induction performed','Early ind/delivery','G9356','3','','1','0','','','','0','1','0','0'),
('13156','Post-partum screenings; evaluations and education performed','Pp eval/edu perf','G9357','3','','1','0','','','','0','1','0','0'),
('13157','Post-partum screenings; evaluations and education not performed','Pp eval/edu not perf','G9358','3','','1','0','','','','0','1','0','0'),
('13158','Documentation of negative or managed positive tb screen with further evidence that tb is not active within one year of patient visit','Doc of neg or man pos tb scn','G9359','3','','1','0','','','','0','1','0','0'),
('13159','No documentation of negative or managed positive tb screen','No doc of neg or man pos tb','G9360','3','','1','0','','','','0','1','0','0'),
('13160','Medical indication for induction [documentation of reason(s) for elective delivery (c-section) or early induction (e.g.; hemorrhage and placental complications; hypertension; preeclampsia and eclampsia; rupture of membranes-premature or prolonged; maternal conditions complicating pregnancy/delivery; fetal conditions complicating pregnancy/delivery; late pregnancy; prior uterine surgery; or participation in clinical trial)]','Doc rsn elect c-sec/induct','G9361','3','','1','0','','','','0','1','0','0'),
('13161','Duration of monitored anesthesia care (mac) or peripheral nerve block (pnb) without the use of general anesthesia during an applicable procedure 60 minutes or longer; as documented in the anesthesia record','Mac or pnb w/o genanes >60m','G9362','3','','1','0','','','','0','1','0','0'),
('13162','Duration of monitored anesthesia care (mac) or peripheral nerve block (pnb) without the use of general anesthesia during an applicable procedure or general or neuraxial anesthesia less than 60 minutes; as documented in the anesthesia record','Mac or pnb w/o genanes <60m','G9363','3','','1','0','','','','0','1','0','0'),
('13163','Sinusitis caused by; or presumed to be caused by; bacterial infection','Sinus caus bac inx','G9364','3','','1','0','','','','0','1','0','0'),
('13164','One high-risk medication ordered','1high risk med ord','G9365','3','','1','0','','','','0','1','0','0'),
('13165','One high-risk medication not ordered','1high risk no ord','G9366','3','','1','0','','','','0','1','0','0'),
('13166','At least two different high-risk medications ordered','2high risk med ord','G9367','3','','1','0','','','','0','1','0','0'),
('13167','At least two different high-risk medications not ordered','2high risk no ord','G9368','3','','1','0','','','','0','1','0','0'),
('13168','Individual filled at least two prescriptions for any antipsychotic medication and had a pdc of 0.8 or greater','Fill 2 rx antipsych','G9369','3','','1','0','','','','0','1','0','0'),
('13169','Individual who did not fill at least two prescriptions for any antipsychotic medication or did not have a pdc of 0.8 or greater','Not fill 2 rx antipsych','G9370','3','','1','0','','','','0','1','0','0'),
('13170','Patient continued to have the retina attached at the 6 months follow up visit (+/- 1 month) following only one surgery','Contd ret attach at 6mth f/u','G9376','3','','1','0','','','','0','1','0','0'),
('13171','Patient did not have the retina attached after 6 months following only one surgery','No ret attach after 6mt','G9377','3','','1','0','','','','0','1','0','0'),
('13172','Patient continued to have the retina attached at the 6 months follow up visit (+/- 1 month)','Contd ret attach f/u vis','G9378','3','','1','0','','','','0','1','0','0'),
('13173','Patient did not achieve flat retinas six months post surgery','No acheive flat ret 6mth','G9379','3','','1','0','','','','0','1','0','0'),
('13174','Patient offered assistance with end of life issues during the measurement period','Off assis eol iss','G9380','3','','1','0','','','','0','1','0','0'),
('13175','Documentation of medical reason(s) for not offering assistance with end of life issues (e.g.; patient in hospice care; patient in terminal phase) during the measurement period','Doc med reas no offer eol','G9381','3','','1','0','','','','0','1','0','0'),
('13176','Patient not offered assistance with end of life issues during the measurement period','No off assis eol','G9382','3','','1','0','','','','0','1','0','0'),
('13177','Patient received screening for hcv infection within the 12 month reporting period','Recd scrn hcv infec','G9383','3','','1','0','','','','0','1','0','0'),
('13178','Documentation of medical reason(s) for not receiving annual screening for hcv infection (e.g.; decompensated cirrhosis indicating advanced disease [i.e.; ascites; esophageal variceal bleeding; hepatic encephalopathy]; hepatocellular carcinoma; waitlist for organ transplant; limited life expectancy; other medical reasons)','Doc med reas no ann srn hcv','G9384','3','','1','0','','','','0','1','0','0'),
('13179','Documentation of patient reason(s) for not receiving annual screening for hcv infection (e.g.; patient declined; other patient reasons)','Doc pt reas not rec hcv srn','G9385','3','','1','0','','','','0','1','0','0'),
('13180','Screening for hcv infection not received within the 12 month reporting period; reason not given','Scrn hcv infec not recd','G9386','3','','1','0','','','','0','1','0','0'),
('13181','Unplanned rupture of the posterior capsule requiring vitrectomy during cataract surgery','Unpln rup post cap','G9389','3','','1','0','','','','0','1','0','0'),
('13182','No unplanned rupture of the posterior capsule requiring vitrectomy during cataract surgery','No unpln rup post cap','G9390','3','','1','0','','','','0','1','0','0'),
('13183','Patient achieves refraction +-1 d for the eye that underwent cataract surgery; measured at the one month follow up visit','Achv refrac +1d','G9391','3','','1','0','','','','0','1','0','0'),
('13184','Patient does not achieve refraction +-1 d for the eye that underwent cataract surgery; measured at the one month follow up visit','Not achv refrac +1d','G9392','3','','1','0','','','','0','1','0','0'),
('13185','Patient with an initial phq-9 score greater than nine who achieves remission at twelve months as demonstrated by a twelve month (+/- 30 days) phq-9 score of less than five','Ini phq9 >9 remiss <5','G9393','3','','1','0','','','','0','1','0','0'),
('13186','Patient who had a diagnosis of bipolar disorder or personality disorder; death; permanent nursing home resident or receiving hospice or palliative care any time during the measurement or assessment period','Dx bipol; death; nhres; hosp','G9394','3','','1','0','','','','0','1','0','0'),
('13187','Patient with an initial phq-9 score greater than nine who did not achieve remission at twelve months as demonstrated by a twelve month (+/- 30 days) phq-9 score greater than or equal to five','Ini phq9 >9 no remiss >=5','G9395','3','','1','0','','','','0','1','0','0'),
('13188','Patient with an initial phq-9 score greater than nine who was not assessed for remission at twelve months (+/- 30 days)','Ini phq9 >9 not assess','G9396','3','','1','0','','','','0','1','0','0'),
('13189','Documentation in the patient record of a discussion between the physician/clinician and the patient that includes all of the following: treatment choices appropriate to genotype; risks and benefits; evidence of effectiveness; and patient preferences toward the outcome of the treatment','Doc disc tx choices','G9399','3','','1','0','','','','0','1','0','0'),
('13190','Documentation of medical or patient reason(s) for not discussing treatment options; medical reasons: patient is not a candidate for treatment due to advanced physical or mental health comorbidity (including active substance use); currently receiving antiviral treatment; successful antiviral treatment (with sustained virologic response) prior to reporting period; other documented medical reasons; patient reasons: patient unable or unwilling to participate in the discussion or other patient reasons','Doc reas no disc tx opt','G9400','3','','1','0','','','','0','1','0','0'),
('13191','No documentation of a discussion in the patient record of a discussion between the physician or other qualfied healthcare professional and the patient that includes all of the following: treatment choices appropriate to genotype; risks and benefits; evidence of effectiveness; and patient preferences toward treatment','No disc tx choices','G9401','3','','1','0','','','','0','1','0','0'),
('13192','Patient received follow-up on the date of discharge or within 30 days after discharge','Recd f/u w/in 30d disch','G9402','3','','1','0','','','','0','1','0','0'),
('13193','Clinician documented reason patient was not able to complete 30 day follow-up from acute inpatient setting discharge (e.g.; patient death prior to follow-up visit; patient non-compliant for visit follow-up)','Doc reas no 30 day f/u','G9403','3','','1','0','','','','0','1','0','0'),
('13194','Patient did not receive follow-up on the date of discharge or within 30 days after discharge','No 30 day f/u','G9404','3','','1','0','','','','0','1','0','0'),
('13195','Patient received follow-up within 7 days from discharge','Recd f/u w/in 7d disch','G9405','3','','1','0','','','','0','1','0','0'),
('13196','Clinician documented reason patient was not able to complete 7 day follow-up from acute inpatient setting discharge (i.e patient death prior to follow-up visit; patient non-compliance for visit follow-up)','Doc reas no 7d f/u','G9406','3','','1','0','','','','0','1','0','0'),
('13197','Patient did not receive follow-up on or within 7 days after discharge','No 7d f/u','G9407','3','','1','0','','','','0','1','0','0'),
('13198','Patients with cardiac tamponade and/or pericardiocentesis occurring within 30 days','Card tamp w/in 30d','G9408','3','','1','0','','','','0','1','0','0'),
('13199','Patients without cardiac tamponade and/or pericardiocentesis occurring within 30 days','No card tamp e/in 30d','G9409','3','','1','0','','','','0','1','0','0'),
('13200','Patient admitted within 180 days; status post cied implantation; replacement; or revision with an infection requiring device removal or surgical revision','Admit w/in 180d req remov','G9410','3','','1','0','','','','0','1','0','0'),
('13201','Patient not admitted within 180 days; status post cied implantation; replacement; or revision with an infection requiring device removal or surgical revision','No admit w/in 180d req remov','G9411','3','','1','0','','','','0','1','0','0'),
('13202','Patient admitted within 180 days; status post cied implantation; replacement; or revision with an infection requiring device removal or surgical revision','Admit w/in 180d req surg rev','G9412','3','','1','0','','','','0','1','0','0'),
('13203','Patient not admitted within 180 days; status post cied implantation; replacement; or revision with an infection requiring device removal or surgical revision','No admit req surg rev','G9413','3','','1','0','','','','0','1','0','0'),
('13204','Patient had one dose of meningococcal vaccine on or between the patients 11th and 13th birthdays','1dose menig vac btwn 11 & 13','G9414','3','','1','0','','','','0','1','0','0'),
('13205','Patient did not have one dose of meningococcal vaccine on or between the patients 11th and 13th birthdays','No 1dose meni vac btwn 11&13','G9415','3','','1','0','','','','0','1','0','0'),
('13206','Patient had one tetanus; diphtheria toxoids and acellular pertussis vaccine (tdap) on or between the patients 10th and 13th birthdays','Pt 1 tdap betw 10-13 yrs','G9416','3','','1','0','','','','0','1','0','0'),
('13207','Patient did not have one tetanus; diphtheria toxoids and acellular pertussis vaccine (tdap) on or between the patients 10th and 13th birthdays','Pt not 1 tdap betw 10-13 yrs','G9417','3','','1','0','','','','0','1','0','0'),
('13208','Primary non-small cell lung cancer biopsy and cytology specimen report documents classification into specific histologic type or classified as nsclc-nos with an explanation','Lungcx bx rpt docs class','G9418','3','','1','0','','','','0','1','0','0'),
('13209','Documentation of medical reason(s) for not including the histological type or nsclc-nos classification with an explanation (e.g.; biopsy taken for other purposes in a patient with a history of primary non-small cell lung cancer or other documented medical reasons)','Med reas not incl histo type','G9419','3','','1','0','','','','0','1','0','0'),
('13210','Specimen site other than anatomic location of lung or is not classified as primary non-small cell lung cancer','Spec site no lung','G9420','3','','1','0','','','','0','1','0','0'),
('13211','Primary non-small cell lung cancer biopsy and cytology specimen report does not document classification into specific histologic type or classified as nsclc-nos with an explanation','Lung cx bx rpt no doc class','G9421','3','','1','0','','','','0','1','0','0'),
('13212','Primary lung carcinoma resection report documents pt category; pn category and for non-small cell lung cancer; histologic type (squamous cell carcinoma; adenocarcinoma and not nsclc-nos)','Rpt doc class histo type','G9422','3','','1','0','','','','0','1','0','0'),
('13213','Documentation of medical reason for not including pt category; pn category and histologic type [for patient with appropriate exclusion criteria (e.g.; metastatic disease; benign tumors; malignant tumors other than carcinomas; inadequate surgical specimens)]','Med reas rpt no histo type','G9423','3','','1','0','','','','0','1','0','0'),
('13214','Specimen site other than anatomic location of lung; or classified as nsclc-nos','Site no lung or lung cx','G9424','3','','1','0','','','','0','1','0','0'),
('13215','Primary lung carcinoma resection report does not document pt category; pn category and for non-small cell lung cancer; histologic type (squamous cell carcinoma; adenocarcinoma)','Spec rpt no doc class histo','G9425','3','','1','0','','','','0','1','0','0'),
('13216','Improvement in median time from ed arrival to initial ed oral or parenteral pain medication administration performed for ed admitted patients','Impr med time edarr pain med','G9426','3','','1','0','','','','0','1','0','0'),
('13217','Improvement in median time from ed arrival to initial ed oral or parenteral pain medication administration not performed for ed admitted patients','No impro med time pain med','G9427','3','','1','0','','','','0','1','0','0'),
('13218','Pathology report includes the pt category and a statement on thickness and ulceration and for pt1; mitotic rate','Rpt pt cat and pt1','G9428','3','','1','0','','','','0','1','0','0'),
('13219','Documentation of medical reason(s) for not including pt category and a statement on thickness and ulceration and for pt1; mitotic rate (e.g.; negative skin biopsies in a patient with a history of melanoma or other documented medical reasons)','Doc med reas no pt cat','G9429','3','','1','0','','','','0','1','0','0'),
('13220','Specimen site other than anatomic cutaneous location','Spec site no cutaneous','G9430','3','','1','0','','','','0','1','0','0'),
('13221','Pathology report does not include the pt category and a statement on thickness and ulceration and for pt1; mitotic rate','No pt cat and  pt1','G9431','3','','1','0','','','','0','1','0','0'),
('13222','Asthma well-controlled based on the act; c-act; acq; or ataq score and results documented','Asth controlled','G9432','3','','1','0','','','','0','1','0','0'),
('13223','Death; permanent nursing home resident or receiving hospice or palliative care any time during the measurement period','Death; nhres; hospice','G9433','3','','1','0','','','','0','1','0','0'),
('13224','Asthma not well-controlled based on the act; c-act; acq; or ataq score; or specified asthma control tool not used; reason not given','Asth not controlled','G9434','3','','1','0','','','','0','1','0','0'),
('13225','Aspirin prescribed at discharge','Asp presc disch','G9435','3','','1','0','','','','0','1','0','0'),
('13226','Aspirin not prescribed for documented reasons (e.g.; allergy; medical intolerance; history of bleed)','Asp not presc doc reas','G9436','3','','1','0','','','','0','1','0','0'),
('13227','Aspirin not prescribed at discharge','Asp not presc disch','G9437','3','','1','0','','','','0','1','0','0'),
('13228','P2y inhibitor prescribed at discharge','P2y inhib presc','G9438','3','','1','0','','','','0','1','0','0'),
('13229','P2y inhibitor not prescribed for documented reasons (e.g.; allergy; medical intolerance; history of bleed)','P2y inhib not presc doc reas','G9439','3','','1','0','','','','0','1','0','0'),
('13230','P2y inhibitor not prescribed at discharge','P2y inhib not presc','G9440','3','','1','0','','','','0','1','0','0'),
('13231','Statin prescribed at discharge','Statin presc disch','G9441','3','','1','0','','','','0','1','0','0'),
('13232','Statin not prescribed for documented reasons (e.g.; allergy; medical intolerance)','Statin not presc doc reas','G9442','3','','1','0','','','','0','1','0','0'),
('13233','Statin not prescribed at discharge','Statin not presc disch','G9443','3','','1','0','','','','0','1','0','0'),
('13234','Patients who were born in the years 1945?1965','Born 1945-1965','G9448','3','','1','0','','','','0','1','0','0'),
('13235','History of receiving blood transfusions prior to 1992','Hx bld transf b/f 1992','G9449','3','','1','0','','','','0','1','0','0'),
('13236','History of injection drug use','Hx injec drug use','G9450','3','','1','0','','','','0','1','0','0'),
('13237','Patient received one-time screening for hcv infection','1x scrn hcv infect','G9451','3','','1','0','','','','0','1','0','0'),
('13238','Documentation of medical reason(s) for not receiving one-time screening for hcv infection (e.g.; decompensated cirrhosis indicating advanced disease [ie; ascites; esophageal variceal bleeding; hepatic encephalopathy]; hepatocellular carcinoma; waitlist for organ transplant; limited life expectancy; other medical reasons)','Doc med reas no scrn hcv','G9452','3','','1','0','','','','0','1','0','0'),
('13239','Documentation of patient reason(s) for not receiving one-time screening for hcv infection (e.g.; patient declined; other patient reasons)','Pt reas no hcv infect','G9453','3','','1','0','','','','0','1','0','0'),
('13240','One-time screening for hcv infection not received within 12 month reporting period and no documentation of prior screening for hcv infection; reason not given','No hcv infect srn','G9454','3','','1','0','','','','0','1','0','0'),
('13241','Patient underwent abdominal imaging with ultrasound; contrast enhanced ct or contrast mri for hcc','Abd imag w/us; ct or mri','G9455','3','','1','0','','','','0','1','0','0'),
('13242','Documentation of medical or patient reason(s) for not ordering or performing screening for hcc. medical reason: comorbid medical conditions with expected survival < 5 years; hepatic decompensation and not a candidate for liver transplantation; or other medical reasons; patient reasons: patient declined or other patient reasons (e.g.; cost of tests; time related to accessing testing equipment)','Doc med pt reas no hcc scrn','G9456','3','','1','0','','','','0','1','0','0'),
('13243','Patient did not undergo abdominal imaging and did not have a documented reason for not undergoing abdominal imaging in the reporting period','No abd imag w/o reason','G9457','3','','1','0','','','','0','1','0','0'),
('13244','Patient documented as tobacco user and received tobacco cessation intervention (must include at least one of the following: advice given to quit smoking or tobacco use; counseling on the benefits of quitting smoking or tobacco use; assistance with or referral to external smoking or tobacco cessation support programs; or current enrollment in smoking or tobacco use cessation program) if identified as a tobacco user','Tob user recd cess interv','G9458','3','','1','0','','','','0','1','0','0'),
('13245','Currently a tobacco non-user','Tob non-user','G9459','3','','1','0','','','','0','1','0','0'),
('13246','Tobacco assessment or tobacco cessation intervention not performed; reason not given','No tob assess or cess inter','G9460','3','','1','0','','','','0','1','0','0'),
('13247','I intend to report the sinusitis measures group','Sinusitis intent','G9463','3','','1','0','','','','0','1','0','0'),
('13248','All quality actions for the applicable measures in the sinusitis measures group have been performed for this patient','Sinusitis comp','G9464','3','','1','0','','','','0','1','0','0'),
('13249','I intend to report the acute otitis externa (aoe) measures group','Aoe intent','G9465','3','','1','0','','','','0','1','0','0'),
('13250','All quality actions for the applicable measures in the aoe measures group have been performed for this patient','Aoe comp','G9466','3','','1','0','','','','0','1','0','0'),
('13251','Patient who have received or are receiving corticosteroids greater than or equal to 10 mg/day of prednisone equivalents for 60 or greater consecutive days or a single prescription equating to 600 mg prednisone or greater for all fills within the last twelve months','Recd cortico >=10mg/day >60d','G9467','3','','1','0','','','','0','1','0','0'),
('13252','Patient not receiving corticosteroids greater than or equal to 10 mg/day of prednisone equivalents for 60 or greater consecutive days or a single prescription equating to 600 mg prednisone or greater for all fills','No recd cortico>=10mg/d >60d','G9468','3','','1','0','','','','0','1','0','0'),
('13253','Patients who have received or are receiving corticosteroids greater than or equal to 10 mg/day of prednisone equivalents for 60 or greater consecutive days or a single prescription equating to 600 mg prednisone or greater for all fills','Rec cortico>60d or 1rx 600mg','G9469','3','','1','0','','','','0','1','0','0'),
('13254','Patients not receiving corticosteroids greater than or equal to 10 mg/day of prednisone equivalents for 60 or greater consecutive days or a single prescription equating to 600 mg prednisone or greater for all fills','No rec cortico>60d 1rx 600mg','G9470','3','','1','0','','','','0','1','0','0'),
('13255','Within the past 2 years; central dual-energy x-ray absorptiometry (dxa) not ordered or documented','W/in 2yr dxa not order','G9471','3','','1','0','','','','0','1','0','0'),
('13256','Within the past 2 years; central dual-energy x-ray absorptiometry (dxa) not ordered and documented; no review of systems and no medication history or pharmacologic therapy (other than minerals/vitamins) for osteoporosis prescribed','No dxa no med hx no rv sx','G9472','3','','1','0','','','','0','1','0','0'),
('13257','Services performed by chaplain in the hospice setting; each 15 minutes','Chap services at hospice','G9473','3','','1','0','','','','0','1','0','0'),
('13258','Services performed by dietary counselor in the hospice setting; each 15 minutes','Diet counsel at hospice','G9474','3','','1','0','','','','0','1','0','0'),
('13259','Services performed by other counselor in the hospice setting; each 15 minutes','Other counselor at hospice','G9475','3','','1','0','','','','0','1','0','0'),
('13260','Services performed by volunteer in the hospice setting; each 15 minutes','Volun service at hospice','G9476','3','','1','0','','','','0','1','0','0'),
('13261','Services performed by care coordinator in the hospice setting; each 15 minutes','Care coord at hospice','G9477','3','','1','0','','','','0','1','0','0'),
('13262','Services performed by other qualified therapist in the hospice setting; each 15 minutes','Othe therapist at hospice','G9478','3','','1','0','','','','0','1','0','0'),
('13263','Services performed by qualified pharmacist in the hospice setting; each 15 minutes','Pharmacist at hospice','G9479','3','','1','0','','','','0','1','0','0'),
('13264','Admission to medicare care choice model program (mccm)','Admission to mccm','G9480','3','','1','0','','','','0','1','0','0'),
('13265','Remote in-home visit for the evaluation and management of a new patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires these 3 key components: a problem focused history;  a problem focused examination; and straightforward medical decision making; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both. usually; the presenting problem(s) are self limited or minor.  typically; 10 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m new pt 10mins','G9481','3','','1','0','','','','0','1','0','0'),
('13266','Remote in-home visit for the evaluation and management of a new patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires these 3 key components: an expanded problem focused history; an expanded problem focused examination;  straightforward medical decision making; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of low to moderate severity.  typically; 20 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m new pt 20mins','G9482','3','','1','0','','','','0','1','0','0'),
('13267','Remote in-home visit for the evaluation and management of a new patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires these 3 key components: a detailed history; a detailed examination; medical decision making of low complexity; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of moderate severity.  typically; 30 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m new pt 30mins','G9483','3','','1','0','','','','0','1','0','0'),
('13268','Remote in-home visit for the evaluation and management of a new patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires these 3 key components: a comprehensive history; a comprehensive examination; medical decision making of moderate complexity; furnished in real time using interactive audio and video technology. counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of moderate to high severity.  typically; 45 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m new pt 45mins','G9484','3','','1','0','','','','0','1','0','0'),
('13269','Remote in-home visit for the evaluation and management of a new patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires these 3 key components: a comprehensive history; a comprehensive examination; medical decision making of high complexity; furnished in real time using interactive audio and video technology. counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of moderate to high severity.  typically; 60 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m new pt 60mins','G9485','3','','1','0','','','','0','1','0','0'),
('13270','Remote in-home visit for the evaluation and management of an established patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires at least 2 of the following 3 key components: a problem focused history; a problem focused examination; straightforward medical decision making; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are self limited or minor.  typically; 10 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m est. pt 10mins','G9486','3','','1','0','','','','0','1','0','0'),
('13271','Remote in-home visit for the evaluation and management of an established patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires at least 2 of the following 3 key components: an expanded problem focused history; an expanded problem focused examination; medical decision making of low complexity; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of low to moderate severity.  typically; 15 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m est. pt 15mins','G9487','3','','1','0','','','','0','1','0','0'),
('13272','Remote in-home visit for the evaluation and management of an established patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires at least 2 of the following 3 key components: a detailed history; a detailed examination; medical decision making of moderate complexity; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of moderate to high severity.  typically; 25 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m est. pt 25mins','G9488','3','','1','0','','','','0','1','0','0'),
('13273','Remote in-home visit for the evaluation and management of an established patient for use only in the medicare-approved comprehensive care for joint replacement model; which requires at least 2 of the following 3 key components: a comprehensive history; a comprehensive examination; medical decision making of high complexity; furnished in real time using interactive audio and video technology.  counseling and coordination of care with other physicians; other qualified health care professionals or agencies are provided consistent with the nature of the problem(s) and the needs of the patient or the family or both.  usually; the presenting problem(s) are of moderate to high severity.  typically; 40 minutes are spent with the patient or family or both via real time; audio and video intercommunications technology','Remote e/m est. pt 40mins','G9489','3','','1','0','','','','0','1','0','0'),
('13274','Comprehensive care for joint replacement model; home visit for patient assessment performed by clinical staff for an individual not considered homebound; including; but not necessarily limited to patient assessment of clinical status; safety/fall prevention; functional status/ambulation; medication reconciliation/management; compliance with orders/plan of care; performance of activities of daily living; and ensuring beneficiary connections to community and other services.  (for use only in the medicare-approved cjr model); may not be billed for a 30 day period covered by a transitional care management code','Joint replac mod home visit','G9490','3','','1','0','','','','0','1','0','0'),
('13275','Documentation of reason for not detecting adenoma(s) or other neoplasm. (e.g.; neoplasm detected is only diagnosed as traditional serrated adenoma; sessile serrated polyp; or sessile serrated adenoma','Doc rsn no adeno/neopl detec','G9496','3','','1','0','','','','0','1','0','0'),
('13276','Received instruction from the anesthesiologist or proxy prior to the day of surgery to abstain from smoking on the day of surgery','Rec inst no smoke day surg','G9497','3','','1','0','','','','0','1','0','0'),
('13277','Antibiotic regimen prescribed','Abx reg prescribed','G9498','3','','1','0','','','','0','1','0','0'),
('13278','Patient did not start or is not receiving antiviral treatment for hepatitis c during the measurement period','No start/rec antvir tx hep c','G9499','3','','1','0','','','','0','1','0','0'),
('13279','Radiation exposure indices; or exposure time and number of fluorographic images in final report for procedures using fluoroscopy; documented','Rad expos ind/exp tm doc','G9500','3','','1','0','','','','0','1','0','0'),
('13280','Radiation exposure indices; or exposure time and number of fluorographic images not documented in final report for procedure using fluoroscopy; reason not given','Rad expos ind/exp tm no doc','G9501','3','','1','0','','','','0','1','0','0'),
('13281','Documentation of medical reason for not performing foot exam (i.e.; patients who have had either a bilateral amputation above or below the knee; or both a left and right amputation above or below the knee before or during the measurement period)','Med reas no perf foot exam','G9502','3','','1','0','','','','0','1','0','0'),
('13282','Patient taking tamsulosin hydrochloride','Pt tk tams hcl','G9503','3','','1','0','','','','0','1','0','0'),
('13283','Documented reason for not assessing hepatitis b virus (hbv) status (e.g. patient not receiving a first course of anti-tnf therapy; patient declined) within one year prior to first course of anti-tnf therapy','Doc reas no hbv status','G9504','3','','1','0','','','','0','1','0','0'),
('13284','Antibiotic regimen prescribed within 10 days after onset of symptoms for documented medical reason','Abx pres w/in 10 dys of symp','G9505','3','','1','0','','','','0','1','0','0'),
('13285','Biologic immune response modifier prescribed','Bio imm resp mod presc','G9506','3','','1','0','','','','0','1','0','0'),
('13286','Documentation that the patient is on a statin medication or has documentation of a valid contraindication or exception to statin medications; contraindications/exceptions that can be defined by diagnosis codes include pregnancy during the measurement period; active liver disease; rhabdomyolysis; end stage renal disease on dialysis and heart failure; provider documented contraindications/exceptions include breastfeeding during the measurement period; woman of child-bearing age not actively taking birth control; allergy to statin; drug interaction (hiv protease inhibitors; nefazodone; cyclosporine; gemfibrozil; and danazol) and intolerance (with supporting documentation of trying a statin at least once within the last 5 years or diagnosis codes for myostitis or toxic myopathy related to drugs)','Doc reas on statin or contra','G9507','3','','1','0','','','','0','1','0','0'),
('13287','Documentation that the patient is not on a statin medication','Doc pt not on statin','G9508','3','','1','0','','','','0','1','0','0'),
('13288','Remission at twelve months as demonstrated by a twelve month (+/-30 days) phq-9 score of less than 5','Remis 12m phq-9 score <5','G9509','3','','1','0','','','','0','1','0','0'),
('13289','Remission at twelve months not demonstrated by a twelve month (+/-30 days) phq-9 score of less than five; either phq-9 score was not assessed or is greater than or equal to 5','Remis 12m not phq-9 score <5','G9510','3','','1','0','','','','0','1','0','0'),
('13290','Index date phq-9 score greater than 9 documented during the twelve month denominator identification period','Phq-9 >9 during 12m time','G9511','3','','1','0','','','','0','1','0','0'),
('13291','Individual had a pdc of 0.8 or greater','Indiv pdc > 0.8','G9512','3','','1','0','','','','0','1','0','0'),
('13292','Individual did not have a pdc of 0.8 or greater','Indiv pdc not > 0.8','G9513','3','','1','0','','','','0','1','0','0'),
('13293','Patient required a return to the operating room within 90 days of surgery','Req ret or w/in 90d of surg','G9514','3','','1','0','','','','0','1','0','0'),
('13294','Patient did not require a return to the operating room within 90 days of surgery','No reas; no ret or w/in 90d','G9515','3','','1','0','','','','0','1','0','0'),
('13295','Patient achieved an improvement in visual acuity; from their preoperative level; within 90 days of surgery','Impr vis acuit w/in 90d','G9516','3','','1','0','','','','0','1','0','0'),
('13296','Patient did not achieve an improvement in visual acuity; from their preoperative level; within 90 days of surgery; reason not given','No impr vis acuit w/in 90d','G9517','3','','1','0','','','','0','1','0','0'),
('13297','Documentation of active injection drug use','Doc active inj drug use','G9518','3','','1','0','','','','0','1','0','0'),
('13298','Patient achieves final refraction (spherical equivalent) +/- 0.5 diopters of their planned refraction within 90 days of surgery','Final ref +/- 0.5 w/in 90d','G9519','3','','1','0','','','','0','1','0','0'),
('13299','Patient does not achieve final refraction (spherical equivalent) +/- 0.5 diopters of their planned refraction within 90 days of surgery','Refract not +/- 0.5 w/in 90d','G9520','3','','1','0','','','','0','1','0','0'),
('13300','Total number of emergency department visits and inpatient hospitalizations less than two in the past 12 months','Er and ip hosp <2 in 12 mos','G9521','3','','1','0','','','','0','1','0','0'),
('13301','Total number of emergency department visits and inpatient hospitalizations equal to or greater than two in the past 12 months or patient not screened; reason not given','Er/ip hosp =/>2 in 12 mos','G9522','3','','1','0','','','','0','1','0','0'),
('13302','Patient discontinued from hemodialysis or peritoneal dialysis','D/c hemo or perit dialysis','G9523','3','','1','0','','','','0','1','0','0'),
('13303','Patient was referred to hospice care','Refer to hospice','G9524','3','','1','0','','','','0','1','0','0'),
('13304','Documentation of patient reason(s) for not referring to hospice care (e.g.; patient declined; other patient reasons)','Doc pt reas no hospice refer','G9525','3','','1','0','','','','0','1','0','0'),
('13305','Patient was not referred to hospice care; reason not given','No reason; no refer hospice','G9526','3','','1','0','','','','0','1','0','0'),
('13306','Patient with minor blunt head trauma had an appropriate indication(s) for a head ct','Minor blunt trauma w/head ct','G9529','3','','1','0','','','','0','1','0','0'),
('13307','Patient presented within 24 hours of a minor blunt head trauma with a gcs score of 15 and had a head ct ordered for trauma by an emergency care provider','Min hd traum gcs=15 w/ct ed','G9530','3','','1','0','','','','0','1','0','0'),
('13308','Patient has documentation of ventricular shunt; brain tumor; multisystem trauma; pregnancy; or is currently taking an antiplatelet medication including: asa/dipyridamole; clopidogrel; prasugrel; ticlopidine; ticagrelor or cilstazol)','Doc shnt/br tum/on antipl rx','G9531','3','','1','0','','','','0','1','0','0'),
('13309','Patients head injury occurred greater than 24 hours before presentation to the emergency department; or has a gcs score less than 15 or does not have a gcs score documented; or had a head ct for trauma ordered by someone other than an emergency care provider; or was ordered for a reason other than trauma','Inj >24 hr in ed gcs <15','G9532','3','','1','0','','','','0','1','0','0'),
('13310','Patient with minor blunt head trauma did not have an appropriate indication(s) for a head ct','Indic for head ct not valid','G9533','3','','1','0','','','','0','1','0','0'),
('13311','Advanced brain imaging (cta; ct; mra or mri) was not ordered','Adv brain image not ordered','G9534','3','','1','0','','','','0','1','0','0'),
('13312','Patients with a normal neurological examination','Normal neuro exam','G9535','3','','1','0','','','','0','1','0','0'),
('13313','Documentation of medical reason(s) for ordering an advanced brain imaging study (i.e.; patient has an abnormal neurological examination; patient has the coexistence of seizures; or both; recent onset of severe headache; change in the type of headache; signs of increased intracranial pressure (e.g.; papilledema; absent venous pulsations on funduscopic examination; altered mental status; focal neurologic deficits; signs of meningeal irritation); hiv-positive patients with a new type of headache; immunocompromised patient with unexplained headache symptoms; patient on coagulopathy/anti-coagulation or anti-platelet therapy; very young patients with unexplained headache symptoms)','Doc med reas adv brain image','G9536','3','','1','0','','','','0','1','0','0'),
('13314','Documentation of system reason(s) for ordering an advanced brain imaging study (i.e.; needed as part of a clinical trial; other clinician ordered the study)','Doc system reas adv imaging','G9537','3','','1','0','','','','0','1','0','0'),
('13315','Advanced brain imaging (cta; ct; mra or mri) was ordered','Adv brain image ordered','G9538','3','','1','0','','','','0','1','0','0'),
('13316','Intent for potential removal at time of placement','Intent pot remv time placemt','G9539','3','','1','0','','','','0','1','0','0'),
('13317','Patient alive 3 months post procedure','Pt alive 3 mos post proc','G9540','3','','1','0','','','','0','1','0','0'),
('13318','Filter removed within 3 months of placement','Filter gone aft 3mos placmt','G9541','3','','1','0','','','','0','1','0','0'),
('13319','Documented re-assessment for the appropriateness of filter removal within 3 months of placement','Doc reass appr remo filt 3ms','G9542','3','','1','0','','','','0','1','0','0'),
('13320','Documentation of at least two attempts to reach the patient to arrange a clinical re-assessment for the appropriateness of filter removal within 3 months of placement','Doc 2x re-assess filt remov','G9543','3','','1','0','','','','0','1','0','0'),
('13321','Patients that do not have the filter removed; documented re-assessment for the appropriateness of filter removal; or documentation of at least two attempts to reach the patient to arrange a clinical re-assessment for the appropriateness of filter removal within 3 months of placement','No filt remov w/in 3mos plcm','G9544','3','','1','0','','','','0','1','0','0'),
('13322','Incidental finding: liver lesion <= 0.5 cm; cystic kidney lesion < 1.0 cm or adrenal lesion <= 1.0 cm','Incid finding liver/kid/adre','G9547','3','','1','0','','','','0','1','0','0'),
('13323','Final reports for abdominal imaging studies with follow-up imaging recommended','Abd imag and followup rec','G9548','3','','1','0','','','','0','1','0','0'),
('13324','Documentation of medical reason(s) that follow-up imaging is indicated (e.g.; patient has a known malignancy that can metastasize; other medical reason(s) such as fever in an immunocompromised patient)','Doc med rsn for follow imag','G9549','3','','1','0','','','','0','1','0','0'),
('13325','Final reports for abdominal imaging studies with follow-up imaging not recommended','Abd imag and followup no rec','G9550','3','','1','0','','','','0','1','0','0'),
('13326','Final reports for abdominal imaging studies without an incidentally found lesion noted: liver lesion <= 0.5 cm; cystic kidney lesion < 1.0 cm or adrenal lesion <= 1.0 cm noted or no lesion found','Abd imag no les;kid/livr/adr','G9551','3','','1','0','','','','0','1','0','0'),
('13327','Incidental thyroid nodule < 1.0 cm noted in report','Inc thyr node <1.0 in rpt','G9552','3','','1','0','','','','0','1','0','0'),
('13328','Prior thyroid disease diagnosis','Prior thyroid dise dx','G9553','3','','1','0','','','','0','1','0','0'),
('13329','Final reports for ct; cta; mri or mra of the chest or neck or ultrasound of the neck with follow-up imaging recommended','Ct/cta/mri/a chst foll rec','G9554','3','','1','0','','','','0','1','0','0'),
('13330','Documentation of medical reason(s) for recommending follow up imaging (e.g.; patient has multiple endocrine neoplasia; patient has cervical lymphadenopathy; other medical reason(s))','Doc med rsn for follup image','G9555','3','','1','0','','','','0','1','0','0'),
('13331','Final reports for ct; cta; mri or mra of the chest or neck or ultrasound of the neck with follow-up imaging not recommended','Ct/cta/mri/a no follup imag','G9556','3','','1','0','','','','0','1','0','0'),
('13332','Final reports for ct; cta; mri or mra studies of the chest or neck or ultrasound of the neck without an incidentally found thyroid nodule < 1.0 cm noted or no nodule found','Ct/cta/mri/a no thyr <1.0cm','G9557','3','','1','0','','','','0','1','0','0'),
('13333','Patient treated with a beta-lactam antibiotic as definitive therapy','Tx beta-lactam abx therapy','G9558','3','','1','0','','','','0','1','0','0'),
('13334','Documentation of medical reason(s) for not prescribing a beta-lactam antibiotic (e.g.; allergy; intolerance to beta-lactam antibiotics)','Doc med reas no abx therapy','G9559','3','','1','0','','','','0','1','0','0'),
('13335','Patient not treated with a beta-lactam antibiotic as definitive therapy; reason not given','No beta-lactam abx ther; rng','G9560','3','','1','0','','','','0','1','0','0'),
('13336','Patients prescribed opiates for longer than six weeks','Presc opiates >6 wks','G9561','3','','1','0','','','','0','1','0','0'),
('13337','Patients who had a follow-up evaluation conducted at least every three months during opioid therapy','Foll-up eval q3mo opiod tx','G9562','3','','1','0','','','','0','1','0','0'),
('13338','Patients who did not have a follow-up evaluation conducted at least every three months during opioid therapy','No f/u eval q3mo opiod tx','G9563','3','','1','0','','','','0','1','0','0'),
('13339','Index date phq-score greater than 9 documented during the twelve month denominator identification period','Phq-scr >9 doc in 12m time','G9572','3','','1','0','','','','0','1','0','0'),
('13340','Remission at six months as demonstrated by a six month (+/-30 days) phq-9 score of less than five','Remis 6m w/6mos phq-9 <5','G9573','3','','1','0','','','','0','1','0','0'),
('13341','Remission at six months not demonstrated by a six month (+/-30 days) phq-9 score of less than five; either phq-9 score was not assessed or is greater than or equal to five','Remis 6m w/o 6mos phq-9 <5','G9574','3','','1','0','','','','0','1','0','0'),
('13342','Patients prescribed opiates for longer than six weeks','Presc opiates >6 wks','G9577','3','','1','0','','','','0','1','0','0'),
('13343','Documentation of signed opioid treatment agreement at least once during opioid therapy','Doc opioid tx 1x during ther','G9578','3','','1','0','','','','0','1','0','0'),
('13344','No documentation of signed an opioid treatment agreement at least once during opioid therapy','No doc opioid tx 1x at ther','G9579','3','','1','0','','','','0','1','0','0'),
('13345','Door to puncture time of less than 2 hours','Door to punc time <2hrs','G9580','3','','1','0','','','','0','1','0','0'),
('13346','Door to puncture time of greater than 2 hours for reasons documented by clinician (e.g.; patients who are transferred from one institution to another with a known diagnosis of cva for endovascular stroke treatment; hospitalized patients with newly diagnosed cva considered for endovascular stroke treatment)','Md doc; door to punc tm >2hr','G9581','3','','1','0','','','','0','1','0','0'),
('13347','Door to puncture time of greater than 2 hours; no reason given','Door to punc time >2hr; nrg','G9582','3','','1','0','','','','0','1','0','0'),
('13348','Patients prescribed opiates for longer than six weeks','Presc opiates >6 wks','G9583','3','','1','0','','','','0','1','0','0'),
('13349','Patient evaluated for risk of misuse of opiates by using a brief validated instrument (e.g.; opioid risk tool; soapp-r) or patient interviewed at least once during opioid therapy','Eval opioid use instr/pt int','G9584','3','','1','0','','','','0','1','0','0'),
('13350','Patient not evaluated for risk of misuse of opiates by using a brief validated instrument (e.g.; opioid risk tool; soapp-r) or patient not interviewed at least once during opioid therapy','No eval opi use instr/intv','G9585','3','','1','0','','','','0','1','0','0'),
('13351','Pediatric patient with minor blunt head trauma classified as low risk according to the pecarn prediction rules','Low pecarn ped head trauma','G9593','3','','1','0','','','','0','1','0','0'),
('13352','Patient presented within 24 hours of a minor blunt head trauma with a gcs score of 15 and had a head ct ordered for trauma by an emergency care provider','Gsc >15 & hd ct by ed md','G9594','3','','1','0','','','','0','1','0','0'),
('13353','Patient has documentation of ventricular shunt; brain tumor; coagulopathy; including thrombocytopenia','Doc shnt/tum/coag/thrombocyt','G9595','3','','1','0','','','','0','1','0','0'),
('13354','Pediatric patients head injury occurred greater than 24 hours before presentation to the emergency department; or has a gcs score less than 15 or does not have a gcs score documented; or had a head ct for trauma ordered by someone other than an emergency care provider; or was ordered for a reason other than trauma','Hd inj >24h/gcs >15/no res','G9596','3','','1','0','','','','0','1','0','0'),
('13355','Pediatric patient with minor blunt head trauma not classified as low risk according to the pecarn prediction rules','No low pecarn ped head traum','G9597','3','','1','0','','','','0','1','0','0'),
('13356','Aortic aneurysm 5.5 - 5.9 cm maximum diameter on centerline formatted ct or minor diameter on axial formatted ct','Aor ane 5.5-5.9 cm max diam','G9598','3','','1','0','','','','0','1','0','0'),
('13357','Aortic aneurysm 6.0 cm or greater maximum diameter on centerline formatted ct or minor diameter on axial formatted ct','Aor ane >=6.0 cm max diam','G9599','3','','1','0','','','','0','1','0','0'),
('13358','Symptomatic aaas that required urgent/emergent (non-elective) repair','Symp aaa urgent repair','G9600','3','','1','0','','','','0','1','0','0'),
('13359','Patient discharge to home no later than post-operative day #7','Pt dchg home post op day 7','G9601','3','','1','0','','','','0','1','0','0'),
('13360','Patient not discharged to home by post-operative day #7','Pt no dchg home postop day 7','G9602','3','','1','0','','','','0','1','0','0'),
('13361','Patient survey score improved from baseline following treatment','Pt surv improv bsline tx','G9603','3','','1','0','','','','0','1','0','0'),
('13362','Patient survey results not available','Pt surv results not avail','G9604','3','','1','0','','','','0','1','0','0'),
('13363','Patient survey score did not improve from baseline following treatment','Surv score no improv w/tx','G9605','3','','1','0','','','','0','1','0','0'),
('13364','Intraoperative cystoscopy performed to evaluate for lower tract injury','Intraop cyst eval trac inj','G9606','3','','1','0','','','','0','1','0','0'),
('13365','Documented medical reasons for not performing intraoperative cystoscopy (e.g.; urethral pathology precluding cystoscopy; any patient who has a congenital or acquired absence of the urethra)','Doc rsn no interop cysto','G9607','3','','1','0','','','','0','1','0','0'),
('13366','Intraoperative cystoscopy not performed to evaluate for lower tract injury','Intraop cyst eval not done','G9608','3','','1','0','','','','0','1','0','0'),
('13367','Documentation of an order for anti-platelet agents','Doc order anti-plat','G9609','3','','1','0','','','','0','1','0','0'),
('13368','Documentation of medical reason(s) in the patients record for not ordering anti-platelet agents','Doc md rsn no antipla','G9610','3','','1','0','','','','0','1','0','0'),
('13369','Order for anti-platelet agents was not documented in the patients record; reason not given','No doc order anti-plat rng','G9611','3','','1','0','','','','0','1','0','0'),
('13370','Photodocumentation of one or more cecal landmarks to establish a complete examination','Pho doc >1 cecal ldmk com ex','G9612','3','','1','0','','','','0','1','0','0'),
('13371','Documentation of post-surgical anatomy (e.g.; right hemicolectomy; ileocecal resection; etc.)','Doc post surg anatomy','G9613','3','','1','0','','','','0','1','0','0'),
('13372','No photodocumentation of cecal landmarks to establish a complete examination','No photodoc cecal ldmk exam','G9614','3','','1','0','','','','0','1','0','0'),
('13373','Preoperative assessment documented','Pre-op asst doc','G9615','3','','1','0','','','','0','1','0','0'),
('13374','Documentation of reason(s) for not documenting a preoperative assessment (e.g.; patient with a gynecologic or other pelvic malignancy noted at the time of surgery)','Doc rsn no preop assmt','G9616','3','','1','0','','','','0','1','0','0'),
('13375','Preoperative assessment not documented; reason not given','Pre-op asst not doc; rng','G9617','3','','1','0','','','','0','1','0','0'),
('13376','Documentation of screening for uterine malignancy or those that had an ultrasound and/or endometrial sampling of any kind','Doc scr uter mal or us/samp','G9618','3','','1','0','','','','0','1','0','0'),
('13377','Documentation of reason(s) for not screening for uterine malignancy (e.g.; prior hysterectomy)','Doc rsn no scr uter malig','G9619','3','','1','0','','','','0','1','0','0'),
('13378','Patient not screened for uterine malignancy; or those that have not had an ultrasound and/or endometrial sampling of any kind; reason not given','No scr utr malig/us/samp rng','G9620','3','','1','0','','','','0','1','0','0'),
('13379','Patient identified as an unhealthy alcohol user when screened for unhealthy alcohol use using a systematic screening method and received brief counseling','Scr unheal etoh w/counsel','G9621','3','','1','0','','','','0','1','0','0'),
('13380','Patient not identified as an unhealthy alcohol user when screened for unhealthy alcohol use using a systematic screening method','No unheal etoh user','G9622','3','','1','0','','','','0','1','0','0'),
('13381','Documentation of medical reason(s) for not screening for unhealthy alcohol use (e.g.; limited life expectancy; other medical reasons)','Doc med rsn no scr etoh use','G9623','3','','1','0','','','','0','1','0','0'),
('13382','Patient not screened for unhealthy alcohol screening using a systematic screening method or patient did not receive brief counseling; reason not given','No etoh scr/no counc/nrg','G9624','3','','1','0','','','','0','1','0','0'),
('13383','Patient sustained bladder injury at the time of surgery or discovered subsequently up to 1 month post-surgery','Ptblad inj at surg/1mo post','G9625','3','','1','0','','','','0','1','0','0'),
('13384','Documented medical reason for not reporting bladder injury (e.g.; gynecologic or other pelvic malignancy documented; concurrent surgery involving bladder pathology; injury that occurs during urinary incontinence procedure; patient death from non-medical causes not related to surgery; patient died during procedure without evidence of bladder injury)','Med rsn no rpt baldder inj','G9626','3','','1','0','','','','0','1','0','0'),
('13385','Patient did not sustain bladder injury at the time of surgery nor discovered  subsequently up to 1 month post-surgery','No bld inj at surg/1 mo pos','G9627','3','','1','0','','','','0','1','0','0'),
('13386','Patient sustained bowel injury at the time of surgery or discovered subsequently up to 1 month post-surgery','Bowel inj at surg/1mos post','G9628','3','','1','0','','','','0','1','0','0'),
('13387','Documented medical reasons for not reporting bowel injury (e.g.; gynecologic or other pelvic malignancy documented; planned (e.g.; not due to an unexpected bowel injury) resection and/or re-anastomosis of bowel; or patient death from non-medical causes not related to surgery; patient died during procedure without evidence of bowel injury)','Med rsn no rpt bowel inj','G9629','3','','1','0','','','','0','1','0','0'),
('13388','Patient did not sustain a bowel injury at the time of surgery nor discovered subsequently up to 1 month post-surgery','No bow inj at surg/1mos post','G9630','3','','1','0','','','','0','1','0','0'),
('13389','Patient sustained ureter injury at the time of surgery or discovered subsequently up to 1 month post-surgery','Urtr inj at surg/1mos post','G9631','3','','1','0','','','','0','1','0','0'),
('13390','Documented medical reasons for not reporting ureter injury (e.g.; gynecologic or other pelvic malignancy documented; concurrent surgery involving bladder pathology; injury that occurs during a urinary incontinence procedure; patient death from non-medical causes not related to surgery; patient died during procedure without evidence of ureter injury)','Med rsn for no rpt uret inj','G9632','3','','1','0','','','','0','1','0','0'),
('13391','Patient did not sustain ureter injury at the time of surgery nor discovered subsequently up to 1 month post-surgery','No uret inj at surg/1mo post','G9633','3','','1','0','','','','0','1','0','0'),
('13392','Health-related quality of life assessed with tool during at least two visits and quality of life score remained the same or improved','Qual life tool 2x same/impr','G9634','3','','1','0','','','','0','1','0','0'),
('13393','Health-related quality of life not assessed with tool for documented reason(s) (e.g.; patient has a cognitive or neuropsychiatric impairment that impairs his/her ability to complete the hrqol survey; patient has the inability to read and/or write in order to complete the hrqol questionnaire)','No doc rsn do qual life assm','G9635','3','','1','0','','','','0','1','0','0'),
('13394','Health-related quality of life not assessed with tool during at least two visits or quality of life score declined','No life asst 2x same/decr','G9636','3','','1','0','','','','0','1','0','0'),
('13395','Final reports with documentation of one or more dose reduction techniques (e.g.; automated exposure control; adjustment of the ma and/or kv according to patient size; use of iterative reconstruction technique)','Doc >1 dose reduc tech','G9637','3','','1','0','','','','0','1','0','0'),
('13396','Final reports without documentation of one or more dose reduction techniques (e.g.; automated exposure control; adjustment of the ma and/or kv according to patient size; use of iterative reconstruction technique)','No doc >1 dose reduc tech','G9638','3','','1','0','','','','0','1','0','0'),
('13397','Major amputation or open surgical bypass not required within 48 hours of the index endovascular lower extremity revascularization procedure','Amp no reqd in48h ieler proc','G9639','3','','1','0','','','','0','1','0','0'),
('13398','Documentation of planned hybrid or staged procedure','Doc plan hybrid/stage proc','G9640','3','','1','0','','','','0','1','0','0'),
('13399','Major amputation or open surgical bypass required within 48 hours of the index endovascular lower extremity revascularization procedure','Amp reqd w/in 48h ieler proc','G9641','3','','1','0','','','','0','1','0','0'),
('13400','Current smokers (e.g.; cigarette; cigar; pipe; e-cigarette or marijuana)','Current smoker','G9642','3','','1','0','','','','0','1','0','0'),
('13401','Elective surgery','Elective surgery','G9643','3','','1','0','','','','0','1','0','0'),
('13402','Patients who abstained from smoking prior to anesthesia on the day of surgery or procedure','No smok b/4 anes day of surg','G9644','3','','1','0','','','','0','1','0','0'),
('13403','Patients who did not abstain from smoking prior to anesthesia on the day of surgery or procedure','Had smoke b/4 anes day surg','G9645','3','','1','0','','','','0','1','0','0'),
('13404','Patients with 90 day mrs score of 0 to 2','Pt w/90d mrs 0-2','G9646','3','','1','0','','','','0','1','0','0'),
('13405','Patients in whom mrs score could not be obtained at 90 day follow-up','No mrs score in 90d followup','G9647','3','','1','0','','','','0','1','0','0'),
('13406','Patients with 90 day mrs score greater than 2','Pt w/90d mrs >2','G9648','3','','1','0','','','','0','1','0','0'),
('13407','Psoriasis assessment tool documented meeting any one of the specified benchmarks (e.g.; (pga; 6-point scale); body surface area (bsa); psoriasis area and severity index (pasi) and/or dermatology life quality index) (dlqi))','Psori tool doc w/benchmk','G9649','3','','1','0','','','','0','1','0','0'),
('13408','Documentation that the patient declined therapy change or has documented contraindications (e.g.; experienced adverse effects or lack of efficacy with all other therapy options) in order to achieve better disease control as measured by pga; bsa; pasi; or dlqi','Doc pt no ther chg or contra','G9650','3','','1','0','','','','0','1','0','0'),
('13409','Psoriasis assessment tool documented not meeting any one of the specified benchmarks (e.g.; (pga; 6-point scale); body surface area (bsa); psoriasis area and severity index (pasi) and/or dermatology life quality index) (dlqi)) or psoriasis assessment tool not documented','Psori tool doc/no bnchmk met','G9651','3','','1','0','','','','0','1','0','0'),
('13410','Patient has been treated with a systemic or biologic medication for psoriasis for at least six months','Pt tx sys bio med psori 6mth','G9652','3','','1','0','','','','0','1','0','0'),
('13411','Patient has not been treated with a systemic or biologic medication for psoriasis for at least six months','Pt no tx sys bio rx 6 mths','G9653','3','','1','0','','','','0','1','0','0'),
('13412','Monitored anesthesia care (mac)','Mon anesth care','G9654','3','','1','0','','','','0','1','0','0'),
('13413','A transfer of care protocol or handoff tool/checklist that includes the required key handoff elements is used','Toc tool incl key elem','G9655','3','','1','0','','','','0','1','0','0'),
('13414','Patient transferred directly from anesthetizing location to pacu','Pt direct anesth loc to pacu','G9656','3','','1','0','','','','0','1','0','0'),
('13415','Transfer of care during an anesthetic or to the intensive care unit','Toc dur aneth to icu','G9657','3','','1','0','','','','0','1','0','0'),
('13416','A transfer of care protocol or handoff tool/checklist that includes the required key handoff elements is not used','Toc tool incl elem not used','G9658','3','','1','0','','','','0','1','0','0'),
('13417','Patients greater than 85 years of age who did not have a history of colorectal cancer or valid medical reason for the colonoscopy; including: iron deficiency anemia; lower gastrointestinal bleeding; crohns disease (i.e.; regional enteritis); familial adenomatous polyposis; lynch syndrome (i.e.; hereditary non-polyposis colorectal cancer); inflammatory bowel disease; ulcerative colitis; abnormal finding of gastrointestinal tract; or changes in bowel habits','>85y no hx colo ca/rsn scope','G9659','3','','1','0','','','','0','1','0','0'),
('13418','Documentation of medical reason(s) for a colonoscopy performed on a patient greater than 85 years of age (e.g.; last colonoscopy incomplete; last colonoscopy had inadequate prep; iron deficiency anemia; lower gastrointestinal bleeding; crohns disease (i.e.; regional enteritis); familial history of adenomatous polyposis; lynch syndrome (i.e.; hereditary non-polyposis colorectal cancer); inflammatory bowel disease; ulcerative colitis; abnormal finding of gastrointestinal tract; or changes in bowel habits)','Doc med rsn scope pt >85y','G9660','3','','1','0','','','','0','1','0','0'),
('13419','Patients greater than 85 years of age who received a routine colonoscopy for a reason other than the following: an assessment of signs/symptoms of gi tract illness; and/or the patient is considered high risk; and/or to follow-up on previously diagnosed advance lesions','>85y scope othr rsn','G9661','3','','1','0','','','','0','1','0','0'),
('13420','Previously diagnosed or have an active diagnosis of clinical ascvd','Prior dx/active clin ascvd','G9662','3','','1','0','','','','0','1','0','0'),
('13421','Any fasting or direct ldl-c laboratory test result = 190 mg/dl','Fast/dir ldl = 190 mg/dl','G9663','3','','1','0','','','','0','1','0','0'),
('13422','Patients who are currently statin therapy users or received an order (prescription) for statin therapy','Taking statin or recd order','G9664','3','','1','0','','','','0','1','0','0'),
('13423','Patients who are not currently statin therapy users or did not receive an order (prescription) for statin therapy','No statin/no order statin','G9665','3','','1','0','','','','0','1','0','0'),
('13424','The highest fasting or direct ldl-c laboratory test result of 70-189 mg/dl in the measurement period or two years prior to the beginning of the measurement period','Fas/dir ldl 70-189mg/dl mst','G9666','3','','1','0','','','','0','1','0','0'),
('13425','Documentation of medical reason(s) for not currently being a statin   therapy user or receive an order (prescription) for statin therapy (e.g.; patient with adverse effect; allergy or intolerance to statin medication therapy; patients who have an active diagnosis of pregnancy or who are breastfeeding; patients who are receiving palliative care; patients with active liver disease or hepatic disease or insufficiency; patients with end stage renal disease (esrd); and patients with diabetes who have a fasting or direct ldl-c laboratory test result < 70 mg/dl and are not taking statin therapy)','Doc med rsn no stat tx/presc','G9667','3','','1','0','','','','0','1','0','0'),
('13426','I intend to report the multiple chronic conditions measures group','Intend rpt mult chr msr grp','G9669','3','','1','0','','','','0','1','0','0'),
('13427','All quality actions for the applicable measures in the multiple chronic conditions measures group have been performed for this patient','Qty act mcc mg perf','G9670','3','','1','0','','','','0','1','0','0'),
('13428','I intend to report the diabetic retinopathy measures group','Intend rpt dia retin msr grp','G9671','3','','1','0','','','','0','1','0','0'),
('13429','All quality actions for the applicable measures in the diabetic retinopathy measures group have been performed for this patient','Qty act diab retin mg perf','G9672','3','','1','0','','','','0','1','0','0'),
('13430','I intend to report the cardiovascular prevention measures group','Intend rpt card prev msr grp','G9673','3','','1','0','','','','0','1','0','0'),
('13431','Patients with clinical ascvd diagnosis','Pt w/clin ascvd dx','G9674','3','','1','0','','','','0','1','0','0'),
('13432','Patients who have ever had a fasting or direct laboratory result of ldl-c = 190 mg/dl','Pt w/fast/dir lab ldl-c >190','G9675','3','','1','0','','','','0','1','0','0'),
('13433','Patients aged 40 to 75 years at the beginning of the measurement period with type 1 or type 2 diabetes and with an ldl-c result of 70?189 mg/dl recorded as the highest fasting or direct laboratory test result in the measurement year or during the two years prior to the beginning of the measurement period','40-75y w/type 1/2 w/ldl-c rs','G9676','3','','1','0','','','','0','1','0','0'),
('13434','All quality actions for the applicable measures in the cardiovascular prevention measures group have been performed for this patient','Qty act card prev mg perf','G9677','3','','1','0','','','','0','1','0','0'),
('13435','Oncology care model (ocm) monthly enhanced oncology services (meos) payment for  ocm enhanced services.  g9678 payments may only be made to ocm practitioners for ocm beneficiaries for the furnishment of enhanced services as defined in the ocm participation agreement','Oncology care model service','G9678','3','','1','0','','','','0','1','0','0'),
('13436','This code is for onsite acute care treatment of a nursing facility resident with pneumonia; may only be billed once per day per beneficiary','Acute care pneumonia','G9679','3','','1','0','','','','0','1','0','0'),
('13437','This code is for onsite acute care treatment of a nursing facility resident with chf; may only be billed once per day per beneficiary','Acute care congestive heart','G9680','3','','1','0','','','','0','1','0','0'),
('13438','This code is for onsite acute care treatment of a resident with copd or asthma; may only be billed once per day per beneficiary','Acute care chronic obstruct','G9681','3','','1','0','','','','0','1','0','0'),
('13439','This code is for the onsite acute care treatment a nursing facility resident with a skin infection; may only be billed once per day per beneficiary','Acute care skin infection','G9682','3','','1','0','','','','0','1','0','0'),
('13440','This code is for the onsite acute care treatment of a nursing facility resident with fluid or electrolyte disorder or dehydration (similar pattern); may only be billed once per day per beneficiary','Acute care fluid or electrol','G9683','3','','1','0','','','','0','1','0','0'),
('13441','This code is for the onsite acute care treatment of a nursing facility resident for a uti; may only be billed once per day per beneficiary','Acute care urinary tract inf','G9684','3','','1','0','','','','0','1','0','0'),
('13442','This code is for the evaluation and management of a beneficiarys acute change in condition in a nursing facility','Acute nursing facility care','G9685','3','','1','0','','','','0','1','0','0'),
('13443','Onsite nursing facility conference; that is separate and distinct from an evaluation and management visit; including qualified practitioner and at least one member of the nursing facility interdisciplinary care team','Nursing facility conference','G9686','3','','1','0','','','','0','1','0','0'),
('13444','Hospice services provided to patient any time during the measurement period','Hospice anytime msmt per','G9687','3','','1','0','','','','0','1','0','0'),
('13445','Patients using hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9688','3','','1','0','','','','0','1','0','0'),
('13446','Patient admitted for performance of elective carotid intervention','Inpt elect carotid intervent','G9689','3','','1','0','','','','0','1','0','0'),
('13447','Patient receiving hospice services any time during the measurement period','Pt rec hospice dur msmt per','G9690','3','','1','0','','','','0','1','0','0'),
('13448','Patient had hospice services any time during the measurement period','Pt hosp dur msmt period','G9691','3','','1','0','','','','0','1','0','0'),
('13449','Hospice services received by patient any time during the measurement period','Hosp recd by pt dur msmt per','G9692','3','','1','0','','','','0','1','0','0'),
('13450','Patient use of hospice services any time during the measurement period','Pt use hosp during msmt per','G9693','3','','1','0','','','','0','1','0','0'),
('13451','Hospice services utilized by patient any time during the measurement period','Hosp srv used pt in msmt per','G9694','3','','1','0','','','','0','1','0','0'),
('13452','Long-acting inhaled bronchodilator prescribed','Long act inhal bronchdil pre','G9695','3','','1','0','','','','0','1','0','0'),
('13453','Documentation of medical reason(s) for not prescribing a long-acting inhaled bronchodilator','Med rsn no presc bronchdil','G9696','3','','1','0','','','','0','1','0','0'),
('13454','Documentation of patient reason(s) for not prescribing a long-acting inhaled bronchodilator','Pt rsn no presc bronchdil','G9697','3','','1','0','','','','0','1','0','0'),
('13455','Documentation of system reason(s) for not prescribing a long-acting inhaled bronchodilator','Sys rsn no presc bronchdil','G9698','3','','1','0','','','','0','1','0','0'),
('13456','Long-acting inhaled bronchodilator not prescribed; reason not otherwise specified','Long inhal bronchdil no pres','G9699','3','','1','0','','','','0','1','0','0'),
('13457','Patients who use hospice services any time during the measurement period','Pt is w/hosp during msmt per','G9700','3','','1','0','','','','0','1','0','0'),
('13458','Children who are taking antibiotics in the 30 days prior to the date of the encounter during which the diagnosis was established','Child anbx 30 prior dx estab','G9701','3','','1','0','','','','0','1','0','0'),
('13459','Patients who use hospice services any time during the measurement period','Pt use hosp during msmt per','G9702','3','','1','0','','','','0','1','0','0'),
('13460','Children who are taking antibiotics in the 30 days prior to the  diagnosis of pharyngitis','Child anbx 30 prior dx phary','G9703','3','','1','0','','','','0','1','0','0'),
('13461','Ajcc breast cancer stage i: t1 mic or t1a documented','Ajcc br ca stg i: t1 mic/t1a','G9704','3','','1','0','','','','0','1','0','0'),
('13462','Ajcc breast cancer stage i: t1b (tumor > 0.5 cm but <= 1 cm in greatest dimension) documented','Ajcc br ca stg ib','G9705','3','','1','0','','','','0','1','0','0'),
('13463','Low (or very low) risk of recurrence; prostate cancer','Low recur prost ca','G9706','3','','1','0','','','','0','1','0','0'),
('13464','Patient received hospice services any time during the measurement period','Pt had hosp dur msmt per','G9707','3','','1','0','','','','0','1','0','0'),
('13465','Women who had a bilateral mastectomy or who have a history of a bilateral mastectomy or for whom there is evidence of a right and a left unilateral mastectomy','Bilat mast/hx bi /unilat mas','G9708','3','','1','0','','','','0','1','0','0'),
('13466','Hospice services used by patient any time during the measurement period','Hosp srv used pt in msmt per','G9709','3','','1','0','','','','0','1','0','0'),
('13467','Patient was provided hospice services any time during the measurement period','Pt prov hosp srv msmt per','G9710','3','','1','0','','','','0','1','0','0'),
('13468','Patients with a diagnosis or past history of total colectomy or colorectal cancer','Pt hx tot col or colon ca','G9711','3','','1','0','','','','0','1','0','0'),
('13469','Documentation of medical reason(s) for prescribing or dispensing antibiotic (e.g.; intestinal   infection; pertussis; bacterial infection; lyme disease; otitis media; acute sinusitis; acute pharyngitis; acute tonsillitis; chronic sinusitis; infection of the pharynx/larynx/tonsils/adenoids; prostatitis; cellulitis/ mastoiditis/bone infections; acute lymphadenitis; impetigo; skin staph infections; pneumonia; gonococcal infections/venereal disease (syphilis; chlamydia; inflammatory diseases [female reproductive organs]); infections of the kidney; cystitis/uti; acne; hiv disease/asymptomatic hiv; cystic fibrosis; disorders of the immune system; malignancy neoplasms; chronic bronchitis; emphysema; bronchiectasis; extrinsic allergic alveolitis; chronic airway obstruction; chronic obstructive asthma; pneumoconiosis and other lung disease due to external agents; other diseases of the respiratory system; and tuberculosis','Doc med rsn presc anbx','G9712','3','','1','0','','','','0','1','0','0'),
('13470','Patients who use hospice services any time during the measurement period','Pt use hosp during msmt per','G9713','3','','1','0','','','','0','1','0','0'),
('13471','Patient is using hospice services any time during the measurement period','Pt is w/hosp during msmt per','G9714','3','','1','0','','','','0','1','0','0'),
('13472','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9715','3','','1','0','','','','0','1','0','0'),
('13473','Bmi is documented as being outside of normal limits; follow-up plan is not completed for documented reason','Bmi not norm; no follow; doc','G9716','3','','1','0','','','','0','1','0','0'),
('13474','Documentation stating the patient has an active diagnosis of depression or has a diagnosed bipolar disorder; therefore screening or follow-up not required','Doc dx depr/dx bipol; no scr','G9717','3','','1','0','','','','0','1','0','0'),
('13475','Hospice services for patient provided any time during the measurement period','Hospice anytime msmt per','G9718','3','','1','0','','','','0','1','0','0'),
('13476','Patient is not ambulatory; bed ridden; immobile; confined to chair; wheelchair bound; dependent on helper pushing wheelchair; independent in wheelchair or minimal help in wheelchair','Pt not ambul/immob/wc','G9719','3','','1','0','','','','0','1','0','0'),
('13477','Hospice services for patient occurred any time during the measurement period','Hospice anytime msmt per','G9720','3','','1','0','','','','0','1','0','0'),
('13478','Patient not ambulatory; bed ridden; immobile; confined to chair; wheelchair bound; dependent on helper pushing wheelchair; independent in wheelchair or minimal help in wheelchair','Pt not ambul/immob/wc','G9721','3','','1','0','','','','0','1','0','0'),
('13479','Documented history of renal failure or baseline serum creatinine = 4.0 mg/dl; renal transplant recipients are not considered to have preoperative renal failure; unless; since transplantation the cr has been or is 4.0 or higher','Doc hx renal fail or cr+ >4','G9722','3','','1','0','','','','0','1','0','0'),
('13480','Hospice services for patient received any time during the measurement period','Hosp recd by pt dur msmt per','G9723','3','','1','0','','','','0','1','0','0'),
('13481','Patients who had documentation of use of anticoagulant medications overlapping the measurement year','Pt w/doc use anticoag mst yr','G9724','3','','1','0','','','','0','1','0','0'),
('13482','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9725','3','','1','0','','','','0','1','0','0'),
('13483','Patient refused to participate','Refused to participate','G9726','3','','1','0','','','','0','1','0','0'),
('13484','Patient unable to complete the foto knee intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','No knee intake prom; no prox','G9727','3','','1','0','','','','0','1','0','0'),
('13485','Patient refused to participate','Refused to participate','G9728','3','','1','0','','','','0','1','0','0'),
('13486','Patient unable to complete the foto hip intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','No hip intake prom; no proxy','G9729','3','','1','0','','','','0','1','0','0'),
('13487','Patient refused to participate','Refused to participate','G9730','3','','1','0','','','','0','1','0','0'),
('13488','Patient unable to complete the foto foot or ankle intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','No foot prom; no proxy','G9731','3','','1','0','','','','0','1','0','0'),
('13489','Patient refused to participate','Refused to participate','G9732','3','','1','0','','','','0','1','0','0'),
('13490','Patient unable to complete the foto lumbar intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','No back intake prom; no prox','G9733','3','','1','0','','','','0','1','0','0'),
('13491','Patient refused to participate','Refused to participate','G9734','3','','1','0','','','','0','1','0','0'),
('13492','Patient unable to complete the foto shoulder intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','Pt no foto knee and no proxy','G9735','3','','1','0','','','','0','1','0','0'),
('13493','Patient refused to participate','Refused to participate','G9736','3','','1','0','','','','0','1','0','0'),
('13494','Patient unable to complete the foto elbow; wrist or hand intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','Pt no foto elbow; no proxy','G9737','3','','1','0','','','','0','1','0','0'),
('13495','Patient refused to participate','Refused to participate','G9738','3','','1','0','','','','0','1','0','0'),
('13496','Patient unable to complete the foto general orthopedic intake prom at admission and discharge due to blindness; illiteracy; severe mental incapacity or language incompatibility and an adequate proxy is not available','Pt no foto orth; no proxy','G9739','3','','1','0','','','','0','1','0','0'),
('13497','Hospice services given to patient any time during the measurement period','Hosp srv to pt dur msmt per','G9740','3','','1','0','','','','0','1','0','0'),
('13498','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9741','3','','1','0','','','','0','1','0','0'),
('13499','Psychiatric symptoms assessed','Psych sympt assessed','G9742','3','','1','0','','','','0','1','0','0'),
('13500','Psychiatric symptoms not assessed; reason not otherwise specified','Psych symp not assessed; rns','G9743','3','','1','0','','','','0','1','0','0'),
('13501','Patient not eligible due to active diagnosis of hypertension','Pt not elig; dx htn','G9744','3','','1','0','','','','0','1','0','0'),
('13502','Documented reason for not screening or recommending a follow-up for high blood pressure','Doc rsn no scr high bp','G9745','3','','1','0','','','','0','1','0','0'),
('13503','Patient has mitral stenosis or prosthetic heart valves or patient has transient or reversible cause of af (e.g.; pneumonia; hyperthyroidism; pregnancy; cardiac surgery)','Mit sten; valve or trans af','G9746','3','','1','0','','','','0','1','0','0'),
('13504','Patient is undergoing palliative dialysis with a catheter','Pall dialysis with catheter','G9747','3','','1','0','','','','0','1','0','0'),
('13505','Patient approved by a qualified transplant program and scheduled to receive a living donor kidney transplant','App transpl lvg kidney donor','G9748','3','','1','0','','','','0','1','0','0'),
('13506','Patient is undergoing palliative dialysis with a catheter','Pall dialysis with catheter','G9749','3','','1','0','','','','0','1','0','0'),
('13507','Patient approved by a qualified transplant program and scheduled to receive a living donor kidney transplant','App transpl lvg kidney donor','G9750','3','','1','0','','','','0','1','0','0'),
('13508','Patient died at any time during the 24-month measurement period','Pt died w/in 24 mos rpt time','G9751','3','','1','0','','','','0','1','0','0'),
('13509','Emergency surgery','Urgent surgery','G9752','3','','1','0','','','','0','1','0','0'),
('13510','Documentation of medical reason for not conducting a search for dicom format images for prior patient ct imaging studies completed at non-affiliated external healthcare facilities or entities within the past 12 months that are available through a secure; authorized; media-free; shared archive (e.g.; trauma; acute myocardial infarction; stroke; aortic aneurysm where time is of the essence)','Doc no dicom; ct other fac','G9753','3','','1','0','','','','0','1','0','0'),
('13511','A finding of an incidental pulmonary nodule','Incid pulm nodule','G9754','3','','1','0','','','','0','1','0','0'),
('13512','Documentation of medical reason(s) that follow-up imaging is indicated (e.g.; patient has a known malignancy that can metastasize; other medical reason(s)','Doc med rsn for imaging','G9755','3','','1','0','','','','0','1','0','0'),
('13513','Surgical procedures that included the use of silicone oil','Surg proc w/silicone oil','G9756','3','','1','0','','','','0','1','0','0'),
('13514','Surgical procedures that included the use of silicone oil','Surg proc w/silicone oil','G9757','3','','1','0','','','','0','1','0','0'),
('13515','Patient in hospice and in terminal phase','Hospice or term phase','G9758','3','','1','0','','','','0','1','0','0'),
('13516','History of preoperative posterior capsule rupture','Hx preop post cap rup','G9759','3','','1','0','','','','0','1','0','0'),
('13517','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9760','3','','1','0','','','','0','1','0','0'),
('13518','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9761','3','','1','0','','','','0','1','0','0'),
('13519','Patient had at least three hpv vaccines on or between the patients 9th and 13th birthdays','Pt had hpv b/t 9-13 yr','G9762','3','','1','0','','','','0','1','0','0'),
('13520','Patient did not have at least three hpv vaccines on or between the patients 9th and 13th birthdays','Pt no hpv b/t 9-13 yr','G9763','3','','1','0','','','','0','1','0','0'),
('13521','Patient has been treated with an oral systemic or biologic medication for psoriasis','Pt tx oral syst/bio med psor','G9764','3','','1','0','','','','0','1','0','0'),
('13522','Documentation that the patient declined therapy change; has documented contraindications; or has not been treated with an oral systemic or biologic for at least six consecutive months (e.g.; experienced adverse effects or lack of efficacy with all other therapy options) in order to achieve better disease control as measured by pga; bsa; pasi; or dlqi','Pt decl chan/conind or <6m','G9765','3','','1','0','','','','0','1','0','0'),
('13523','Patients who are transferred from one institution to another with a known diagnosis of cva for endovascular stroke treatment','Cva stroke dx tx transf fac','G9766','3','','1','0','','','','0','1','0','0'),
('13524','Hospitalized patients with newly diagnosed cva considered for endovascular stroke treatment','Hosp new dx cva consid evst','G9767','3','','1','0','','','','0','1','0','0'),
('13525','Patients who utilize hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9768','3','','1','0','','','','0','1','0','0'),
('13526','Patient had a bone mineral density test in the past two years or received osteoporosis medication or therapy in the past 12 months','Bn den 2yr/got ost med/ther','G9769','3','','1','0','','','','0','1','0','0'),
('13527','Peripheral nerve block (pnb)','Perip nerve block','G9770','3','','1','0','','','','0','1','0','0'),
('13528','At least 1 body temperature measurement equal to or greater than 35.5 degrees celsius (or 95.9 degrees fahrenheit) achieved within the 30 minutes immediately before or the 15 minutes immediately after anesthesia end time','Anes end; 1 temp >35.5(95.9)','G9771','3','','1','0','','','','0','1','0','0'),
('13529','Documentation of one of the following medical reason(s) for not achieving at least 1 body temperature measurement equal to or greater than 35.5 degrees celsius (or 95.9 degrees fahrenheit) achieved within the 30 minutes immediately before or the 15 minutes immediately after anesthesia end time (e.g.; emergency cases; intentional hypothermia; etc.)','Doc temp >35.5(95.9); anest','G9772','3','','1','0','','','','0','1','0','0'),
('13530','At least 1 body temperature measurement equal to or greater than 35.5 degrees celsius (or 95.9 degrees fahrenheit) not achieved within the 30 minutes immediately before or the 15 minutes immediately after anesthesia end time','No temp >35.5(95.9); anes','G9773','3','','1','0','','','','0','1','0','0'),
('13531','Patients who have had a hysterectomy','Pt had hyst','G9774','3','','1','0','','','','0','1','0','0'),
('13532','Patient received at least 2 prophylactic pharmacologic anti-emetic agents of different classes preoperatively and/or intraoperatively','Recd 2 anti-emet pre/intraop','G9775','3','','1','0','','','','0','1','0','0'),
('13533','Documentation of medical reason for not receiving at least 2 prophylactic pharmacologic anti-emetic agents of different classes preoperatively and/or intraoperatively  (e.g.; intolerance or other medical reason)','Doc med rsn no proph antiem','G9776','3','','1','0','','','','0','1','0','0'),
('13534','Patient did not receive at least 2 prophylactic pharmacologic anti-emetic agents of different classes preoperatively and/or intraoperatively','Pt no antiemet pre/intraop','G9777','3','','1','0','','','','0','1','0','0'),
('13535','Patients who have a diagnosis of pregnancy','Pts dx w/pregn','G9778','3','','1','0','','','','0','1','0','0'),
('13536','Patients who are breastfeeding','Pts breastfeeding','G9779','3','','1','0','','','','0','1','0','0'),
('13537','Patients who have a diagnosis of rhabdomyolysis','Pts dx w/rhabdomyolysis','G9780','3','','1','0','','','','0','1','0','0'),
('13538','Documentation of medical reason(s) for not currently being a statin therapy user or receive an order (prescription) for statin therapy (e.g.; patient with adverse effect; allergy or intolerance to statin medication therapy; patients who are receiving palliative care; patients with active liver disease or hepatic disease or insufficiency; and patients with end stage renal disease (esrd))','Doc rsn no statin','G9781','3','','1','0','','','','0','1','0','0'),
('13539','History of or active diagnosis of familial or pure hypercholesterolemia','Hx dx fam/pure hypercholes','G9782','3','','1','0','','','','0','1','0','0'),
('13540','Documentation of patients with diabetes who have a most recent fasting or direct ldl- c laboratory test result < 70 mg/dl and are not taking statin therapy','Doc dx dm; fast <70; no stat','G9783','3','','1','0','','','','0','1','0','0'),
('13541','Pathologists/dermatopathologists providing a second opinion on a biopsy','Path/derm 2nd opin bx','G9784','3','','1','0','','','','0','1','0','0'),
('13542','Pathology report diagnosing cutaneous basal cell carcinoma or squamous cell carcinoma (to include in situ disease) sent from the pathologist/dermatopathologist to the biopsying clinician for review within 7 business days from the time when the tissue specimen was received by the pathologist','Path rpt snt path/derm in 7d','G9785','3','','1','0','','','','0','1','0','0'),
('13543','Pathology report diagnosing cutaneous basal cell carcinoma or squamous cell carcinoma (to include in situ disease) was not sent from the pathologist/dermatopathologist to the biopsying clinician for review within 7 business days from the time when the tissue specimen was received by the pathologist','No path rpt sent in 7d','G9786','3','','1','0','','','','0','1','0','0'),
('13544','Patient alive as of the last day of the measurement year','Pt alive lst day msmt yr','G9787','3','','1','0','','','','0','1','0','0'),
('13545','Most recent bp is less than or equal to 140/90 mm hg','Most rct bp </= 140/90','G9788','3','','1','0','','','','0','1','0','0'),
('13546','Blood pressure recorded during inpatient stays; emergency room visits; urgent care visits; and patient self-reported bps (home and health fair bp results)','Record bp ip; er; urg/self','G9789','3','','1','0','','','','0','1','0','0'),
('13547','Most recent bp is greater than 140/90 mm hg; or blood pressure not documented','Most rct bp >/= 140/90','G9790','3','','1','0','','','','0','1','0','0'),
('13548','Most recent tobacco status is tobacco free','Most rct tob stat free','G9791','3','','1','0','','','','0','1','0','0'),
('13549','Most recent tobacco status is not tobacco free','Most rct tob stat not free','G9792','3','','1','0','','','','0','1','0','0'),
('13550','Patient is currently on a daily aspirin or other antiplatelet','Pt on daily asa/antiplat','G9793','3','','1','0','','','','0','1','0','0'),
('13551','Documentation of medical reason(s) for not on a daily aspirin or other antiplatelet (e.g. history of gastrointestinal bleed or intra-cranial bleed or documentation of active anticoagulant use during the measurement period','Doc med rsn no asa/antiplat','G9794','3','','1','0','','','','0','1','0','0'),
('13552','Patient is not currently on a daily aspirin or other antiplatelet','Pt no daily asa/antiplat','G9795','3','','1','0','','','','0','1','0','0'),
('13553','Patient is currently on a statin therapy','Pt not currently on statin','G9796','3','','1','0','','','','0','1','0','0'),
('13554','Patient is not on a statin therapy','Pt currently on statin','G9797','3','','1','0','','','','0','1','0','0'),
('13555','Discharge(s) for ami between july 1 of the year prior measurement year to june 30 of the measurement period','D/c ami btw 7/1-6/30 mst per','G9798','3','','1','0','','','','0','1','0','0'),
('13556','Patients with a medication dispensing event indicator of a history of asthma any time during the patients history through the end of the measure period','Med disp evt indic hx asth','G9799','3','','1','0','','','','0','1','0','0'),
('13557','Patients who are identified as having an intolerance or allergy to beta-blocker therapy','Pt id intol/alleg beta-block','G9800','3','','1','0','','','','0','1','0','0'),
('13558','Hospitalizations in which the patient was transferred directly to a non-acute care facility for any diagnosis`','Nonacut transf from inpt','G9801','3','','1','0','','','','0','1','0','0'),
('13559','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9802','3','','1','0','','','','0','1','0','0'),
('13560','Patient prescribed a 180-day course of treatment with beta-blockers post discharge for ami','Post d/c 180d tx beta-bl ami','G9803','3','','1','0','','','','0','1','0','0'),
('13561','Patient was not prescribed a 180-day course of treatment with beta-blockers post discharge for ami','No post d/c 180d tx bb ami','G9804','3','','1','0','','','','0','1','0','0'),
('13562','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9805','3','','1','0','','','','0','1','0','0'),
('13563','Patients who received cervical cytology or an hpv test','Pt recd cerv cyto/hpv','G9806','3','','1','0','','','','0','1','0','0'),
('13564','Patients who did not receive cervical cytology or an hpv test','Pt no recd cerv cyto/hpv','G9807','3','','1','0','','','','0','1','0','0'),
('13565','Any patients who had no asthma controller medications dispensed during the measurement year','Pt no asthm cont med mst per','G9808','3','','1','0','','','','0','1','0','0'),
('13566','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9809','3','','1','0','','','','0','1','0','0'),
('13567','Patient achieved a pdc of at least 75% for their asthma controller medication','Pdc 75% w/asth cont med','G9810','3','','1','0','','','','0','1','0','0'),
('13568','Patient did not achieve a pdc of at least 75% for their asthma controller medication','No pdc 75% w/asth cont med','G9811','3','','1','0','','','','0','1','0','0'),
('13569','Patient died including all deaths occurring during the hospitalization in which the operation was performed; even if after 30 days; and those deaths occurring after discharge from the hospital; but within 30 days of the procedure','Pt died during inpt/30d aft','G9812','3','','1','0','','','','0','1','0','0'),
('13570','Patient did not die within 30 days of the procedure or during the index hospitalization','Pt not died w/in 30d of proc','G9813','3','','1','0','','','','0','1','0','0'),
('13571','Death occurring during hospitalization','Death occ dur hospitaliz','G9814','3','','1','0','','','','0','1','0','0'),
('13572','Death did not occur during hospitalization','No death occ dur hospitaliz','G9815','3','','1','0','','','','0','1','0','0'),
('13573','Death occurring 30 days post procedure','Death occ 30d post proc','G9816','3','','1','0','','','','0','1','0','0'),
('13574','Death did not occur 30 days post procedure','No death occ 30d post proc','G9817','3','','1','0','','','','0','1','0','0'),
('13575','Documentation of sexual activity','Doc sex activity','G9818','3','','1','0','','','','0','1','0','0'),
('13576','Patients who use hospice services any time during the measurement period','Pt w/hosp anytime msmt per','G9819','3','','1','0','','','','0','1','0','0'),
('13577','Documentation of a chlamydia screening test with proper follow-up','Doc chlam scr test w/follow','G9820','3','','1','0','','','','0','1','0','0'),
('13578','No documentation of a chlamydia screening test with proper follow-up','No doc chlam scr ts w/follow','G9821','3','','1','0','','','','0','1','0','0'),
('13579','Women who had an endometrial ablation procedure during the year prior to the index date (exclusive of the index date)','Endo abl proc yr prev ind dt','G9822','3','','1','0','','','','0','1','0','0'),
('13580','Endometrial sampling or hysteroscopy with biopsy and results documented','Endo smpl/hyst bx res doc','G9823','3','','1','0','','','','0','1','0','0'),
('13581','Endometrial sampling or hysteroscopy with biopsy and results not documented','Endo smpl/hyst bx res no doc','G9824','3','','1','0','','','','0','1','0','0'),
('13582','Her-2/neu negative or undocumented/unknown','Her-2 neg;undoc/unkn','G9825','3','','1','0','','','','0','1','0','0'),
('13583','Patient transferred to practice after initiation of chemotherapy','Transf pract aft init chemo','G9826','3','','1','0','','','','0','1','0','0'),
('13584','Her2-targeted therapies not administered during the initial course of treatment','Her-2 targ ther no init tx','G9827','3','','1','0','','','','0','1','0','0'),
('13585','Her2-targeted therapies administered during the initial course of treatment','Her-2 targ ther dur init tx','G9828','3','','1','0','','','','0','1','0','0'),
('13586','Breast adjuvant chemotherapy administered','Breast adj chemo admin','G9829','3','','1','0','','','','0','1','0','0'),
('13587','Her-2/neu positive','Her-2 pos','G9830','3','','1','0','','','','0','1','0','0'),
('13588','Ajcc stage at breast cancer diagnosis = ii or iii','Ajcc stg brt ca dx ii or iii','G9831','3','','1','0','','','','0','1','0','0'),
('13589','Ajcc stage at breast cancer diagnosis = i (ia or ib) and t-stage at breast cancer diagnosis does not equal = t1; t1a; t1b','Brt ca dx i; no t1/t1a/t1b','G9832','3','','1','0','','','','0','1','0','0'),
('13590','Patient transfer to practice after initiation of chemotherapy','Transf pract aft init chemo','G9833','3','','1','0','','','','0','1','0','0'),
('13591','Patient has metastatic disease at diagnosis','Pt met dis at dx','G9834','3','','1','0','','','','0','1','0','0'),
('13592','Trastuzumab administered within 12 months of diagnosis','Trastuz given w/in 12 mos dx','G9835','3','','1','0','','','','0','1','0','0'),
('13593','Reason for not administering trastuzumab documented (e.g. patient declined; patient died; patient transferred; contraindication or other clinical exclusion; neoadjuvant chemotherapy or radiation not complete)','Rsn no trast given doc','G9836','3','','1','0','','','','0','1','0','0'),
('13594','Trastuzumab not administered within 12 months of diagnosis','Trastuz not in 12 mos dx','G9837','3','','1','0','','','','0','1','0','0'),
('13595','Patient has metastatic disease at diagnosis','Pt met dis at dx','G9838','3','','1','0','','','','0','1','0','0'),
('13596','Anti-egfr monoclonal antibody therapy','Anti-egfr mon anti ther','G9839','3','','1','0','','','','0','1','0','0'),
('13597','Kras gene mutation testing performed before initiation of anti-egfr moab','Kras tst bfr beg anti moab','G9840','3','','1','0','','','','0','1','0','0'),
('13598','Kras gene mutation testing not performed before initiation of anti-egfr moab','No kras tst bfr beg ant moab','G9841','3','','1','0','','','','0','1','0','0'),
('13599','Patient has metastatic disease at diagnosis','Pt met dis at dx','G9842','3','','1','0','','','','0','1','0','0'),
('13600','Kras gene mutation','Kras gene mut','G9843','3','','1','0','','','','0','1','0','0'),
('13601','Patient did not receive anti-egfr monoclonal antibody therapy','Pt no recd anti-egfr ther','G9844','3','','1','0','','','','0','1','0','0'),
('13602','Patient received anti-egfr monoclonal antibody therapy','Pt recd anti-egfr ther','G9845','3','','1','0','','','','0','1','0','0'),
('13603','Patients who died from cancer','Pt died from cancer','G9846','3','','1','0','','','','0','1','0','0'),
('13604','Patient received chemotherapy in the last 14 days of life','Pt recd chemo last 14d life','G9847','3','','1','0','','','','0','1','0','0'),
('13605','Patient did not receive chemotherapy in the last 14 days of life','Pt no chemo last 14d life','G9848','3','','1','0','','','','0','1','0','0'),
('13606','Patients who died from cancer','Pt died from cancer','G9849','3','','1','0','','','','0','1','0','0'),
('13607','Patient had more than one emergency department visit in the last 30 days of life','1/more ed last 30d life','G9850','3','','1','0','','','','0','1','0','0'),
('13608','Patient had one or less emergency department visits in the last 30 days of life','1/no ed visit last 30d life','G9851','3','','1','0','','','','0','1','0','0'),
('13609','Patients who died from cancer','Pt died from cancer','G9852','3','','1','0','','','','0','1','0','0'),
('13610','Patient admitted to the icu in the last 30 days of life','Icu stay last 30d life','G9853','3','','1','0','','','','0','1','0','0'),
('13611','Patient was not admitted to the icu in the last 30 days of life','No icu stay last 30d life','G9854','3','','1','0','','','','0','1','0','0'),
('13612','Patients who died from cancer','Pt died from cancer','G9855','3','','1','0','','','','0','1','0','0'),
('13613','Patient was not admitted to hospice','Pt no hospice','G9856','3','','1','0','','','','0','1','0','0'),
('13614','Patient admitted to hospice','Pt admit hospice','G9857','3','','1','0','','','','0','1','0','0'),
('13615','Patient enrolled in hospice','Pt enroll hospice','G9858','3','','1','0','','','','0','1','0','0'),
('13616','Patients who died from cancer','Pt died from cancer','G9859','3','','1','0','','','','0','1','0','0'),
('13617','Patient spent less than three days in hospice care','Pt less 3d hospice','G9860','3','','1','0','','','','0','1','0','0'),
('13618','Patient spent greater than or equal to three days in hospice care','Pt more than 3d hospice','G9861','3','','1','0','','','','0','1','0','0'),
('13619','Documentation of medical reason(s) for not recommending at least a 10 year follow-up interval (e.g.; inadequate prep; familial or personal history of colonic polyps; patient had no adenoma and age is = 66 years old; or life expectancy < 10 years old; other medical reasons)','Doc rsn no 10 yr follow','G9862','3','','1','0','','','','0','1','0','0'),
('13620','Alcohol and/or drug assessment','Alcohol and/or drug assess','H0001','3','','1','0','','','','0','1','0','0'),
('13621','Behavioral health screening to determine eligibility for admission to treatment program','Alcohol and/or drug screenin','H0002','3','','1','0','','','','0','1','0','0'),
('13622','Alcohol and/or drug screening; laboratory analysis of specimens for presence of alcohol and/or drugs','Alcohol and/or drug screenin','H0003','3','','1','0','','','','0','1','0','0'),
('13623','Behavioral health counseling and therapy; per 15 minutes','Alcohol and/or drug services','H0004','3','','1','0','','','','0','1','0','0'),
('13624','Alcohol and/or drug services; group counseling by a clinician','Alcohol and/or drug services','H0005','3','','1','0','','','','0','1','0','0'),
('13625','Alcohol and/or drug services; case management','Alcohol and/or drug services','H0006','3','','1','0','','','','0','1','0','0'),
('13626','Alcohol and/or drug services; crisis intervention (outpatient)','Alcohol and/or drug services','H0007','3','','1','0','','','','0','1','0','0'),
('13627','Alcohol and/or drug services; sub-acute detoxification (hospital inpatient)','Alcohol and/or drug services','H0008','3','','1','0','','','','0','1','0','0'),
('13628','Alcohol and/or drug services; acute detoxification (hospital inpatient)','Alcohol and/or drug services','H0009','3','','1','0','','','','0','1','0','0'),
('13629','Alcohol and/or drug services; sub-acute detoxification (residential addiction program inpatient)','Alcohol and/or drug services','H0010','3','','1','0','','','','0','1','0','0'),
('13630','Alcohol and/or drug services; acute detoxification (residential addiction program inpatient)','Alcohol and/or drug services','H0011','3','','1','0','','','','0','1','0','0'),
('13631','Alcohol and/or drug services; sub-acute detoxification (residential addiction program outpatient)','Alcohol and/or drug services','H0012','3','','1','0','','','','0','1','0','0'),
('13632','Alcohol and/or drug services; acute detoxification (residential addiction program outpatient)','Alcohol and/or drug services','H0013','3','','1','0','','','','0','1','0','0'),
('13633','Alcohol and/or drug services; ambulatory detoxification','Alcohol and/or drug services','H0014','3','','1','0','','','','0','1','0','0'),
('13634','Alcohol and/or drug services; intensive outpatient (treatment program that operates at least 3 hours/day and at least 3 days/week and is based on an individualized treatment plan); including assessment; counseling; crisis intervention; and activity therapies or education','Alcohol and/or drug services','H0015','3','','1','0','','','','0','1','0','0'),
('13635','Alcohol and/or drug services; medical/somatic (medical intervention in ambulatory setting)','Alcohol and/or drug services','H0016','3','','1','0','','','','0','1','0','0'),
('13636','Behavioral health; residential (hospital residential treatment program); without room and board; per diem','Alcohol and/or drug services','H0017','3','','1','0','','','','0','1','0','0'),
('13637','Behavioral health; short-term residential (non-hospital residential treatment program); without room and board; per diem','Alcohol and/or drug services','H0018','3','','1','0','','','','0','1','0','0'),
('13638','Behavioral health; long-term residential (non-medical; non-acute care in a residential treatment program where stay is typically longer than 30 days); without room and board; per diem','Alcohol and/or drug services','H0019','3','','1','0','','','','0','1','0','0'),
('13639','Alcohol and/or drug services; methadone administration and/or service (provision of the drug by a licensed program)','Alcohol and/or drug services','H0020','3','','1','0','','','','0','1','0','0'),
('13640','Alcohol and/or drug training service (for staff and personnel not employed by providers)','Alcohol and/or drug training','H0021','3','','1','0','','','','0','1','0','0'),
('13641','Alcohol and/or drug intervention service (planned facilitation)','Alcohol and/or drug interven','H0022','3','','1','0','','','','0','1','0','0'),
('13642','Behavioral health outreach service (planned approach to reach a targeted population)','Alcohol and/or drug outreach','H0023','3','','1','0','','','','0','1','0','0'),
('13643','Behavioral health prevention information dissemination service (one-way direct or non-direct contact with service audiences to affect knowledge and attitude)','Alcohol and/or drug preventi','H0024','3','','1','0','','','','0','1','0','0'),
('13644','Behavioral health prevention education service (delivery of services with target population to affect knowledge; attitude and/or behavior)','Alcohol and/or drug preventi','H0025','3','','1','0','','','','0','1','0','0'),
('13645','Alcohol and/or drug prevention process service; community-based (delivery of services to develop skills of impactors)','Alcohol and/or drug preventi','H0026','3','','1','0','','','','0','1','0','0'),
('13646','Alcohol and/or drug prevention environmental service (broad range of external activities geared toward modifying systems in order to mainstream prevention through policy and law)','Alcohol and/or drug preventi','H0027','3','','1','0','','','','0','1','0','0'),
('13647','Alcohol and/or drug prevention problem identification and referral service (e.g.; student assistance and employee assistance programs); does not include assessment','Alcohol and/or drug preventi','H0028','3','','1','0','','','','0','1','0','0'),
('13648','Alcohol and/or drug prevention alternatives service (services for populations that exclude alcohol and other drug use e.g.; alcohol free social events)','Alcohol and/or drug preventi','H0029','3','','1','0','','','','0','1','0','0'),
('13649','Behavioral health hotline service','Alcohol and/or drug hotline','H0030','3','','1','0','','','','0','1','0','0'),
('13650','Mental health assessment; by non-physician','Mh health assess by non-md','H0031','3','','1','0','','','','0','1','0','0'),
('13651','Mental health service plan development by non-physician','Mh svc plan dev by non-md','H0032','3','','1','0','','','','0','1','0','0'),
('13652','Oral medication administration; direct observation','Oral med adm direct observe','H0033','3','','1','0','','','','0','1','0','0'),
('13653','Medication training and support; per 15 minutes','Med trng & support per 15min','H0034','3','','1','0','','','','0','1','0','0'),
('13654','Mental health partial hospitalization; treatment; less than 24 hours','Mh partial hosp tx under 24h','H0035','3','','1','0','','','','0','1','0','0'),
('13655','Community psychiatric supportive treatment; face-to-face; per 15 minutes','Comm psy face-face per 15min','H0036','3','','1','0','','','','0','1','0','0'),
('13656','Community psychiatric supportive treatment program; per diem','Comm psy sup tx pgm per diem','H0037','3','','1','0','','','','0','1','0','0'),
('13657','Self-help/peer services; per 15 minutes','Self-help/peer svc per 15min','H0038','3','','1','0','','','','0','1','0','0'),
('13658','Assertive community treatment; face-to-face; per 15 minutes','Asser com tx face-face/15min','H0039','3','','1','0','','','','0','1','0','0'),
('13659','Assertive community treatment program; per diem','Assert comm tx pgm per diem','H0040','3','','1','0','','','','0','1','0','0'),
('13660','Foster care; child; non-therapeutic; per diem','Fos c chld non-ther per diem','H0041','3','','1','0','','','','0','1','0','0'),
('13661','Foster care; child; non-therapeutic; per month','Fos c chld non-ther per mon','H0042','3','','1','0','','','','0','1','0','0'),
('13662','Supported housing; per diem','Supported housing; per diem','H0043','3','','1','0','','','','0','1','0','0'),
('13663','Supported housing; per month','Supported housing; per month','H0044','3','','1','0','','','','0','1','0','0'),
('13664','Respite care services; not in the home; per diem','Respite not-in-home per diem','H0045','3','','1','0','','','','0','1','0','0'),
('13665','Mental health services; not otherwise specified','Mental health service; nos','H0046','3','','1','0','','','','0','1','0','0'),
('13666','Alcohol and/or other drug abuse services; not otherwise specified','Alcohol/drug abuse svc nos','H0047','3','','1','0','','','','0','1','0','0'),
('13667','Alcohol and/or other drug testing: collection and handling only; specimens other than blood','Spec coll non-blood:a/d test','H0048','3','','1','0','','','','0','1','0','0'),
('13668','Alcohol and/or drug screening','Alcohol/drug screening','H0049','3','','1','0','','','','0','1','0','0'),
('13669','Alcohol and/or drug services; brief intervention; per 15 minutes','Alcohol/drug service 15 min','H0050','3','','1','0','','','','0','1','0','0'),
('13670','Prenatal care; at-risk assessment','Prenatal care atrisk assessm','H1000','3','','1','0','','','','0','1','0','0'),
('13671','Prenatal care; at-risk enhanced service; antepartum management','Antepartum management','H1001','3','','1','0','','','','0','1','0','0'),
('13672','Prenatal care; at risk enhanced service; care coordination','Carecoordination prenatal','H1002','3','','1','0','','','','0','1','0','0'),
('13673','Prenatal care; at-risk enhanced service; education','Prenatal at risk education','H1003','3','','1','0','','','','0','1','0','0'),
('13674','Prenatal care; at-risk enhanced service; follow-up home visit','Follow up home visit/prental','H1004','3','','1','0','','','','0','1','0','0'),
('13675','Prenatal care; at-risk enhanced service package (includes h1001-h1004)','Prenatalcare enhanced srv pk','H1005','3','','1','0','','','','0','1','0','0'),
('13676','Non-medical family planning education; per session','Nonmed family planning ed','H1010','3','','1','0','','','','0','1','0','0'),
('13677','Family assessment by licensed behavioral health professional for state defined purposes','Family assessment','H1011','3','','1','0','','','','0','1','0','0'),
('13678','Comprehensive multidisciplinary evaluation','Comp multidisipln evaluation','H2000','3','','1','0','','','','0','1','0','0'),
('13679','Rehabilitation program; per 1/2 day','Rehabilitation program 1/2 d','H2001','3','','1','0','','','','0','1','0','0'),
('13680','Comprehensive medication services; per 15 minutes','Comprehensive med svc 15 min','H2010','3','','1','0','','','','0','1','0','0'),
('13681','Crisis intervention service; per 15 minutes','Crisis interven svc; 15 min','H2011','3','','1','0','','','','0','1','0','0'),
('13682','Behavioral health day treatment; per hour','Behav hlth day treat; per hr','H2012','3','','1','0','','','','0','1','0','0'),
('13683','Psychiatric health facility service; per diem','Psych hlth fac svc; per diem','H2013','3','','1','0','','','','0','1','0','0'),
('13684','Skills training and development; per 15 minutes','Skills train and dev; 15 min','H2014','3','','1','0','','','','0','1','0','0'),
('13685','Comprehensive community support services; per 15 minutes','Comp comm supp svc; 15 min','H2015','3','','1','0','','','','0','1','0','0'),
('13686','Comprehensive community support services; per diem','Comp comm supp svc; per diem','H2016','3','','1','0','','','','0','1','0','0'),
('13687','Psychosocial rehabilitation services; per 15 minutes','Psysoc rehab svc; per 15 min','H2017','3','','1','0','','','','0','1','0','0'),
('13688','Psychosocial rehabilitation services; per diem','Psysoc rehab svc; per diem','H2018','3','','1','0','','','','0','1','0','0'),
('13689','Therapeutic behavioral services; per 15 minutes','Ther behav svc; per 15 min','H2019','3','','1','0','','','','0','1','0','0'),
('13690','Therapeutic behavioral services; per diem','Ther behav svc; per diem','H2020','3','','1','0','','','','0','1','0','0'),
('13691','Community-based wrap-around services; per 15 minutes','Com wrap-around sv; 15 min','H2021','3','','1','0','','','','0','1','0','0'),
('13692','Community-based wrap-around services; per diem','Com wrap-around sv; per diem','H2022','3','','1','0','','','','0','1','0','0'),
('13693','Supported employment; per 15 minutes','Supported employ; per 15 min','H2023','3','','1','0','','','','0','1','0','0'),
('13694','Supported employment; per diem','Supported employ; per diem','H2024','3','','1','0','','','','0','1','0','0'),
('13695','Ongoing support to maintain employment; per 15 minutes','Supp maint employ; 15 min','H2025','3','','1','0','','','','0','1','0','0'),
('13696','Ongoing support to maintain employment; per diem','Supp maint employ; per diem','H2026','3','','1','0','','','','0','1','0','0'),
('13697','Psychoeducational service; per 15 minutes','Psychoed svc; per 15 min','H2027','3','','1','0','','','','0','1','0','0'),
('13698','Sexual offender treatment service; per 15 minutes','Sex offend tx svc; 15 min','H2028','3','','1','0','','','','0','1','0','0'),
('13699','Sexual offender treatment service; per diem','Sex offend tx svc; per diem','H2029','3','','1','0','','','','0','1','0','0'),
('13700','Mental health clubhouse services; per 15 minutes','Mh clubhouse svc; per 15 min','H2030','3','','1','0','','','','0','1','0','0'),
('13701','Mental health clubhouse services; per diem','Mh clubhouse svc; per diem','H2031','3','','1','0','','','','0','1','0','0'),
('13702','Activity therapy; per 15 minutes','Activity therapy; per 15 min','H2032','3','','1','0','','','','0','1','0','0'),
('13703','Multisystemic therapy for juveniles; per 15 minutes','Multisys ther/juvenile 15min','H2033','3','','1','0','','','','0','1','0','0'),
('13704','Alcohol and/or drug abuse halfway house services; per diem','A/d halfway house; per diem','H2034','3','','1','0','','','','0','1','0','0'),
('13705','Alcohol and/or other drug treatment program; per hour','A/d tx program; per hour','H2035','3','','1','0','','','','0','1','0','0'),
('13706','Alcohol and/or other drug treatment program; per diem','A/d tx program; per diem','H2036','3','','1','0','','','','0','1','0','0'),
('13707','Developmental delay prevention activities; dependent child of client; per 15 minutes','Dev delay prev dp ch; 15 min','H2037','3','','1','0','','','','0','1','0','0'),
('13708','Injection; tetracycline; up to 250 mg','Tetracyclin injection','J0120','3','','1','0','','','','0','1','0','0'),
('13709','Injection; abatacept; 10 mg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Abatacept injection','J0129','3','','1','0','','','','0','1','0','0'),
('13710','Injection abciximab; 10 mg','Abciximab injection','J0130','3','','1','0','','','','0','1','0','0'),
('13711','Injection; acetaminophen; 10 mg','Acetaminophen injection','J0131','3','','1','0','','','','0','1','0','0'),
('13712','Injection; acetylcysteine; 100 mg','Acetylcysteine injection','J0132','3','','1','0','','','','0','1','0','0'),
('13713','Injection; acyclovir; 5 mg','Acyclovir injection','J0133','3','','1','0','','','','0','1','0','0'),
('13714','Injection; adalimumab; 20 mg','Adalimumab injection','J0135','3','','1','0','','','','0','1','0','0'),
('13715','Injection; adenosine for therapeutic use;  6 mg (not to be used to report any adenosine phosphate compounds; instead use a9270),','Injection adenosine 6 mg','J0150','3','','1','0','','','','0','1','0','0'),
('13716','Injection; adenosine for diagnostic use; 1 mg (not to be used to report any adenosine phosphate compounds; instead use a9270),','Inj adenosine diag 1mg','J0151','3','','1','0','','','','0','1','0','0'),
('13717','Injection; adenosine for diagnostic use; 30 mg (not to be used to report any adenosine phosphate compounds; instead use a9270),','Adenosine injection','J0152','3','','1','0','','','','0','1','0','0'),
('13718','Injection; adenosine; 1 mg (not to be used to report any adenosine phosphate compounds)','Adenosine inj 1mg','J0153','3','','1','0','','','','0','1','0','0'),
('13719','Injection; adrenalin; epinephrine; 0.1 mg','Adrenalin epinephrine inject','J0171','3','','1','0','','','','0','1','0','0'),
('13720','Injection; aflibercept; 1 mg','Aflibercept injection','J0178','3','','1','0','','','','0','1','0','0'),
('13721','Injection; agalsidase beta; 1 mg','Agalsidase beta injection','J0180','3','','1','0','','','','0','1','0','0'),
('13722','Injection; biperiden lactate; per 5 mg','Inj biperiden lactate/5 mg','J0190','3','','1','0','','','','0','1','0','0'),
('13723','Injection; alatrofloxacin mesylate; 100 mg','Alatrofloxacin mesylate','J0200','3','','1','0','','','','0','1','0','0'),
('13724','Injection; alemtuzumab; 1 mg','Injection; alemtuzumab','J0202','3','','1','0','','','','0','1','0','0'),
('13725','Injection; alglucerase; per 10 units','Alglucerase injection','J0205','3','','1','0','','','','0','1','0','0'),
('13726','Injection; amifostine; 500 mg','Amifostine','J0207','3','','1','0','','','','0','1','0','0'),
('13727','Injection; methyldopate hcl; up to 250 mg','Methyldopate hcl injection','J0210','3','','1','0','','','','0','1','0','0'),
('13728','Injection; alefacept; 0.5 mg','Alefacept','J0215','3','','1','0','','','','0','1','0','0'),
('13729','Injection; alglucosidase alfa; 10 mg; not otherwise specified','Alglucosidase alfa injection','J0220','3','','1','0','','','','0','1','0','0'),
('13730','Injection; alglucosidase alfa; (lumizyme); 10 mg','Lumizyme injection','J0221','3','','1','0','','','','0','1','0','0'),
('13731','Injection; alpha 1 proteinase inhibitor (human); not otherwise specified; 10 mg','Alpha 1 proteinase inhibitor','J0256','3','','1','0','','','','0','1','0','0'),
('13732','Injection; alpha 1 proteinase inhibitor (human); (glassia); 10 mg','Glassia injection','J0257','3','','1','0','','','','0','1','0','0'),
('13733','Injection; alprostadil; 1.25 mcg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Alprostadil for injection','J0270','3','','1','0','','','','0','1','0','0'),
('13734','Alprostadil urethral suppository (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Alprostadil urethral suppos','J0275','3','','1','0','','','','0','1','0','0'),
('13735','Injection; amikacin sulfate; 100 mg','Amikacin sulfate injection','J0278','3','','1','0','','','','0','1','0','0'),
('13736','Injection; aminophyllin; up to 250 mg','Aminophyllin 250 mg inj','J0280','3','','1','0','','','','0','1','0','0'),
('13737','Injection; amiodarone hydrochloride; 30 mg','Amiodarone hcl','J0282','3','','1','0','','','','0','1','0','0'),
('13738','Injection; amphotericin b; 50 mg','Amphotericin b','J0285','3','','1','0','','','','0','1','0','0'),
('13739','Injection; amphotericin b lipid complex; 10 mg','Amphotericin b lipid complex','J0287','3','','1','0','','','','0','1','0','0'),
('13740','Injection; amphotericin b cholesteryl sulfate complex; 10 mg','Ampho b cholesteryl sulfate','J0288','3','','1','0','','','','0','1','0','0'),
('13741','Injection; amphotericin b liposome; 10 mg','Amphotericin b liposome inj','J0289','3','','1','0','','','','0','1','0','0'),
('13742','Injection; ampicillin sodium; 500 mg','Ampicillin 500 mg inj','J0290','3','','1','0','','','','0','1','0','0'),
('13743','Injection; ampicillin sodium/sulbactam sodium; per 1.5 gm','Ampicillin sodium per 1.5 gm','J0295','3','','1','0','','','','0','1','0','0'),
('13744','Injection; amobarbital; up to 125 mg','Amobarbital 125 mg inj','J0300','3','','1','0','','','','0','1','0','0'),
('13745','Injection; succinylcholine chloride; up to 20 mg','Succinycholine chloride inj','J0330','3','','1','0','','','','0','1','0','0'),
('13746','Injection; anidulafungin; 1 mg','Anidulafungin injection','J0348','3','','1','0','','','','0','1','0','0'),
('13747','Injection; anistreplase; per 30 units','Injection anistreplase 30 u','J0350','3','','1','0','','','','0','1','0','0'),
('13748','Injection; hydralazine hcl; up to 20 mg','Hydralazine hcl injection','J0360','3','','1','0','','','','0','1','0','0'),
('13749','Injection; apomorphine hydrochloride; 1 mg','Apomorphine hydrochloride','J0364','3','','1','0','','','','0','1','0','0'),
('13750','Injection; aprotonin; 10;000 kiu','Aprotonin; 10;000 kiu','J0365','3','','1','0','','','','0','1','0','0'),
('13751','Injection; metaraminol bitartrate; per 10 mg','Inj metaraminol bitartrate','J0380','3','','1','0','','','','0','1','0','0'),
('13752','Injection; chloroquine hydrochloride; up to 250 mg','Chloroquine injection','J0390','3','','1','0','','','','0','1','0','0'),
('13753','Injection; arbutamine hcl; 1 mg','Arbutamine hcl injection','J0395','3','','1','0','','','','0','1','0','0'),
('13754','Injection; aripiprazole; intramuscular; 0.25 mg','Aripiprazole injection','J0400','3','','1','0','','','','0','1','0','0'),
('13755','Injection; aripiprazole; extended release; 1 mg','Inj aripiprazole ext rel 1mg','J0401','3','','1','0','','','','0','1','0','0'),
('13756','Injection; azithromycin; 500 mg','Azithromycin','J0456','3','','1','0','','','','0','1','0','0'),
('13757','Injection; atropine sulfate; 0.01 mg','Atropine sulfate injection','J0461','3','','1','0','','','','0','1','0','0'),
('13758','Injection; dimercaprol; per 100 mg','Dimecaprol injection','J0470','3','','1','0','','','','0','1','0','0'),
('13759','Injection; baclofen; 10 mg','Baclofen 10 mg injection','J0475','3','','1','0','','','','0','1','0','0'),
('13760','Injection; baclofen; 50 mcg for intrathecal trial','Baclofen intrathecal trial','J0476','3','','1','0','','','','0','1','0','0'),
('13761','Injection; basiliximab; 20 mg','Basiliximab','J0480','3','','1','0','','','','0','1','0','0'),
('13762','Injection; belatacept; 1 mg','Belatacept injection','J0485','3','','1','0','','','','0','1','0','0'),
('13763','Injection; belimumab; 10 mg','Belimumab injection','J0490','3','','1','0','','','','0','1','0','0'),
('13764','Injection; dicyclomine hcl; up to 20 mg','Dicyclomine injection','J0500','3','','1','0','','','','0','1','0','0'),
('13765','Injection; benztropine mesylate; per 1 mg','Inj benztropine mesylate','J0515','3','','1','0','','','','0','1','0','0'),
('13766','Injection; bethanechol chloride; myotonachol or urecholine; up to 5 mg','Bethanechol chloride inject','J0520','3','','1','0','','','','0','1','0','0'),
('13767','Injection; penicillin g benzathine and penicillin g procaine; 100;000 units','Peng benzathine/procaine inj','J0558','3','','1','0','','','','0','1','0','0'),
('13768','Injection; penicillin g benzathine; 100;000 units','Penicillin g benzathine inj','J0561','3','','1','0','','','','0','1','0','0'),
('13769','Buprenorphine implant; 74.2 mg','Buprenorphine implant 74.2mg','J0570','3','','1','0','','','','0','1','0','0'),
('13770','Buprenorphine; oral; 1 mg','Buprenorphine oral 1mg','J0571','3','','1','0','','','','0','1','0','0'),
('13771','Buprenorphine/naloxone; oral; less than or equal to 3 mg buprenorphine','Bupren/nal up to 3mg bupreno','J0572','3','','1','0','','','','0','1','0','0'),
('13772','Buprenorphine/naloxone; oral; greater than 3 mg; but less than or equal to 6 mg buprenorphine','Bupren/nal 3.1 to 6mg bupren','J0573','3','','1','0','','','','0','1','0','0'),
('13773','Buprenorphine/naloxone; oral; greater than 6 mg; but less than or equal to 10 mg buprenorphine','Bupren/nal 6.1 to 10mg bupre','J0574','3','','1','0','','','','0','1','0','0'),
('13774','Buprenorphine/naloxone; oral; greater than 10 mg buprenorphine','Bupren/nal over 10mg bupreno','J0575','3','','1','0','','','','0','1','0','0'),
('13775','Injection; bivalirudin; 1 mg','Bivalirudin','J0583','3','','1','0','','','','0','1','0','0'),
('13776','Injection; onabotulinumtoxina; 1 unit','Injection;onabotulinumtoxina','J0585','3','','1','0','','','','0','1','0','0'),
('13777','Injection; abobotulinumtoxina; 5 units','Abobotulinumtoxina','J0586','3','','1','0','','','','0','1','0','0'),
('13778','Injection; rimabotulinumtoxinb; 100 units','Inj; rimabotulinumtoxinb','J0587','3','','1','0','','','','0','1','0','0'),
('13779','Injection; incobotulinumtoxin a; 1 unit','Incobotulinumtoxin a','J0588','3','','1','0','','','','0','1','0','0'),
('13780','Injection; buprenorphine hydrochloride; 0.1 mg','Buprenorphine hydrochloride','J0592','3','','1','0','','','','0','1','0','0'),
('13781','injection; busulfan; 1 mg','Busulfan injection','J0594','3','','1','0','','','','0','1','0','0'),
('13782','Injection; butorphanol tartrate; 1 mg','Butorphanol tartrate 1 mg','J0595','3','','1','0','','','','0','1','0','0'),
('13783','Injection; c1 esterase inhibitor (recombinant); ruconest; 10 units','Injection; ruconest','J0596','3','','1','0','','','','0','1','0','0'),
('13784','Injection; c-1 esterase inhibitor (human); berinert; 10 units','C-1 esterase; berinert','J0597','3','','1','0','','','','0','1','0','0'),
('13785','Injection; c-1 esterase inhibitor (human); cinryze; 10 units','C-1 esterase; cinryze','J0598','3','','1','0','','','','0','1','0','0'),
('13786','Injection; edetate calcium disodium; up to 1000 mg','Edetate calcium disodium inj','J0600','3','','1','0','','','','0','1','0','0'),
('13787','Injection; calcium gluconate; per 10 ml','Calcium gluconate injection','J0610','3','','1','0','','','','0','1','0','0'),
('13788','Injection; calcium glycerophosphate and calcium lactate; per 10 ml','Calcium glycer & lact/10 ml','J0620','3','','1','0','','','','0','1','0','0'),
('13789','Injection; calcitonin salmon; up to 400 units','Calcitonin salmon injection','J0630','3','','1','0','','','','0','1','0','0'),
('13790','Injection; calcitriol; 0.1 mcg','Inj calcitriol per 0.1 mcg','J0636','3','','1','0','','','','0','1','0','0'),
('13791','Injection; caspofungin acetate; 5 mg','Caspofungin acetate','J0637','3','','1','0','','','','0','1','0','0'),
('13792','Injection; canakinumab; 1 mg','Canakinumab injection','J0638','3','','1','0','','','','0','1','0','0'),
('13793','Injection; leucovorin calcium; per 50 mg','Leucovorin calcium injection','J0640','3','','1','0','','','','0','1','0','0'),
('13794','Injection; levoleucovorin calcium; 0.5 mg','Levoleucovorin injection','J0641','3','','1','0','','','','0','1','0','0'),
('13795','Injection; mepivacaine hydrochloride; per 10 ml','Inj mepivacaine hcl/10 ml','J0670','3','','1','0','','','','0','1','0','0'),
('13796','Injection; cefazolin sodium; 500 mg','Cefazolin sodium injection','J0690','3','','1','0','','','','0','1','0','0'),
('13797','Injection; cefepime hydrochloride; 500 mg','Cefepime hcl for injection','J0692','3','','1','0','','','','0','1','0','0'),
('13798','Injection; cefoxitin sodium; 1 gm','Cefoxitin sodium injection','J0694','3','','1','0','','','','0','1','0','0'),
('13799','Injection; ceftolozane 50 mg and tazobactam 25 mg','Inj ceftolozane tazobactam','J0695','3','','1','0','','','','0','1','0','0'),
('13800','Injection; ceftriaxone sodium; per 250 mg','Ceftriaxone sodium injection','J0696','3','','1','0','','','','0','1','0','0'),
('13801','Injection; sterile cefuroxime sodium; per 750 mg','Sterile cefuroxime injection','J0697','3','','1','0','','','','0','1','0','0'),
('13802','Injection; cefotaxime sodium; per gm','Cefotaxime sodium injection','J0698','3','','1','0','','','','0','1','0','0'),
('13803','Injection; betamethasone acetate 3 mg and betamethasone sodium phosphate 3 mg','Betamethasone acet&sod phosp','J0702','3','','1','0','','','','0','1','0','0'),
('13804','Injection; caffeine citrate; 5 mg','Caffeine citrate injection','J0706','3','','1','0','','','','0','1','0','0'),
('13805','Injection; cephapirin sodium; up to 1 gm','Cephapirin sodium injection','J0710','3','','1','0','','','','0','1','0','0'),
('13806','Injection; ceftaroline fosamil; 10 mg','Ceftaroline fosamil inj','J0712','3','','1','0','','','','0','1','0','0'),
('13807','Injection; ceftazidime; per 500 mg','Inj ceftazidime per 500 mg','J0713','3','','1','0','','','','0','1','0','0'),
('13808','Injection; ceftazidime and avibactam; 0.5 g/0.125 g','Ceftazidime and avibactam','J0714','3','','1','0','','','','0','1','0','0'),
('13809','Injection; ceftizoxime sodium; per 500 mg','Ceftizoxime sodium / 500 mg','J0715','3','','1','0','','','','0','1','0','0'),
('13810','Injection; centruroides immune f(ab)2; up to 120 milligrams','Centruroides immune f(ab)','J0716','3','','1','0','','','','0','1','0','0'),
('13811','Injection; certolizumab pegol; 1 mg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Certolizumab pegol inj 1mg','J0717','3','','1','0','','','','0','1','0','0'),
('13812','Injection; certolizumab pegol; 1 mg','Certolizumab pegol inj','J0718','3','','1','0','','','','0','1','0','0'),
('13813','Injection; chloramphenicol sodium succinate; up to 1 gm','Chloramphenicol sodium injec','J0720','3','','1','0','','','','0','1','0','0'),
('13814','Injection; chorionic gonadotropin; per 1;000 usp units','Chorionic gonadotropin/1000u','J0725','3','','1','0','','','','0','1','0','0'),
('13815','Injection; clonidine hydrochloride; 1 mg','Clonidine hydrochloride','J0735','3','','1','0','','','','0','1','0','0'),
('13816','Injection; cidofovir; 375 mg','Cidofovir injection','J0740','3','','1','0','','','','0','1','0','0'),
('13817','Injection; cilastatin sodium; imipenem; per 250 mg','Cilastatin sodium injection','J0743','3','','1','0','','','','0','1','0','0'),
('13818','Injection; ciprofloxacin for intravenous infusion; 200 mg','Ciprofloxacin iv','J0744','3','','1','0','','','','0','1','0','0'),
('13819','Injection; codeine phosphate; per 30 mg','Inj codeine phosphate /30 mg','J0745','3','','1','0','','','','0','1','0','0'),
('13820','Injection; colchicine; per 1 mg','Colchicine injection','J0760','3','','1','0','','','','0','1','0','0'),
('13821','Injection; colistimethate sodium; up to 150 mg','Colistimethate sodium inj','J0770','3','','1','0','','','','0','1','0','0'),
('13822','Injection; collagenase; clostridium histolyticum; 0.01 mg','Collagenase; clost hist inj','J0775','3','','1','0','','','','0','1','0','0'),
('13823','Injection; prochlorperazine; up to 10 mg','Prochlorperazine injection','J0780','3','','1','0','','','','0','1','0','0'),
('13824','Injection; corticorelin ovine triflutate; 1 microgram','Corticorelin ovine triflutal','J0795','3','','1','0','','','','0','1','0','0'),
('13825','Injection; corticotropin; up to 40 units','Corticotropin injection','J0800','3','','1','0','','','','0','1','0','0'),
('13826','Injection; cosyntropin; not otherwise specified; 0.25 mg','Cosyntropin injection nos','J0833','3','','1','0','','','','0','1','0','0'),
('13827','Injection; cosyntropin (cortrosyn); 0.25 mg','Cosyntropin cortrosyn inj','J0834','3','','1','0','','','','0','1','0','0'),
('13828','Injection; crotalidae polyvalent immune fab (ovine); up to 1 gram','Crotalidae poly immune fab','J0840','3','','1','0','','','','0','1','0','0'),
('13829','Injection; cytomegalovirus immune globulin intravenous (human); per vial','Cytomegalovirus imm iv /vial','J0850','3','','1','0','','','','0','1','0','0'),
('13830','Injection; dalbavancin; 5 mg','Injection; dalbavancin','J0875','3','','1','0','','','','0','1','0','0'),
('13831','Injection; daptomycin; 1 mg','Daptomycin injection','J0878','3','','1','0','','','','0','1','0','0'),
('13832','Injection; darbepoetin alfa; 1 microgram (non-esrd use)','Darbepoetin alfa; non-esrd','J0881','3','','1','0','','','','0','1','0','0'),
('13833','Injection; darbepoetin alfa; 1 microgram (for esrd on dialysis)','Darbepoetin alfa; esrd use','J0882','3','','1','0','','','','0','1','0','0'),
('13834','Injection; argatroban; 1 mg (for non-esrd use)','Argatroban nonesrd use 1mg','J0883','3','','1','0','','','','0','1','0','0'),
('13835','Injection; argatroban; 1 mg (for esrd on dialysis)','Argatroban esrd dialysis 1mg','J0884','3','','1','0','','','','0','1','0','0'),
('13836','Injection; epoetin alfa; (for non-esrd use); 1000 units','Epoetin alfa; non-esrd','J0885','3','','1','0','','','','0','1','0','0'),
('13837','Injection; epoetin alfa; 1000 units (for esrd on dialysis)','Epoetin alfa 1000 units esrd','J0886','3','','1','0','','','','0','1','0','0'),
('13838','Injection; epoetin beta; 1 microgram; (for esrd on dialysis)','Epoetin beta esrd use','J0887','3','','1','0','','','','0','1','0','0'),
('13839','Injection; epoetin beta; 1 microgram; (for non esrd use)','Epoetin beta non esrd','J0888','3','','1','0','','','','0','1','0','0'),
('13840','Injection; peginesatide; 0.1 mg (for esrd on dialysis)','Peginesatide injection','J0890','3','','1','0','','','','0','1','0','0'),
('13841','Injection; decitabine; 1 mg','Decitabine injection','J0894','3','','1','0','','','','0','1','0','0'),
('13842','Injection; deferoxamine mesylate; 500 mg','Deferoxamine mesylate inj','J0895','3','','1','0','','','','0','1','0','0'),
('13843','Injection; denosumab; 1 mg','Denosumab injection','J0897','3','','1','0','','','','0','1','0','0'),
('13844','Injection; testosterone enanthate and estradiol valerate; up to 1 cc','Testosterone enanthate inj','J0900','3','','1','0','','','','0','1','0','0'),
('13845','Injection; brompheniramine maleate; per 10 mg','Brompheniramine maleate inj','J0945','3','','1','0','','','','0','1','0','0'),
('13846','Injection; depo-estradiol cypionate; up to 5 mg','Depo-estradiol cypionate inj','J1000','3','','1','0','','','','0','1','0','0'),
('13847','Injection; methylprednisolone acetate; 20 mg','Methylprednisolone 20 mg inj','J1020','3','','1','0','','','','0','1','0','0'),
('13848','Injection; methylprednisolone acetate; 40 mg','Methylprednisolone 40 mg inj','J1030','3','','1','0','','','','0','1','0','0'),
('13849','Injection; methylprednisolone acetate; 80 mg','Methylprednisolone 80 mg inj','J1040','3','','1','0','','','','0','1','0','0'),
('13850','Injection; medroxyprogesterone acetate; 1 mg','Medroxyprogesterone acetate','J1050','3','','1','0','','','','0','1','0','0'),
('13851','Injection; testosterone cypionate and estradiol cypionate; up to 1 ml','Testosterone cypionate 1 ml','J1060','3','','1','0','','','','0','1','0','0'),
('13852','Injection; testosterone cypionate; up to 100 mg','Testosterone cypionat 100 mg','J1070','3','','1','0','','','','0','1','0','0'),
('13853','Injection; testosterone cypionate; 1 mg','Inj testosterone cypionate','J1071','3','','1','0','','','','0','1','0','0'),
('13854','Injection; testosterone cypionate; 1 cc; 200 mg','Testosterone cypionat 200 mg','J1080','3','','1','0','','','','0','1','0','0'),
('13855','Injection; dexamethasone acetate; 1 mg','Inj dexamethasone acetate','J1094','3','','1','0','','','','0','1','0','0'),
('13856','Injection; dexamethasone sodium phosphate; 1 mg','Dexamethasone sodium phos','J1100','3','','1','0','','','','0','1','0','0'),
('13857','Injection; dihydroergotamine mesylate; per 1 mg','Inj dihydroergotamine mesylt','J1110','3','','1','0','','','','0','1','0','0'),
('13858','Injection; acetazolamide sodium; up to 500 mg','Acetazolamid sodium injectio','J1120','3','','1','0','','','','0','1','0','0'),
('13859','Injection; diclofenac sodium; 0.5 mg','Inj diclofenac sodium 0.5mg','J1130','3','','1','0','','','','0','1','0','0'),
('13860','Injection; digoxin; up to 0.5 mg','Digoxin injection','J1160','3','','1','0','','','','0','1','0','0'),
('13861','Injection; digoxin immune fab (ovine); per vial','Digoxin immune fab (ovine)','J1162','3','','1','0','','','','0','1','0','0'),
('13862','Injection; phenytoin sodium; per 50 mg','Phenytoin sodium injection','J1165','3','','1','0','','','','0','1','0','0'),
('13863','Injection; hydromorphone; up to 4 mg','Hydromorphone injection','J1170','3','','1','0','','','','0','1','0','0'),
('13864','Injection; dyphylline; up to 500 mg','Dyphylline injection','J1180','3','','1','0','','','','0','1','0','0'),
('13865','Injection; dexrazoxane hydrochloride; per 250 mg','Dexrazoxane hcl injection','J1190','3','','1','0','','','','0','1','0','0'),
('13866','Injection; diphenhydramine hcl; up to 50 mg','Diphenhydramine hcl injectio','J1200','3','','1','0','','','','0','1','0','0'),
('13867','Injection; chlorothiazide sodium; per 500 mg','Chlorothiazide sodium inj','J1205','3','','1','0','','','','0','1','0','0'),
('13868','Injection; dmso; dimethyl sulfoxide; 50%; 50 ml','Dimethyl sulfoxide 50% 50 ml','J1212','3','','1','0','','','','0','1','0','0'),
('13869','Injection; methadone hcl; up to 10 mg','Methadone injection','J1230','3','','1','0','','','','0','1','0','0'),
('13870','Injection; dimenhydrinate; up to 50 mg','Dimenhydrinate injection','J1240','3','','1','0','','','','0','1','0','0'),
('13871','Injection; dipyridamole; per 10 mg','Dipyridamole injection','J1245','3','','1','0','','','','0','1','0','0'),
('13872','Injection; dobutamine hydrochloride; per 250 mg','Inj dobutamine hcl/250 mg','J1250','3','','1','0','','','','0','1','0','0'),
('13873','Injection; dolasetron mesylate; 10 mg','Dolasetron mesylate','J1260','3','','1','0','','','','0','1','0','0'),
('13874','Injection; dopamine hcl; 40 mg','Dopamine injection','J1265','3','','1','0','','','','0','1','0','0'),
('13875','Injection; doripenem; 10 mg','Doripenem injection','J1267','3','','1','0','','','','0','1','0','0'),
('13876','Injection; doxercalciferol; 1 mcg','Injection; doxercalciferol','J1270','3','','1','0','','','','0','1','0','0'),
('13877','Injection; ecallantide; 1 mg','Ecallantide injection','J1290','3','','1','0','','','','0','1','0','0'),
('13878','Injection; eculizumab; 10 mg','Eculizumab injection','J1300','3','','1','0','','','','0','1','0','0'),
('13879','Injection; amitriptyline hcl; up to 20 mg','Amitriptyline injection','J1320','3','','1','0','','','','0','1','0','0'),
('13880','Injection; elosulfase alfa; 1 mg','Elosulfase alfa; injection','J1322','3','','1','0','','','','0','1','0','0'),
('13881','Injection; enfuvirtide; 1 mg','Enfuvirtide injection','J1324','3','','1','0','','','','0','1','0','0'),
('13882','Injection; epoprostenol; 0.5 mg','Epoprostenol injection','J1325','3','','1','0','','','','0','1','0','0'),
('13883','Injection; eptifibatide; 5 mg','Eptifibatide injection','J1327','3','','1','0','','','','0','1','0','0'),
('13884','Injection; ergonovine maleate; up to 0.2 mg','Ergonovine maleate injection','J1330','3','','1','0','','','','0','1','0','0'),
('13885','Injection; ertapenem sodium; 500 mg','Ertapenem injection','J1335','3','','1','0','','','','0','1','0','0'),
('13886','Injection; erythromycin lactobionate; per 500 mg','Erythro lactobionate /500 mg','J1364','3','','1','0','','','','0','1','0','0'),
('13887','Injection; estradiol valerate; up to 10 mg','Estradiol valerate 10 mg inj','J1380','3','','1','0','','','','0','1','0','0'),
('13888','Injection; estrogen conjugated; per 25 mg','Inj estrogen conjugate 25 mg','J1410','3','','1','0','','','','0','1','0','0'),
('13889','Injection; ethanolamine oleate; 100 mg','Ethanolamine oleate 100 mg','J1430','3','','1','0','','','','0','1','0','0'),
('13890','Injection; estrone; per 1 mg','Injection estrone per 1 mg','J1435','3','','1','0','','','','0','1','0','0'),
('13891','Injection; etidronate disodium; per 300 mg','Etidronate disodium inj','J1436','3','','1','0','','','','0','1','0','0'),
('13892','Injection; etanercept; 25 mg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Etanercept injection','J1438','3','','1','0','','','','0','1','0','0'),
('13893','Injection; ferric carboxymaltose; 1 mg','Inj ferric carboxymaltos 1mg','J1439','3','','1','0','','','','0','1','0','0'),
('13894','Injection; filgrastim (g-csf); 300 mcg','Filgrastim 300 mcg injection','J1440','3','','1','0','','','','0','1','0','0'),
('13895','Injection; filgrastim (g-csf); 480 mcg','Filgrastim 480 mcg injection','J1441','3','','1','0','','','','0','1','0','0'),
('13896','Injection; filgrastim (g-csf); excludes biosimilars; 1 microgram','Inj filgrastim excl biosimil','J1442','3','','1','0','','','','0','1','0','0'),
('13897','Injection; ferric pyrophosphate citrate solution; 0.1 mg of iron','Inj ferric pyrophosphate cit','J1443','3','','1','0','','','','0','1','0','0'),
('13898','Injection; tbo-filgrastim; 5 micrograms','Inj; tbo-filgrastim; 5 mcg','J1446','3','','1','0','','','','0','1','0','0'),
('13899','Injection; tbo-filgrastim; 1 microgram','Inj tbo filgrastim 1 microg','J1447','3','','1','0','','','','0','1','0','0'),
('13900','Injection fluconazole; 200 mg','Fluconazole','J1450','3','','1','0','','','','0','1','0','0'),
('13901','Injection; fomepizole; 15 mg','Fomepizole; 15 mg','J1451','3','','1','0','','','','0','1','0','0'),
('13902','Injection; fomivirsen sodium; intraocular; 1.65 mg','Intraocular fomivirsen na','J1452','3','','1','0','','','','0','1','0','0'),
('13903','Injection; fosaprepitant; 1 mg','Fosaprepitant injection','J1453','3','','1','0','','','','0','1','0','0'),
('13904','Injection; foscarnet sodium; per 1000 mg','Foscarnet sodium injection','J1455','3','','1','0','','','','0','1','0','0'),
('13905','Injection; gallium nitrate; 1 mg','Gallium nitrate injection','J1457','3','','1','0','','','','0','1','0','0'),
('13906','Injection; galsulfase; 1 mg','Galsulfase injection','J1458','3','','1','0','','','','0','1','0','0'),
('13907','Injection; immune globulin (privigen); intravenous; non-lyophilized (e.g.; liquid); 500 mg','Inj ivig privigen 500 mg','J1459','3','','1','0','','','','0','1','0','0'),
('13908','Injection; gamma globulin; intramuscular; 1 cc','Gamma globulin 1 cc inj','J1460','3','','1','0','','','','0','1','0','0'),
('13909','Injection; immune globulin (bivigam); 500 mg','Inj; imm glob bivigam; 500mg','J1556','3','','1','0','','','','0','1','0','0'),
('13910','Injection; immune globulin; (gammaplex); intravenous; non-lyophilized (e.g.; liquid); 500 mg','Gammaplex injection','J1557','3','','1','0','','','','0','1','0','0'),
('13911','Injection; immune globulin (hizentra); 100 mg','Hizentra injection','J1559','3','','1','0','','','','0','1','0','0'),
('13912','Injection; gamma globulin; intramuscular; over 10 cc','Gamma globulin > 10 cc inj','J1560','3','','1','0','','','','0','1','0','0'),
('13913','Injection; immune globulin; (gamunex-c/gammaked); non-lyophilized (e.g.; liquid); 500 mg','Gamunex-c/gammaked','J1561','3','','1','0','','','','0','1','0','0'),
('13914','Injection; immune globulin (vivaglobin); 100 mg','Vivaglobin; inj','J1562','3','','1','0','','','','0','1','0','0'),
('13915','Injection; immune globulin; intravenous; lyophilized (e.g.; powder); not otherwise specified; 500 mg','Immune globulin; powder','J1566','3','','1','0','','','','0','1','0','0'),
('13916','Injection; immune globulin; (octagam); intravenous; non-lyophilized (e.g.; liquid); 500 mg','Octagam injection','J1568','3','','1','0','','','','0','1','0','0'),
('13917','Injection; immune globulin; (gammagard liquid); non-lyophilized; (e.g.; liquid); 500 mg','Gammagard liquid injection','J1569','3','','1','0','','','','0','1','0','0'),
('13918','Injection; ganciclovir sodium; 500 mg','Ganciclovir sodium injection','J1570','3','','1','0','','','','0','1','0','0'),
('13919','Injection; hepatitis b immune globulin (hepagam b); intramuscular; 0.5 ml','Hepagam b im injection','J1571','3','','1','0','','','','0','1','0','0'),
('13920','Injection; immune globulin; (flebogamma/flebogamma dif); intravenous; non-lyophilized (e.g.; liquid); 500 mg','Flebogamma injection','J1572','3','','1','0','','','','0','1','0','0'),
('13921','Injection; hepatitis b immune globulin (hepagam b); intravenous; 0.5 ml','Hepagam b intravenous; inj','J1573','3','','1','0','','','','0','1','0','0'),
('13922','Injection; immune globulin/hyaluronidase; (hyqvia); 100 mg immuneglobulin','Hyqvia 100mg immuneglobulin','J1575','3','','1','0','','','','0','1','0','0'),
('13923','Injection; garamycin; gentamicin; up to 80 mg','Garamycin gentamicin inj','J1580','3','','1','0','','','','0','1','0','0'),
('13924','Injection; gatifloxacin; 10 mg','Gatifloxacin injection','J1590','3','','1','0','','','','0','1','0','0'),
('13925','Injection; glatiramer acetate; 20 mg','Injection glatiramer acetate','J1595','3','','1','0','','','','0','1','0','0'),
('13926','Injection; immune globulin; intravenous; non-lyophilized (e.g.; liquid); not otherwise specified; 500 mg','Ivig non-lyophilized; nos','J1599','3','','1','0','','','','0','1','0','0'),
('13927','Injection; gold sodium thiomalate; up to 50 mg','Gold sodium thiomaleate inj','J1600','3','','1','0','','','','0','1','0','0'),
('13928','Injection; golimumab; 1 mg; for intravenous use','Golimumab for iv use 1mg','J1602','3','','1','0','','','','0','1','0','0'),
('13929','Injection; glucagon hydrochloride; per 1 mg','Glucagon hydrochloride/1 mg','J1610','3','','1','0','','','','0','1','0','0'),
('13930','Injection; gonadorelin hydrochloride; per 100 mcg','Gonadorelin hydroch/ 100 mcg','J1620','3','','1','0','','','','0','1','0','0'),
('13931','Injection; granisetron hydrochloride; 100 mcg','Granisetron hcl injection','J1626','3','','1','0','','','','0','1','0','0'),
('13932','Injection; haloperidol; up to 5 mg','Haloperidol injection','J1630','3','','1','0','','','','0','1','0','0'),
('13933','Injection; haloperidol decanoate; per 50 mg','Haloperidol decanoate inj','J1631','3','','1','0','','','','0','1','0','0'),
('13934','Injection; hemin; 1 mg','Hemin; 1 mg','J1640','3','','1','0','','','','0','1','0','0'),
('13935','Injection; heparin sodium; (heparin lock flush); per 10 units','Inj heparin sodium per 10 u','J1642','3','','1','0','','','','0','1','0','0'),
('13936','Injection; heparin sodium; per 1000 units','Inj heparin sodium per 1000u','J1644','3','','1','0','','','','0','1','0','0'),
('13937','Injection; dalteparin sodium; per 2500 iu','Dalteparin sodium','J1645','3','','1','0','','','','0','1','0','0'),
('13938','Injection; enoxaparin sodium; 10 mg','Inj enoxaparin sodium','J1650','3','','1','0','','','','0','1','0','0'),
('13939','Injection; fondaparinux sodium; 0.5 mg','Fondaparinux sodium','J1652','3','','1','0','','','','0','1','0','0'),
('13940','Injection; tinzaparin sodium; 1000 iu','Tinzaparin sodium injection','J1655','3','','1','0','','','','0','1','0','0'),
('13941','Injection; tetanus immune globulin; human; up to 250 units','Tetanus immune globulin inj','J1670','3','','1','0','','','','0','1','0','0'),
('13942','Injection; histrelin acetate; 10 micrograms','Histrelin acetate','J1675','3','','1','0','','','','0','1','0','0'),
('13943','Injection; hydrocortisone acetate; up to 25 mg','Hydrocortisone acetate inj','J1700','3','','1','0','','','','0','1','0','0'),
('13944','Injection; hydrocortisone sodium phosphate; up to 50 mg','Hydrocortisone sodium ph inj','J1710','3','','1','0','','','','0','1','0','0'),
('13945','Injection; hydrocortisone sodium succinate; up to 100 mg','Hydrocortisone sodium succ i','J1720','3','','1','0','','','','0','1','0','0'),
('13946','Injection; hydroxyprogesterone caproate; 1 mg','Hydroxyprogesterone caproate','J1725','3','','1','0','','','','0','1','0','0'),
('13947','Injection; diazoxide; up to 300 mg','Diazoxide injection','J1730','3','','1','0','','','','0','1','0','0'),
('13948','Injection; ibandronate sodium; 1 mg','Ibandronate sodium injection','J1740','3','','1','0','','','','0','1','0','0'),
('13949','Injection; ibuprofen; 100 mg','Ibuprofen injection','J1741','3','','1','0','','','','0','1','0','0'),
('13950','Injection; ibutilide fumarate; 1 mg','Ibutilide fumarate injection','J1742','3','','1','0','','','','0','1','0','0'),
('13951','Injection; idursulfase; 1 mg','Idursulfase injection','J1743','3','','1','0','','','','0','1','0','0'),
('13952','Injection; icatibant; 1 mg','Icatibant injection','J1744','3','','1','0','','','','0','1','0','0'),
('13953','Injection; infliximab; excludes biosimilar; 10 mg','Infliximab not biosimil 10mg','J1745','3','','1','0','','','','0','1','0','0'),
('13954','Injection; iron dextran; 50 mg','Inj iron dextran','J1750','3','','1','0','','','','0','1','0','0'),
('13955','Injection; iron sucrose; 1 mg','Iron sucrose injection','J1756','3','','1','0','','','','0','1','0','0'),
('13956','Injection; imiglucerase; 10 units','Imuglucerase injection','J1786','3','','1','0','','','','0','1','0','0'),
('13957','Injection; droperidol; up to 5 mg','Droperidol injection','J1790','3','','1','0','','','','0','1','0','0'),
('13958','Injection; propranolol hcl; up to 1 mg','Propranolol injection','J1800','3','','1','0','','','','0','1','0','0'),
('13959','Injection; droperidol and fentanyl citrate; up to 2 ml ampule','Droperidol/fentanyl inj','J1810','3','','1','0','','','','0','1','0','0'),
('13960','Injection; insulin; per 5 units','Insulin injection','J1815','3','','1','0','','','','0','1','0','0'),
('13961','Insulin for administration through dme (i.e.; insulin pump) per 50 units','Insulin for insulin pump use','J1817','3','','1','0','','','','0','1','0','0'),
('13962','Injection; interferon beta-1a; 30 mcg','Interferon beta-1a inj','J1826','3','','1','0','','','','0','1','0','0'),
('13963','Injection; interferon beta-1b; 0.25 mg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Interferon beta-1b / .25 mg','J1830','3','','1','0','','','','0','1','0','0'),
('13964','Injection; isavuconazonium; 1 mg','Injection; isavuconazonium','J1833','3','','1','0','','','','0','1','0','0'),
('13965','Injection; itraconazole; 50 mg','Itraconazole injection','J1835','3','','1','0','','','','0','1','0','0'),
('13966','Injection; kanamycin sulfate; up to 500 mg','Kanamycin sulfate 500 mg inj','J1840','3','','1','0','','','','0','1','0','0'),
('13967','Injection; kanamycin sulfate; up to 75 mg','Kanamycin sulfate 75 mg inj','J1850','3','','1','0','','','','0','1','0','0'),
('13968','Injection; ketorolac tromethamine; per 15 mg','Ketorolac tromethamine inj','J1885','3','','1','0','','','','0','1','0','0'),
('13969','Injection; cephalothin sodium; up to 1 gram','Cephalothin sodium injection','J1890','3','','1','0','','','','0','1','0','0'),
('13970','Injection; lanreotide; 1 mg','Lanreotide injection','J1930','3','','1','0','','','','0','1','0','0'),
('13971','Injection; laronidase; 0.1 mg','Laronidase injection','J1931','3','','1','0','','','','0','1','0','0'),
('13972','Injection; furosemide; up to 20 mg','Furosemide injection','J1940','3','','1','0','','','','0','1','0','0'),
('13973','Injection; aripiprazole lauroxil; 1 mg','Aripiprazole lauroxil 1mg','J1942','3','','1','0','','','','0','1','0','0'),
('13974','Injection; lepirudin; 50 mg','Lepirudin','J1945','3','','1','0','','','','0','1','0','0'),
('13975','Injection; leuprolide acetate (for depot suspension); per 3.75 mg','Leuprolide acetate /3.75 mg','J1950','3','','1','0','','','','0','1','0','0'),
('13976','Injection; levetiracetam; 10 mg','Levetiracetam injection','J1953','3','','1','0','','','','0','1','0','0'),
('13977','Injection; levocarnitine; per 1 gm','Inj levocarnitine per 1 gm','J1955','3','','1','0','','','','0','1','0','0'),
('13978','Injection; levofloxacin; 250 mg','Levofloxacin injection','J1956','3','','1','0','','','','0','1','0','0'),
('13979','Injection; levorphanol tartrate; up to 2 mg','Levorphanol tartrate inj','J1960','3','','1','0','','','','0','1','0','0'),
('13980','Injection; hyoscyamine sulfate; up to 0.25 mg','Hyoscyamine sulfate inj','J1980','3','','1','0','','','','0','1','0','0'),
('13981','Injection; chlordiazepoxide hcl; up to 100 mg','Chlordiazepoxide injection','J1990','3','','1','0','','','','0','1','0','0'),
('13982','Injection; lidocaine hcl for intravenous infusion; 10 mg','Lidocaine injection','J2001','3','','1','0','','','','0','1','0','0'),
('13983','Injection; lincomycin hcl; up to 300 mg','Lincomycin injection','J2010','3','','1','0','','','','0','1','0','0'),
('13984','Injection; linezolid; 200 mg','Linezolid injection','J2020','3','','1','0','','','','0','1','0','0'),
('13985','Injection; lorazepam; 2 mg','Lorazepam injection','J2060','3','','1','0','','','','0','1','0','0'),
('13986','Injection; mannitol; 25% in 50 ml','Mannitol injection','J2150','3','','1','0','','','','0','1','0','0'),
('13987','Injection; mecasermin; 1 mg','Mecasermin injection','J2170','3','','1','0','','','','0','1','0','0'),
('13988','Injection; meperidine hydrochloride; per 100 mg','Meperidine hydrochl /100 mg','J2175','3','','1','0','','','','0','1','0','0'),
('13989','Injection; meperidine and promethazine hcl; up to 50 mg','Meperidine/promethazine inj','J2180','3','','1','0','','','','0','1','0','0'),
('13990','Injection; mepolizumab; 1 mg','Injection; mepolizumab; 1mg','J2182','3','','1','0','','','','0','1','0','0'),
('13991','Injection; meropenem; 100 mg','Meropenem','J2185','3','','1','0','','','','0','1','0','0'),
('13992','Injection; methylergonovine maleate; up to 0.2 mg','Methylergonovin maleate inj','J2210','3','','1','0','','','','0','1','0','0'),
('13993','Injection; methylnaltrexone; 0.1 mg','Methylnaltrexone injection','J2212','3','','1','0','','','','0','1','0','0'),
('13994','Injection; micafungin sodium; 1 mg','Micafungin sodium injection','J2248','3','','1','0','','','','0','1','0','0'),
('13995','Injection; midazolam hydrochloride; per 1 mg','Inj midazolam hydrochloride','J2250','3','','1','0','','','','0','1','0','0'),
('13996','Injection; milrinone lactate; 5 mg','Inj milrinone lactate / 5 mg','J2260','3','','1','0','','','','0','1','0','0'),
('13997','Injection; minocycline hydrochloride; 1 mg','Minocycline hydrochloride','J2265','3','','1','0','','','','0','1','0','0'),
('13998','Injection; morphine sulfate; up to 10 mg','Morphine sulfate injection','J2270','3','','1','0','','','','0','1','0','0'),
('13999','Injection; morphine sulfate; 100mg','Morphine so4 injection 100mg','J2271','3','','1','0','','','','0','1','0','0'),
('14000','Injection; morphine sulfate; preservative-free for epidural or intrathecal use; 10 mg','In morphine preservativ free','J2274','3','','1','0','','','','0','1','0','0'),
('14001','Injection; morphine sulfate (preservative-free sterile solution); per 10 mg','Morphine sulfate injection','J2275','3','','1','0','','','','0','1','0','0'),
('14002','Injection; ziconotide; 1 microgram','Ziconotide injection','J2278','3','','1','0','','','','0','1','0','0'),
('14003','Injection; moxifloxacin; 100 mg','Inj; moxifloxacin 100 mg','J2280','3','','1','0','','','','0','1','0','0'),
('14004','Injection; nalbuphine hydrochloride; per 10 mg','Inj nalbuphine hydrochloride','J2300','3','','1','0','','','','0','1','0','0'),
('14005','Injection; naloxone hydrochloride; per 1 mg','Inj naloxone hydrochloride','J2310','3','','1','0','','','','0','1','0','0'),
('14006','Injection; naltrexone; depot form; 1 mg','Naltrexone; depot form','J2315','3','','1','0','','','','0','1','0','0'),
('14007','Injection; nandrolone decanoate; up to 50 mg','Nandrolone decanoate 50 mg','J2320','3','','1','0','','','','0','1','0','0'),
('14008','Injection; natalizumab; 1 mg','Natalizumab injection','J2323','3','','1','0','','','','0','1','0','0'),
('14009','Injection; nesiritide; 0.1 mg','Nesiritide injection','J2325','3','','1','0','','','','0','1','0','0'),
('14010','Injection; octreotide; depot form for intramuscular injection; 1 mg','Octreotide injection; depot','J2353','3','','1','0','','','','0','1','0','0'),
('14011','Injection; octreotide; non-depot form for subcutaneous or intravenous injection; 25 mcg','Octreotide inj; non-depot','J2354','3','','1','0','','','','0','1','0','0'),
('14012','Injection; oprelvekin; 5 mg','Oprelvekin injection','J2355','3','','1','0','','','','0','1','0','0'),
('14013','Injection; omalizumab; 5 mg','Omalizumab injection','J2357','3','','1','0','','','','0','1','0','0'),
('14014','Injection; olanzapine; long-acting; 1 mg','Olanzapine long-acting inj','J2358','3','','1','0','','','','0','1','0','0'),
('14015','Injection; orphenadrine citrate; up to 60 mg','Orphenadrine injection','J2360','3','','1','0','','','','0','1','0','0'),
('14016','Injection; phenylephrine hcl; up to 1 ml','Phenylephrine hcl injection','J2370','3','','1','0','','','','0','1','0','0'),
('14017','Injection; chloroprocaine hydrochloride; per 30 ml','Chloroprocaine hcl injection','J2400','3','','1','0','','','','0','1','0','0'),
('14018','Injection; ondansetron hydrochloride; per 1 mg','Ondansetron hcl injection','J2405','3','','1','0','','','','0','1','0','0'),
('14019','Injection; oritavancin; 10 mg','Injection; oritavancin','J2407','3','','1','0','','','','0','1','0','0'),
('14020','Injection; oxymorphone hcl; up to 1 mg','Oxymorphone hcl injection','J2410','3','','1','0','','','','0','1','0','0'),
('14021','Injection; palifermin; 50 micrograms','Palifermin injection','J2425','3','','1','0','','','','0','1','0','0'),
('14022','Injection; paliperidone palmitate extended release; 1 mg','Paliperidone palmitate inj','J2426','3','','1','0','','','','0','1','0','0'),
('14023','Injection; pamidronate disodium; per 30 mg','Pamidronate disodium /30 mg','J2430','3','','1','0','','','','0','1','0','0'),
('14024','Injection; papaverine hcl; up to 60 mg','Papaverin hcl injection','J2440','3','','1','0','','','','0','1','0','0'),
('14025','Injection; oxytetracycline hcl; up to 50 mg','Oxytetracycline injection','J2460','3','','1','0','','','','0','1','0','0'),
('14026','Injection; palonosetron hcl; 25 mcg','Palonosetron hcl','J2469','3','','1','0','','','','0','1','0','0'),
('14027','Injection; paricalcitol; 1 mcg','Paricalcitol','J2501','3','','1','0','','','','0','1','0','0'),
('14028','Injection; pasireotide long acting; 1 mg','Inj; pasireotide long acting','J2502','3','','1','0','','','','0','1','0','0'),
('14029','Injection; pegaptanib sodium; 0.3 mg','Pegaptanib sodium injection','J2503','3','','1','0','','','','0','1','0','0'),
('14030','Injection; pegademase bovine; 25 iu','Pegademase bovine; 25 iu','J2504','3','','1','0','','','','0','1','0','0'),
('14031','Injection; pegfilgrastim; 6 mg','Injection; pegfilgrastim 6mg','J2505','3','','1','0','','','','0','1','0','0'),
('14032','Injection; pegloticase; 1 mg','Pegloticase injection','J2507','3','','1','0','','','','0','1','0','0'),
('14033','Injection; penicillin g procaine; aqueous; up to 600;000 units','Penicillin g procaine inj','J2510','3','','1','0','','','','0','1','0','0'),
('14034','Injection; pentastarch; 10% solution; 100 ml','Pentastarch 10% solution','J2513','3','','1','0','','','','0','1','0','0'),
('14035','Injection; pentobarbital sodium; per 50 mg','Pentobarbital sodium inj','J2515','3','','1','0','','','','0','1','0','0'),
('14036','Injection; penicillin g potassium; up to 600;000 units','Penicillin g potassium inj','J2540','3','','1','0','','','','0','1','0','0'),
('14037','Injection; piperacillin sodium/tazobactam sodium; 1 gram/0.125 grams (1.125 grams)','Piperacillin/tazobactam','J2543','3','','1','0','','','','0','1','0','0'),
('14038','Pentamidine isethionate; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per 300 mg','Pentamidine non-comp unit','J2545','3','','1','0','','','','0','1','0','0'),
('14039','Injection; peramivir; 1 mg','Injection; peramivir','J2547','3','','1','0','','','','0','1','0','0'),
('14040','Injection; promethazine hcl; up to 50 mg','Promethazine hcl injection','J2550','3','','1','0','','','','0','1','0','0'),
('14041','Injection; phenobarbital sodium; up to 120 mg','Phenobarbital sodium inj','J2560','3','','1','0','','','','0','1','0','0'),
('14042','Injection; plerixafor; 1 mg','Plerixafor injection','J2562','3','','1','0','','','','0','1','0','0'),
('14043','Injection; oxytocin; up to 10 units','Oxytocin injection','J2590','3','','1','0','','','','0','1','0','0'),
('14044','Injection; desmopressin acetate; per 1 mcg','Inj desmopressin acetate','J2597','3','','1','0','','','','0','1','0','0'),
('14045','Injection; prednisolone acetate; up to 1 ml','Prednisolone acetate inj','J2650','3','','1','0','','','','0','1','0','0'),
('14046','Injection; tolazoline hcl; up to 25 mg','Totazoline hcl injection','J2670','3','','1','0','','','','0','1','0','0'),
('14047','Injection; progesterone; per 50 mg','Inj progesterone per 50 mg','J2675','3','','1','0','','','','0','1','0','0'),
('14048','Injection; fluphenazine decanoate; up to 25 mg','Fluphenazine decanoate 25 mg','J2680','3','','1','0','','','','0','1','0','0'),
('14049','Injection; procainamide hcl; up to 1 gm','Procainamide hcl injection','J2690','3','','1','0','','','','0','1','0','0'),
('14050','Injection; oxacillin sodium; up to 250 mg','Oxacillin sodium injeciton','J2700','3','','1','0','','','','0','1','0','0'),
('14051','Injection; propofol; 10 mg','Inj; propofol; 10 mg','J2704','3','','1','0','','','','0','1','0','0'),
('14052','Injection; neostigmine methylsulfate; up to 0.5 mg','Neostigmine methylslfte inj','J2710','3','','1','0','','','','0','1','0','0'),
('14053','Injection; protamine sulfate; per 10 mg','Inj protamine sulfate/10 mg','J2720','3','','1','0','','','','0','1','0','0'),
('14054','Injection; protein c concentrate; intravenous; human; 10 iu','Protein c concentrate','J2724','3','','1','0','','','','0','1','0','0'),
('14055','Injection; protirelin; per 250 mcg','Inj protirelin per 250 mcg','J2725','3','','1','0','','','','0','1','0','0'),
('14056','Injection; pralidoxime chloride; up to 1 gm','Pralidoxime chloride inj','J2730','3','','1','0','','','','0','1','0','0'),
('14057','Injection; phentolamine mesylate; up to 5 mg','Phentolaine mesylate inj','J2760','3','','1','0','','','','0','1','0','0'),
('14058','Injection; metoclopramide hcl; up to 10 mg','Metoclopramide hcl injection','J2765','3','','1','0','','','','0','1','0','0'),
('14059','Injection; quinupristin/dalfopristin; 500 mg (150/350),','Quinupristin/dalfopristin','J2770','3','','1','0','','','','0','1','0','0'),
('14060','Injection; ranibizumab; 0.1 mg','Ranibizumab injection','J2778','3','','1','0','','','','0','1','0','0'),
('14061','Injection; ranitidine hydrochloride; 25 mg','Ranitidine hydrochloride inj','J2780','3','','1','0','','','','0','1','0','0'),
('14062','Injection; rasburicase; 0.5 mg','Rasburicase','J2783','3','','1','0','','','','0','1','0','0'),
('14063','Injection; regadenoson; 0.1 mg','Regadenoson injection','J2785','3','','1','0','','','','0','1','0','0'),
('14064','Injection; reslizumab; 1 mg','Injection; reslizumab; 1mg','J2786','3','','1','0','','','','0','1','0','0'),
('14065','Injection; rho d immune globulin; human; minidose; 50 micrograms (250 i.u.)','Rho d immune globulin 50 mcg','J2788','3','','1','0','','','','0','1','0','0'),
('14066','Injection; rho d immune globulin; human; full dose; 300 micrograms (1500 i.u.)','Rho d immune globulin inj','J2790','3','','1','0','','','','0','1','0','0'),
('14067','Injection; rho(d) immune globulin (human); (rhophylac); intramuscular or intravenous; 100 iu','Rhophylac injection','J2791','3','','1','0','','','','0','1','0','0'),
('14068','Injection; rho d immune globulin; intravenous; human; solvent detergent; 100 iu','Rho(d) immune globulin h; sd','J2792','3','','1','0','','','','0','1','0','0'),
('14069','Injection; rilonacept; 1 mg','Rilonacept injection','J2793','3','','1','0','','','','0','1','0','0'),
('14070','Injection; risperidone; long acting; 0.5 mg','Risperidone; long acting','J2794','3','','1','0','','','','0','1','0','0'),
('14071','Injection; ropivacaine hydrochloride; 1 mg','Ropivacaine hcl injection','J2795','3','','1','0','','','','0','1','0','0'),
('14072','Injection; romiplostim; 10 micrograms','Romiplostim injection','J2796','3','','1','0','','','','0','1','0','0'),
('14073','Injection; methocarbamol; up to 10 ml','Methocarbamol injection','J2800','3','','1','0','','','','0','1','0','0'),
('14074','Injection; sincalide; 5 micrograms','Sincalide injection','J2805','3','','1','0','','','','0','1','0','0'),
('14075','Injection; theophylline; per 40 mg','Inj theophylline per 40 mg','J2810','3','','1','0','','','','0','1','0','0'),
('14076','Injection; sargramostim (gm-csf); 50 mcg','Sargramostim injection','J2820','3','','1','0','','','','0','1','0','0'),
('14077','Injection; sebelipase alfa; 1 mg','Inj sebelipase alfa 1 mg','J2840','3','','1','0','','','','0','1','0','0'),
('14078','Injection; secretin; synthetic; human; 1 microgram','Inj secretin synthetic human','J2850','3','','1','0','','','','0','1','0','0'),
('14079','Injection; siltuximab; 10 mg','Injection; siltuximab','J2860','3','','1','0','','','','0','1','0','0'),
('14080','Injection; aurothioglucose; up to 50 mg','Aurothioglucose injeciton','J2910','3','','1','0','','','','0','1','0','0'),
('14081','Injection; sodium ferric gluconate complex in sucrose injection; 12.5 mg','Na ferric gluconate complex','J2916','3','','1','0','','','','0','1','0','0'),
('14082','Injection; methylprednisolone sodium succinate; up to 40 mg','Methylprednisolone injection','J2920','3','','1','0','','','','0','1','0','0'),
('14083','Injection; methylprednisolone sodium succinate; up to 125 mg','Methylprednisolone injection','J2930','3','','1','0','','','','0','1','0','0'),
('14084','Injection; somatrem; 1 mg','Somatrem injection','J2940','3','','1','0','','','','0','1','0','0'),
('14085','Injection; somatropin; 1 mg','Somatropin injection','J2941','3','','1','0','','','','0','1','0','0'),
('14086','Injection; promazine hcl; up to 25 mg','Promazine hcl injection','J2950','3','','1','0','','','','0','1','0','0'),
('14087','Injection; reteplase; 18.1 mg','Reteplase injection','J2993','3','','1','0','','','','0','1','0','0'),
('14088','Injection; streptokinase; per 250;000 iu','Inj streptokinase /250000 iu','J2995','3','','1','0','','','','0','1','0','0'),
('14089','Injection; alteplase recombinant; 1 mg','Alteplase recombinant','J2997','3','','1','0','','','','0','1','0','0'),
('14090','Injection; streptomycin; up to 1 gm','Streptomycin injection','J3000','3','','1','0','','','','0','1','0','0'),
('14091','Injection; fentanyl citrate; 0.1 mg','Fentanyl citrate injeciton','J3010','3','','1','0','','','','0','1','0','0'),
('14092','Injection; sumatriptan succinate; 6 mg (code may be used for medicare when drug administered under the direct supervision of a physician; not for use when drug is self administered)','Sumatriptan succinate / 6 mg','J3030','3','','1','0','','','','0','1','0','0'),
('14093','Injection; taliglucerace alfa; 10 units','Inj; taliglucerace alfa 10 u','J3060','3','','1','0','','','','0','1','0','0'),
('14094','Injection; pentazocine; 30 mg','Pentazocine injection','J3070','3','','1','0','','','','0','1','0','0'),
('14095','Injection; tedizolid phosphate; 1 mg','Inj tedizolid phosphate','J3090','3','','1','0','','','','0','1','0','0'),
('14096','Injection; telavancin; 10 mg','Telavancin injection','J3095','3','','1','0','','','','0','1','0','0'),
('14097','Injection; tenecteplase; 1 mg','Tenecteplase injection','J3101','3','','1','0','','','','0','1','0','0'),
('14098','Injection; terbutaline sulfate; up to 1 mg','Terbutaline sulfate inj','J3105','3','','1','0','','','','0','1','0','0'),
('14099','Injection; teriparatide; 10 mcg','Teriparatide injection','J3110','3','','1','0','','','','0','1','0','0'),
('14100','Injection; testosterone enanthate; up to 100 mg','Testosterone enanthate inj','J3120','3','','1','0','','','','0','1','0','0'),
('14101','Injection; testosterone enanthate; 1 mg','Inj testostero enanthate 1mg','J3121','3','','1','0','','','','0','1','0','0'),
('14102','Injection; testosterone enanthate; up to 200 mg','Testosterone enanthate inj','J3130','3','','1','0','','','','0','1','0','0'),
('14103','Injection; testosterone suspension; up to 50 mg','Testosterone suspension inj','J3140','3','','1','0','','','','0','1','0','0'),
('14104','Injection; testosterone undecanoate; 1 mg','Testosterone undecanoate 1mg','J3145','3','','1','0','','','','0','1','0','0'),
('14105','Injection; testosterone propionate; up to 100 mg','Testosteron propionate inj','J3150','3','','1','0','','','','0','1','0','0'),
('14106','Injection; chlorpromazine hcl; up to 50 mg','Chlorpromazine hcl injection','J3230','3','','1','0','','','','0','1','0','0'),
('14107','Injection; thyrotropin alpha; 0.9 mg; provided in 1.1 mg vial','Thyrotropin injection','J3240','3','','1','0','','','','0','1','0','0'),
('14108','Injection; tigecycline; 1 mg','Tigecycline injection','J3243','3','','1','0','','','','0','1','0','0'),
('14109','Injection; tirofiban hcl; 0.25 mg','Tirofiban hcl','J3246','3','','1','0','','','','0','1','0','0'),
('14110','Injection; trimethobenzamide hcl; up to 200 mg','Trimethobenzamide hcl inj','J3250','3','','1','0','','','','0','1','0','0'),
('14111','Injection; tobramycin sulfate; up to 80 mg','Tobramycin sulfate injection','J3260','3','','1','0','','','','0','1','0','0'),
('14112','Injection; tocilizumab; 1 mg','Tocilizumab injection','J3262','3','','1','0','','','','0','1','0','0'),
('14113','Injection; torsemide; 10 mg/ml','Injection torsemide 10 mg/ml','J3265','3','','1','0','','','','0','1','0','0'),
('14114','Injection; thiethylperazine maleate; up to 10 mg','Thiethylperazine maleate inj','J3280','3','','1','0','','','','0','1','0','0'),
('14115','Injection; treprostinil; 1 mg','Treprostinil injection','J3285','3','','1','0','','','','0','1','0','0'),
('14116','Injection; triamcinolone acetonide; preservative free; 1 mg','Triamcinolone a inj prs-free','J3300','3','','1','0','','','','0','1','0','0'),
('14117','Injection; triamcinolone acetonide; not otherwise specified; 10 mg','Triamcinolone acet inj nos','J3301','3','','1','0','','','','0','1','0','0'),
('14118','Injection; triamcinolone diacetate; per 5 mg','Triamcinolone diacetate inj','J3302','3','','1','0','','','','0','1','0','0'),
('14119','Injection; triamcinolone hexacetonide; per 5 mg','Triamcinolone hexacetonl inj','J3303','3','','1','0','','','','0','1','0','0'),
('14120','Injection; trimetrexate glucuronate; per 25 mg','Inj trimetrexate glucoronate','J3305','3','','1','0','','','','0','1','0','0'),
('14121','Injection; perphenazine; up to 5 mg','Perphenazine injeciton','J3310','3','','1','0','','','','0','1','0','0'),
('14122','Injection; triptorelin pamoate; 3.75 mg','Triptorelin pamoate','J3315','3','','1','0','','','','0','1','0','0'),
('14123','Injection; spectinomycin dihydrochloride; up to 2 gm','Spectinomycn di-hcl inj','J3320','3','','1','0','','','','0','1','0','0'),
('14124','Injection; urea; up to 40 gm','Urea injection','J3350','3','','1','0','','','','0','1','0','0'),
('14125','Injection; urofollitropin; 75 iu','Urofollitropin; 75 iu','J3355','3','','1','0','','','','0','1','0','0'),
('14126','Ustekinumab; for subcutaneous injection; 1 mg','Ustekinumab sub cu inj; 1 mg','J3357','3','','1','0','','','','0','1','0','0'),
('14127','Injection; diazepam; up to 5 mg','Diazepam injection','J3360','3','','1','0','','','','0','1','0','0'),
('14128','Injection; urokinase; 5000 iu vial','Urokinase 5000 iu injection','J3364','3','','1','0','','','','0','1','0','0'),
('14129','Injection; iv; urokinase; 250;000 i.u. vial','Urokinase 250;000 iu inj','J3365','3','','1','0','','','','0','1','0','0'),
('14130','Injection; vancomycin hcl; 500 mg','Vancomycin hcl injection','J3370','3','','1','0','','','','0','1','0','0'),
('14131','Injection; vedolizumab; 1 mg','Injection; vedolizumab','J3380','3','','1','0','','','','0','1','0','0'),
('14132','Injection; velaglucerase alfa; 100 units','Velaglucerase alfa','J3385','3','','1','0','','','','0','1','0','0'),
('14133','Injection; verteporfin; 0.1 mg','Verteporfin injection','J3396','3','','1','0','','','','0','1','0','0'),
('14134','Injection; triflupromazine hcl; up to 20 mg','Triflupromazine hcl inj','J3400','3','','1','0','','','','0','1','0','0'),
('14135','Injection; hydroxyzine hcl; up to 25 mg','Hydroxyzine hcl injection','J3410','3','','1','0','','','','0','1','0','0'),
('14136','Injection; thiamine hcl; 100 mg','Thiamine hcl 100 mg','J3411','3','','1','0','','','','0','1','0','0'),
('14137','Injection; pyridoxine hcl; 100 mg','Pyridoxine hcl 100 mg','J3415','3','','1','0','','','','0','1','0','0'),
('14138','Injection; vitamin b-12 cyanocobalamin; up to 1000 mcg','Vitamin b12 injection','J3420','3','','1','0','','','','0','1','0','0'),
('14139','Injection; phytonadione (vitamin k); per 1 mg','Vitamin k phytonadione inj','J3430','3','','1','0','','','','0','1','0','0'),
('14140','Injection; voriconazole; 10 mg','Injection; voriconazole','J3465','3','','1','0','','','','0','1','0','0'),
('14141','Injection; hyaluronidase; up to 150 units','Hyaluronidase injection','J3470','3','','1','0','','','','0','1','0','0'),
('14142','Injection; hyaluronidase; ovine; preservative free; per 1 usp unit (up to 999 usp units)','Ovine; up to 999 usp units','J3471','3','','1','0','','','','0','1','0','0'),
('14143','Injection; hyaluronidase; ovine; preservative free; per 1000 usp units','Ovine; 1000 usp units','J3472','3','','1','0','','','','0','1','0','0'),
('14144','Injection; hyaluronidase; recombinant; 1 usp unit','Hyaluronidase recombinant','J3473','3','','1','0','','','','0','1','0','0'),
('14145','Injection; magnesium sulfate; per 500 mg','Inj magnesium sulfate','J3475','3','','1','0','','','','0','1','0','0'),
('14146','Injection; potassium chloride; per 2 meq','Inj potassium chloride','J3480','3','','1','0','','','','0','1','0','0'),
('14147','Injection; zidovudine; 10 mg','Zidovudine','J3485','3','','1','0','','','','0','1','0','0'),
('14148','Injection; ziprasidone mesylate; 10 mg','Ziprasidone mesylate','J3486','3','','1','0','','','','0','1','0','0'),
('14149','Injection; zoledronic acid (zometa); 1 mg','Zoledronic acid','J3487','3','','1','0','','','','0','1','0','0'),
('14150','Injection; zoledronic acid (reclast); 1 mg','Reclast injection','J3488','3','','1','0','','','','0','1','0','0'),
('14151','Injection; zoledronic acid; 1 mg','Zoledronic acid 1mg','J3489','3','','1','0','','','','0','1','0','0'),
('14152','Unclassified drugs','Drugs unclassified injection','J3490','3','','1','0','','','','0','1','0','0'),
('14153','Edetate disodium; per 150 mg','Edetate disodium per 150 mg','J3520','3','','1','0','','','','0','1','0','0'),
('14154','Nasal vaccine inhalation','Nasal vaccine inhalation','J3530','3','','1','0','','','','0','1','0','0'),
('14155','Drug administered through a metered dose inhaler','Metered dose inhaler drug','J3535','3','','1','0','','','','0','1','0','0'),
('14156','Laetrile; amygdalin; vitamin b17','Laetrile amygdalin vit b17','J3570','3','','1','0','','','','0','1','0','0'),
('14157','Unclassified biologics','Unclassified biologics','J3590','3','','1','0','','','','0','1','0','0'),
('14158','Infusion; normal saline solution ; 1000 cc','Normal saline solution infus','J7030','3','','1','0','','','','0','1','0','0'),
('14159','Infusion; normal saline solution; sterile (500 ml = 1 unit)','Normal saline solution infus','J7040','3','','1','0','','','','0','1','0','0'),
('14160','5% dextrose/normal saline (500 ml = 1 unit)','5% dextrose/normal saline','J7042','3','','1','0','','','','0','1','0','0'),
('14161','Infusion; normal saline solution; 250 cc','Normal saline solution infus','J7050','3','','1','0','','','','0','1','0','0'),
('14162','5% dextrose/water (500 ml = 1 unit)','5% dextrose/water','J7060','3','','1','0','','','','0','1','0','0'),
('14163','Infusion; d5w; 1000 cc','D5w infusion','J7070','3','','1','0','','','','0','1','0','0'),
('14164','Infusion; dextran 40; 500 ml','Dextran 40 infusion','J7100','3','','1','0','','','','0','1','0','0'),
('14165','Infusion; dextran 75; 500 ml','Dextran 75 infusion','J7110','3','','1','0','','','','0','1','0','0'),
('14166','Ringers lactate infusion; up to 1000 cc','Ringers lactate infusion','J7120','3','','1','0','','','','0','1','0','0'),
('14167','5% dextrose in lactated ringers infusion; up to 1000 cc','5% dextrose in lac ringers','J7121','3','','1','0','','','','0','1','0','0'),
('14168','Hypertonic saline solution; 1 ml','Hypertonic saline sol','J7131','3','','1','0','','','','0','1','0','0'),
('14169','Injection; factor x; (human); 1 i.u.','Inj; factor x; (human); 1iu','J7175','3','','1','0','','','','0','1','0','0'),
('14170','Injection; human fibrinogen concentrate; 1 mg','Human fibrinogen conc inj','J7178','3','','1','0','','','','0','1','0','0'),
('14171','Injection; von willebrand factor (recombinant); (vonvendi); 1 i.u. vwf:rco','Vonvendi inj 1 iu vwf:rco','J7179','3','','1','0','','','','0','1','0','0'),
('14172','Injection; factor xiii (antihemophilic factor; human); 1 i.u.','Factor xiii anti-hem factor','J7180','3','','1','0','','','','0','1','0','0'),
('14173','Injection; factor xiii a-subunit; (recombinant); per iu','Factor xiii recomb a-subunit','J7181','3','','1','0','','','','0','1','0','0'),
('14174','Injection; factor viii; (antihemophilic factor; recombinant); (novoeight); per iu','Factor viii recomb novoeight','J7182','3','','1','0','','','','0','1','0','0'),
('14175','Injection; von willebrand factor complex (human); wilate; 1 i.u. vwf:rco','Wilate injection','J7183','3','','1','0','','','','0','1','0','0'),
('14176','Injection; factor viii (antihemophilic factor; recombinant) (xyntha); per i.u.','Xyntha inj','J7185','3','','1','0','','','','0','1','0','0'),
('14177','Injection; antihemophilic factor viii/von willebrand factor complex (human); per factor viii i.u.','Antihemophilic viii/vwf comp','J7186','3','','1','0','','','','0','1','0','0'),
('14178','Injection; von willebrand factor complex (humate-p); per iu vwf:rco','Humate-p; inj','J7187','3','','1','0','','','','0','1','0','0'),
('14179','Injection; factor viii (antihemophilic factor; recombinant); (obizur); per i.u.','Factor viii recomb obizur','J7188','3','','1','0','','','','0','1','0','0'),
('14180','Factor viia (antihemophilic factor; recombinant); per 1 microgram','Factor viia','J7189','3','','1','0','','','','0','1','0','0'),
('14181','Factor viii (antihemophilic factor; human) per i.u.','Factor viii','J7190','3','','1','0','','','','0','1','0','0'),
('14182','Factor viii (antihemophilic factor (porcine)); per i.u.','Factor viii (porcine)','J7191','3','','1','0','','','','0','1','0','0'),
('14183','Factor viii (antihemophilic factor; recombinant) per i.u.; not otherwise specified','Factor viii recombinant nos','J7192','3','','1','0','','','','0','1','0','0'),
('14184','Factor ix (antihemophilic factor; purified; non-recombinant) per i.u.','Factor ix non-recombinant','J7193','3','','1','0','','','','0','1','0','0'),
('14185','Factor ix; complex; per i.u.','Factor ix complex','J7194','3','','1','0','','','','0','1','0','0'),
('14186','Injection; factor ix (antihemophilic factor; recombinant) per iu; not otherwise specified','Factor ix recombinant nos','J7195','3','','1','0','','','','0','1','0','0'),
('14187','Injection; antithrombin recombinant; 50 i.u.','Antithrombin recombinant','J7196','3','','1','0','','','','0','1','0','0'),
('14188','Antithrombin iii (human); per i.u.','Antithrombin iii injection','J7197','3','','1','0','','','','0','1','0','0'),
('14189','Anti-inhibitor; per i.u.','Anti-inhibitor','J7198','3','','1','0','','','','0','1','0','0'),
('14190','Hemophilia clotting factor; not otherwise classified','Hemophilia clot factor noc','J7199','3','','1','0','','','','0','1','0','0'),
('14191','Injection; factor ix; (antihemophilic factor; recombinant); rixubis; per iu','Factor ix recombinan rixubis','J7200','3','','1','0','','','','0','1','0','0'),
('14192','Injection; factor ix; fc fusion protein; (recombinant); alprolix; 1 i.u.','Factor ix alprolix recomb','J7201','3','','1','0','','','','0','1','0','0'),
('14193','Injection; factor ix; albumin fusion protein; (recombinant); idelvion; 1 i.u.','Factor ix idelvion inj','J7202','3','','1','0','','','','0','1','0','0'),
('14194','Injection; factor viii fc fusion protein (recombinant); per iu','Factor viii fc fusion recomb','J7205','3','','1','0','','','','0','1','0','0'),
('14195','Injection; factor viii; (antihemophilic factor; recombinant); pegylated; 1 i.u.','Factor viii pegylated recomb','J7207','3','','1','0','','','','0','1','0','0'),
('14196','Injection; factor viii; (antihemophilic factor; recombinant); (nuwiq); 1 i.u.','Factor viii nuwiq recomb 1iu','J7209','3','','1','0','','','','0','1','0','0'),
('14197','Levonorgestrel-releasing intrauterine contraceptive system (liletta); 52 mg','Liletta; 52 mg','J7297','3','','1','0','','','','0','1','0','0'),
('14198','Levonorgestrel-releasing intrauterine contraceptive system (mirena); 52 mg','Mirena; 52 mg','J7298','3','','1','0','','','','0','1','0','0'),
('14199','Intrauterine copper contraceptive','Intraut copper contraceptive','J7300','3','','1','0','','','','0','1','0','0'),
('14200','Levonorgestrel-releasing intrauterine contraceptive system (skyla); 13.5 mg','Skyla; 13.5 mg','J7301','3','','1','0','','','','0','1','0','0'),
('14201','Levonorgestrel-releasing intrauterine contraceptive system; 52 mg','Levonorgestrel iu 52 mg','J7302','3','','1','0','','','','0','1','0','0'),
('14202','Contraceptive supply; hormone containing vaginal ring; each','Contraceptive vaginal ring','J7303','3','','1','0','','','','0','1','0','0'),
('14203','Contraceptive supply; hormone containing patch; each','Contraceptive hormone patch','J7304','3','','1','0','','','','0','1','0','0'),
('14204','Levonorgestrel (contraceptive) implant system; including implants and supplies','Levonorgestrel implant sys','J7306','3','','1','0','','','','0','1','0','0'),
('14205','Etonogestrel (contraceptive) implant system; including implant and supplies','Etonogestrel implant system','J7307','3','','1','0','','','','0','1','0','0'),
('14206','Aminolevulinic acid hcl for topical administration; 20%; single unit dosage form (354 mg)','Aminolevulinic acid hcl top','J7308','3','','1','0','','','','0','1','0','0'),
('14207','Methyl aminolevulinate (mal) for topical administration; 16.8%; 1 gram','Methyl aminolevulinate; top','J7309','3','','1','0','','','','0','1','0','0'),
('14208','Ganciclovir; 4.5 mg; long-acting implant','Ganciclovir long act implant','J7310','3','','1','0','','','','0','1','0','0'),
('14209','Fluocinolone acetonide; intravitreal implant','Fluocinolone acetonide implt','J7311','3','','1','0','','','','0','1','0','0'),
('14210','Injection; dexamethasone; intravitreal implant; 0.1 mg','Dexamethasone intra implant','J7312','3','','1','0','','','','0','1','0','0'),
('14211','Injection; fluocinolone acetonide; intravitreal implant; 0.01 mg','Fluocinol acet intravit imp','J7313','3','','1','0','','','','0','1','0','0'),
('14212','Mitomycin; ophthalmic; 0.2 mg','Ophthalmic mitomycin','J7315','3','','1','0','','','','0','1','0','0'),
('14213','Injection; ocriplasmin; 0.125 mg','Inj; ocriplasmin; 0.125 mg','J7316','3','','1','0','','','','0','1','0','0'),
('14214','Hyaluronan or derivitive; genvisc 850; for intra-articular injection; 1 mg','Genvisc 850; inj; 1mg','J7320','3','','1','0','','','','0','1','0','0'),
('14215','Hyaluronan or derivative; hyalgan or supartz; for intra-articular injection; per dose','Hyalgan/supartz inj per dose','J7321','3','','1','0','','','','0','1','0','0'),
('14216','Hyaluronan or derivative; hymovis; for intra-articular injection; 1 mg','Hymovis injection 1 mg','J7322','3','','1','0','','','','0','1','0','0'),
('14217','Hyaluronan or derivative; euflexxa; for intra-articular injection; per dose','Euflexxa inj per dose','J7323','3','','1','0','','','','0','1','0','0'),
('14218','Hyaluronan or derivative; orthovisc; for intra-articular injection; per dose','Orthovisc inj per dose','J7324','3','','1','0','','','','0','1','0','0'),
('14219','Hyaluronan or derivative; synvisc or synvisc-one; for intra-articular injection; 1 mg','Synvisc or synvisc-one','J7325','3','','1','0','','','','0','1','0','0'),
('14220','Hyaluronan or derivative; gel-one; for intra-articular injection; per dose','Gel-one','J7326','3','','1','0','','','','0','1','0','0'),
('14221','Hyaluronan or derivative; monovisc; for intra-articular injection; per dose','Monovisc inj per dose','J7327','3','','1','0','','','','0','1','0','0'),
('14222','Hyaluronan or derivative; gel-syn; for intra-articular injection; 0.1 mg','Gel-syn injection 0.1 mg','J7328','3','','1','0','','','','0','1','0','0'),
('14223','Autologous cultured chondrocytes; implant','Cultured chondrocytes implnt','J7330','3','','1','0','','','','0','1','0','0'),
('14224','Capsaicin 8% patch; per 10 square centimeters','Capsaicin 8% patch','J7335','3','','1','0','','','','0','1','0','0'),
('14225','Capsaicin 8% patch; per square centimeter','Capsaicin 8% patch','J7336','3','','1','0','','','','0','1','0','0'),
('14226','Carbidopa 5 mg/levodopa 20 mg enteral suspension; 100 ml','Carbidopa levodopa ent 100ml','J7340','3','','1','0','','','','0','1','0','0'),
('14227','Installation; ciprofloxacin otic suspension; 6 mg','Ciprofloxacin otic susp 6 mg','J7342','3','','1','0','','','','0','1','0','0'),
('14228','Azathioprine; oral; 50 mg','Azathioprine oral 50mg','J7500','3','','1','0','','','','0','1','0','0'),
('14229','Azathioprine; parenteral; 100 mg','Azathioprine parenteral','J7501','3','','1','0','','','','0','1','0','0'),
('14230','Cyclosporine; oral; 100 mg','Cyclosporine oral 100 mg','J7502','3','','1','0','','','','0','1','0','0'),
('14231','Tacrolimus; extended release; (envarsus xr); oral; 0.25 mg','Tacrol envarsus ex rel oral','J7503','3','','1','0','','','','0','1','0','0'),
('14232','Lymphocyte immune globulin; antithymocyte globulin; equine; parenteral; 250 mg','Lymphocyte immune globulin','J7504','3','','1','0','','','','0','1','0','0'),
('14233','Muromonab-cd3; parenteral; 5 mg','Monoclonal antibodies','J7505','3','','1','0','','','','0','1','0','0'),
('14234','Prednisone; oral; per 5 mg','Prednisone oral','J7506','3','','1','0','','','','0','1','0','0'),
('14235','Tacrolimus; immediate release; oral; 1 mg','Tacrolimus imme rel oral 1mg','J7507','3','','1','0','','','','0','1','0','0'),
('14236','Tacrolimus; extended release; (astagraf xl); oral; 0.1 mg','Tacrol astagraf ex rel oral','J7508','3','','1','0','','','','0','1','0','0'),
('14237','Methylprednisolone oral; per 4 mg','Methylprednisolone oral','J7509','3','','1','0','','','','0','1','0','0'),
('14238','Prednisolone oral; per 5 mg','Prednisolone oral per 5 mg','J7510','3','','1','0','','','','0','1','0','0'),
('14239','Lymphocyte immune globulin; antithymocyte globulin; rabbit; parenteral; 25 mg','Antithymocyte globuln rabbit','J7511','3','','1','0','','','','0','1','0','0'),
('14240','Prednisone; immediate release or delayed release; oral; 1 mg','Prednisone ir or dr oral 1mg','J7512','3','','1','0','','','','0','1','0','0'),
('14241','Daclizumab; parenteral; 25 mg','Daclizumab; parenteral','J7513','3','','1','0','','','','0','1','0','0'),
('14242','Cyclosporine; oral; 25 mg','Cyclosporine oral 25 mg','J7515','3','','1','0','','','','0','1','0','0'),
('14243','Cyclosporin; parenteral; 250 mg','Cyclosporin parenteral 250mg','J7516','3','','1','0','','','','0','1','0','0'),
('14244','Mycophenolate mofetil; oral; 250 mg','Mycophenolate mofetil oral','J7517','3','','1','0','','','','0','1','0','0'),
('14245','Mycophenolic acid; oral; 180 mg','Mycophenolic acid','J7518','3','','1','0','','','','0','1','0','0'),
('14246','Sirolimus; oral; 1 mg','Sirolimus; oral','J7520','3','','1','0','','','','0','1','0','0'),
('14247','Tacrolimus; parenteral; 5 mg','Tacrolimus injection','J7525','3','','1','0','','','','0','1','0','0'),
('14248','Everolimus; oral; 0.25 mg','Oral everolimus','J7527','3','','1','0','','','','0','1','0','0'),
('14249','Immunosuppressive drug; not otherwise classified','Immunosuppressive drug noc','J7599','3','','1','0','','','','0','1','0','0'),
('14250','Acetylcysteine; inhalation solution; compounded product; administered through dme; unit dose form; per gram','Acetylcysteine comp unit','J7604','3','','1','0','','','','0','1','0','0'),
('14251','Arformoterol; inhalation solution; fda approved final product; non-compounded; administered through dme; unit dose form; 15 micrograms','Arformoterol non-comp unit','J7605','3','','1','0','','','','0','1','0','0'),
('14252','Formoterol fumarate; inhalation solution; fda approved final product; non-compounded; administered through dme; unit dose form; 20 micrograms','Formoterol fumarate; inh','J7606','3','','1','0','','','','0','1','0','0'),
('14253','Levalbuterol; inhalation solution; compounded product; administered through dme; concentrated form; 0.5 mg','Levalbuterol comp con','J7607','3','','1','0','','','','0','1','0','0'),
('14254','Acetylcysteine; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per gram','Acetylcysteine non-comp unit','J7608','3','','1','0','','','','0','1','0','0'),
('14255','Albuterol; inhalation solution; compounded product; administered through dme; unit dose; 1 mg','Albuterol comp unit','J7609','3','','1','0','','','','0','1','0','0'),
('14256','Albuterol; inhalation solution; compounded product; administered through dme; concentrated form; 1 mg','Albuterol comp con','J7610','3','','1','0','','','','0','1','0','0'),
('14257','Albuterol; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; 1 mg','Albuterol non-comp con','J7611','3','','1','0','','','','0','1','0','0'),
('14258','Levalbuterol; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; 0.5 mg','Levalbuterol non-comp con','J7612','3','','1','0','','','','0','1','0','0'),
('14259','Albuterol; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose; 1 mg','Albuterol non-comp unit','J7613','3','','1','0','','','','0','1','0','0'),
('14260','Levalbuterol; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose; 0.5 mg','Levalbuterol non-comp unit','J7614','3','','1','0','','','','0','1','0','0'),
('14261','Levalbuterol; inhalation solution; compounded product; administered through dme; unit dose; 0.5 mg','Levalbuterol comp unit','J7615','3','','1','0','','','','0','1','0','0'),
('14262','Albuterol; up to 2.5 mg and ipratropium bromide; up to 0.5 mg; fda-approved final product; non-compounded; administered through dme','Albuterol ipratrop non-comp','J7620','3','','1','0','','','','0','1','0','0'),
('14263','Beclomethasone; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Beclomethasone comp unit','J7622','3','','1','0','','','','0','1','0','0'),
('14264','Betamethasone; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Betamethasone comp unit','J7624','3','','1','0','','','','0','1','0','0'),
('14265','Budesonide; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; up to 0.5 mg','Budesonide non-comp unit','J7626','3','','1','0','','','','0','1','0','0'),
('14266','Budesonide; inhalation solution; compounded product; administered through dme; unit dose form; up to 0.5 mg','Budesonide comp unit','J7627','3','','1','0','','','','0','1','0','0'),
('14267','Bitolterol mesylate; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Bitolterol mesylate comp con','J7628','3','','1','0','','','','0','1','0','0'),
('14268','Bitolterol mesylate; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Bitolterol mesylate comp unt','J7629','3','','1','0','','','','0','1','0','0'),
('14269','Cromolyn sodium; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per 10 milligrams','Cromolyn sodium noncomp unit','J7631','3','','1','0','','','','0','1','0','0'),
('14270','Cromolyn sodium; inhalation solution; compounded product; administered through dme; unit dose form; per 10 milligrams','Cromolyn sodium comp unit','J7632','3','','1','0','','','','0','1','0','0'),
('14271','Budesonide; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; per 0.25 milligram','Budesonide non-comp con','J7633','3','','1','0','','','','0','1','0','0'),
('14272','Budesonide; inhalation solution; compounded product; administered through dme; concentrated form; per 0.25 milligram','Budesonide comp con','J7634','3','','1','0','','','','0','1','0','0'),
('14273','Atropine; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Atropine comp con','J7635','3','','1','0','','','','0','1','0','0'),
('14274','Atropine; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Atropine comp unit','J7636','3','','1','0','','','','0','1','0','0'),
('14275','Dexamethasone; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Dexamethasone comp con','J7637','3','','1','0','','','','0','1','0','0'),
('14276','Dexamethasone; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Dexamethasone comp unit','J7638','3','','1','0','','','','0','1','0','0'),
('14277','Dornase alfa; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per milligram','Dornase alfa non-comp unit','J7639','3','','1','0','','','','0','1','0','0'),
('14278','Formoterol; inhalation solution; compounded product; administered through dme; unit dose form; 12 micrograms','Formoterol comp unit','J7640','3','','1','0','','','','0','1','0','0'),
('14279','Flunisolide; inhalation solution; compounded product; administered through dme; unit dose; per milligram','Flunisolide comp unit','J7641','3','','1','0','','','','0','1','0','0'),
('14280','Glycopyrrolate; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Glycopyrrolate comp con','J7642','3','','1','0','','','','0','1','0','0'),
('14281','Glycopyrrolate; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Glycopyrrolate comp unit','J7643','3','','1','0','','','','0','1','0','0'),
('14282','Ipratropium bromide; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per milligram','Ipratropium bromide non-comp','J7644','3','','1','0','','','','0','1','0','0'),
('14283','Ipratropium bromide; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Ipratropium bromide comp','J7645','3','','1','0','','','','0','1','0','0'),
('14284','Isoetharine hcl; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Isoetharine comp con','J7647','3','','1','0','','','','0','1','0','0'),
('14285','Isoetharine hcl; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; per milligram','Isoetharine non-comp con','J7648','3','','1','0','','','','0','1','0','0'),
('14286','Isoetharine hcl; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per milligram','Isoetharine non-comp unit','J7649','3','','1','0','','','','0','1','0','0'),
('14287','Isoetharine hcl; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Isoetharine comp unit','J7650','3','','1','0','','','','0','1','0','0'),
('14288','Isoproterenol hcl; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Isoproterenol comp con','J7657','3','','1','0','','','','0','1','0','0'),
('14289','Isoproterenol hcl; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; per milligram','Isoproterenol non-comp con','J7658','3','','1','0','','','','0','1','0','0'),
('14290','Isoproterenol hcl; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per milligram','Isoproterenol non-comp unit','J7659','3','','1','0','','','','0','1','0','0'),
('14291','Isoproterenol hcl; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Isoproterenol comp unit','J7660','3','','1','0','','','','0','1','0','0'),
('14292','Mannitol; administered through an inhaler; 5 mg','Mannitol for inhaler','J7665','3','','1','0','','','','0','1','0','0'),
('14293','Metaproterenol sulfate; inhalation solution; compounded product; concentrated form; per 10 milligrams','Metaproterenol comp con','J7667','3','','1','0','','','','0','1','0','0'),
('14294','Metaproterenol sulfate; inhalation solution; fda-approved final product; non-compounded; administered through dme; concentrated form; per 10 milligrams','Metaproterenol non-comp con','J7668','3','','1','0','','','','0','1','0','0'),
('14295','Metaproterenol sulfate; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; per 10 milligrams','Metaproterenol non-comp unit','J7669','3','','1','0','','','','0','1','0','0'),
('14296','Metaproterenol sulfate; inhalation solution; compounded product; administered through dme; unit dose form; per 10 milligrams','Metaproterenol comp unit','J7670','3','','1','0','','','','0','1','0','0'),
('14297','Methacholine chloride administered as inhalation solution through a nebulizer; per 1 mg','Methacholine chloride; neb','J7674','3','','1','0','','','','0','1','0','0'),
('14298','Pentamidine isethionate; inhalation solution; compounded product; administered through dme; unit dose form; per 300 mg','Pentamidine comp unit dose','J7676','3','','1','0','','','','0','1','0','0'),
('14299','Terbutaline sulfate; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Terbutaline sulf comp con','J7680','3','','1','0','','','','0','1','0','0'),
('14300','Terbutaline sulfate; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Terbutaline sulf comp unit','J7681','3','','1','0','','','','0','1','0','0'),
('14301','Tobramycin; inhalation solution; fda-approved final product; non-compounded; unit dose form; administered through dme; per 300 milligrams','Tobramycin non-comp unit','J7682','3','','1','0','','','','0','1','0','0'),
('14302','Triamcinolone; inhalation solution; compounded product; administered through dme; concentrated form; per milligram','Triamcinolone comp con','J7683','3','','1','0','','','','0','1','0','0'),
('14303','Triamcinolone; inhalation solution; compounded product; administered through dme; unit dose form; per milligram','Triamcinolone comp unit','J7684','3','','1','0','','','','0','1','0','0'),
('14304','Tobramycin; inhalation solution; compounded product; administered through dme; unit dose form; per 300 milligrams','Tobramycin comp unit','J7685','3','','1','0','','','','0','1','0','0'),
('14305','Treprostinil; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; 1.74 mg','Treprostinil; non-comp unit','J7686','3','','1','0','','','','0','1','0','0'),
('14306','Noc drugs; inhalation solution administered through dme','Inhalation solution for dme','J7699','3','','1','0','','','','0','1','0','0'),
('14307','Noc drugs; other than inhalation drugs; administered through dme','Non-inhalation drug for dme','J7799','3','','1','0','','','','0','1','0','0'),
('14308','Compounded drug; not otherwise classified','Compounded drug; noc','J7999','3','','1','0','','','','0','1','0','0'),
('14309','Antiemetic drug; rectal/suppository; not otherwise specified','Antiemetic rectal/supp nos','J8498','3','','1','0','','','','0','1','0','0'),
('14310','Prescription drug; oral; non chemotherapeutic; nos','Oral prescrip drug non chemo','J8499','3','','1','0','','','','0','1','0','0'),
('14311','Aprepitant; oral; 5 mg','Oral aprepitant','J8501','3','','1','0','','','','0','1','0','0'),
('14312','Busulfan; oral; 2 mg','Oral busulfan','J8510','3','','1','0','','','','0','1','0','0'),
('14313','Cabergoline; oral; 0.25 mg','Cabergoline; oral 0.25mg','J8515','3','','1','0','','','','0','1','0','0'),
('14314','Capecitabine; oral; 150 mg','Capecitabine; oral; 150 mg','J8520','3','','1','0','','','','0','1','0','0'),
('14315','Capecitabine; oral; 500 mg','Capecitabine; oral; 500 mg','J8521','3','','1','0','','','','0','1','0','0'),
('14316','Cyclophosphamide; oral; 25 mg','Cyclophosphamide oral 25 mg','J8530','3','','1','0','','','','0','1','0','0'),
('14317','Dexamethasone; oral; 0.25 mg','Oral dexamethasone','J8540','3','','1','0','','','','0','1','0','0'),
('14318','Etoposide; oral; 50 mg','Etoposide oral 50 mg','J8560','3','','1','0','','','','0','1','0','0'),
('14319','Fludarabine phosphate; oral; 10 mg','Oral fludarabine phosphate','J8562','3','','1','0','','','','0','1','0','0'),
('14320','Gefitinib; oral; 250 mg','Gefitinib oral','J8565','3','','1','0','','','','0','1','0','0'),
('14321','Antiemetic drug; oral; not otherwise specified','Antiemetic drug oral nos','J8597','3','','1','0','','','','0','1','0','0'),
('14322','Melphalan; oral; 2 mg','Melphalan oral 2 mg','J8600','3','','1','0','','','','0','1','0','0'),
('14323','Methotrexate; oral; 2.5 mg','Methotrexate oral 2.5 mg','J8610','3','','1','0','','','','0','1','0','0'),
('14324','Nabilone; oral; 1 mg','Nabilone oral','J8650','3','','1','0','','','','0','1','0','0'),
('14325','Netupitant 300 mg and palonosetron 0.5 mg','Netupitant palonosetron oral','J8655','3','','1','0','','','','0','1','0','0'),
('14326','Rolapitant; oral; 1 mg','Rolapitant; oral; 1mg','J8670','3','','1','0','','','','0','1','0','0'),
('14327','Temozolomide; oral; 5 mg','Temozolomide','J8700','3','','1','0','','','','0','1','0','0'),
('14328','Topotecan; oral; 0.25 mg','Topotecan oral','J8705','3','','1','0','','','','0','1','0','0'),
('14329','Prescription drug; oral; chemotherapeutic; nos','Oral prescription drug chemo','J8999','3','','1','0','','','','0','1','0','0'),
('14330','Injection; doxorubicin hydrochloride; 10 mg','Doxorubicin hcl injection','J9000','3','','1','0','','','','0','1','0','0'),
('14331','Injection; doxorubicin hydrochloride; liposomal; doxil; 10 mg','Doxil injection','J9002','3','','1','0','','','','0','1','0','0'),
('14332','Injection; alemtuzumab; 10 mg','Alemtuzumab injection','J9010','3','','1','0','','','','0','1','0','0'),
('14333','Injection; aldesleukin; per single use vial','Aldesleukin injection','J9015','3','','1','0','','','','0','1','0','0'),
('14334','Injection; arsenic trioxide; 1 mg','Arsenic trioxide injection','J9017','3','','1','0','','','','0','1','0','0'),
('14335','Injection; asparaginase (erwinaze); 1;000 iu','Erwinaze injection','J9019','3','','1','0','','','','0','1','0','0'),
('14336','Injection; asparaginase; not otherwise specified; 10;000 units','Asparaginase; nos','J9020','3','','1','0','','','','0','1','0','0'),
('14337','Injection; azacitidine; 1 mg','Azacitidine injection','J9025','3','','1','0','','','','0','1','0','0'),
('14338','Injection; clofarabine; 1 mg','Clofarabine injection','J9027','3','','1','0','','','','0','1','0','0'),
('14339','Bcg (intravesical) per instillation','Bcg live intravesical vac','J9031','3','','1','0','','','','0','1','0','0'),
('14340','Injection; belinostat; 10 mg','Injection; belinostat; 10mg','J9032','3','','1','0','','','','0','1','0','0'),
('14341','Injection; bendamustine hcl (treanda); 1 mg','Inj.; treanda 1 mg','J9033','3','','1','0','','','','0','1','0','0'),
('14342','Injection; bendamustine hcl (bendeka); 1 mg','Inj.; bendeka 1 mg','J9034','3','','1','0','','','','0','1','0','0'),
('14343','Injection; bevacizumab; 10 mg','Bevacizumab injection','J9035','3','','1','0','','','','0','1','0','0'),
('14344','Injection; blinatumomab; 1 microgram','Injection; blinatumomab','J9039','3','','1','0','','','','0','1','0','0'),
('14345','Injection; bleomycin sulfate; 15 units','Bleomycin sulfate injection','J9040','3','','1','0','','','','0','1','0','0'),
('14346','Injection; bortezomib; 0.1 mg','Bortezomib injection','J9041','3','','1','0','','','','0','1','0','0'),
('14347','Injection; brentuximab vedotin; 1 mg','Brentuximab vedotin inj','J9042','3','','1','0','','','','0','1','0','0'),
('14348','Injection; cabazitaxel; 1 mg','Cabazitaxel injection','J9043','3','','1','0','','','','0','1','0','0'),
('14349','Injection; carboplatin; 50 mg','Carboplatin injection','J9045','3','','1','0','','','','0','1','0','0'),
('14350','Injection; carfilzomib; 1 mg','Injection; carfilzomib; 1 mg','J9047','3','','1','0','','','','0','1','0','0'),
('14351','Injection; carmustine; 100 mg','Carmustine injection','J9050','3','','1','0','','','','0','1','0','0'),
('14352','Injection; cetuximab; 10 mg','Cetuximab injection','J9055','3','','1','0','','','','0','1','0','0'),
('14353','Injection; cisplatin; powder or solution; 10 mg','Cisplatin 10 mg injection','J9060','3','','1','0','','','','0','1','0','0'),
('14354','Injection; cladribine; per 1 mg','Inj cladribine per 1 mg','J9065','3','','1','0','','','','0','1','0','0'),
('14355','Cyclophosphamide; 100 mg','Cyclophosphamide 100 mg inj','J9070','3','','1','0','','','','0','1','0','0'),
('14356','Injection; cytarabine liposome; 10 mg','Cytarabine liposome inj','J9098','3','','1','0','','','','0','1','0','0'),
('14357','Injection; cytarabine; 100 mg','Cytarabine hcl 100 mg inj','J9100','3','','1','0','','','','0','1','0','0'),
('14358','Injection; dactinomycin; 0.5 mg','Dactinomycin injection','J9120','3','','1','0','','','','0','1','0','0'),
('14359','Dacarbazine; 100 mg','Dacarbazine 100 mg inj','J9130','3','','1','0','','','','0','1','0','0'),
('14360','Injection; daratumumab; 10 mg','Injection; daratumumab 10 mg','J9145','3','','1','0','','','','0','1','0','0'),
('14361','Injection; daunorubicin; 10 mg','Daunorubicin injection','J9150','3','','1','0','','','','0','1','0','0'),
('14362','Injection; daunorubicin citrate; liposomal formulation; 10 mg','Daunorubicin citrate inj','J9151','3','','1','0','','','','0','1','0','0'),
('14363','Injection; degarelix; 1 mg','Degarelix injection','J9155','3','','1','0','','','','0','1','0','0'),
('14364','Injection; denileukin diftitox; 300 micrograms','Denileukin diftitox inj','J9160','3','','1','0','','','','0','1','0','0'),
('14365','Injection; diethylstilbestrol diphosphate; 250 mg','Diethylstilbestrol injection','J9165','3','','1','0','','','','0','1','0','0'),
('14366','Injection; docetaxel; 1 mg','Docetaxel injection','J9171','3','','1','0','','','','0','1','0','0'),
('14367','Injection; elliotts b solution; 1 ml','Elliotts b solution per ml','J9175','3','','1','0','','','','0','1','0','0'),
('14368','Injection; elotuzumab; 1 mg','Injection; elotuzumab; 1mg','J9176','3','','1','0','','','','0','1','0','0'),
('14369','Injection; epirubicin hcl; 2 mg','Inj; epirubicin hcl; 2 mg','J9178','3','','1','0','','','','0','1','0','0'),
('14370','Injection; eribulin mesylate; 0.1 mg','Eribulin mesylate injection','J9179','3','','1','0','','','','0','1','0','0'),
('14371','Injection; etoposide; 10 mg','Etoposide injection','J9181','3','','1','0','','','','0','1','0','0'),
('14372','Injection; fludarabine phosphate; 50 mg','Fludarabine phosphate inj','J9185','3','','1','0','','','','0','1','0','0'),
('14373','Injection; fluorouracil; 500 mg','Fluorouracil injection','J9190','3','','1','0','','','','0','1','0','0'),
('14374','Injection; floxuridine; 500 mg','Floxuridine injection','J9200','3','','1','0','','','','0','1','0','0'),
('14375','Injection; gemcitabine hydrochloride; 200 mg','Gemcitabine hcl injection','J9201','3','','1','0','','','','0','1','0','0'),
('14376','Goserelin acetate implant; per 3.6 mg','Goserelin acetate implant','J9202','3','','1','0','','','','0','1','0','0'),
('14377','Injection; irinotecan liposome; 1 mg','Inj irinotecan liposome 1 mg','J9205','3','','1','0','','','','0','1','0','0'),
('14378','Injection; irinotecan; 20 mg','Irinotecan injection','J9206','3','','1','0','','','','0','1','0','0'),
('14379','Injection; ixabepilone; 1 mg','Ixabepilone injection','J9207','3','','1','0','','','','0','1','0','0'),
('14380','Injection; ifosfamide; 1 gram','Ifosfamide injection','J9208','3','','1','0','','','','0','1','0','0'),
('14381','Injection; mesna; 200 mg','Mesna injection','J9209','3','','1','0','','','','0','1','0','0'),
('14382','Injection; idarubicin hydrochloride; 5 mg','Idarubicin hcl injection','J9211','3','','1','0','','','','0','1','0','0'),
('14383','Injection; interferon alfacon-1; recombinant; 1 microgram','Interferon alfacon-1 inj','J9212','3','','1','0','','','','0','1','0','0'),
('14384','Injection; interferon; alfa-2a; recombinant; 3 million units','Interferon alfa-2a inj','J9213','3','','1','0','','','','0','1','0','0'),
('14385','Injection; interferon; alfa-2b; recombinant; 1 million units','Interferon alfa-2b inj','J9214','3','','1','0','','','','0','1','0','0'),
('14386','Injection; interferon; alfa-n3; (human leukocyte derived); 250;000 iu','Interferon alfa-n3 inj','J9215','3','','1','0','','','','0','1','0','0'),
('14387','Injection; interferon; gamma 1-b; 3 million units','Interferon gamma 1-b inj','J9216','3','','1','0','','','','0','1','0','0'),
('14388','Leuprolide acetate (for depot suspension); 7.5 mg','Leuprolide acetate suspnsion','J9217','3','','1','0','','','','0','1','0','0'),
('14389','Leuprolide acetate; per 1 mg','Leuprolide acetate injeciton','J9218','3','','1','0','','','','0','1','0','0'),
('14390','Leuprolide acetate implant; 65 mg','Leuprolide acetate implant','J9219','3','','1','0','','','','0','1','0','0'),
('14391','Histrelin implant (vantas); 50 mg','Vantas implant','J9225','3','','1','0','','','','0','1','0','0'),
('14392','Histrelin implant (supprelin la); 50 mg','Supprelin la implant','J9226','3','','1','0','','','','0','1','0','0'),
('14393','Injection; ipilimumab; 1 mg','Ipilimumab injection','J9228','3','','1','0','','','','0','1','0','0'),
('14394','Injection; mechlorethamine hydrochloride; (nitrogen mustard); 10 mg','Mechlorethamine hcl inj','J9230','3','','1','0','','','','0','1','0','0'),
('14395','Injection; melphalan hydrochloride; 50 mg','Inj melphalan hydrochl 50 mg','J9245','3','','1','0','','','','0','1','0','0'),
('14396','Methotrexate sodium; 5 mg','Methotrexate sodium inj','J9250','3','','1','0','','','','0','1','0','0'),
('14397','Methotrexate sodium; 50 mg','Methotrexate sodium inj','J9260','3','','1','0','','','','0','1','0','0'),
('14398','Injection; nelarabine; 50 mg','Nelarabine injection','J9261','3','','1','0','','','','0','1','0','0'),
('14399','Injection; omacetaxine mepesuccinate; 0.01 mg','Inj; omacetaxine mep; 0.01mg','J9262','3','','1','0','','','','0','1','0','0'),
('14400','Injection; oxaliplatin; 0.5 mg','Oxaliplatin','J9263','3','','1','0','','','','0','1','0','0'),
('14401','Injection; paclitaxel protein-bound particles; 1 mg','Paclitaxel protein bound','J9264','3','','1','0','','','','0','1','0','0'),
('14402','Injection; paclitaxel; 30 mg','Paclitaxel injection','J9265','3','','1','0','','','','0','1','0','0'),
('14403','Injection; pegaspargase; per single dose vial','Pegaspargase injection','J9266','3','','1','0','','','','0','1','0','0'),
('14404','Injection; paclitaxel; 1 mg','Paclitaxel injection','J9267','3','','1','0','','','','0','1','0','0'),
('14405','Injection; pentostatin; 10 mg','Pentostatin injection','J9268','3','','1','0','','','','0','1','0','0'),
('14406','Injection; plicamycin; 2.5 mg','Plicamycin (mithramycin) inj','J9270','3','','1','0','','','','0','1','0','0'),
('14407','Injection; pembrolizumab; 1 mg','Inj pembrolizumab','J9271','3','','1','0','','','','0','1','0','0'),
('14408','Injection; mitomycin; 5 mg','Mitomycin injection','J9280','3','','1','0','','','','0','1','0','0'),
('14409','Injection; mitoxantrone hydrochloride; per 5 mg','Mitoxantrone hydrochl / 5 mg','J9293','3','','1','0','','','','0','1','0','0'),
('14410','Injection; necitumumab; 1 mg','Injection; necitumumab; 1 mg','J9295','3','','1','0','','','','0','1','0','0'),
('14411','Injection; nivolumab; 1 mg','Injection; nivolumab','J9299','3','','1','0','','','','0','1','0','0'),
('14412','Injection; gemtuzumab ozogamicin; 5 mg','Gemtuzumab ozogamicin inj','J9300','3','','1','0','','','','0','1','0','0'),
('14413','Injection; obinutuzumab; 10 mg','Obinutuzumab inj','J9301','3','','1','0','','','','0','1','0','0'),
('14414','Injection; ofatumumab; 10 mg','Ofatumumab injection','J9302','3','','1','0','','','','0','1','0','0'),
('14415','Injection; panitumumab; 10 mg','Panitumumab injection','J9303','3','','1','0','','','','0','1','0','0'),
('14416','Injection; pemetrexed; 10 mg','Pemetrexed injection','J9305','3','','1','0','','','','0','1','0','0'),
('14417','Injection; pertuzumab; 1 mg','Injection; pertuzumab; 1 mg','J9306','3','','1','0','','','','0','1','0','0'),
('14418','Injection; pralatrexate; 1 mg','Pralatrexate injection','J9307','3','','1','0','','','','0','1','0','0'),
('14419','Injection; ramucirumab; 5 mg','Injection; ramucirumab','J9308','3','','1','0','','','','0','1','0','0'),
('14420','Injection; rituximab; 100 mg','Rituximab injection','J9310','3','','1','0','','','','0','1','0','0'),
('14421','Injection; romidepsin; 1 mg','Romidepsin injection','J9315','3','','1','0','','','','0','1','0','0'),
('14422','Injection; streptozocin; 1 gram','Streptozocin injection','J9320','3','','1','0','','','','0','1','0','0'),
('14423','Injection; talimogene laherparepvec; per 1 million plaque forming units','Inj talimogene laherparepvec','J9325','3','','1','0','','','','0','1','0','0'),
('14424','Injection; temozolomide; 1 mg','Temozolomide injection','J9328','3','','1','0','','','','0','1','0','0'),
('14425','Injection; temsirolimus; 1 mg','Temsirolimus injection','J9330','3','','1','0','','','','0','1','0','0'),
('14426','Injection; thiotepa; 15 mg','Thiotepa injection','J9340','3','','1','0','','','','0','1','0','0'),
('14427','Injection; topotecan; 0.1 mg','Topotecan injection','J9351','3','','1','0','','','','0','1','0','0'),
('14428','Injection; trabectedin; 0.1 mg','Injection trabectedin 0.1mg','J9352','3','','1','0','','','','0','1','0','0'),
('14429','Injection; ado-trastuzumab emtansine; 1 mg','Inj; ado-trastuzumab emt 1mg','J9354','3','','1','0','','','','0','1','0','0'),
('14430','Injection; trastuzumab; 10 mg','Trastuzumab injection','J9355','3','','1','0','','','','0','1','0','0'),
('14431','Injection; valrubicin; intravesical; 200 mg','Valrubicin injection','J9357','3','','1','0','','','','0','1','0','0'),
('14432','Injection; vinblastine sulfate; 1 mg','Vinblastine sulfate inj','J9360','3','','1','0','','','','0','1','0','0'),
('14433','Vincristine sulfate; 1 mg','Vincristine sulfate 1 mg inj','J9370','3','','1','0','','','','0','1','0','0'),
('14434','Injection; vincristine sulfate liposome; 1 mg','Inj; vincristine sul lip 1mg','J9371','3','','1','0','','','','0','1','0','0'),
('14435','Injection; vinorelbine tartrate; 10 mg','Vinorelbine tartrate inj','J9390','3','','1','0','','','','0','1','0','0'),
('14436','Injection; fulvestrant; 25 mg','Injection; fulvestrant','J9395','3','','1','0','','','','0','1','0','0'),
('14437','Injection; ziv-aflibercept; 1 mg','Inj; ziv-aflibercept; 1mg','J9400','3','','1','0','','','','0','1','0','0'),
('14438','Injection; porfimer sodium; 75 mg','Porfimer sodium injection','J9600','3','','1','0','','','','0','1','0','0'),
('14439','Not otherwise classified; antineoplastic drugs','Chemotherapy drug','J9999','3','','1','0','','','','0','1','0','0'),
('14440','Standard wheelchair','Standard wheelchair','K0001','3','','1','0','','','','0','1','0','0'),
('14441','Standard hemi (low seat) wheelchair','Stnd hemi (low seat) whlchr','K0002','3','','1','0','','','','0','1','0','0'),
('14442','Lightweight wheelchair','Lightweight wheelchair','K0003','3','','1','0','','','','0','1','0','0'),
('14443','High strength; lightweight wheelchair','High strength ltwt whlchr','K0004','3','','1','0','','','','0','1','0','0'),
('14444','Ultralightweight wheelchair','Ultralightweight wheelchair','K0005','3','','1','0','','','','0','1','0','0'),
('14445','Heavy duty wheelchair','Heavy duty wheelchair','K0006','3','','1','0','','','','0','1','0','0'),
('14446','Extra heavy duty wheelchair','Extra heavy duty wheelchair','K0007','3','','1','0','','','','0','1','0','0'),
('14447','Custom manual wheelchair/base','Cstm manual wheelchair/base','K0008','3','','1','0','','','','0','1','0','0'),
('14448','Other manual wheelchair/base','Other manual wheelchair/base','K0009','3','','1','0','','','','0','1','0','0'),
('14449','Standard - weight frame motorized/power wheelchair','Stnd wt frame power whlchr','K0010','3','','1','0','','','','0','1','0','0'),
('14450','Standard - weight frame motorized/power wheelchair with programmable control parameters for speed adjustment; tremor dampening; acceleration control and braking','Stnd wt pwr whlchr w control','K0011','3','','1','0','','','','0','1','0','0'),
('14451','Lightweight portable motorized/power wheelchair','Ltwt portbl power whlchr','K0012','3','','1','0','','','','0','1','0','0'),
('14452','Custom motorized/power wheelchair base','Custom power whlchr base','K0013','3','','1','0','','','','0','1','0','0'),
('14453','Other motorized/power wheelchair base','Other power whlchr base','K0014','3','','1','0','','','','0','1','0','0'),
('14454','Detachable; non-adjustable height armrest; replacement only; each','Detach non-adj ht armrst rep','K0015','3','','1','0','','','','0','1','0','0'),
('14455','Detachable; adjustable height armrest; base; replacement only; each','Detach adjust armrest base','K0017','3','','1','0','','','','0','1','0','0'),
('14456','Detachable; adjustable height armrest; upper portion; replacement only; each','Detach adjust armrst upper','K0018','3','','1','0','','','','0','1','0','0'),
('14457','Arm pad; replacement only; each','Arm pad repl; each','K0019','3','','1','0','','','','0','1','0','0'),
('14458','Fixed; adjustable height armrest; pair','Fixed adjust armrest pair','K0020','3','','1','0','','','','0','1','0','0'),
('14459','High mount flip-up footrest; replacement only; each','Hi mount flip-up ftrest repl','K0037','3','','1','0','','','','0','1','0','0'),
('14460','Leg strap; each','Leg strap each','K0038','3','','1','0','','','','0','1','0','0'),
('14461','Leg strap; h style; each','Leg strap h style each','K0039','3','','1','0','','','','0','1','0','0'),
('14462','Adjustable angle footplate; each','Adjustable angle footplate','K0040','3','','1','0','','','','0','1','0','0'),
('14463','Large size footplate; each','Large size footplate each','K0041','3','','1','0','','','','0','1','0','0'),
('14464','Standard size footplate; replacement only; each','Standard size ftplate rep ea','K0042','3','','1','0','','','','0','1','0','0'),
('14465','Footrest; lower extension tube; replacement only; each','Ftrst lowr exten tube rep ea','K0043','3','','1','0','','','','0','1','0','0'),
('14466','Footrest; upper hanger bracket; replacement only; each','Ftrst upr hanger brac rep ea','K0044','3','','1','0','','','','0','1','0','0'),
('14467','Footrest; complete assembly; replacement only; each','Ftrst compl assembly repl ea','K0045','3','','1','0','','','','0','1','0','0'),
('14468','Elevating legrest; lower extension tube; replacement only; each','Elev lgrst lwr exten repl ea','K0046','3','','1','0','','','','0','1','0','0'),
('14469','Elevating legrest; upper hanger bracket; replacement only; each','Elev legrst upr hangr rep ea','K0047','3','','1','0','','','','0','1','0','0'),
('14470','Ratchet assembly; replacement only','Ratchet assembly replacement','K0050','3','','1','0','','','','0','1','0','0'),
('14471','Cam release assembly; footrest or legrest; replacement only; each','Cam rel asm ft/legrst rep ea','K0051','3','','1','0','','','','0','1','0','0'),
('14472','Swingaway; detachable footrests; replacement only; each','Swingaway detach ftrest repl','K0052','3','','1','0','','','','0','1','0','0'),
('14473','Elevating footrests; articulating (telescoping); each','Elevate footrest articulate','K0053','3','','1','0','','','','0','1','0','0'),
('14474','Seat height less than 17'' or equal to or greater than 21'' for a high strength; lightweight; or ultralightweight wheelchair','Seat ht <17 or >=21 ltwt wc','K0056','3','','1','0','','','','0','1','0','0'),
('14475','Spoke protectors; each','Spoke protectors','K0065','3','','1','0','','','','0','1','0','0'),
('14476','Rear wheel assembly; complete; with solid tire; spokes or molded; replacement only; each','Rr whl compl sol tire rep ea','K0069','3','','1','0','','','','0','1','0','0'),
('14477','Rear wheel assembly; complete; with pneumatic tire; spokes or molded; replacement only; each','Rr whl compl pne tire rep ea','K0070','3','','1','0','','','','0','1','0','0'),
('14478','Front caster assembly; complete; with pneumatic tire; replacement only; each','Fr cstr comp pne tire rep ea','K0071','3','','1','0','','','','0','1','0','0'),
('14479','Front caster assembly; complete; with semi-pneumatic tire; replacement only; each','Fr cstr semi-pne tire rep ea','K0072','3','','1','0','','','','0','1','0','0'),
('14480','Caster pin lock; each','Caster pin lock each','K0073','3','','1','0','','','','0','1','0','0'),
('14481','Front caster assembly; complete; with solid tire; replacement only; each','Fr cstr asmb sol tire rep ea','K0077','3','','1','0','','','','0','1','0','0'),
('14482','Drive belt for power wheelchair; replacement only','Drive belt for pwc; repl','K0098','3','','1','0','','','','0','1','0','0'),
('14483','Iv hanger; each','Iv hanger','K0105','3','','1','0','','','','0','1','0','0'),
('14484','Wheelchair component or accessory; not otherwise specified','W/c component-accessory nos','K0108','3','','1','0','','','','0','1','0','0'),
('14485','Elevating leg rests; pair (for use with capped rental wheelchair base)','Elevating whlchair leg rests','K0195','3','','1','0','','','','0','1','0','0'),
('14486','Infusion pump used for uninterrupted parenteral administration of medication; (e.g.; epoprostenol or treprostinol)','Pump uninterrupted infusion','K0455','3','','1','0','','','','0','1','0','0'),
('14487','Temporary replacement for patient owned equipment being repaired; any type','Temporary replacement eqpmnt','K0462','3','','1','0','','','','0','1','0','0'),
('14488','Supplies for external non-insulin drug infusion pump; syringe type cartridge; sterile; each','Sup/ext non-ins inf pump syr','K0552','3','','1','0','','','','0','1','0','0'),
('14489','Replacement battery for external infusion pump owned by patient; silver oxide; 1.5 volt; each','Repl batt silver oxide 1.5 v','K0601','3','','1','0','','','','0','1','0','0'),
('14490','Replacement battery for external infusion pump owned by patient; silver oxide; 3 volt; each','Repl batt silver oxide 3 v','K0602','3','','1','0','','','','0','1','0','0'),
('14491','Replacement battery for external infusion pump owned by patient; alkaline; 1.5 volt; each','Repl batt alkaline 1.5 v','K0603','3','','1','0','','','','0','1','0','0'),
('14492','Replacement battery for external infusion pump owned by patient; lithium; 3.6 volt; each','Repl batt lithium 3.6 v','K0604','3','','1','0','','','','0','1','0','0'),
('14493','Replacement battery for external infusion pump owned by patient; lithium; 4.5 volt; each','Repl batt lithium 4.5 v','K0605','3','','1','0','','','','0','1','0','0'),
('14494','Automatic external defibrillator; with integrated electrocardiogram analysis; garment type','Aed garment w elec analysis','K0606','3','','1','0','','','','0','1','0','0'),
('14495','Replacement battery for automated external defibrillator; garment type only; each','Repl batt for aed','K0607','3','','1','0','','','','0','1','0','0'),
('14496','Replacement garment for use with automated external defibrillator; each','Repl garment for aed','K0608','3','','1','0','','','','0','1','0','0'),
('14497','Replacement electrodes for use with automated external defibrillator; garment type only; each','Repl electrode for aed','K0609','3','','1','0','','','','0','1','0','0'),
('14498','Wheelchair accessory; wheelchair seat or back cushion; does not meet specific code criteria or no written coding verification from dme pdac','Seat/back cus no dmepdac ver','K0669','3','','1','0','','','','0','1','0','0'),
('14499','Addition to lower extremity orthosis; removable soft interface; all components; replacement only; each','Removable soft interface le','K0672','3','','1','0','','','','0','1','0','0'),
('14500','Controlled dose inhalation drug delivery system','Ctrl dose inh drug deliv sys','K0730','3','','1','0','','','','0','1','0','0'),
('14501','Power wheelchair accessory; 12 to 24 amp hour sealed lead acid battery; each (e.g.; gel cell; absorbed glassmat)','12-24hr sealed lead acid','K0733','3','','1','0','','','','0','1','0','0'),
('14502','Portable gaseous oxygen system; rental; home compressor used to fill portable oxygen cylinders; includes portable containers; regulator; flowmeter; humidifier; cannula or mask; and tubing','Portable gas oxygen system','K0738','3','','1','0','','','','0','1','0','0'),
('14503','Repair or nonroutine service for durable medical equipment other than oxygen equipment requiring the skill of a technician; labor component; per 15 minutes','Repair/svc dme non-oxygen eq','K0739','3','','1','0','','','','0','1','0','0'),
('14504','Repair or nonroutine service for oxygen equipment requiring the skill of a technician; labor component; per 15 minutes','Repair/svc oxygen equipment','K0740','3','','1','0','','','','0','1','0','0'),
('14505','Suction pump; home model; portable; for use on wounds','Portable home suction pump','K0743','3','','1','0','','','','0','1','0','0'),
('14506','Absorptive wound dressing for use with suction pump; home model; portable; pad size 16 square inches or less','Absorp drg <= 16 suc pump','K0744','3','','1','0','','','','0','1','0','0'),
('14507','Absorptive wound dressing for use with suction pump; home model; portable; pad size more than 16 square inches but less than or equal to 48 square inches','Absorp drg >16<=48 suc pump','K0745','3','','1','0','','','','0','1','0','0'),
('14508','Absorptive wound dressing for use with suction pump; home model; portable; pad size greater than 48 square inches','Absorp drg >48 suc pump','K0746','3','','1','0','','','','0','1','0','0'),
('14509','Power operated vehicle; group 1 standard; patient weight capacity up to and including 300 pounds','Pov group 1 std up to 300lbs','K0800','3','','1','0','','','','0','1','0','0'),
('14510','Power operated vehicle; group 1 heavy duty; patient weight capacity 301 to 450 pounds','Pov group 1 hd 301-450 lbs','K0801','3','','1','0','','','','0','1','0','0'),
('14511','Power operated vehicle; group 1 very heavy duty; patient weight capacity 451 to 600 pounds','Pov group 1 vhd 451-600 lbs','K0802','3','','1','0','','','','0','1','0','0'),
('14512','Power operated vehicle; group 2 standard; patient weight capacity up to and including 300 pounds','Pov group 2 std up to 300lbs','K0806','3','','1','0','','','','0','1','0','0'),
('14513','Power operated vehicle; group 2 heavy duty; patient weight capacity 301 to 450 pounds','Pov group 2 hd 301-450 lbs','K0807','3','','1','0','','','','0','1','0','0'),
('14514','Power operated vehicle; group 2 very heavy duty; patient weight capacity 451 to 600 pounds','Pov group 2 vhd 451-600 lbs','K0808','3','','1','0','','','','0','1','0','0'),
('14515','Power operated vehicle; not otherwise classified','Power operated vehicle noc','K0812','3','','1','0','','','','0','1','0','0'),
('14516','Power wheelchair; group 1 standard; portable; sling/solid seat and back; patient weight capacity up to and including 300 pounds','Pwc gp 1 std port seat/back','K0813','3','','1','0','','','','0','1','0','0'),
('14517','Power wheelchair; group 1 standard; portable; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 1 std port cap chair','K0814','3','','1','0','','','','0','1','0','0'),
('14518','Power wheelchair; group 1 standard; sling/solid seat and back; patient weight capacity up to and including 300 pounds','Pwc gp 1 std seat/back','K0815','3','','1','0','','','','0','1','0','0'),
('14519','Power wheelchair; group 1 standard; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 1 std cap chair','K0816','3','','1','0','','','','0','1','0','0'),
('14520','Power wheelchair; group 2 standard; portable; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp 2 std port seat/back','K0820','3','','1','0','','','','0','1','0','0'),
('14521','Power wheelchair; group 2 standard; portable; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 2 std port cap chair','K0821','3','','1','0','','','','0','1','0','0'),
('14522','Power wheelchair; group 2 standard; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp 2 std seat/back','K0822','3','','1','0','','','','0','1','0','0'),
('14523','Power wheelchair; group 2 standard; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 2 std cap chair','K0823','3','','1','0','','','','0','1','0','0'),
('14524','Power wheelchair; group 2 heavy duty; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp 2 hd seat/back','K0824','3','','1','0','','','','0','1','0','0'),
('14525','Power wheelchair; group 2 heavy duty; captains chair; patient weight capacity 301 to 450 pounds','Pwc gp 2 hd cap chair','K0825','3','','1','0','','','','0','1','0','0'),
('14526','Power wheelchair; group 2 very heavy duty; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp 2 vhd seat/back','K0826','3','','1','0','','','','0','1','0','0'),
('14527','Power wheelchair; group 2 very heavy duty; captains chair; patient weight capacity 451 to 600 pounds','Pwc gp vhd cap chair','K0827','3','','1','0','','','','0','1','0','0'),
('14528','Power wheelchair; group 2 extra heavy duty; sling/solid seat/back; patient weight capacity 601 pounds or more','Pwc gp 2 xtra hd seat/back','K0828','3','','1','0','','','','0','1','0','0'),
('14529','Power wheelchair; group 2 extra heavy duty; captains chair; patient weight 601 pounds or more','Pwc gp 2 xtra hd cap chair','K0829','3','','1','0','','','','0','1','0','0'),
('14530','Power wheelchair; group 2 standard; seat elevator; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp2 std seat elevate s/b','K0830','3','','1','0','','','','0','1','0','0'),
('14531','Power wheelchair; group 2 standard; seat elevator; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp2 std seat elevate cap','K0831','3','','1','0','','','','0','1','0','0'),
('14532','Power wheelchair; group 2 standard; single power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp2 std sing pow opt s/b','K0835','3','','1','0','','','','0','1','0','0'),
('14533','Power wheelchair; group 2 standard; single power option; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp2 std sing pow opt cap','K0836','3','','1','0','','','','0','1','0','0'),
('14534','Power wheelchair; group 2 heavy duty; single power option; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp 2 hd sing pow opt s/b','K0837','3','','1','0','','','','0','1','0','0'),
('14535','Power wheelchair; group 2 heavy duty; single power option; captains chair; patient weight capacity 301 to 450 pounds','Pwc gp 2 hd sing pow opt cap','K0838','3','','1','0','','','','0','1','0','0'),
('14536','Power wheelchair; group 2 very heavy duty; single power option; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp2 vhd sing pow opt s/b','K0839','3','','1','0','','','','0','1','0','0'),
('14537','Power wheelchair; group 2 extra heavy duty; single power option; sling/solid seat/back; patient weight capacity 601 pounds or more','Pwc gp2 xhd sing pow opt s/b','K0840','3','','1','0','','','','0','1','0','0'),
('14538','Power wheelchair; group 2 standard; multiple power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp2 std mult pow opt s/b','K0841','3','','1','0','','','','0','1','0','0'),
('14539','Power wheelchair; group 2 standard; multiple power option; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp2 std mult pow opt cap','K0842','3','','1','0','','','','0','1','0','0'),
('14540','Power wheelchair; group 2 heavy duty; multiple power option; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp2 hd mult pow opt s/b','K0843','3','','1','0','','','','0','1','0','0'),
('14541','Power wheelchair; group 3 standard; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp 3 std seat/back','K0848','3','','1','0','','','','0','1','0','0'),
('14542','Power wheelchair; group 3 standard; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 3 std cap chair','K0849','3','','1','0','','','','0','1','0','0'),
('14543','Power wheelchair; group 3 heavy duty; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp 3 hd seat/back','K0850','3','','1','0','','','','0','1','0','0'),
('14544','Power wheelchair; group 3 heavy duty; captains chair; patient weight capacity 301 to 450 pounds','Pwc gp 3 hd cap chair','K0851','3','','1','0','','','','0','1','0','0'),
('14545','Power wheelchair; group 3 very heavy duty; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp 3 vhd seat/back','K0852','3','','1','0','','','','0','1','0','0'),
('14546','Power wheelchair; group 3 very heavy duty; captains chair; patient weight capacity 451 to 600 pounds','Pwc gp 3 vhd cap chair','K0853','3','','1','0','','','','0','1','0','0'),
('14547','Power wheelchair; group 3 extra heavy duty; sling/solid seat/back; patient weight capacity 601 pounds or more','Pwc gp 3 xhd seat/back','K0854','3','','1','0','','','','0','1','0','0'),
('14548','Power wheelchair; group 3 extra heavy duty; captains chair; patient weight capacity 601 pounds or more','Pwc gp 3 xhd cap chair','K0855','3','','1','0','','','','0','1','0','0'),
('14549','Power wheelchair; group 3 standard; single power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp3 std sing pow opt s/b','K0856','3','','1','0','','','','0','1','0','0'),
('14550','Power wheelchair; group 3 standard; single power option; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp3 std sing pow opt cap','K0857','3','','1','0','','','','0','1','0','0'),
('14551','Power wheelchair; group 3 heavy duty; single power option; sling/solid seat/back; patient weight 301 to 450 pounds','Pwc gp3 hd sing pow opt s/b','K0858','3','','1','0','','','','0','1','0','0'),
('14552','Power wheelchair; group 3 heavy duty; single power option; captains chair; patient weight capacity 301 to 450 pounds','Pwc gp3 hd sing pow opt cap','K0859','3','','1','0','','','','0','1','0','0'),
('14553','Power wheelchair; group 3 very heavy duty; single power option; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp3 vhd sing pow opt s/b','K0860','3','','1','0','','','','0','1','0','0'),
('14554','Power wheelchair; group 3 standard; multiple power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp3 std mult pow opt s/b','K0861','3','','1','0','','','','0','1','0','0'),
('14555','Power wheelchair; group 3 heavy duty; multiple power option; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp3 hd mult pow opt s/b','K0862','3','','1','0','','','','0','1','0','0'),
('14556','Power wheelchair; group 3 very heavy duty; multiple power option; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp3 vhd mult pow opt s/b','K0863','3','','1','0','','','','0','1','0','0'),
('14557','Power wheelchair; group 3 extra heavy duty; multiple power option; sling/solid seat/back; patient weight capacity 601 pounds or more','Pwc gp3 xhd mult pow opt s/b','K0864','3','','1','0','','','','0','1','0','0'),
('14558','Power wheelchair; group 4 standard; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp 4 std seat/back','K0868','3','','1','0','','','','0','1','0','0'),
('14559','Power wheelchair; group 4 standard; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp 4 std cap chair','K0869','3','','1','0','','','','0','1','0','0'),
('14560','Power wheelchair; group 4 heavy duty; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp 4 hd seat/back','K0870','3','','1','0','','','','0','1','0','0'),
('14561','Power wheelchair; group 4 very heavy duty; sling/solid seat/back; patient weight capacity 451 to 600 pounds','Pwc gp 4 vhd seat/back','K0871','3','','1','0','','','','0','1','0','0'),
('14562','Power wheelchair; group 4 standard; single power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp4 std sing pow opt s/b','K0877','3','','1','0','','','','0','1','0','0'),
('14563','Power wheelchair; group 4 standard; single power option; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp4 std sing pow opt cap','K0878','3','','1','0','','','','0','1','0','0'),
('14564','Power wheelchair; group 4 heavy duty; single power option; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp4 hd sing pow opt s/b','K0879','3','','1','0','','','','0','1','0','0'),
('14565','Power wheelchair; group 4 very heavy duty; single power option; sling/solid seat/back; patient weight 451 to 600 pounds','Pwc gp4 vhd sing pow opt s/b','K0880','3','','1','0','','','','0','1','0','0'),
('14566','Power wheelchair; group 4 standard; multiple power option; sling/solid seat/back; patient weight capacity up to and including 300 pounds','Pwc gp4 std mult pow opt s/b','K0884','3','','1','0','','','','0','1','0','0'),
('14567','Power wheelchair; group 4 standard; multiple power option; captains chair; patient weight capacity up to and including 300 pounds','Pwc gp4 std mult pow opt cap','K0885','3','','1','0','','','','0','1','0','0'),
('14568','Power wheelchair; group 4 heavy duty; multiple power option; sling/solid seat/back; patient weight capacity 301 to 450 pounds','Pwc gp4 hd mult pow s/b','K0886','3','','1','0','','','','0','1','0','0'),
('14569','Power wheelchair; group 5 pediatric; single power option; sling/solid seat/back; patient weight capacity up to and including 125 pounds','Pwc gp5 ped sing pow opt s/b','K0890','3','','1','0','','','','0','1','0','0'),
('14570','Power wheelchair; group 5 pediatric; multiple power option; sling/solid seat/back; patient weight capacity up to and including 125 pounds','Pwc gp5 ped mult pow opt s/b','K0891','3','','1','0','','','','0','1','0','0'),
('14571','Power wheelchair; not otherwise classified','Power wheelchair noc','K0898','3','','1','0','','','','0','1','0','0'),
('14572','Power mobility device; not coded by dme pdac or does not meet criteria','Pow mobil dev no dmepdac','K0899','3','','1','0','','','','0','1','0','0'),
('14573','Customized durable medical equipment; other than wheelchair','Cstm dme other than wheelchr','K0900','3','','1','0','','','','0','1','0','0'),
('14574','Knee orthosis (ko); single upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated; off-the-shelf','Ko single upright pre ots','K0901','3','','1','0','','','','0','1','0','0'),
('14575','Knee orthosis (ko); double upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated; off-the-shelf','Ko double upright pre ots','K0902','3','','1','0','','','','0','1','0','0'),
('14576','Cranial cervical orthosis; congenital torticollis type; with or without soft interface material; adjustable range of motion joint; custom fabricated','Cranial cervical orthosis','L0112','3','','1','0','','','','0','1','0','0'),
('14577','Cranial cervical orthosis; torticollis type; with or without joint; with or without soft interface material; prefabricated; includes fitting and adjustment','Cranial cervical torticollis','L0113','3','','1','0','','','','0','1','0','0'),
('14578','Cervical; flexible; non-adjustable; prefabricated; off-the-shelf (foam collar)','Cerv flex n/adj foam pre ots','L0120','3','','1','0','','','','0','1','0','0'),
('14579','Cervical; flexible; thermoplastic collar; molded to patient','Flex thermoplastic collar mo','L0130','3','','1','0','','','','0','1','0','0'),
('14580','Cervical; semi-rigid; adjustable (plastic collar)','Cervical semi-rigid adjustab','L0140','3','','1','0','','','','0','1','0','0'),
('14581','Cervical; semi-rigid; adjustable molded chin cup (plastic collar with mandibular/occipital piece)','Cerv semi-rig adj molded chn','L0150','3','','1','0','','','','0','1','0','0'),
('14582','Cervical; semi-rigid; wire frame occipital/mandibular support; prefabricated; off-the-shelf','Cerv sr wire occ/man pre ots','L0160','3','','1','0','','','','0','1','0','0'),
('14583','Cervical; collar; molded to patient model','Cervical collar molded to pt','L0170','3','','1','0','','','','0','1','0','0'),
('14584','Cervical; collar; semi-rigid thermoplastic foam; two-piece; prefabricated; off-the-shelf','Cerv col sr foam 2pc pre ots','L0172','3','','1','0','','','','0','1','0','0'),
('14585','Cervical; collar; semi-rigid; thermoplastic foam; two piece with thoracic extension; prefabricated; off-the-shelf','Cerv sr 2pc thor ext pre ots','L0174','3','','1','0','','','','0','1','0','0'),
('14586','Cervical; multiple post collar; occipital/mandibular supports; adjustable','Cer post col occ/man sup adj','L0180','3','','1','0','','','','0','1','0','0'),
('14587','Cervical; multiple post collar; occipital/mandibular supports; adjustable cervical bars (somi; guilford; taylor types)','Cerv collar supp adj cerv ba','L0190','3','','1','0','','','','0','1','0','0'),
('14588','Cervical; multiple post collar; occipital/mandibular supports; adjustable cervical bars; and thoracic extension','Cerv col supp adj bar & thor','L0200','3','','1','0','','','','0','1','0','0'),
('14589','Thoracic; rib belt; custom fabricated','Thor rib belt custom fabrica','L0220','3','','1','0','','','','0','1','0','0'),
('14590','Spinal orthosis; anterior-posterior-lateral control; with interface material; custom fitted (dewall posture protector only)','Dewall posture protector','L0430','3','','1','0','','','','0','1','0','0'),
('14591','Tlso; flexible; provides trunk support; upper thoracic region; produces intracavitary pressure to reduce load on the intervertebral disks with rigid stays or panel(s); includes shoulder straps and closures; prefabricated; off-the-shelf','Tlso flex trunk/thor pre ots','L0450','3','','1','0','','','','0','1','0','0'),
('14592','Tlso; flexible; provides trunk support; upper thoracic region; produces intracavitary pressure to reduce load on the intervertebral disks with rigid stays or panel(s); includes shoulder straps and closures; custom fabricated','Tlso flex custom fab thoraci','L0452','3','','1','0','','','','0','1','0','0'),
('14593','Tlso flexible; provides trunk support; extends from sacrococcygeal junction to above t-9 vertebra; restricts gross trunk motion in the sagittal plane; produces intracavitary pressure to reduce load on the intervertebral disks with rigid stays or panel(s); includes shoulder straps and closures; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Tlso trnk sj-t9 pre cst','L0454','3','','1','0','','','','0','1','0','0'),
('14594','Tlso; flexible; provides trunk support; extends from sacrococcygeal junction to above t-9 vertebra; restricts gross trunk motion in the sagittal plane; produces intracavitary pressure to reduce load on the intervertebral disks with rigid stays or panel(s); includes shoulder straps and closures; prefabricated; off-the-shelf','Tlso flex trnk sj-t9 pre ots','L0455','3','','1','0','','','','0','1','0','0'),
('14595','Tlso; flexible; provides trunk support; thoracic region; rigid posterior panel and soft anterior apron; extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; restricts gross trunk motion in the sagittal plane; produces intracavitary pressure to reduce load on the intervertebral disks; includes straps and closures; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Tlso flex trnk sj-ss pre cst','L0456','3','','1','0','','','','0','1','0','0'),
('14596','Tlso; flexible; provides trunk support; thoracic region; rigid posterior panel and soft anterior apron; extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; restricts gross trunk motion in the sagittal plane; produces intracavitary pressure to reduce load on the intervertebral disks; includes straps and closures; prefabricated; off-the-shelf','Tlso flex trnk sj-ss pre ots','L0457','3','','1','0','','','','0','1','0','0'),
('14597','Tlso; triplanar control; modular segmented spinal system; two rigid plastic shells; posterior extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; anterior extends from the symphysis pubis to the xiphoid; soft liner; restricts gross trunk motion in the sagittal; coronal; and transverse planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated; includes fitting and adjustment','Tlso 2mod symphis-xipho pre','L0458','3','','1','0','','','','0','1','0','0'),
('14598','Tlso; triplanar control; modular segmented spinal system; two rigid plastic shells; posterior extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; anterior extends from the symphysis pubis to the sternal notch; soft liner; restricts gross trunk motion in the sagittal; coronal; and transverse planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Tlso 2 shl symphys-stern cst','L0460','3','','1','0','','','','0','1','0','0'),
('14599','Tlso; triplanar control; modular segmented spinal system; three rigid plastic shells; posterior extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; anterior extends from the symphysis pubis to the sternal notch; soft liner; restricts gross trunk motion in the sagittal; coronal; and transverse planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated; includes fitting and adjustment','Tlso 3mod sacro-scap pre','L0462','3','','1','0','','','','0','1','0','0'),
('14600','Tlso; triplanar control; modular segmented spinal system; four rigid plastic shells; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to the sternal notch; soft liner; restricts gross trunk motion in sagittal; coronal; and transverse planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated; includes fitting and adjustment','Tlso 4mod sacro-scap pre','L0464','3','','1','0','','','','0','1','0','0'),
('14601','Tlso; sagittal control; rigid posterior frame and flexible soft anterior apron with straps; closures and padding; restricts gross trunk motion in sagittal plane; produces intracavitary pressure to reduce load on intervertebral disks; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Tlso r fram soft ant pre cst','L0466','3','','1','0','','','','0','1','0','0'),
('14602','Tlso; sagittal control; rigid posterior frame and flexible soft anterior apron with straps; closures and padding; restricts gross trunk motion in sagittal plane; produces intracavitary pressure to reduce load on intervertebral disks; prefabricated; off-the-shelf','Tlso r fram soft pre ots','L0467','3','','1','0','','','','0','1','0','0'),
('14603','Tlso; sagittal-coronal control; rigid posterior frame and flexible soft anterior apron with straps; closures and padding; extends from sacrococcygeal junction over scapulae; lateral strength provided by pelvic; thoracic; and lateral frame pieces; restricts gross trunk motion in sagittal; and coronal planes; produces intracavitary pressure to reduce load on intervertebral disks; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Tlso rig fram pelvic pre cst','L0468','3','','1','0','','','','0','1','0','0'),
('14604','Tlso; sagittal-coronal control; rigid posterior frame and flexible soft anterior apron with straps; closures and padding; extends from sacrococcygeal junction over scapulae; lateral strength provided by pelvic; thoracic; and lateral frame pieces; restricts gross trunk motion in sagittal and coronal planes; produces intracavitary pressure to reduce load on intervertebral disks; prefabricated; off-the-shelf','Tlso rig fram pelvic pre ots','L0469','3','','1','0','','','','0','1','0','0'),
('14605','Tlso; triplanar control; rigid posterior frame and flexible soft anterior apron with straps; closures and padding; extends from sacrococcygeal junction to scapula; lateral strength provided by pelvic; thoracic; and lateral frame pieces; rotational strength provided by subclavicular extensions; restricts gross trunk motion in sagittal; coronal; and transverse planes; provides intracavitary pressure to reduce load on the intervertebral disks; includes fitting and shaping the frame; prefabricated; includes fitting and adjustment','Tlso rigid frame pre subclav','L0470','3','','1','0','','','','0','1','0','0'),
('14606','Tlso; triplanar control; hyperextension; rigid anterior and lateral frame extends from symphysis pubis to sternal notch with two anterior components (one pubic and one sternal); posterior and lateral pads with straps and closures; limits spinal flexion; restricts gross trunk motion in sagittal; coronal; and transverse planes; includes fitting and shaping the frame; prefabricated; includes fitting and adjustment','Tlso rigid frame hyperex pre','L0472','3','','1','0','','','','0','1','0','0'),
('14607','Tlso; triplanar control; one piece rigid plastic shell without interface liner; with multiple straps and closures; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to sternal notch; anterior or posterior opening; restricts gross trunk motion in sagittal; coronal; and transverse planes; includes a carved plaster or cad-cam model; custom fabricated','Tlso rigid plastic custom fa','L0480','3','','1','0','','','','0','1','0','0'),
('14608','Tlso; triplanar control; one piece rigid plastic shell with interface liner; multiple straps and closures; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to sternal notch; anterior or posterior opening; restricts gross trunk motion in sagittal; coronal; and transverse planes; includes a carved plaster or cad-cam model; custom fabricated','Tlso rigid lined custom fab','L0482','3','','1','0','','','','0','1','0','0'),
('14609','Tlso; triplanar control; two piece rigid plastic shell without interface liner; with multiple straps and closures; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to sternal notch; lateral strength is enhanced by overlapping plastic; restricts gross trunk motion in the sagittal; coronal; and transverse planes; includes a carved plaster or cad-cam model; custom fabricated','Tlso rigid plastic cust fab','L0484','3','','1','0','','','','0','1','0','0'),
('14610','Tlso; triplanar control; two piece rigid plastic shell with interface liner; multiple straps and closures; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to sternal notch; lateral strength is enhanced by overlapping plastic; restricts gross trunk motion in the sagittal; coronal; and transverse planes; includes a carved plaster or cad-cam model; custom fabricated','Tlso rigidlined cust fab two','L0486','3','','1','0','','','','0','1','0','0'),
('14611','Tlso; triplanar control; one piece rigid plastic shell with interface liner; multiple straps and closures; posterior extends from sacrococcygeal junction and terminates just inferior to scapular spine; anterior extends from symphysis pubis to sternal notch; anterior or posterior opening; restricts gross trunk motion in sagittal; coronal; and transverse planes; prefabricated; includes fitting and adjustment','Tlso rigid lined pre one pie','L0488','3','','1','0','','','','0','1','0','0'),
('14612','Tlso; sagittal-coronal control; one piece rigid plastic shell; with overlapping reinforced anterior; with multiple straps and closures; posterior extends from sacrococcygeal junction and terminates at or before the t-9 vertebra; anterior extends from symphysis pubis to xiphoid; anterior opening; restricts gross trunk motion in sagittal and coronal planes; prefabricated; includes fitting and adjustment','Tlso rigid plastic pre one','L0490','3','','1','0','','','','0','1','0','0'),
('14613','Tlso; sagittal-coronal control; modular segmented spinal system; two rigid plastic shells; posterior extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; anterior extends from the symphysis pubis to the xiphoid; soft liner; restricts gross trunk motion in the sagittal and coronal planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated; includes fitting and adjustment','Tlso 2 piece rigid shell','L0491','3','','1','0','','','','0','1','0','0'),
('14614','Tlso; sagittal-coronal control; modular segmented spinal system; three rigid plastic shells; posterior extends from the sacrococcygeal junction and terminates just inferior to the scapular spine; anterior extends from the symphysis pubis to the xiphoid; soft liner; restricts gross trunk motion in the sagittal and coronal planes; lateral strength is provided by overlapping plastic and stabilizing closures; includes straps and closures; prefabricated; includes fitting and adjustment','Tlso 3 piece rigid shell','L0492','3','','1','0','','','','0','1','0','0'),
('14615','Sacroiliac orthosis; flexible; provides pelvic-sacral support; reduces motion about the sacroiliac joint; includes straps; closures; may include pendulous abdomen design; prefabricated; off-the-shelf','Sio flex pelvic/sacr pre ots','L0621','3','','1','0','','','','0','1','0','0'),
('14616','Sacroiliac orthosis; flexible; provides pelvic-sacral support; reduces motion about the sacroiliac joint; includes straps; closures; may include pendulous abdomen design; custom fabricated','Sio flex pelvisacral custom','L0622','3','','1','0','','','','0','1','0','0'),
('14617','Sacroiliac orthosis; provides pelvic-sacral support; with rigid or semi-rigid panels over the sacrum and abdomen; reduces motion about the sacroiliac joint; includes straps; closures; may include pendulous abdomen design; prefabricated; off-the-shelf','Sio rig pnl pelv/sac pre ots','L0623','3','','1','0','','','','0','1','0','0'),
('14618','Sacroiliac orthosis; provides pelvic-sacral support; with rigid or semi-rigid panels placed over the sacrum and abdomen; reduces motion about the sacroiliac joint; includes straps; closures; may include pendulous abdomen design; custom fabricated','Sio panel custom','L0624','3','','1','0','','','','0','1','0','0'),
('14619','Lumbar orthosis; flexible; provides lumbar support; posterior extends from l-1 to below l-5 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include pendulous abdomen design; shoulder straps; stays; prefabricated; off-the-shelf','Lo flex l1-below l5 pre ots','L0625','3','','1','0','','','','0','1','0','0'),
('14620','Lumbar orthosis; sagittal control; with rigid posterior panel(s); posterior extends from l-1 to below l-5 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lo sag rig pnl stays pre cst','L0626','3','','1','0','','','','0','1','0','0'),
('14621','Lumbar orthosis; sagittal control; with rigid anterior and posterior panels; posterior extends from l-1 to below l-5 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lo sag ri an/pos pnl pre cst','L0627','3','','1','0','','','','0','1','0','0'),
('14622','Lumbar-sacral orthosis; flexible; provides lumbo-sacral support; posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include stays; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lso flex no ri stays pre ots','L0628','3','','1','0','','','','0','1','0','0'),
('14623','Lumbar-sacral orthosis; flexible; provides lumbo-sacral support; posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include stays; shoulder straps; pendulous abdomen design; custom fabricated','Lso flex w/rigid stays cust','L0629','3','','1','0','','','','0','1','0','0'),
('14624','Lumbar-sacral orthosis; sagittal control; with rigid posterior panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lso r post pnl sj-t9 pre cst','L0630','3','','1','0','','','','0','1','0','0'),
('14625','Lumbar-sacral orthosis; sagittal control; with rigid anterior and posterior panels; posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lso sag r an/pos pnl pre cst','L0631','3','','1','0','','','','0','1','0','0'),
('14626','Lumbar-sacral orthosis; sagittal control; with rigid anterior and posterior panels; posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; custom fabricated','Lso sag rigid frame cust','L0632','3','','1','0','','','','0','1','0','0'),
('14627','Lumbar-sacral orthosis; sagittal-coronal control; with rigid posterior frame/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panels; produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lso sc r pos/lat pnl pre cst','L0633','3','','1','0','','','','0','1','0','0'),
('14628','Lumbar-sacral orthosis; sagittal-coronal control; with rigid posterior frame/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panel(s); produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; custom fabricated','Lso flexion control custom','L0634','3','','1','0','','','','0','1','0','0'),
('14629','Lumbar-sacral orthosis; sagittal-coronal control; lumbar flexion; rigid posterior frame/panel(s); lateral articulating design to flex the lumbar spine; posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panel(s); produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; anterior panel; pendulous abdomen design; prefabricated; includes fitting and adjustment','Lso sagit rigid panel prefab','L0635','3','','1','0','','','','0','1','0','0'),
('14630','Lumbar sacral orthosis; sagittal-coronal control; lumbar flexion; rigid posterior frame/panels; lateral articulating design to flex the lumbar spine; posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panels; produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; anterior panel; pendulous abdomen design; custom fabricated','Lso sagittal rigid panel cus','L0636','3','','1','0','','','','0','1','0','0'),
('14631','Lumbar-sacral orthosis; sagittal-coronal control; with rigid anterior and posterior frame/panels; posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panels; produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lso sc r ant/pos pnl pre cst','L0637','3','','1','0','','','','0','1','0','0'),
('14632','Lumbar-sacral orthosis; sagittal-coronal control; with rigid anterior and posterior frame/panels; posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panels; produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; custom fabricated','Lso sag-coronal panel custom','L0638','3','','1','0','','','','0','1','0','0'),
('14633','Lumbar-sacral orthosis; sagittal-coronal control; rigid shell(s)/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; anterior extends from symphysis pubis to xyphoid; produces intracavitary pressure to reduce load on the intervertebral discs; overall strength is provided by overlapping rigid material and stabilizing closures; includes straps; closures; may include soft interface; pendulous abdomen design; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Lso s/c shell/panel prefab','L0639','3','','1','0','','','','0','1','0','0'),
('14634','Lumbar-sacral orthosis; sagittal-coronal control; rigid shell(s)/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; anterior extends from symphysis pubis to xyphoid; produces intracavitary pressure to reduce load on the intervertebral discs; overall strength is provided by overlapping rigid material and stabilizing closures; includes straps; closures; may include soft interface; pendulous abdomen design; custom fabricated','Lso s/c shell/panel custom','L0640','3','','1','0','','','','0','1','0','0'),
('14635','Lumbar orthosis; sagittal control; with rigid posterior panel(s); posterior extends from l-1 to below l-5 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lo rig pos pnl l1-l5 pre ots','L0641','3','','1','0','','','','0','1','0','0'),
('14636','Lumbar orthosis; sagittal control; with rigid anterior and posterior panels; posterior extends from l-1 to below l-5 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lo sag ri an/pos pnl pre ots','L0642','3','','1','0','','','','0','1','0','0'),
('14637','Lumbar-sacral orthosis; sagittal control; with rigid posterior panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lso sag ctr rigi pos pre ots','L0643','3','','1','0','','','','0','1','0','0'),
('14638','Lumbar-sacral orthosis; sagittal control; with rigid anterior and posterior panels; posterior extends from sacrococcygeal junction to t-9 vertebra; produces intracavitary pressure to reduce load on the intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lso sag r an/pos pnl pre ots','L0648','3','','1','0','','','','0','1','0','0'),
('14639','Lumbar-sacral orthosis; sagittal-coronal control; with rigid posterior frame/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panels; produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; stays; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lso sc r pos/lat pnl pre ots','L0649','3','','1','0','','','','0','1','0','0'),
('14640','Lumbar-sacral orthosis; sagittal-coronal control; with rigid anterior and posterior frame/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; lateral strength provided by rigid lateral frame/panel(s); produces intracavitary pressure to reduce load on intervertebral discs; includes straps; closures; may include padding; shoulder straps; pendulous abdomen design; prefabricated; off-the-shelf','Lso sc r ant/pos pnl pre ots','L0650','3','','1','0','','','','0','1','0','0'),
('14641','Lumbar-sacral orthosis; sagittal-coronal control; rigid shell(s)/panel(s); posterior extends from sacrococcygeal junction to t-9 vertebra; anterior extends from symphysis pubis to xyphoid; produces intracavitary pressure to reduce load on the intervertebral discs; overall strength is provided by overlapping rigid material and stabilizing closures; includes straps; closures; may include soft interface; pendulous abdomen design; prefabricated; off-the-shelf','Lso sag-co shell pnl pre ots','L0651','3','','1','0','','','','0','1','0','0'),
('14642','Cervical-thoracic-lumbar-sacral-orthoses (ctlso); anterior-posterior-lateral control; molded to patient model; (minerva type)','Ctlso a-p-l control molded','L0700','3','','1','0','','','','0','1','0','0'),
('14643','Ctlso; anterior-posterior-lateral-control; molded to patient model; with interface material; (minerva type)','Ctlso a-p-l control w/ inter','L0710','3','','1','0','','','','0','1','0','0'),
('14644','Halo procedure; cervical halo incorporated into jacket vest','Halo cervical into jckt vest','L0810','3','','1','0','','','','0','1','0','0'),
('14645','Halo procedure; cervical halo incorporated into plaster body jacket','Halo cervical into body jack','L0820','3','','1','0','','','','0','1','0','0'),
('14646','Halo procedure; cervical halo incorporated into milwaukee type orthosis','Halo cerv into milwaukee typ','L0830','3','','1','0','','','','0','1','0','0'),
('14647','Addition to halo procedure; magnetic resonance image compatible systems; rings and pins; any material','Mri compatible system','L0859','3','','1','0','','','','0','1','0','0'),
('14648','Addition to halo procedure; replacement liner/interface material','Halo repl liner/interface','L0861','3','','1','0','','','','0','1','0','0'),
('14649','Tlso; corset front','Tlso corset front','L0970','3','','1','0','','','','0','1','0','0'),
('14650','Lso; corset front','Lso corset front','L0972','3','','1','0','','','','0','1','0','0'),
('14651','Tlso; full corset','Tlso full corset','L0974','3','','1','0','','','','0','1','0','0'),
('14652','Lso; full corset','Lso full corset','L0976','3','','1','0','','','','0','1','0','0'),
('14653','Axillary crutch extension','Axillary crutch extension','L0978','3','','1','0','','','','0','1','0','0'),
('14654','Peroneal straps; prefabricated; off-the-shelf; pair','Peroneal straps pair pre ots','L0980','3','','1','0','','','','0','1','0','0'),
('14655','Stocking supporter grips; prefabricated; off-the-shelf; set of four (4)','Stocking sup grips 4 pre ots','L0982','3','','1','0','','','','0','1','0','0'),
('14656','Protective body sock; prefabricated; off-the-shelf; each','Protect body sock ea pre ots','L0984','3','','1','0','','','','0','1','0','0'),
('14657','Addition to spinal orthosis; not otherwise specified','Add to spinal orthosis nos','L0999','3','','1','0','','','','0','1','0','0'),
('14658','Cervical-thoracic-lumbar-sacral orthosis (ctlso) (milwaukee); inclusive of furnishing initial orthosis; including model','Ctlso milwauke initial model','L1000','3','','1','0','','','','0','1','0','0'),
('14659','Cervical thoracic lumbar sacral orthosis; immobilizer; infant size; prefabricated; includes fitting and adjustment','Ctlso infant immobilizer','L1001','3','','1','0','','','','0','1','0','0'),
('14660','Tension based scoliosis orthosis and accessory pads; includes fitting and adjustment','Tension based scoliosis orth','L1005','3','','1','0','','','','0','1','0','0'),
('14661','Addition to cervical-thoracic-lumbar-sacral orthosis (ctlso) or scoliosis orthosis; axilla sling','Ctlso axilla sling','L1010','3','','1','0','','','','0','1','0','0'),
('14662','Addition to ctlso or scoliosis orthosis; kyphosis pad','Kyphosis pad','L1020','3','','1','0','','','','0','1','0','0'),
('14663','Addition to ctlso or scoliosis orthosis; kyphosis pad; floating','Kyphosis pad floating','L1025','3','','1','0','','','','0','1','0','0'),
('14664','Addition to ctlso or scoliosis orthosis; lumbar bolster pad','Lumbar bolster pad','L1030','3','','1','0','','','','0','1','0','0'),
('14665','Addition to ctlso or scoliosis orthosis; lumbar or lumbar rib pad','Lumbar or lumbar rib pad','L1040','3','','1','0','','','','0','1','0','0'),
('14666','Addition to ctlso or scoliosis orthosis; sternal pad','Sternal pad','L1050','3','','1','0','','','','0','1','0','0'),
('14667','Addition to ctlso or scoliosis orthosis; thoracic pad','Thoracic pad','L1060','3','','1','0','','','','0','1','0','0'),
('14668','Addition to ctlso or scoliosis orthosis; trapezius sling','Trapezius sling','L1070','3','','1','0','','','','0','1','0','0'),
('14669','Addition to ctlso or scoliosis orthosis; outrigger','Outrigger','L1080','3','','1','0','','','','0','1','0','0'),
('14670','Addition to ctlso or scoliosis orthosis; outrigger; bilateral with vertical extensions','Outrigger bil w/ vert extens','L1085','3','','1','0','','','','0','1','0','0'),
('14671','Addition to ctlso or scoliosis orthosis; lumbar sling','Lumbar sling','L1090','3','','1','0','','','','0','1','0','0'),
('14672','Addition to ctlso or scoliosis orthosis; ring flange; plastic or leather','Ring flange plastic/leather','L1100','3','','1','0','','','','0','1','0','0'),
('14673','Addition to ctlso or scoliosis orthosis; ring flange; plastic or leather; molded to patient model','Ring flange plas/leather mol','L1110','3','','1','0','','','','0','1','0','0'),
('14674','Addition to ctlso; scoliosis orthosis; cover for upright; each','Covers for upright each','L1120','3','','1','0','','','','0','1','0','0'),
('14675','Thoracic-lumbar-sacral-orthosis (tlso); inclusive of furnishing initial orthosis only','Furnsh initial orthosis only','L1200','3','','1','0','','','','0','1','0','0'),
('14676','Addition to tlso; (low profile); lateral thoracic extension','Lateral thoracic extension','L1210','3','','1','0','','','','0','1','0','0'),
('14677','Addition to tlso; (low profile); anterior thoracic extension','Anterior thoracic extension','L1220','3','','1','0','','','','0','1','0','0'),
('14678','Addition to tlso; (low profile); milwaukee type superstructure','Milwaukee type superstructur','L1230','3','','1','0','','','','0','1','0','0'),
('14679','Addition to tlso; (low profile); lumbar derotation pad','Lumbar derotation pad','L1240','3','','1','0','','','','0','1','0','0'),
('14680','Addition to tlso; (low profile); anterior asis pad','Anterior asis pad','L1250','3','','1','0','','','','0','1','0','0'),
('14681','Addition to tlso; (low profile); anterior thoracic derotation pad','Anterior thoracic derotation','L1260','3','','1','0','','','','0','1','0','0'),
('14682','Addition to tlso; (low profile); abdominal pad','Abdominal pad','L1270','3','','1','0','','','','0','1','0','0'),
('14683','Addition to tlso; (low profile); rib gusset (elastic); each','Rib gusset (elastic) each','L1280','3','','1','0','','','','0','1','0','0'),
('14684','Addition to tlso; (low profile); lateral trochanteric pad','Lateral trochanteric pad','L1290','3','','1','0','','','','0','1','0','0'),
('14685','Other scoliosis procedure; body jacket molded to patient model','Body jacket mold to patient','L1300','3','','1','0','','','','0','1','0','0'),
('14686','Other scoliosis procedure; post-operative body jacket','Post-operative body jacket','L1310','3','','1','0','','','','0','1','0','0'),
('14687','Spinal orthosis; not otherwise specified','Spinal orthosis nos','L1499','3','','1','0','','','','0','1','0','0'),
('14688','Hip orthosis; abduction control of hip joints; flexible; frejka type with cover; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an inidividual with expertise','Ho flex frejka w/cov pre cst','L1600','3','','1','0','','','','0','1','0','0'),
('14689','Hip orthosis; abduction control of hip joints; flexible; (frejka cover only); prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ho frejka cov only pre cst','L1610','3','','1','0','','','','0','1','0','0'),
('14690','Hip orthosis; abduction control of hip joints; flexible; (pavlik harness); prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ho flex pavlik harns pre cst','L1620','3','','1','0','','','','0','1','0','0'),
('14691','Hip orthosis; abduction control of hip joints; semi-flexible (von rosen type); custom fabricated','Abduct control hip semi-flex','L1630','3','','1','0','','','','0','1','0','0'),
('14692','Hip orthosis; abduction control of hip joints; static; pelvic band or spreader bar; thigh cuffs; custom fabricated','Pelv band/spread bar thigh c','L1640','3','','1','0','','','','0','1','0','0'),
('14693','Hip orthosis; abduction control of hip joints; static; adjustable; (ilfled type); prefabricated; includes fitting and adjustment','Ho abduction hip adjustable','L1650','3','','1','0','','','','0','1','0','0'),
('14694','Hip orthosis; bilateral thigh cuffs with adjustable abductor spreader bar; adult size; prefabricated; includes fitting and adjustment; any type','Ho bi thighcuffs w sprdr bar','L1652','3','','1','0','','','','0','1','0','0'),
('14695','Hip orthosis; abduction control of hip joints; static; plastic; prefabricated; includes fitting and adjustment','Ho abduction static plastic','L1660','3','','1','0','','','','0','1','0','0'),
('14696','Hip orthosis; abduction control of hip joints; dynamic; pelvic control; adjustable hip motion control; thigh cuffs (rancho hip action type); custom fabricated','Pelvic & hip control thigh c','L1680','3','','1','0','','','','0','1','0','0'),
('14697','Hip orthosis; abduction control of hip joint; postoperative hip abduction type; custom fabricated','Post-op hip abduct custom fa','L1685','3','','1','0','','','','0','1','0','0'),
('14698','Hip orthosis; abduction control of hip joint; postoperative hip abduction type; prefabricated; includes fitting and adjustment','Ho post-op hip abduction','L1686','3','','1','0','','','','0','1','0','0'),
('14699','Combination; bilateral; lumbo-sacral; hip; femur orthosis providing adduction and internal rotation control; prefabricated; includes fitting and adjustment','Combination bilateral ho','L1690','3','','1','0','','','','0','1','0','0'),
('14700','Legg perthes orthosis; (toronto type); custom fabricated','Leg perthes orth toronto typ','L1700','3','','1','0','','','','0','1','0','0'),
('14701','Legg perthes orthosis; (newington type); custom fabricated','Legg perthes orth newington','L1710','3','','1','0','','','','0','1','0','0'),
('14702','Legg perthes orthosis; trilateral; (tachdijan type); custom fabricated','Legg perthes orthosis trilat','L1720','3','','1','0','','','','0','1','0','0'),
('14703','Legg perthes orthosis; (scottish rite type); custom fabricated','Legg perthes orth scottish r','L1730','3','','1','0','','','','0','1','0','0'),
('14704','Legg perthes orthosis; (patten bottom type); custom fabricated','Legg perthes patten bottom t','L1755','3','','1','0','','','','0','1','0','0'),
('14705','Knee orthosis; elastic with joints; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ko elastic with joints','L1810','3','','1','0','','','','0','1','0','0'),
('14706','Knee orthosis; elastic with joints; prefabricated; off-the-shelf','Ko elastic w/joints pre ots','L1812','3','','1','0','','','','0','1','0','0'),
('14707','Knee orthosis; elastic with condylar pads and joints; with or without patellar control; prefabricated; includes fitting and adjustment','Ko elas w/ condyle pads & jo','L1820','3','','1','0','','','','0','1','0','0'),
('14708','Knee orthosis; immobilizer; canvas longitudinal; prefabricated; off-the-shelf','Ko immob canvas long pre ots','L1830','3','','1','0','','','','0','1','0','0'),
('14709','Knee orthosis; locking knee joint(s); positional orthosis; prefabricated; includes fitting and adjustment','Knee orth pos locking joint','L1831','3','','1','0','','','','0','1','0','0'),
('14710','Knee orthosis; adjustable knee joints (unicentric or polycentric); positional orthosis; rigid support; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ko adj jnt pos r sup pre cst','L1832','3','','1','0','','','','0','1','0','0'),
('14711','Knee orthosis; adjustable knee joints (unicentric or polycentric); positional orthosis; rigid support; prefabricated; off-the shelf','Ko adj jnt pos r sup pre ots','L1833','3','','1','0','','','','0','1','0','0'),
('14712','Knee orthosis; without knee joint; rigid; custom fabricated','Ko w/0 joint rigid molded to','L1834','3','','1','0','','','','0','1','0','0'),
('14713','Knee orthosis; rigid; without joint(s); includes soft interface material; prefabricated; off-the-shelf','Ko rigid w/o joints pre ots','L1836','3','','1','0','','','','0','1','0','0'),
('14714','Knee orthosis; derotation; medial-lateral; anterior cruciate ligament; custom fabricated','Ko derot ant cruciate custom','L1840','3','','1','0','','','','0','1','0','0'),
('14715','Knee orthosis; single upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ko single upright pre cst','L1843','3','','1','0','','','','0','1','0','0'),
('14716','Knee orthosis; single upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; custom fabricated','Ko w/adj jt rot cntrl molded','L1844','3','','1','0','','','','0','1','0','0'),
('14717','Knee orthosis; double upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ko double upright pre cst','L1845','3','','1','0','','','','0','1','0','0'),
('14718','Knee orthosis; double upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; custom fabricated','Ko w adj flex/ext rotat mold','L1846','3','','1','0','','','','0','1','0','0'),
('14719','Knee orthosis; double upright with adjustable joint; with inflatable air support chamber(s); prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Ko dbl upright w/air pre cst','L1847','3','','1','0','','','','0','1','0','0'),
('14720','Knee orthosis; double upright with adjustable joint; with inflatable air support chamber(s); prefabricated; off-the-shelf','Ko dbl upright w/air pre ots','L1848','3','','1','0','','','','0','1','0','0'),
('14721','Knee orthosis; swedish type; prefabricated; off-the-shelf','Ko swedish type pre ots','L1850','3','','1','0','','','','0','1','0','0'),
('14722','Knee orthosis (ko); single upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated; off-the-shelf','Ko single upright prefab ots','L1851','3','','1','0','','','','0','1','0','0'),
('14723','Knee orthosis (ko); double upright; thigh and calf; with adjustable flexion and extension joint (unicentric or polycentric); medial-lateral and rotation control; with or without varus/valgus adjustment; prefabricated; off-the-shelf','Ko double upright prefab ots','L1852','3','','1','0','','','','0','1','0','0'),
('14724','Knee orthosis; modification of supracondylar prosthetic socket; custom fabricated (sk)','Ko supracondylar socket mold','L1860','3','','1','0','','','','0','1','0','0'),
('14725','Ankle foot orthosis; spring wire; dorsiflexion assist calf band; custom fabricated','Afo sprng wir drsflx calf bd','L1900','3','','1','0','','','','0','1','0','0'),
('14726','Ankle orthosis; ankle gauntlet or similar; with or without joints; prefabricated; off-the-shelf','Afo ankle gauntlet pre ots','L1902','3','','1','0','','','','0','1','0','0'),
('14727','Ankle orthosis; ankle gauntlet or similar; with or without joints; custom fabricated','Afo molded ankle gauntlet','L1904','3','','1','0','','','','0','1','0','0'),
('14728','Ankle foot orthosis; multiligamentous ankle support; prefabricated; off-the-shelf','Afo multilig ank sup pre ots','L1906','3','','1','0','','','','0','1','0','0'),
('14729','Ankle orthosis; supramalleolar with straps; with or without interface/pads; custom fabricated','Afo supramalleolar custom','L1907','3','','1','0','','','','0','1','0','0'),
('14730','Ankle foot orthosis; posterior; single bar; clasp attachment to shoe counter; prefabricated; includes fitting and adjustment','Afo sing bar clasp attach sh','L1910','3','','1','0','','','','0','1','0','0'),
('14731','Ankle foot orthosis; single upright with static or adjustable stop (phelps or perlstein type); custom fabricated','Afo sing upright w/ adjust s','L1920','3','','1','0','','','','0','1','0','0'),
('14732','Ankle foot orthosis; plastic or other material; prefabricated; includes fitting and adjustment','Afo plastic','L1930','3','','1','0','','','','0','1','0','0'),
('14733','Afo; rigid anterior tibial section; total carbon fiber or equal material; prefabricated; includes fitting and adjustment','Afo rig ant tib prefab tcf/=','L1932','3','','1','0','','','','0','1','0','0'),
('14734','Ankle foot orthosis; plastic or other material; custom fabricated','Afo molded to patient plasti','L1940','3','','1','0','','','','0','1','0','0'),
('14735','Ankle foot orthosis; plastic; rigid anterior tibial section (floor reaction); custom fabricated','Afo molded plas rig ant tib','L1945','3','','1','0','','','','0','1','0','0'),
('14736','Ankle foot orthosis; spiral; (institute of rehabilitative medicine type); plastic; custom fabricated','Afo spiral molded to pt plas','L1950','3','','1','0','','','','0','1','0','0'),
('14737','Ankle foot orthosis; spiral; (institute of rehabilitative medicine type); plastic or other material; prefabricated; includes fitting and adjustment','Afo spiral prefabricated','L1951','3','','1','0','','','','0','1','0','0'),
('14738','Ankle foot orthosis; posterior solid ankle; plastic; custom fabricated','Afo pos solid ank plastic mo','L1960','3','','1','0','','','','0','1','0','0'),
('14739','Ankle foot orthosis; plastic with ankle joint; custom fabricated','Afo plastic molded w/ankle j','L1970','3','','1','0','','','','0','1','0','0'),
('14740','Ankle foot orthosis; plastic or other material with ankle joint; prefabricated; includes fitting and adjustment','Afo w/ankle joint; prefab','L1971','3','','1','0','','','','0','1','0','0'),
('14741','Ankle foot orthosis; single upright free plantar dorsiflexion; solid stirrup; calf band/cuff (single bar bk orthosis); custom fabricated','Afo sing solid stirrup calf','L1980','3','','1','0','','','','0','1','0','0'),
('14742','Ankle foot orthosis; double upright free plantar dorsiflexion; solid stirrup; calf band/cuff (double bar bk orthosis); custom fabricated','Afo doub solid stirrup calf','L1990','3','','1','0','','','','0','1','0','0'),
('14743','Knee ankle foot orthosis; single upright; free knee; free ankle; solid stirrup; thigh and calf bands/cuffs (single bar ak orthosis); custom fabricated','Kafo sing fre stirr thi/calf','L2000','3','','1','0','','','','0','1','0','0'),
('14744','Knee ankle foot orthosis; any material; single or double upright; stance control; automatic lock and swing phase release; any type activation; includes ankle joint; any type; custom fabricated','Kafo sng/dbl mechanical act','L2005','3','','1','0','','','','0','1','0','0'),
('14745','Knee ankle foot orthosis; single upright; free ankle; solid stirrup; thigh and calf bands/cuffs (single bar ak orthosis); without knee joint; custom fabricated','Kafo sng solid stirrup w/o j','L2010','3','','1','0','','','','0','1','0','0'),
('14746','Knee ankle foot orthosis; double upright; free ankle; solid stirrup; thigh and calf bands/cuffs (double bar ak orthosis); custom fabricated','Kafo dbl solid stirrup band/','L2020','3','','1','0','','','','0','1','0','0'),
('14747','Knee ankle foot orthosis; double upright; free ankle; solid stirrup; thigh and calf bands/cuffs; (double bar ak orthosis); without knee joint; custom fabricated','Kafo dbl solid stirrup w/o j','L2030','3','','1','0','','','','0','1','0','0'),
('14748','Knee ankle foot orthosis; full plastic; single upright; with or without free motion knee; medial lateral rotation control; with or without free motion ankle; custom fabricated','Kafo pla sin up w/wo k/a cus','L2034','3','','1','0','','','','0','1','0','0'),
('14749','Knee ankle foot orthosis; full plastic; static (pediatric size); without free motion ankle; prefabricated; includes fitting and adjustment','Kafo plastic pediatric size','L2035','3','','1','0','','','','0','1','0','0'),
('14750','Knee ankle foot orthosis; full plastic; double upright; with or without free motion knee; with or without free motion ankle; custom fabricated','Kafo plas doub free knee mol','L2036','3','','1','0','','','','0','1','0','0'),
('14751','Knee ankle foot orthosis; full plastic; single upright; with or without free motion knee; with or without free motion ankle; custom fabricated','Kafo plas sing free knee mol','L2037','3','','1','0','','','','0','1','0','0'),
('14752','Knee ankle foot orthosis; full plastic; with or without free motion knee; multi-axis ankle; custom fabricated','Kafo w/o joint multi-axis an','L2038','3','','1','0','','','','0','1','0','0'),
('14753','Hip knee ankle foot orthosis; torsion control; bilateral rotation straps; pelvic band/belt; custom fabricated','Hkafo torsion bil rot straps','L2040','3','','1','0','','','','0','1','0','0'),
('14754','Hip knee ankle foot orthosis; torsion control; bilateral torsion cables; hip joint; pelvic band/belt; custom fabricated','Hkafo torsion cable hip pelv','L2050','3','','1','0','','','','0','1','0','0'),
('14755','Hip knee ankle foot orthosis; torsion control; bilateral torsion cables; ball bearing hip joint; pelvic band/ belt; custom fabricated','Hkafo torsion ball bearing j','L2060','3','','1','0','','','','0','1','0','0'),
('14756','Hip knee ankle foot orthosis; torsion control; unilateral rotation straps; pelvic band/belt; custom fabricated','Hkafo torsion unilat rot str','L2070','3','','1','0','','','','0','1','0','0'),
('14757','Hip knee ankle foot orthosis; torsion control; unilateral torsion cable; hip joint; pelvic band/belt; custom fabricated','Hkafo unilat torsion cable','L2080','3','','1','0','','','','0','1','0','0'),
('14758','Hip knee ankle foot orthosis; torsion control; unilateral torsion cable; ball bearing hip joint; pelvic band/ belt; custom fabricated','Hkafo unilat torsion ball br','L2090','3','','1','0','','','','0','1','0','0'),
('14759','Ankle foot orthosis; fracture orthosis; tibial fracture cast orthosis; thermoplastic type casting material; custom fabricated','Afo tib fx cast plaster mold','L2106','3','','1','0','','','','0','1','0','0'),
('14760','Ankle foot orthosis; fracture orthosis; tibial fracture cast orthosis; custom fabricated','Afo tib fx cast molded to pt','L2108','3','','1','0','','','','0','1','0','0'),
('14761','Ankle foot orthosis; fracture orthosis; tibial fracture orthosis; soft; prefabricated; includes fitting and adjustment','Afo tibial fracture soft','L2112','3','','1','0','','','','0','1','0','0'),
('14762','Ankle foot orthosis; fracture orthosis; tibial fracture orthosis; semi-rigid; prefabricated; includes fitting and adjustment','Afo tib fx semi-rigid','L2114','3','','1','0','','','','0','1','0','0'),
('14763','Ankle foot orthosis; fracture orthosis; tibial fracture orthosis; rigid; prefabricated; includes fitting and adjustment','Afo tibial fracture rigid','L2116','3','','1','0','','','','0','1','0','0'),
('14764','Knee ankle foot orthosis; fracture orthosis; femoral fracture cast orthosis; thermoplastic type casting material; custom fabricated','Kafo fem fx cast thermoplas','L2126','3','','1','0','','','','0','1','0','0'),
('14765','Knee ankle foot orthosis; fracture orthosis; femoral fracture cast orthosis; custom fabricated','Kafo fem fx cast molded to p','L2128','3','','1','0','','','','0','1','0','0'),
('14766','Kafo; fracture orthosis; femoral fracture cast orthosis; soft; prefabricated; includes fitting and adjustment','Kafo femoral fx cast soft','L2132','3','','1','0','','','','0','1','0','0'),
('14767','Kafo; fracture orthosis; femoral fracture cast orthosis; semi-rigid; prefabricated; includes fitting and adjustment','Kafo fem fx cast semi-rigid','L2134','3','','1','0','','','','0','1','0','0'),
('14768','Kafo; fracture orthosis; femoral fracture cast orthosis; rigid; prefabricated; includes fitting and adjustment','Kafo femoral fx cast rigid','L2136','3','','1','0','','','','0','1','0','0'),
('14769','Addition to lower extremity fracture orthosis; plastic shoe insert with ankle joints','Plas shoe insert w ank joint','L2180','3','','1','0','','','','0','1','0','0'),
('14770','Addition to lower extremity fracture orthosis; drop lock knee joint','Drop lock knee','L2182','3','','1','0','','','','0','1','0','0'),
('14771','Addition to lower extremity fracture orthosis; limited motion knee joint','Limited motion knee joint','L2184','3','','1','0','','','','0','1','0','0'),
('14772','Addition to lower extremity fracture orthosis; adjustable motion knee joint; lerman type','Adj motion knee jnt lerman t','L2186','3','','1','0','','','','0','1','0','0'),
('14773','Addition to lower extremity fracture orthosis; quadrilateral brim','Quadrilateral brim','L2188','3','','1','0','','','','0','1','0','0'),
('14774','Addition to lower extremity fracture orthosis; waist belt','Waist belt','L2190','3','','1','0','','','','0','1','0','0'),
('14775','Addition to lower extremity fracture orthosis; hip joint; pelvic band; thigh flange; and pelvic belt','Pelvic band & belt thigh fla','L2192','3','','1','0','','','','0','1','0','0'),
('14776','Addition to lower extremity; limited ankle motion; each joint','Limited ankle motion ea jnt','L2200','3','','1','0','','','','0','1','0','0'),
('14777','Addition to lower extremity; dorsiflexion assist (plantar flexion resist); each joint','Dorsiflexion assist each joi','L2210','3','','1','0','','','','0','1','0','0'),
('14778','Addition to lower extremity; dorsiflexion and plantar flexion assist/resist; each joint','Dorsi & plantar flex ass/res','L2220','3','','1','0','','','','0','1','0','0'),
('14779','Addition to lower extremity; split flat caliper stirrups and plate attachment','Split flat caliper stirr & p','L2230','3','','1','0','','','','0','1','0','0'),
('14780','Addition to lower extremity orthosis; rocker bottom for total contact ankle foot orthosis; for custom fabricated orthosis only','Rocker bottom; contact afo','L2232','3','','1','0','','','','0','1','0','0'),
('14781','Addition to lower extremity; round caliper and plate attachment','Round caliper and plate atta','L2240','3','','1','0','','','','0','1','0','0'),
('14782','Addition to lower extremity; foot plate; molded to patient model; stirrup attachment','Foot plate molded stirrup at','L2250','3','','1','0','','','','0','1','0','0'),
('14783','Addition to lower extremity; reinforced solid stirrup (scott-craig type)','Reinforced solid stirrup','L2260','3','','1','0','','','','0','1','0','0'),
('14784','Addition to lower extremity; long tongue stirrup','Long tongue stirrup','L2265','3','','1','0','','','','0','1','0','0'),
('14785','Addition to lower extremity; varus/valgus correction (t) strap; padded/lined or malleolus pad','Varus/valgus strap padded/li','L2270','3','','1','0','','','','0','1','0','0'),
('14786','Addition to lower extremity; varus/valgus correction; plastic modification; padded/lined','Plastic mod low ext pad/line','L2275','3','','1','0','','','','0','1','0','0'),
('14787','Addition to lower extremity; molded inner boot','Molded inner boot','L2280','3','','1','0','','','','0','1','0','0'),
('14788','Addition to lower extremity; abduction bar (bilateral hip involvement); jointed; adjustable','Abduction bar jointed adjust','L2300','3','','1','0','','','','0','1','0','0'),
('14789','Addition to lower extremity; abduction bar-straight','Abduction bar-straight','L2310','3','','1','0','','','','0','1','0','0'),
('14790','Addition to lower extremity; non-molded lacer; for custom fabricated orthosis only','Non-molded lacer','L2320','3','','1','0','','','','0','1','0','0'),
('14791','Addition to lower extremity; lacer molded to patient model; for custom fabricated orthosis only','Lacer molded to patient mode','L2330','3','','1','0','','','','0','1','0','0'),
('14792','Addition to lower extremity; anterior swing band','Anterior swing band','L2335','3','','1','0','','','','0','1','0','0'),
('14793','Addition to lower extremity; pre-tibial shell; molded to patient model','Pre-tibial shell molded to p','L2340','3','','1','0','','','','0','1','0','0'),
('14794','Addition to lower extremity; prosthetic type; (bk) socket; molded to patient model; (used for ptb afo orthoses)','Prosthetic type socket molde','L2350','3','','1','0','','','','0','1','0','0'),
('14795','Addition to lower extremity; extended steel shank','Extended steel shank','L2360','3','','1','0','','','','0','1','0','0'),
('14796','Addition to lower extremity; patten bottom','Patten bottom','L2370','3','','1','0','','','','0','1','0','0'),
('14797','Addition to lower extremity; torsion control; ankle joint and half solid stirrup','Torsion ank & half solid sti','L2375','3','','1','0','','','','0','1','0','0'),
('14798','Addition to lower extremity; torsion control; straight knee joint; each joint','Torsion straight knee joint','L2380','3','','1','0','','','','0','1','0','0'),
('14799','Addition to lower extremity; straight knee joint; heavy duty; each joint','Straight knee joint heavy du','L2385','3','','1','0','','','','0','1','0','0'),
('14800','Addition to lower extremity; polycentric knee joint; for custom fabricated knee ankle foot orthosis; each joint','Add le poly knee custom kafo','L2387','3','','1','0','','','','0','1','0','0'),
('14801','Addition to lower extremity; offset knee joint; each joint','Offset knee joint each','L2390','3','','1','0','','','','0','1','0','0'),
('14802','Addition to lower extremity; offset knee joint; heavy duty; each joint','Offset knee joint heavy duty','L2395','3','','1','0','','','','0','1','0','0'),
('14803','Addition to lower extremity orthosis; suspension sleeve','Suspension sleeve lower ext','L2397','3','','1','0','','','','0','1','0','0'),
('14804','Addition to knee joint; drop lock; each','Knee joint drop lock ea jnt','L2405','3','','1','0','','','','0','1','0','0'),
('14805','Addition to knee lock with integrated release mechanism (bail; cable; or equal); any material; each joint','Knee joint cam lock each joi','L2415','3','','1','0','','','','0','1','0','0'),
('14806','Addition to knee joint; disc or dial lock for adjustable knee flexion; each joint','Knee disc/dial lock/adj flex','L2425','3','','1','0','','','','0','1','0','0'),
('14807','Addition to knee joint; ratchet lock for active and progressive knee extension; each joint','Knee jnt ratchet lock ea jnt','L2430','3','','1','0','','','','0','1','0','0'),
('14808','Addition to knee joint; lift loop for drop lock ring','Knee lift loop drop lock rin','L2492','3','','1','0','','','','0','1','0','0'),
('14809','Addition to lower extremity; thigh/weight bearing; gluteal/ ischial weight bearing; ring','Thi/glut/ischia wgt bearing','L2500','3','','1','0','','','','0','1','0','0'),
('14810','Addition to lower extremity; thigh/weight bearing; quadri- lateral brim; molded to patient model','Th/wght bear quad-lat brim m','L2510','3','','1','0','','','','0','1','0','0'),
('14811','Addition to lower extremity; thigh/weight bearing; quadri- lateral brim; custom fitted','Th/wght bear quad-lat brim c','L2520','3','','1','0','','','','0','1','0','0'),
('14812','Addition to lower extremity; thigh/weight bearing; ischial containment/narrow m-l brim molded to patient model','Th/wght bear nar m-l brim mo','L2525','3','','1','0','','','','0','1','0','0'),
('14813','Addition to lower extremity; thigh/weight bearing; ischial containment/narrow m-l brim; custom fitted','Th/wght bear nar m-l brim cu','L2526','3','','1','0','','','','0','1','0','0'),
('14814','Addition to lower extremity; thigh-weight bearing; lacer; non-molded','Thigh/wght bear lacer non-mo','L2530','3','','1','0','','','','0','1','0','0'),
('14815','Addition to lower extremity; thigh/weight bearing; lacer; molded to patient model','Thigh/wght bear lacer molded','L2540','3','','1','0','','','','0','1','0','0'),
('14816','Addition to lower extremity; thigh/weight bearing; high roll cuff','Thigh/wght bear high roll cu','L2550','3','','1','0','','','','0','1','0','0'),
('14817','Addition to lower extremity; pelvic control; hip joint; clevis type two position joint; each','Hip clevis type 2 posit jnt','L2570','3','','1','0','','','','0','1','0','0'),
('14818','Addition to lower extremity; pelvic control; pelvic sling','Pelvic control pelvic sling','L2580','3','','1','0','','','','0','1','0','0'),
('14819','Addition to lower extremity; pelvic control; hip joint; clevis type; or thrust bearing; free; each','Hip clevis/thrust bearing fr','L2600','3','','1','0','','','','0','1','0','0'),
('14820','Addition to lower extremity; pelvic control; hip joint; clevis or thrust bearing; lock; each','Hip clevis/thrust bearing lo','L2610','3','','1','0','','','','0','1','0','0'),
('14821','Addition to lower extremity; pelvic control; hip joint; heavy duty; each','Pelvic control hip heavy dut','L2620','3','','1','0','','','','0','1','0','0'),
('14822','Addition to lower extremity; pelvic control; hip joint; adjustable flexion; each','Hip joint adjustable flexion','L2622','3','','1','0','','','','0','1','0','0'),
('14823','Addition to lower extremity; pelvic control; hip joint; adjustable flexion; extension; abduction control; each','Hip adj flex ext abduct cont','L2624','3','','1','0','','','','0','1','0','0'),
('14824','Addition to lower extremity; pelvic control; plastic; molded to patient model; reciprocating hip joint and cables','Plastic mold recipro hip & c','L2627','3','','1','0','','','','0','1','0','0'),
('14825','Addition to lower extremity; pelvic control; metal frame; reciprocating hip joint and cables','Metal frame recipro hip & ca','L2628','3','','1','0','','','','0','1','0','0'),
('14826','Addition to lower extremity; pelvic control; band and belt; unilateral','Pelvic control band & belt u','L2630','3','','1','0','','','','0','1','0','0'),
('14827','Addition to lower extremity; pelvic control; band and belt; bilateral','Pelvic control band & belt b','L2640','3','','1','0','','','','0','1','0','0'),
('14828','Addition to lower extremity; pelvic and thoracic control; gluteal pad; each','Pelv & thor control gluteal','L2650','3','','1','0','','','','0','1','0','0'),
('14829','Addition to lower extremity; thoracic control; thoracic band','Thoracic control thoracic ba','L2660','3','','1','0','','','','0','1','0','0'),
('14830','Addition to lower extremity; thoracic control; paraspinal uprights','Thorac cont paraspinal uprig','L2670','3','','1','0','','','','0','1','0','0'),
('14831','Addition to lower extremity; thoracic control; lateral support uprights','Thorac cont lat support upri','L2680','3','','1','0','','','','0','1','0','0'),
('14832','Addition to lower extremity orthosis; plating chrome or nickel; per bar','Plating chrome/nickel pr bar','L2750','3','','1','0','','','','0','1','0','0'),
('14833','Addition to lower extremity orthosis; high strength; lightweight material; all hybrid lamination/prepreg composite; per segment; for custom fabricated orthosis only','Carbon graphite lamination','L2755','3','','1','0','','','','0','1','0','0'),
('14834','Addition to lower extremity orthosis; extension; per extension; per bar (for lineal adjustment for growth)','Extension per extension per','L2760','3','','1','0','','','','0','1','0','0'),
('14835','Orthotic side bar disconnect device; per bar','Ortho sidebar disconnect','L2768','3','','1','0','','','','0','1','0','0'),
('14836','Addition to lower extremity orthosis; non-corrosive finish; per bar','Non-corrosive finish','L2780','3','','1','0','','','','0','1','0','0'),
('14837','Addition to lower extremity orthosis; drop lock retainer; each','Drop lock retainer each','L2785','3','','1','0','','','','0','1','0','0'),
('14838','Addition to lower extremity orthosis; knee control; full kneecap','Knee control full kneecap','L2795','3','','1','0','','','','0','1','0','0'),
('14839','Addition to lower extremity orthosis; knee control; knee cap; medial or lateral pull; for use with custom fabricated orthosis only','Knee cap medial or lateral p','L2800','3','','1','0','','','','0','1','0','0'),
('14840','Addition to lower extremity orthosis; knee control; condylar pad','Knee control condylar pad','L2810','3','','1','0','','','','0','1','0','0'),
('14841','Addition to lower extremity orthosis; soft interface for molded plastic; below knee section','Soft interface below knee se','L2820','3','','1','0','','','','0','1','0','0'),
('14842','Addition to lower extremity orthosis; soft interface for molded plastic; above knee section','Soft interface above knee se','L2830','3','','1','0','','','','0','1','0','0'),
('14843','Addition to lower extremity orthosis; tibial length sock; fracture or equal; each','Tibial length sock fx or equ','L2840','3','','1','0','','','','0','1','0','0'),
('14844','Addition to lower extremity orthosis; femoral length sock; fracture or equal; each','Femoral lgth sock fx or equa','L2850','3','','1','0','','','','0','1','0','0'),
('14845','Addition to lower extremity joint; knee or ankle; concentric adjustable torsion style mechanism for custom fabricated orthotics only; each','Torsion mechanism knee/ankle','L2861','3','','1','0','','','','0','1','0','0'),
('14846','Lower extremity orthoses; not otherwise specified','Lower extremity orthosis nos','L2999','3','','1','0','','','','0','1','0','0'),
('14847','Foot; insert; removable; molded to patient model; ucb type; berkeley shell; each','Ft insert ucb berkeley shell','L3000','3','','1','0','','','','0','1','0','0'),
('14848','Foot; insert; removable; molded to patient model; spenco; each','Foot insert remov molded spe','L3001','3','','1','0','','','','0','1','0','0'),
('14849','Foot; insert; removable; molded to patient model; plastazote or equal; each','Foot insert plastazote or eq','L3002','3','','1','0','','','','0','1','0','0'),
('14850','Foot; insert; removable; molded to patient model; silicone gel; each','Foot insert silicone gel eac','L3003','3','','1','0','','','','0','1','0','0'),
('14851','Foot; insert; removable; molded to patient model; longitudinal arch support; each','Foot longitudinal arch suppo','L3010','3','','1','0','','','','0','1','0','0'),
('14852','Foot; insert; removable; molded to patient model; longitudinal/ metatarsal support; each','Foot longitud/metatarsal sup','L3020','3','','1','0','','','','0','1','0','0'),
('14853','Foot; insert; removable; formed to patient foot; each','Foot arch support remov prem','L3030','3','','1','0','','','','0','1','0','0'),
('14854','Foot; insert/plate; removable; addition to lower extremity orthosis; high strength; lightweight material; all hybrid lamination/prepreg composite; each','Foot lamin/prepreg composite','L3031','3','','1','0','','','','0','1','0','0'),
('14855','Foot; arch support; removable; premolded; longitudinal; each','Ft arch suprt premold longit','L3040','3','','1','0','','','','0','1','0','0'),
('14856','Foot; arch support; removable; premolded; metatarsal; each','Foot arch supp premold metat','L3050','3','','1','0','','','','0','1','0','0'),
('14857','Foot; arch support; removable; premolded; longitudinal/ metatarsal; each','Foot arch supp longitud/meta','L3060','3','','1','0','','','','0','1','0','0'),
('14858','Foot; arch support; non-removable attached to shoe; longitudinal; each','Arch suprt att to sho longit','L3070','3','','1','0','','','','0','1','0','0'),
('14859','Foot; arch support; non-removable attached to shoe; metatarsal; each','Arch supp att to shoe metata','L3080','3','','1','0','','','','0','1','0','0'),
('14860','Foot; arch support; non-removable attached to shoe; longitudinal/metatarsal; each','Arch supp att to shoe long/m','L3090','3','','1','0','','','','0','1','0','0'),
('14861','Hallus-valgus night dynamic splint; prefabricated; off-the-shelf','Hallus-valgus nt dyn pre ots','L3100','3','','1','0','','','','0','1','0','0'),
('14862','Foot; abduction rotation bar; including shoes','Abduction rotation bar shoe','L3140','3','','1','0','','','','0','1','0','0'),
('14863','Foot; abduction rotation bar; without shoes','Abduct rotation bar w/o shoe','L3150','3','','1','0','','','','0','1','0','0'),
('14864','Foot; adjustable shoe-styled positioning device','Shoe styled positioning dev','L3160','3','','1','0','','','','0','1','0','0'),
('14865','Foot; plastic; silicone or equal; heel stabilizer; prefabricated; off-the-shelf; each','Foot plas heel stabi pre ots','L3170','3','','1','0','','','','0','1','0','0'),
('14866','Orthopedic shoe; oxford with supinator or pronator; infant','Oxford w supinat/pronat inf','L3201','3','','1','0','','','','0','1','0','0'),
('14867','Orthopedic shoe; oxford with supinator or pronator; child','Oxford w/ supinat/pronator c','L3202','3','','1','0','','','','0','1','0','0'),
('14868','Orthopedic shoe; oxford with supinator or pronator; junior','Oxford w/ supinator/pronator','L3203','3','','1','0','','','','0','1','0','0'),
('14869','Orthopedic shoe; hightop with supinator or pronator; infant','Hightop w/ supp/pronator inf','L3204','3','','1','0','','','','0','1','0','0'),
('14870','Orthopedic shoe; hightop with supinator or pronator; child','Hightop w/ supp/pronator chi','L3206','3','','1','0','','','','0','1','0','0'),
('14871','Orthopedic shoe; hightop with supinator or pronator; junior','Hightop w/ supp/pronator jun','L3207','3','','1','0','','','','0','1','0','0'),
('14872','Surgical boot; each; infant','Surgical boot each infant','L3208','3','','1','0','','','','0','1','0','0'),
('14873','Surgical boot; each; child','Surgical boot each child','L3209','3','','1','0','','','','0','1','0','0'),
('14874','Surgical boot; each; junior','Surgical boot each junior','L3211','3','','1','0','','','','0','1','0','0'),
('14875','Benesch boot; pair; infant','Benesch boot pair infant','L3212','3','','1','0','','','','0','1','0','0'),
('14876','Benesch boot; pair; child','Benesch boot pair child','L3213','3','','1','0','','','','0','1','0','0'),
('14877','Benesch boot; pair; junior','Benesch boot pair junior','L3214','3','','1','0','','','','0','1','0','0'),
('14878','Orthopedic footwear; ladies shoe; oxford; each','Orthopedic ftwear ladies oxf','L3215','3','','1','0','','','','0','1','0','0'),
('14879','Orthopedic footwear; ladies shoe; depth inlay; each','Orthoped ladies shoes dpth i','L3216','3','','1','0','','','','0','1','0','0'),
('14880','Orthopedic footwear; ladies shoe; hightop; depth inlay; each','Ladies shoes hightop depth i','L3217','3','','1','0','','','','0','1','0','0'),
('14881','Orthopedic footwear; mens shoe; oxford; each','Orthopedic mens shoes oxford','L3219','3','','1','0','','','','0','1','0','0'),
('14882','Orthopedic footwear; mens shoe; depth inlay; each','Orthopedic mens shoes dpth i','L3221','3','','1','0','','','','0','1','0','0'),
('14883','Orthopedic footwear; mens shoe; hightop; depth inlay; each','Mens shoes hightop depth inl','L3222','3','','1','0','','','','0','1','0','0'),
('14884','Orthopedic footwear; womans shoe; oxford; used as an integral part of a brace (orthosis)','Womans shoe oxford brace','L3224','3','','1','0','','','','0','1','0','0'),
('14885','Orthopedic footwear; mans shoe; oxford; used as an integral part of a brace (orthosis)','Mans shoe oxford brace','L3225','3','','1','0','','','','0','1','0','0'),
('14886','Orthopedic footwear; custom shoe; depth inlay; each','Custom shoes depth inlay','L3230','3','','1','0','','','','0','1','0','0'),
('14887','Orthopedic footwear; custom molded shoe; removable inner mold; prosthetic shoe; each','Custom mold shoe remov prost','L3250','3','','1','0','','','','0','1','0','0'),
('14888','Foot; shoe molded to patient model; silicone shoe; each','Shoe molded to pt silicone s','L3251','3','','1','0','','','','0','1','0','0'),
('14889','Foot; shoe molded to patient model; plastazote (or similar); custom fabricated; each','Shoe molded plastazote cust','L3252','3','','1','0','','','','0','1','0','0'),
('14890','Foot; molded shoe plastazote (or similar) custom fitted; each','Shoe molded plastazote cust','L3253','3','','1','0','','','','0','1','0','0'),
('14891','Non-standard size or width','Orth foot non-stndard size/w','L3254','3','','1','0','','','','0','1','0','0'),
('14892','Non-standard size or length','Orth foot non-standard size/','L3255','3','','1','0','','','','0','1','0','0'),
('14893','Orthopedic footwear; additional charge for split size','Orth foot add charge split s','L3257','3','','1','0','','','','0','1','0','0'),
('14894','Surgical boot/shoe; each','Ambulatory surgical boot eac','L3260','3','','1','0','','','','0','1','0','0'),
('14895','Plastazote sandal; each','Plastazote sandal each','L3265','3','','1','0','','','','0','1','0','0'),
('14896','Lift; elevation; heel; tapered to metatarsals; per inch','Sho lift taper to metatarsal','L3300','3','','1','0','','','','0','1','0','0'),
('14897','Lift; elevation; heel and sole; neoprene; per inch','Shoe lift elev heel/sole neo','L3310','3','','1','0','','','','0','1','0','0'),
('14898','Lift; elevation; heel and sole; cork; per inch','Shoe lift elev heel/sole cor','L3320','3','','1','0','','','','0','1','0','0'),
('14899','Lift; elevation; metal extension (skate)','Lifts elevation metal extens','L3330','3','','1','0','','','','0','1','0','0'),
('14900','Lift; elevation; inside shoe; tapered; up to one-half inch','Shoe lifts tapered to one-ha','L3332','3','','1','0','','','','0','1','0','0'),
('14901','Lift; elevation; heel; per inch','Shoe lifts elevation heel /i','L3334','3','','1','0','','','','0','1','0','0'),
('14902','Heel wedge; sach','Shoe wedge sach','L3340','3','','1','0','','','','0','1','0','0'),
('14903','Heel wedge','Shoe heel wedge','L3350','3','','1','0','','','','0','1','0','0'),
('14904','Sole wedge; outside sole','Shoe sole wedge outside sole','L3360','3','','1','0','','','','0','1','0','0'),
('14905','Sole wedge; between sole','Shoe sole wedge between sole','L3370','3','','1','0','','','','0','1','0','0'),
('14906','Clubfoot wedge','Shoe clubfoot wedge','L3380','3','','1','0','','','','0','1','0','0'),
('14907','Outflare wedge','Shoe outflare wedge','L3390','3','','1','0','','','','0','1','0','0'),
('14908','Metatarsal bar wedge; rocker','Shoe metatarsal bar wedge ro','L3400','3','','1','0','','','','0','1','0','0'),
('14909','Metatarsal bar wedge; between sole','Shoe metatarsal bar between','L3410','3','','1','0','','','','0','1','0','0'),
('14910','Full sole and heel wedge; between sole','Full sole/heel wedge btween','L3420','3','','1','0','','','','0','1','0','0'),
('14911','Heel; counter; plastic reinforced','Sho heel count plast reinfor','L3430','3','','1','0','','','','0','1','0','0'),
('14912','Heel; counter; leather reinforced','Heel leather reinforced','L3440','3','','1','0','','','','0','1','0','0'),
('14913','Heel; sach cushion type','Shoe heel sach cushion type','L3450','3','','1','0','','','','0','1','0','0'),
('14914','Heel; new leather; standard','Shoe heel new leather standa','L3455','3','','1','0','','','','0','1','0','0'),
('14915','Heel; new rubber; standard','Shoe heel new rubber standar','L3460','3','','1','0','','','','0','1','0','0'),
('14916','Heel; thomas with wedge','Shoe heel thomas with wedge','L3465','3','','1','0','','','','0','1','0','0'),
('14917','Heel; thomas extended to ball','Shoe heel thomas extend to b','L3470','3','','1','0','','','','0','1','0','0'),
('14918','Heel; pad and depression for spur','Shoe heel pad & depress for','L3480','3','','1','0','','','','0','1','0','0'),
('14919','Heel; pad; removable for spur','Shoe heel pad removable for','L3485','3','','1','0','','','','0','1','0','0'),
('14920','Orthopedic shoe addition; insole; leather','Ortho shoe add leather insol','L3500','3','','1','0','','','','0','1','0','0'),
('14921','Orthopedic shoe addition; insole; rubber','Orthopedic shoe add rub insl','L3510','3','','1','0','','','','0','1','0','0'),
('14922','Orthopedic shoe addition; insole; felt covered with leather','O shoe add felt w leath insl','L3520','3','','1','0','','','','0','1','0','0'),
('14923','Orthopedic shoe addition; sole; half','Ortho shoe add half sole','L3530','3','','1','0','','','','0','1','0','0'),
('14924','Orthopedic shoe addition; sole; full','Ortho shoe add full sole','L3540','3','','1','0','','','','0','1','0','0'),
('14925','Orthopedic shoe addition; toe tap standard','O shoe add standard toe tap','L3550','3','','1','0','','','','0','1','0','0'),
('14926','Orthopedic shoe addition; toe tap; horseshoe','O shoe add horseshoe toe tap','L3560','3','','1','0','','','','0','1','0','0'),
('14927','Orthopedic shoe addition; special extension to instep (leather with eyelets)','O shoe add instep extension','L3570','3','','1','0','','','','0','1','0','0'),
('14928','Orthopedic shoe addition; convert instep to velcro closure','O shoe add instep velcro clo','L3580','3','','1','0','','','','0','1','0','0'),
('14929','Orthopedic shoe addition; convert firm shoe counter to soft counter','O shoe convert to sof counte','L3590','3','','1','0','','','','0','1','0','0'),
('14930','Orthopedic shoe addition; march bar','Ortho shoe add march bar','L3595','3','','1','0','','','','0','1','0','0'),
('14931','Transfer of an orthosis from one shoe to another; caliper plate; existing','Trans shoe calip plate exist','L3600','3','','1','0','','','','0','1','0','0'),
('14932','Transfer of an orthosis from one shoe to another; caliper plate; new','Trans shoe caliper plate new','L3610','3','','1','0','','','','0','1','0','0'),
('14933','Transfer of an orthosis from one shoe to another; solid stirrup; existing','Trans shoe solid stirrup exi','L3620','3','','1','0','','','','0','1','0','0'),
('14934','Transfer of an orthosis from one shoe to another; solid stirrup; new','Trans shoe solid stirrup new','L3630','3','','1','0','','','','0','1','0','0'),
('14935','Transfer of an orthosis from one shoe to another; dennis browne splint (riveton); both shoes','Shoe dennis browne splint bo','L3640','3','','1','0','','','','0','1','0','0'),
('14936','Orthopedic shoe; modification; addition or transfer; not otherwise specified','Orthopedic shoe modifica nos','L3649','3','','1','0','','','','0','1','0','0'),
('14937','Shoulder orthosis; figure of eight design abduction restrainer; prefabricated; off-the-shelf','So 8 abd restraint pre ots','L3650','3','','1','0','','','','0','1','0','0'),
('14938','Shoulder orthosis; figure of eight design abduction restrainer; canvas and webbing; prefabricated; off-the-shelf','So 8 ab rstr can/web pre ots','L3660','3','','1','0','','','','0','1','0','0'),
('14939','Shoulder orthosis; acromio/clavicular (canvas and webbing type); prefabricated; off-the-shelf','So acro/clav can web pre ots','L3670','3','','1','0','','','','0','1','0','0'),
('14940','Shoulder orthosis; shoulder joint design; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','So cap design w/o jnts cf','L3671','3','','1','0','','','','0','1','0','0'),
('14941','Shoulder orthosis; abduction positioning (airplane design); thoracic component and support bar; with or without nontorsion joint/turnbuckle; may include soft interface; straps; custom fabricated; includes fitting and adjustment','So airplane w/wo joint cf','L3674','3','','1','0','','','','0','1','0','0'),
('14942','Shoulder orthosis; vest type abduction restrainer; canvas webbing type or equal; prefabricated; off-the-shelf','So vest canvas/web pre ots','L3675','3','','1','0','','','','0','1','0','0'),
('14943','Shoulder orthosis; shoulder joint design; without joints; may include soft interface; straps; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','So hard plas stabili pre cst','L3677','3','','1','0','','','','0','1','0','0'),
('14944','Shoulder orthosis; shoulder joint design; without joints; may include soft interface; straps; prefabricated; off-the-shelf','So hard plas stabili pre ots','L3678','3','','1','0','','','','0','1','0','0'),
('14945','Elbow orthosis; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Eo w/o joints cf','L3702','3','','1','0','','','','0','1','0','0'),
('14946','Elbow orthosis; elastic with metal joints; prefabricated; off-the-shelf','Eo elas w/metal jnts pre ots','L3710','3','','1','0','','','','0','1','0','0'),
('14947','Elbow orthosis; double upright with forearm/arm cuffs; free motion; custom fabricated','Forearm/arm cuffs free motio','L3720','3','','1','0','','','','0','1','0','0'),
('14948','Elbow orthosis; double upright with forearm/arm cuffs; extension/ flexion assist; custom fabricated','Forearm/arm cuffs ext/flex a','L3730','3','','1','0','','','','0','1','0','0'),
('14949','Elbow orthosis; double upright with forearm/arm cuffs; adjustable position lock with active control; custom fabricated','Cuffs adj lock w/ active con','L3740','3','','1','0','','','','0','1','0','0'),
('14950','Elbow orthosis; with adjustable position locking joint(s); prefabricated; includes fitting and adjustments; any type','Eo withjoint; prefabricated','L3760','3','','1','0','','','','0','1','0','0'),
('14951','Elbow orthosis; rigid; without joints; includes soft interface material; prefabricated; off-the-shelf','Eo rigid w/o joints pre ots','L3762','3','','1','0','','','','0','1','0','0'),
('14952','Elbow wrist hand orthosis; rigid; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Ewho rigid w/o jnts cf','L3763','3','','1','0','','','','0','1','0','0'),
('14953','Elbow wrist hand orthosis; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Ewho w/joint(s) cf','L3764','3','','1','0','','','','0','1','0','0'),
('14954','Elbow wrist hand finger orthosis; rigid; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Ewhfo rigid w/o jnts cf','L3765','3','','1','0','','','','0','1','0','0'),
('14955','Elbow wrist hand finger orthosis; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Ewhfo w/joint(s) cf','L3766','3','','1','0','','','','0','1','0','0'),
('14956','Wrist hand finger orthosis; includes one or more nontorsion joint(s); turnbuckles; elastic bands/springs; may include soft interface material; straps; custom fabricated; includes fitting and adjustment','Whfo w/joint(s) custom fab','L3806','3','','1','0','','','','0','1','0','0'),
('14957','Wrist hand finger orthosis; without joint(s); prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Whfo w/o joints pre cst','L3807','3','','1','0','','','','0','1','0','0'),
('14958','Wrist hand finger orthosis; rigid without joints; may include soft interface material; straps; custom fabricated; includes fitting and adjustment','Whfo; rigid w/o joints','L3808','3','','1','0','','','','0','1','0','0'),
('14959','Wrist hand finger orthosis; without joint(s); prefabricated; off-the-shelf; any type','Whfo w/o joints pre ots','L3809','3','','1','0','','','','0','1','0','0'),
('14960','Addition to upper extremity joint; wrist or elbow; concentric adjustable torsion style mechanism for custom fabricated orthotics only; each','Torsion mechanism wrist/elbo','L3891','3','','1','0','','','','0','1','0','0'),
('14961','Wrist hand finger orthosis; dynamic flexor hinge; reciprocal wrist extension/ flexion; finger flexion/extension; wrist or finger driven; custom fabricated','Hinge extension/flex wrist/f','L3900','3','','1','0','','','','0','1','0','0'),
('14962','Wrist hand finger orthosis; dynamic flexor hinge; reciprocal wrist extension/ flexion; finger flexion/extension; cable driven; custom fabricated','Hinge ext/flex wrist finger','L3901','3','','1','0','','','','0','1','0','0'),
('14963','Wrist hand finger orthosis; external powered; electric; custom fabricated','Whfo electric custom fitted','L3904','3','','1','0','','','','0','1','0','0'),
('14964','Wrist hand orthosis; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Who w/nontorsion jnt(s) cf','L3905','3','','1','0','','','','0','1','0','0'),
('14965','Wrist hand orthosis; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Who w/o joints cf','L3906','3','','1','0','','','','0','1','0','0'),
('14966','Wrist hand orthosis; wrist extension control cock-up; non molded; prefabricated; off-the-shelf','Who cock-up nonmolde pre ots','L3908','3','','1','0','','','','0','1','0','0'),
('14967','Hand finger orthosis (hfo); flexion glove with elastic finger control; prefabricated; off-the-shelf','Hfo flexion glove pre ots','L3912','3','','1','0','','','','0','1','0','0'),
('14968','Hand finger orthosis; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Hfo w/o joints cf','L3913','3','','1','0','','','','0','1','0','0'),
('14969','Wrist hand orthosis; includes one or more nontorsion joint(s); elastic bands; turnbuckles; may include soft interface; straps; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Who nontorsion jnts pre cst','L3915','3','','1','0','','','','0','1','0','0'),
('14970','Wrist hand orthosis; includes one or more nontorsion joint(s); elastic bands; turnbuckles; may include soft interface; straps; prefabricated; off-the-shelf','Who nontorsion jnts pre ots','L3916','3','','1','0','','','','0','1','0','0'),
('14971','Hand orthosis; metacarpal fracture orthosis; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Metacarp fx orthosis pre cst','L3917','3','','1','0','','','','0','1','0','0'),
('14972','Hand orthosis; metacarpal fracture orthosis; prefabricated; off-the-shelf','Metacarp fx orthosis pre ots','L3918','3','','1','0','','','','0','1','0','0'),
('14973','Hand orthosis; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Ho w/o joints cf','L3919','3','','1','0','','','','0','1','0','0'),
('14974','Hand finger orthosis; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Hfo w/joint(s) cf','L3921','3','','1','0','','','','0','1','0','0'),
('14975','Hand finger orthosis; without joints; may include soft interface; straps; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Hfo without joints pre cst','L3923','3','','1','0','','','','0','1','0','0'),
('14976','Hand finger orthosis; without joints; may include soft interface; straps; prefabricated; off-the-shelf','Hfo without joints pre ots','L3924','3','','1','0','','','','0','1','0','0'),
('14977','Finger orthosis; proximal interphalangeal (pip)/distal interphalangeal (dip); non torsion joint/spring; extension/flexion; may include soft interface material; prefabricated; off-the-shelf','Fo pip dip jnt/sprng pre ots','L3925','3','','1','0','','','','0','1','0','0'),
('14978','Finger orthosis; proximal interphalangeal (pip)/distal interphalangeal (dip); without joint/spring; extension/flexion (e.g.; static or ring type); may include soft interface material; prefabricated; off-the-shelf','Fo pip dip no jt spr pre ots','L3927','3','','1','0','','','','0','1','0','0'),
('14979','Hand finger orthosis; includes one or more nontorsion joint(s); turnbuckles; elastic bands/springs; may include soft interface material; straps; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Hfo nontorsion jnts pre cst','L3929','3','','1','0','','','','0','1','0','0'),
('14980','Hand finger orthosis; includes one or more nontorsion joint(s); turnbuckles; elastic bands/springs; may include soft interface material; straps; prefabricated; off-the-shelf','Hfo nontorsion jnts pre ots','L3930','3','','1','0','','','','0','1','0','0'),
('14981','Wrist hand finger orthosis; includes one or more nontorsion joint(s); turnbuckles; elastic bands/springs; may include soft interface material; straps; prefabricated; includes fitting and adjustment','Whfo nontorsion joint prefab','L3931','3','','1','0','','','','0','1','0','0'),
('14982','Finger orthosis; without joints; may include soft interface; custom fabricated; includes fitting and adjustment','Fo w/o joints cf','L3933','3','','1','0','','','','0','1','0','0'),
('14983','Finger orthosis; nontorsion joint; may include soft interface; custom fabricated; includes fitting and adjustment','Fo nontorsion joint cf','L3935','3','','1','0','','','','0','1','0','0'),
('14984','Addition of joint to upper extremity orthosis; any material; per joint','Add joint upper ext orthosis','L3956','3','','1','0','','','','0','1','0','0'),
('14985','Shoulder elbow wrist hand orthosis; abduction positioning; airplane design; prefabricated; includes fitting and adjustment','Sewho airplan desig abdu pos','L3960','3','','1','0','','','','0','1','0','0'),
('14986','Shoulder elbow wrist hand orthosis; shoulder cap design; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewho cap design w/o jnts cf','L3961','3','','1','0','','','','0','1','0','0'),
('14987','Shoulder elbow wrist hand orthosis; abduction positioning; erbs palsey design; prefabricated; includes fitting and adjustment','Sewho erbs palsey design abd','L3962','3','','1','0','','','','0','1','0','0'),
('14988','Shoulder elbow wrist hand orthosis; abduction positioning (airplane design); thoracic component and support bar; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewho airplane w/o jnts cf','L3967','3','','1','0','','','','0','1','0','0'),
('14989','Shoulder elbow wrist hand orthosis; shoulder cap design; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewho cap design w/jnt(s) cf','L3971','3','','1','0','','','','0','1','0','0'),
('14990','Shoulder elbow wrist hand orthosis; abduction positioning (airplane design); thoracic component and support bar; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewho airplane w/jnt(s) cf','L3973','3','','1','0','','','','0','1','0','0'),
('14991','Shoulder elbow wrist hand finger orthosis; shoulder cap design; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewhfo cap design w/o jnt cf','L3975','3','','1','0','','','','0','1','0','0'),
('14992','Shoulder elbow wrist hand finger orthosis; abduction positioning (airplane design); thoracic component and support bar; without joints; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewhfo airplane w/o jnts cf','L3976','3','','1','0','','','','0','1','0','0'),
('14993','Shoulder elbow wrist hand finger orthosis; shoulder cap design; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewhfo cap desgn w/jnt(s) cf','L3977','3','','1','0','','','','0','1','0','0'),
('14994','Shoulder elbow wrist hand finger orthosis; abduction positioning (airplane design); thoracic component and support bar; includes one or more nontorsion joints; elastic bands; turnbuckles; may include soft interface; straps; custom fabricated; includes fitting and adjustment','Sewhfo airplane w/jnt(s) cf','L3978','3','','1','0','','','','0','1','0','0'),
('14995','Upper extremity fracture orthosis; humeral; prefabricated; includes fitting and adjustment','Up ext fx orthos humeral nos','L3980','3','','1','0','','','','0','1','0','0'),
('14996','Upper extremity fracture orthosis; humeral; prefabricated; includes shoulder cap design; with or without joints; forearm section; may include soft interface; straps; includes fitting and adjustments','Ue fx orth shoul cap forearm','L3981','3','','1','0','','','','0','1','0','0'),
('14997','Upper extremity fracture orthosis; radius/ulnar; prefabricated; includes fitting and adjustment','Upper ext fx orthosis rad/ul','L3982','3','','1','0','','','','0','1','0','0'),
('14998','Upper extremity fracture orthosis; wrist; prefabricated; includes fitting and adjustment','Upper ext fx orthosis wrist','L3984','3','','1','0','','','','0','1','0','0'),
('14999','Addition to upper extremity orthosis; sock; fracture or equal; each','Sock fracture or equal each','L3995','3','','1','0','','','','0','1','0','0');

INSERT INTO `codes` (`id`, `code_text`, `code_text_short`, `code`, `code_type`, `modifier`, `units`, `fee`, `superbill`, `related_code`, `taxrates`, `cyp_factor`, `active`, `reportable`, `financial_reporting`) VALUES

('15000','Upper limb orthosis; not otherwise specified','Upper limb orthosis nos','L3999','3','','1','0','','','','0','1','0','0'),
('15001','Replace girdle for spinal orthosis (ctlso or so)','Repl girdle milwaukee orth','L4000','3','','1','0','','','','0','1','0','0'),
('15002','Replacement strap; any orthosis; includes all components; any length; any type','Replace strap; any orthosis','L4002','3','','1','0','','','','0','1','0','0'),
('15003','Replace trilateral socket brim','Replace trilateral socket br','L4010','3','','1','0','','','','0','1','0','0'),
('15004','Replace quadrilateral socket brim; molded to patient model','Replace quadlat socket brim','L4020','3','','1','0','','','','0','1','0','0'),
('15005','Replace quadrilateral socket brim; custom fitted','Replace socket brim cust fit','L4030','3','','1','0','','','','0','1','0','0'),
('15006','Replace molded thigh lacer; for custom fabricated orthosis only','Replace molded thigh lacer','L4040','3','','1','0','','','','0','1','0','0'),
('15007','Replace non-molded thigh lacer; for custom fabricated orthosis only','Replace non-molded thigh lac','L4045','3','','1','0','','','','0','1','0','0'),
('15008','Replace molded calf lacer; for custom fabricated orthosis only','Replace molded calf lacer','L4050','3','','1','0','','','','0','1','0','0'),
('15009','Replace non-molded calf lacer; for custom fabricated orthosis only','Replace non-molded calf lace','L4055','3','','1','0','','','','0','1','0','0'),
('15010','Replace high roll cuff','Replace high roll cuff','L4060','3','','1','0','','','','0','1','0','0'),
('15011','Replace proximal and distal upright for kafo','Replace prox & dist upright','L4070','3','','1','0','','','','0','1','0','0'),
('15012','Replace metal bands kafo; proximal thigh','Repl met band kafo-afo prox','L4080','3','','1','0','','','','0','1','0','0'),
('15013','Replace metal bands kafo-afo; calf or distal thigh','Repl met band kafo-afo calf/','L4090','3','','1','0','','','','0','1','0','0'),
('15014','Replace leather cuff kafo; proximal thigh','Repl leath cuff kafo prox th','L4100','3','','1','0','','','','0','1','0','0'),
('15015','Replace leather cuff kafo-afo; calf or distal thigh','Repl leath cuff kafo-afo cal','L4110','3','','1','0','','','','0','1','0','0'),
('15016','Replace pretibial shell','Replace pretibial shell','L4130','3','','1','0','','','','0','1','0','0'),
('15017','Repair of orthotic device; labor component; per 15 minutes','Ortho dvc repair per 15 min','L4205','3','','1','0','','','','0','1','0','0'),
('15018','Repair of orthotic device; repair or replace minor parts','Orth dev repair/repl minor p','L4210','3','','1','0','','','','0','1','0','0'),
('15019','Ankle control orthosis; stirrup style; rigid; includes any type interface (e.g.; pneumatic; gel); prefabricated; off-the-shelf','Ankle control ortho pre ots','L4350','3','','1','0','','','','0','1','0','0'),
('15020','Walking boot; pneumatic and/or vacuum; with or without joints; with or without interface material; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Pneumat walking boot pre cst','L4360','3','','1','0','','','','0','1','0','0'),
('15021','Walking boot; pneumatic and/or vacuum; with or without joints; with or without interface material; prefabricated; off-the-shelf','Pneuma/vac walk boot pre ots','L4361','3','','1','0','','','','0','1','0','0'),
('15022','Pneumatic full leg splint; prefabricated; off-the-shelf','Pneum full leg splnt pre ots','L4370','3','','1','0','','','','0','1','0','0'),
('15023','Walking boot; non-pneumatic; with or without joints; with or without interface material; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Non-pneum walk boot pre cst','L4386','3','','1','0','','','','0','1','0','0'),
('15024','Walking boot; non-pneumatic; with or without joints; with or without interface material; prefabricated; off-the-shelf','Non-pneum walk boot pre ots','L4387','3','','1','0','','','','0','1','0','0'),
('15025','Replacement; soft interface material; static afo','Replace afo soft interface','L4392','3','','1','0','','','','0','1','0','0'),
('15026','Replace soft interface material; foot drop splint','Replace foot drop spint','L4394','3','','1','0','','','','0','1','0','0'),
('15027','Static or dynamic ankle foot orthosis; including soft interface material; adjustable for fit; for positioning; may be used for minimal ambulation; prefabricated item that has been trimmed; bent; molded; assembled; or otherwise customized to fit a specific patient by an individual with expertise','Static or dynami afo pre cst','L4396','3','','1','0','','','','0','1','0','0'),
('15028','Static or dynamic ankle foot orthosis; including soft interface material; adjustable for fit; for positioning; may be used for minimal ambulation; prefabricated; off-the-shelf','Static or dynami afo pre ots','L4397','3','','1','0','','','','0','1','0','0'),
('15029','Foot drop splint; recumbent positioning device; prefabricated; off-the-shelf','Foot drop splint pre ots','L4398','3','','1','0','','','','0','1','0','0'),
('15030','Ankle foot orthosis; walking boot type; varus/valgus correction; rocker bottom; anterior tibial shell; soft interface; custom arch support; plastic or other material; includes straps and closures; custom fabricated','Afo; walk boot type; cus fab','L4631','3','','1','0','','','','0','1','0','0'),
('15031','Partial foot; shoe insert with longitudinal arch; toe filler','Sho insert w arch toe filler','L5000','3','','1','0','','','','0','1','0','0'),
('15032','Partial foot; molded socket; ankle height; with toe filler','Mold socket ank hgt w/ toe f','L5010','3','','1','0','','','','0','1','0','0'),
('15033','Partial foot; molded socket; tibial tubercle height; with toe filler','Tibial tubercle hgt w/ toe f','L5020','3','','1','0','','','','0','1','0','0'),
('15034','Ankle; symes; molded socket; sach foot','Ank symes mold sckt sach ft','L5050','3','','1','0','','','','0','1','0','0'),
('15035','Ankle; symes; metal frame; molded leather socket; articulated ankle/foot','Symes met fr leath socket ar','L5060','3','','1','0','','','','0','1','0','0'),
('15036','Below knee; molded socket; shin; sach foot','Molded socket shin sach foot','L5100','3','','1','0','','','','0','1','0','0'),
('15037','Below knee; plastic socket; joints and thigh lacer; sach foot','Plast socket jts/thgh lacer','L5105','3','','1','0','','','','0','1','0','0'),
('15038','Knee disarticulation (or through knee); molded socket; external knee joints; shin; sach foot','Mold sckt ext knee shin sach','L5150','3','','1','0','','','','0','1','0','0'),
('15039','Knee disarticulation (or through knee); molded socket; bent knee configuration; external knee joints; shin; sach foot','Mold socket bent knee shin s','L5160','3','','1','0','','','','0','1','0','0'),
('15040','Above knee; molded socket; single axis constant friction knee; shin; sach foot','Kne sing axis fric shin sach','L5200','3','','1','0','','','','0','1','0','0'),
('15041','Above knee; short prosthesis; no knee joint (stubbies); with foot blocks; no ankle joints; each','No knee/ankle joints w/ ft b','L5210','3','','1','0','','','','0','1','0','0'),
('15042','Above knee; short prosthesis; no knee joint (stubbies); with articulated ankle/foot; dynamically aligned; each','No knee joint with artic ali','L5220','3','','1','0','','','','0','1','0','0'),
('15043','Above knee; for proximal femoral focal deficiency; constant friction knee; shin; sach foot','Fem focal defic constant fri','L5230','3','','1','0','','','','0','1','0','0'),
('15044','Hip disarticulation; canadian type; molded socket; hip joint; single axis constant friction knee; shin; sach foot','Hip canad sing axi cons fric','L5250','3','','1','0','','','','0','1','0','0'),
('15045','Hip disarticulation; tilt table type; molded socket; locking hip joint; single axis constant friction knee; shin; sach foot','Tilt table locking hip sing','L5270','3','','1','0','','','','0','1','0','0'),
('15046','Hemipelvectomy; canadian type; molded socket; hip joint; single axis constant friction knee; shin; sach foot','Hemipelvect canad sing axis','L5280','3','','1','0','','','','0','1','0','0'),
('15047','Below knee; molded socket; shin; sach foot; endoskeletal system','Bk mold socket sach ft endo','L5301','3','','1','0','','','','0','1','0','0'),
('15048','Knee disarticulation (or through knee); molded socket; single axis knee; pylon; sach foot; endoskeletal system','Knee disart; sach ft; endo','L5312','3','','1','0','','','','0','1','0','0'),
('15049','Above knee; molded socket; open end; sach foot; endoskeletal system; single axis knee','Ak open end sach','L5321','3','','1','0','','','','0','1','0','0'),
('15050','Hip disarticulation; canadian type; molded socket; endoskeletal system; hip joint; single axis knee; sach foot','Hip disart canadian sach ft','L5331','3','','1','0','','','','0','1','0','0'),
('15051','Hemipelvectomy; canadian type; molded socket; endoskeletal system; hip joint; single axis knee; sach foot','Hemipelvectomy canadian sach','L5341','3','','1','0','','','','0','1','0','0'),
('15052','Immediate post surgical or early fitting; application of initial rigid dressing; including fitting; alignment; suspension; and one cast change; below knee','Postop dress & 1 cast chg bk','L5400','3','','1','0','','','','0','1','0','0'),
('15053','Immediate post surgical or early fitting; application of initial rigid dressing; including fitting; alignment and suspension; below knee; each additional cast change and realignment','Postop dsg bk ea add cast ch','L5410','3','','1','0','','','','0','1','0','0'),
('15054','Immediate post surgical or early fitting; application of initial rigid dressing; including fitting; alignment and suspension and one cast change ak or knee disarticulation','Postop dsg & 1 cast chg ak/d','L5420','3','','1','0','','','','0','1','0','0'),
('15055','Immediate post surgical or early fitting; application of initial rigid dressing; incl. fitting; alignment and supension; ak or knee disarticulation; each additional cast change and realignment','Postop dsg ak ea add cast ch','L5430','3','','1','0','','','','0','1','0','0'),
('15056','Immediate post surgical or early fitting; application of non-weight bearing rigid dressing; below knee','Postop app non-wgt bear dsg','L5450','3','','1','0','','','','0','1','0','0'),
('15057','Immediate post surgical or early fitting; application of non-weight bearing rigid dressing; above knee','Postop app non-wgt bear dsg','L5460','3','','1','0','','','','0','1','0','0'),
('15058','Initial; below knee ptb type socket; non-alignable system; pylon; no cover; sach foot; plaster socket; direct formed','Init bk ptb plaster direct','L5500','3','','1','0','','','','0','1','0','0'),
('15059','Initial; above knee - knee disarticulation; ischial level socket; non-alignable system; pylon; no cover; sach foot; plaster socket; direct formed','Init ak ischal plstr direct','L5505','3','','1','0','','','','0','1','0','0'),
('15060','Preparatory; below knee ptb type socket; non-alignable system; pylon; no cover; sach foot; plaster socket; molded to model','Prep bk ptb plaster molded','L5510','3','','1','0','','','','0','1','0','0'),
('15061','Preparatory; below knee ptb type socket; non-alignable system; pylon; no cover; sach foot; thermoplastic or equal; direct formed','Perp bk ptb thermopls direct','L5520','3','','1','0','','','','0','1','0','0'),
('15062','Preparatory; below knee ptb type socket; non-alignable system; pylon; no cover; sach foot; thermoplastic or equal; molded to model','Prep bk ptb thermopls molded','L5530','3','','1','0','','','','0','1','0','0'),
('15063','Preparatory; below knee ptb type socket; non-alignable system; no cover; sach foot; prefabricated; adjustable open end socket','Prep bk ptb open end socket','L5535','3','','1','0','','','','0','1','0','0'),
('15064','Preparatory; below knee ptb type socket; non-alignable system; pylon; no cover; sach foot; laminated socket; molded to model','Prep bk ptb laminated socket','L5540','3','','1','0','','','','0','1','0','0'),
('15065','Preparatory; above knee- knee disarticulation; ischial level socket; non-alignable system; pylon; no cover; sach foot; plaster socket; molded to model','Prep ak ischial plast molded','L5560','3','','1','0','','','','0','1','0','0'),
('15066','Preparatory; above knee - knee disarticulation; ischial level socket; non-alignable system; pylon; no cover; sach foot; thermoplastic or equal; direct formed','Prep ak ischial direct form','L5570','3','','1','0','','','','0','1','0','0'),
('15067','Preparatory; above knee - knee disarticulation ischial level socket; non-alignable system; pylon; no cover; sach foot; thermoplastic or equal; molded to model','Prep ak ischial thermo mold','L5580','3','','1','0','','','','0','1','0','0'),
('15068','Preparatory; above knee - knee disarticulation; ischial level socket; non-alignable system; pylon; no cover; sach foot; prefabricated adjustable open end socket','Prep ak ischial open end','L5585','3','','1','0','','','','0','1','0','0'),
('15069','Preparatory; above knee - knee disarticulation ischial level socket; non-alignable system; pylon no cover; sach foot; laminated socket; molded to model','Prep ak ischial laminated','L5590','3','','1','0','','','','0','1','0','0'),
('15070','Preparatory; hip disarticulation-hemipelvectomy; pylon; no cover; sach foot; thermoplastic or equal; molded to patient model','Hip disartic sach thermopls','L5595','3','','1','0','','','','0','1','0','0'),
('15071','Preparatory; hip disarticulation-hemipelvectomy; pylon; no cover; sach foot; laminated socket; molded to patient model','Hip disart sach laminat mold','L5600','3','','1','0','','','','0','1','0','0'),
('15072','Addition to lower extremity; endoskeletal system; above knee; hydracadence system','Above knee hydracadence','L5610','3','','1','0','','','','0','1','0','0'),
('15073','Addition to lower extremity; endoskeletal system; above knee - knee disarticulation; 4 bar linkage; with friction swing phase control','Ak 4 bar link w/fric swing','L5611','3','','1','0','','','','0','1','0','0'),
('15074','Addition to lower extremity; endoskeletal system; above knee-knee disarticulation; 4 bar linkage; with hydraulic swing phase control','Ak 4 bar ling w/hydraul swig','L5613','3','','1','0','','','','0','1','0','0'),
('15075','Addition to lower extremity; exoskeletal system; above knee-knee disarticulation; 4 bar linkage; with pneumatic swing phase control','4-bar link above knee w/swng','L5614','3','','1','0','','','','0','1','0','0'),
('15076','Addition to lower extremity; endoskeletal system; above knee; universal multiplex system; friction swing phase control','Ak univ multiplex sys frict','L5616','3','','1','0','','','','0','1','0','0'),
('15077','Addition to lower extremity; quick change self-aligning unit; above knee or below knee; each','Ak/bk self-aligning unit ea','L5617','3','','1','0','','','','0','1','0','0'),
('15078','Addition to lower extremity; test socket; symes','Test socket symes','L5618','3','','1','0','','','','0','1','0','0'),
('15079','Addition to lower extremity; test socket; below knee','Test socket below knee','L5620','3','','1','0','','','','0','1','0','0'),
('15080','Addition to lower extremity; test socket; knee disarticulation','Test socket knee disarticula','L5622','3','','1','0','','','','0','1','0','0'),
('15081','Addition to lower extremity; test socket; above knee','Test socket above knee','L5624','3','','1','0','','','','0','1','0','0'),
('15082','Addition to lower extremity; test socket; hip disarticulation','Test socket hip disarticulat','L5626','3','','1','0','','','','0','1','0','0'),
('15083','Addition to lower extremity; test socket; hemipelvectomy','Test socket hemipelvectomy','L5628','3','','1','0','','','','0','1','0','0'),
('15084','Addition to lower extremity; below knee; acrylic socket','Below knee acrylic socket','L5629','3','','1','0','','','','0','1','0','0'),
('15085','Addition to lower extremity; symes type; expandable wall socket','Syme typ expandabl wall sckt','L5630','3','','1','0','','','','0','1','0','0'),
('15086','Addition to lower extremity; above knee or knee disarticulation; acrylic socket','Ak/knee disartic acrylic soc','L5631','3','','1','0','','','','0','1','0','0'),
('15087','Addition to lower extremity; symes type; ptb brim design socket','Symes type ptb brim design s','L5632','3','','1','0','','','','0','1','0','0'),
('15088','Addition to lower extremity; symes type; posterior opening (canadian) socket','Symes type poster opening so','L5634','3','','1','0','','','','0','1','0','0'),
('15089','Addition to lower extremity; symes type; medial opening socket','Symes type medial opening so','L5636','3','','1','0','','','','0','1','0','0'),
('15090','Addition to lower extremity; below knee; total contact','Below knee total contact','L5637','3','','1','0','','','','0','1','0','0'),
('15091','Addition to lower extremity; below knee; leather socket','Below knee leather socket','L5638','3','','1','0','','','','0','1','0','0'),
('15092','Addition to lower extremity; below knee; wood socket','Below knee wood socket','L5639','3','','1','0','','','','0','1','0','0'),
('15093','Addition to lower extremity; knee disarticulation; leather socket','Knee disarticulat leather so','L5640','3','','1','0','','','','0','1','0','0'),
('15094','Addition to lower extremity; above knee; leather socket','Above knee leather socket','L5642','3','','1','0','','','','0','1','0','0'),
('15095','Addition to lower extremity; hip disarticulation; flexible inner socket; external frame','Hip flex inner socket ext fr','L5643','3','','1','0','','','','0','1','0','0'),
('15096','Addition to lower extremity; above knee; wood socket','Above knee wood socket','L5644','3','','1','0','','','','0','1','0','0'),
('15097','Addition to lower extremity; below knee; flexible inner socket; external frame','Bk flex inner socket ext fra','L5645','3','','1','0','','','','0','1','0','0'),
('15098','Addition to lower extremity; below knee; air; fluid; gel or equal; cushion socket','Below knee cushion socket','L5646','3','','1','0','','','','0','1','0','0'),
('15099','Addition to lower extremity; below knee suction socket','Below knee suction socket','L5647','3','','1','0','','','','0','1','0','0'),
('15100','Addition to lower extremity; above knee; air; fluid; gel or equal; cushion socket','Above knee cushion socket','L5648','3','','1','0','','','','0','1','0','0'),
('15101','Addition to lower extremity; ischial containment/narrow m-l socket','Isch containmt/narrow m-l so','L5649','3','','1','0','','','','0','1','0','0'),
('15102','Additions to lower extremity; total contact; above knee or knee disarticulation socket','Tot contact ak/knee disart s','L5650','3','','1','0','','','','0','1','0','0'),
('15103','Addition to lower extremity; above knee; flexible inner socket; external frame','Ak flex inner socket ext fra','L5651','3','','1','0','','','','0','1','0','0'),
('15104','Addition to lower extremity; suction suspension; above knee or knee disarticulation socket','Suction susp ak/knee disart','L5652','3','','1','0','','','','0','1','0','0'),
('15105','Addition to lower extremity; knee disarticulation; expandable wall socket','Knee disart expand wall sock','L5653','3','','1','0','','','','0','1','0','0'),
('15106','Addition to lower extremity; socket insert; symes; (kemblo; pelite; aliplast; plastazote or equal)','Socket insert symes','L5654','3','','1','0','','','','0','1','0','0'),
('15107','Addition to lower extremity; socket insert; below knee (kemblo; pelite; aliplast; plastazote or equal)','Socket insert below knee','L5655','3','','1','0','','','','0','1','0','0'),
('15108','Addition to lower extremity; socket insert; knee disarticulation (kemblo; pelite; aliplast; plastazote or equal)','Socket insert knee articulat','L5656','3','','1','0','','','','0','1','0','0'),
('15109','Addition to lower extremity; socket insert; above knee (kemblo; pelite; aliplast; plastazote or equal)','Socket insert above knee','L5658','3','','1','0','','','','0','1','0','0'),
('15110','Addition to lower extremity; socket insert; multi-durometer symes','Multi-durometer symes','L5661','3','','1','0','','','','0','1','0','0'),
('15111','Addition to lower extremity; socket insert; multi-durometer; below knee','Multi-durometer below knee','L5665','3','','1','0','','','','0','1','0','0'),
('15112','Addition to lower extremity; below knee; cuff suspension','Below knee cuff suspension','L5666','3','','1','0','','','','0','1','0','0'),
('15113','Addition  to lower extremity; below knee; molded distal cushion','Bk molded distal cushion','L5668','3','','1','0','','','','0','1','0','0'),
('15114','Addition to lower extremity; below knee; molded supracondylar suspension (pts or similar)','Bk molded supracondylar susp','L5670','3','','1','0','','','','0','1','0','0'),
('15115','Addition to lower extremity; below knee / above knee suspension locking mechanism (shuttle; lanyard or equal); excludes socket insert','Bk/ak locking mechanism','L5671','3','','1','0','','','','0','1','0','0'),
('15116','Addition to lower extremity; below knee; removable medial brim suspension','Bk removable medial brim sus','L5672','3','','1','0','','','','0','1','0','0'),
('15117','Addition to lower extremity; below knee/above knee; custom fabricated from existing mold or prefabricated; socket insert; silicone gel; elastomeric or equal; for use with locking mechanism','Socket insert w lock mech','L5673','3','','1','0','','','','0','1','0','0'),
('15118','Additions to lower extremity; below knee; knee joints; single axis; pair','Bk knee joints single axis p','L5676','3','','1','0','','','','0','1','0','0'),
('15119','Additions to lower extremity; below knee; knee joints; polycentric; pair','Bk knee joints polycentric p','L5677','3','','1','0','','','','0','1','0','0'),
('15120','Additions to lower extremity; below knee; joint covers; pair','Bk joint covers pair','L5678','3','','1','0','','','','0','1','0','0'),
('15121','Addition to lower extremity; below knee/above knee; custom fabricated from existing mold or prefabricated; socket insert; silicone gel; elastomeric or equal; not for use with locking mechanism','Socket insert w/o lock mech','L5679','3','','1','0','','','','0','1','0','0'),
('15122','Addition to lower extremity; below knee; thigh lacer; nonmolded','Bk thigh lacer non-molded','L5680','3','','1','0','','','','0','1','0','0'),
('15123','Addition to lower extremity; below knee/above knee; custom fabricated socket insert for congenital or atypical traumatic amputee; silicone gel; elastomeric or equal; for use with or without locking mechanism; initial only (for other than initial; use code l5673 or l5679)','Intl custm cong/latyp insert','L5681','3','','1','0','','','','0','1','0','0'),
('15124','Addition to lower extremity; below knee; thigh lacer; gluteal/ischial; molded','Bk thigh lacer glut/ischia m','L5682','3','','1','0','','','','0','1','0','0'),
('15125','Addition to lower extremity; below knee/above knee; custom fabricated socket insert for other than congenital or atypical traumatic amputee; silicone gel; elastomeric or equal; for use with or without locking mechanism; initial only (for other than initial; use code l5673 or l5679)','Initial custom socket insert','L5683','3','','1','0','','','','0','1','0','0'),
('15126','Addition to lower extremity; below knee; fork strap','Bk fork strap','L5684','3','','1','0','','','','0','1','0','0'),
('15127','Addition to lower extremity prosthesis; below knee; suspension/sealing sleeve; with or without valve; any material; each','Below knee sus/seal sleeve','L5685','3','','1','0','','','','0','1','0','0'),
('15128','Addition to lower extremity; below knee; back check (extension control)','Bk back check','L5686','3','','1','0','','','','0','1','0','0'),
('15129','Addition to lower extremity; below knee; waist belt; webbing','Bk waist belt webbing','L5688','3','','1','0','','','','0','1','0','0'),
('15130','Addition to lower extremity; below knee; waist belt; padded and lined','Bk waist belt padded and lin','L5690','3','','1','0','','','','0','1','0','0'),
('15131','Addition to lower extremity; above knee; pelvic control belt; light','Ak pelvic control belt light','L5692','3','','1','0','','','','0','1','0','0'),
('15132','Addition to lower extremity; above knee; pelvic control belt; padded and lined','Ak pelvic control belt pad/l','L5694','3','','1','0','','','','0','1','0','0'),
('15133','Addition to lower extremity; above knee; pelvic control; sleeve suspension; neoprene or equal; each','Ak sleeve susp neoprene/equa','L5695','3','','1','0','','','','0','1','0','0'),
('15134','Addition to lower extremity; above knee or knee disarticulation; pelvic joint','Ak/knee disartic pelvic join','L5696','3','','1','0','','','','0','1','0','0'),
('15135','Addition to lower extremity; above knee or knee disarticulation; pelvic band','Ak/knee disartic pelvic band','L5697','3','','1','0','','','','0','1','0','0'),
('15136','Addition to lower extremity; above knee or knee disarticulation; silesian bandage','Ak/knee disartic silesian ba','L5698','3','','1','0','','','','0','1','0','0'),
('15137','All lower extremity prostheses; shoulder harness','Shoulder harness','L5699','3','','1','0','','','','0','1','0','0'),
('15138','Replacement; socket; below knee; molded to patient model','Replace socket below knee','L5700','3','','1','0','','','','0','1','0','0'),
('15139','Replacement; socket; above knee/knee disarticulation; including attachment plate; molded to patient model','Replace socket above knee','L5701','3','','1','0','','','','0','1','0','0'),
('15140','Replacement; socket; hip disarticulation; including hip joint; molded to patient model','Replace socket hip','L5702','3','','1','0','','','','0','1','0','0'),
('15141','Ankle; symes; molded to patient model; socket without solid ankle cushion heel (sach) foot; replacement only','Symes ankle w/o (sach) foot','L5703','3','','1','0','','','','0','1','0','0'),
('15142','Custom shaped protective cover; below knee','Custom shape cover bk','L5704','3','','1','0','','','','0','1','0','0'),
('15143','Custom shaped protective cover; above knee','Custom shape cover ak','L5705','3','','1','0','','','','0','1','0','0'),
('15144','Custom shaped protective cover; knee disarticulation','Custom shape cvr knee disart','L5706','3','','1','0','','','','0','1','0','0'),
('15145','Custom shaped protective cover; hip disarticulation','Custom shape cvr hip disart','L5707','3','','1','0','','','','0','1','0','0'),
('15146','Addition; exoskeletal knee-shin system; single axis; manual lock','Kne-shin exo sng axi mnl loc','L5710','3','','1','0','','','','0','1','0','0'),
('15147','Additions exoskeletal knee-shin system; single axis; manual lock; ultra-light material','Knee-shin exo mnl lock ultra','L5711','3','','1','0','','','','0','1','0','0'),
('15148','Addition; exoskeletal knee-shin system; single axis; friction swing and stance phase control (safety knee)','Knee-shin exo frict swg & st','L5712','3','','1','0','','','','0','1','0','0'),
('15149','Addition; exoskeletal knee-shin system; single axis; variable friction swing phase control','Knee-shin exo variable frict','L5714','3','','1','0','','','','0','1','0','0'),
('15150','Addition; exoskeletal knee-shin system; polycentric; mechanical stance phase lock','Knee-shin exo mech stance ph','L5716','3','','1','0','','','','0','1','0','0'),
('15151','Addition; exoskeletal knee-shin system; polycentric; friction swing and stance phase control','Knee-shin exo frct swg & sta','L5718','3','','1','0','','','','0','1','0','0'),
('15152','Addition; exoskeletal knee-shin system; single axis; pneumatic swing; friction stance phase control','Knee-shin pneum swg frct exo','L5722','3','','1','0','','','','0','1','0','0'),
('15153','Addition; exoskeletal knee-shin system; single axis; fluid swing phase control','Knee-shin exo fluid swing ph','L5724','3','','1','0','','','','0','1','0','0'),
('15154','Addition; exoskeletal knee-shin system; single axis; external joints fluid swing phase control','Knee-shin ext jnts fld swg e','L5726','3','','1','0','','','','0','1','0','0'),
('15155','Addition; exoskeletal knee-shin system; single axis; fluid swing and stance phase control','Knee-shin fluid swg & stance','L5728','3','','1','0','','','','0','1','0','0'),
('15156','Addition; exoskeletal knee-shin system; single axis; pneumatic/hydra pneumatic swing phase control','Knee-shin pneum/hydra pneum','L5780','3','','1','0','','','','0','1','0','0'),
('15157','Addition to lower limb prosthesis; vacuum pump; residual limb volume management and moisture evacuation system','Lower limb pros vacuum pump','L5781','3','','1','0','','','','0','1','0','0'),
('15158','Addition to lower limb prosthesis; vacuum pump; residual limb volume management and moisture evacuation system; heavy duty','Hd low limb pros vacuum pump','L5782','3','','1','0','','','','0','1','0','0'),
('15159','Addition; exoskeletal system; below knee; ultra-light material (titanium; carbon fiber or equal)','Exoskeletal bk ultralt mater','L5785','3','','1','0','','','','0','1','0','0'),
('15160','Addition; exoskeletal system; above knee; ultra-light material (titanium; carbon fiber or equal)','Exoskeletal ak ultra-light m','L5790','3','','1','0','','','','0','1','0','0'),
('15161','Addition; exoskeletal system; hip disarticulation; ultra-light material (titanium; carbon fiber or equal)','Exoskel hip ultra-light mate','L5795','3','','1','0','','','','0','1','0','0'),
('15162','Addition; endoskeletal knee-shin system; single axis; manual lock','Endoskel knee-shin mnl lock','L5810','3','','1','0','','','','0','1','0','0'),
('15163','Addition; endoskeletal knee-shin system; single axis; manual lock; ultra-light material','Endo knee-shin mnl lck ultra','L5811','3','','1','0','','','','0','1','0','0'),
('15164','Addition; endoskeletal knee-shin system; single axis; friction swing and stance phase control (safety knee)','Endo knee-shin frct swg & st','L5812','3','','1','0','','','','0','1','0','0'),
('15165','Addition; endoskeletal knee-shin system; polycentric; hydraulic swing phase control; mechanical stance phase lock','Endo knee-shin hydral swg ph','L5814','3','','1','0','','','','0','1','0','0'),
('15166','Addition; endoskeletal knee-shin system; polycentric; mechanical stance phase lock','Endo knee-shin polyc mch sta','L5816','3','','1','0','','','','0','1','0','0'),
('15167','Addition; endoskeletal knee-shin system; polycentric; friction swing; and stance phase control','Endo knee-shin frct swg & st','L5818','3','','1','0','','','','0','1','0','0'),
('15168','Addition; endoskeletal knee-shin system; single axis; pneumatic swing; friction stance phase control','Endo knee-shin pneum swg frc','L5822','3','','1','0','','','','0','1','0','0'),
('15169','Addition; endoskeletal knee-shin system; single axis; fluid swing phase control','Endo knee-shin fluid swing p','L5824','3','','1','0','','','','0','1','0','0'),
('15170','Addition; endoskeletal knee-shin system; single axis; hydraulic swing phase control; with miniature high activity frame','Miniature knee joint','L5826','3','','1','0','','','','0','1','0','0'),
('15171','Addition; endoskeletal knee-shin system; single axis; fluid swing and stance phase control','Endo knee-shin fluid swg/sta','L5828','3','','1','0','','','','0','1','0','0'),
('15172','Addition; endoskeletal knee-shin system; single axis; pneumatic/ swing phase control','Endo knee-shin pneum/swg pha','L5830','3','','1','0','','','','0','1','0','0'),
('15173','Addition; endoskeletal knee/shin system; 4-bar linkage or multiaxial; pneumatic swing phase control','Multi-axial knee/shin system','L5840','3','','1','0','','','','0','1','0','0'),
('15174','Addition; endoskeletal; knee-shin system; stance flexion feature; adjustable','Knee-shin sys stance flexion','L5845','3','','1','0','','','','0','1','0','0'),
('15175','Addition to endoskeletal knee-shin system; fluid stance extension; dampening feature; with or without adjustability','Knee-shin sys hydraul stance','L5848','3','','1','0','','','','0','1','0','0'),
('15176','Addition; endoskeletal system; above knee or hip disarticulation; knee extension assist','Endo ak/hip knee extens assi','L5850','3','','1','0','','','','0','1','0','0'),
('15177','Addition; endoskeletal system; hip disarticulation; mechanical hip extension assist','Mech hip extension assist','L5855','3','','1','0','','','','0','1','0','0'),
('15178','Addition to lower extremity prosthesis; endoskeletal knee-shin system; microprocessor control feature; swing and stance phase; includes electronic sensor(s); any type','Elec knee-shin swing/stance','L5856','3','','1','0','','','','0','1','0','0'),
('15179','Addition to lower extremity prosthesis; endoskeletal knee-shin system; microprocessor control feature; swing phase only; includes electronic sensor(s); any type','Elec knee-shin swing only','L5857','3','','1','0','','','','0','1','0','0'),
('15180','Addition to lower extremity prosthesis; endoskeletal knee shin system; microprocessor control feature; stance phase only; includes electronic sensor(s); any type','Stance phase only','L5858','3','','1','0','','','','0','1','0','0'),
('15181','Addition to lower extremity prosthesis; endoskeletal knee-shin system; powered and programmable flexion/extension assist control; includes any type motor(s)','Knee-shin pro flex/ext cont','L5859','3','','1','0','','','','0','1','0','0'),
('15182','Addition; endoskeletal system; below knee; alignable system','Endo below knee alignable sy','L5910','3','','1','0','','','','0','1','0','0'),
('15183','Addition; endoskeletal system; above knee or hip disarticulation; alignable system','Endo ak/hip alignable system','L5920','3','','1','0','','','','0','1','0','0'),
('15184','Addition; endoskeletal system; above knee; knee disarticulation or hip disarticulation; manual lock','Above knee manual lock','L5925','3','','1','0','','','','0','1','0','0'),
('15185','Addition; endoskeletal system; high activity knee control frame','High activity knee frame','L5930','3','','1','0','','','','0','1','0','0'),
('15186','Addition; endoskeletal system; below knee; ultra-light material (titanium; carbon fiber or equal)','Endo bk ultra-light material','L5940','3','','1','0','','','','0','1','0','0'),
('15187','Addition; endoskeletal system; above knee; ultra-light material (titanium; carbon fiber or equal)','Endo ak ultra-light material','L5950','3','','1','0','','','','0','1','0','0'),
('15188','Addition; endoskeletal system; hip disarticulation; ultra-light material (titanium; carbon fiber or equal)','Endo hip ultra-light materia','L5960','3','','1','0','','','','0','1','0','0'),
('15189','Addition; endoskeletal system; polycentric hip joint; pneumatic or hydraulic control; rotation control; with or without flexion and/or extension control','Endo poly hip; pneu/hyd/rot','L5961','3','','1','0','','','','0','1','0','0'),
('15190','Addition; endoskeletal system; below knee; flexible protective outer surface covering system','Below knee flex cover system','L5962','3','','1','0','','','','0','1','0','0'),
('15191','Addition; endoskeletal system; above knee; flexible protective outer surface covering system','Above knee flex cover system','L5964','3','','1','0','','','','0','1','0','0'),
('15192','Addition; endoskeletal system; hip disarticulation; flexible protective outer surface covering system','Hip flexible cover system','L5966','3','','1','0','','','','0','1','0','0'),
('15193','Addition to lower limb prosthesis; multiaxial ankle with swing phase active dorsiflexion feature','Multiaxial ankle w dorsiflex','L5968','3','','1','0','','','','0','1','0','0'),
('15194','Addition; endoskeletal ankle-foot or ankle system; power assist; includes any type motor(s)','Ak/ft power asst incl motors','L5969','3','','1','0','','','','0','1','0','0'),
('15195','All lower extremity prostheses; foot; external keel; sach foot','Foot external keel sach foot','L5970','3','','1','0','','','','0','1','0','0'),
('15196','All lower extremity prosthesis; solid ankle cushion heel (sach) foot; replacement only','Sach foot; replacement','L5971','3','','1','0','','','','0','1','0','0'),
('15197','All lower extremity prostheses; foot; flexible keel','Flexible keel foot','L5972','3','','1','0','','','','0','1','0','0'),
('15198','Endoskeletal ankle foot system; microprocessor controlled feature; dorsiflexion and/or plantar flexion control; includes power source','Ank-foot sys dors-plant flex','L5973','3','','1','0','','','','0','1','0','0'),
('15199','All lower extremity prostheses; foot; single axis ankle/foot','Foot single axis ankle/foot','L5974','3','','1','0','','','','0','1','0','0'),
('15200','All lower extremity prosthesis; combination single axis ankle and flexible keel foot','Combo ankle/foot prosthesis','L5975','3','','1','0','','','','0','1','0','0'),
('15201','All lower extremity prostheses; energy storing foot (seattle carbon copy ii or equal)','Energy storing foot','L5976','3','','1','0','','','','0','1','0','0'),
('15202','All lower extremity prostheses; foot; multiaxial ankle/foot','Ft prosth multiaxial ankl/ft','L5978','3','','1','0','','','','0','1','0','0'),
('15203','All lower extremity prosthesis; multi-axial ankle; dynamic response foot; one piece system','Multi-axial ankle/ft prosth','L5979','3','','1','0','','','','0','1','0','0'),
('15204','All lower extremity prostheses; flex foot system','Flex foot system','L5980','3','','1','0','','','','0','1','0','0'),
('15205','All lower extremity prostheses; flex-walk system or equal','Flex-walk sys low ext prosth','L5981','3','','1','0','','','','0','1','0','0'),
('15206','All exoskeletal lower extremity prostheses; axial rotation unit','Exoskeletal axial rotation u','L5982','3','','1','0','','','','0','1','0','0'),
('15207','All endoskeletal lower extremity prosthesis; axial rotation unit; with or without adjustability','Endoskeletal axial rotation','L5984','3','','1','0','','','','0','1','0','0'),
('15208','All endoskeletal lower extremity prostheses; dynamic prosthetic pylon','Lwr ext dynamic prosth pylon','L5985','3','','1','0','','','','0','1','0','0'),
('15209','All lower extremity prostheses; multi-axial rotation unit (mcp or equal)','Multi-axial rotation unit','L5986','3','','1','0','','','','0','1','0','0'),
('15210','All lower extremity prosthesis; shank foot system with vertical loading pylon','Shank ft w vert load pylon','L5987','3','','1','0','','','','0','1','0','0'),
('15211','Addition to lower limb prosthesis; vertical shock reducing pylon feature','Vertical shock reducing pylo','L5988','3','','1','0','','','','0','1','0','0'),
('15212','Addition to lower extremity prosthesis; user adjustable heel height','User adjustable heel height','L5990','3','','1','0','','','','0','1','0','0'),
('15213','Lower extremity prosthesis; not otherwise specified','Lowr extremity prosthes nos','L5999','3','','1','0','','','','0','1','0','0'),
('15214','Partial hand; thumb remaining','Part hand thumb rem','L6000','3','','1','0','','','','0','1','0','0'),
('15215','Partial hand; little and/or ring finger remaining','Part hand little/ring','L6010','3','','1','0','','','','0','1','0','0'),
('15216','Partial hand; no finger remaining','Part hand no fingers','L6020','3','','1','0','','','','0','1','0','0'),
('15217','Transcarpal/metacarpal or partial hand disarticulation prosthesis; external power; self-suspended; inner socket with removable forearm section; electrodes and cables; two batteries; charger; myoelectric control of terminal device','Part hand disart myoelectric','L6025','3','','1','0','','','','0','1','0','0'),
('15218','Transcarpal/metacarpal or partial hand disarticulation prosthesis; external power; self-suspended; inner socket with removable forearm section; electrodes and cables; two batteries; charger; myoelectric control of terminal device; excludes terminal device(s)','Part hand myo exclu term dev','L6026','3','','1','0','','','','0','1','0','0'),
('15219','Wrist disarticulation; molded socket; flexible elbow hinges; triceps pad','Wrst mld sck flx hng tri pad','L6050','3','','1','0','','','','0','1','0','0'),
('15220','Wrist disarticulation; molded socket with expandable interface; flexible elbow hinges; triceps pad','Wrst mold sock w/exp interfa','L6055','3','','1','0','','','','0','1','0','0'),
('15221','Below elbow; molded socket; flexible elbow hinge; triceps pad','Elb mold sock flex hinge pad','L6100','3','','1','0','','','','0','1','0','0'),
('15222','Below elbow; molded socket; (muenster or northwestern suspension types)','Elbow mold sock suspension t','L6110','3','','1','0','','','','0','1','0','0'),
('15223','Below elbow; molded double wall split socket; step-up hinges; half cuff','Elbow mold doub splt soc ste','L6120','3','','1','0','','','','0','1','0','0'),
('15224','Below elbow; molded double wall split socket; stump activated locking hinge; half cuff','Elbow stump activated lock h','L6130','3','','1','0','','','','0','1','0','0'),
('15225','Elbow disarticulation; molded socket; outside locking hinge; forearm','Elbow mold outsid lock hinge','L6200','3','','1','0','','','','0','1','0','0'),
('15226','Elbow disarticulation; molded socket with expandable interface; outside locking hinges; forearm','Elbow molded w/ expand inter','L6205','3','','1','0','','','','0','1','0','0'),
('15227','Above elbow; molded double wall socket; internal locking elbow; forearm','Elbow inter loc elbow forarm','L6250','3','','1','0','','','','0','1','0','0'),
('15228','Shoulder disarticulation; molded socket; shoulder bulkhead; humeral section; internal locking elbow; forearm','Shlder disart int lock elbow','L6300','3','','1','0','','','','0','1','0','0'),
('15229','Shoulder disarticulation; passive restoration (complete prosthesis)','Shoulder passive restor comp','L6310','3','','1','0','','','','0','1','0','0'),
('15230','Shoulder disarticulation; passive restoration (shoulder cap only)','Shoulder passive restor cap','L6320','3','','1','0','','','','0','1','0','0'),
('15231','Interscapular thoracic; molded socket; shoulder bulkhead; humeral section; internal locking elbow; forearm','Thoracic intern lock elbow','L6350','3','','1','0','','','','0','1','0','0'),
('15232','Interscapular thoracic; passive restoration (complete prosthesis)','Thoracic passive restor comp','L6360','3','','1','0','','','','0','1','0','0'),
('15233','Interscapular thoracic; passive restoration (shoulder cap only)','Thoracic passive restor cap','L6370','3','','1','0','','','','0','1','0','0'),
('15234','Immediate post surgical or early fitting; application of initial rigid dressing; including fitting alignment and suspension of components; and one cast change; wrist disarticulation or below elbow','Postop dsg cast chg wrst/elb','L6380','3','','1','0','','','','0','1','0','0'),
('15235','Immediate post surgical or early fitting; application of initial rigid dressing including fitting alignment and suspension of components; and one cast change; elbow disarticulation or above elbow','Postop dsg cast chg elb dis/','L6382','3','','1','0','','','','0','1','0','0'),
('15236','Immediate post surgical or early fitting; application of initial rigid dressing including fitting alignment and suspension of components; and one cast change; shoulder disarticulation or interscapular thoracic','Postop dsg cast chg shlder/t','L6384','3','','1','0','','','','0','1','0','0'),
('15237','Immediate post surgical or early fitting; each additional cast change and realignment','Postop ea cast chg & realign','L6386','3','','1','0','','','','0','1','0','0'),
('15238','Immediate post surgical or early fitting; application of rigid dressing only','Postop applicat rigid dsg on','L6388','3','','1','0','','','','0','1','0','0'),
('15239','Below elbow; molded socket; endoskeletal system; including soft prosthetic tissue shaping','Below elbow prosth tiss shap','L6400','3','','1','0','','','','0','1','0','0'),
('15240','Elbow disarticulation; molded socket; endoskeletal system; including soft prosthetic tissue shaping','Elb disart prosth tiss shap','L6450','3','','1','0','','','','0','1','0','0'),
('15241','Above elbow; molded socket; endoskeletal system; including soft prosthetic tissue shaping','Above elbow prosth tiss shap','L6500','3','','1','0','','','','0','1','0','0'),
('15242','Shoulder disarticulation; molded socket; endoskeletal system; including soft prosthetic tissue shaping','Shldr disar prosth tiss shap','L6550','3','','1','0','','','','0','1','0','0'),
('15243','Interscapular thoracic; molded socket; endoskeletal system; including soft prosthetic tissue shaping','Scap thorac prosth tiss shap','L6570','3','','1','0','','','','0','1','0','0'),
('15244','Preparatory; wrist disarticulation or below elbow; single wall plastic socket; friction wrist; flexible elbow hinges; figure of eight harness; humeral cuff; bowden cable control; usmc or equal pylon; no cover; molded to patient model','Wrist/elbow bowden cable mol','L6580','3','','1','0','','','','0','1','0','0'),
('15245','Preparatory; wrist disarticulation or below elbow; single wall socket; friction wrist; flexible elbow hinges; figure of eight harness; humeral cuff; bowden cable control; usmc or equal pylon; no cover; direct formed','Wrist/elbow bowden cbl dir f','L6582','3','','1','0','','','','0','1','0','0'),
('15246','Preparatory; elbow disarticulation or above elbow; single wall plastic socket; friction wrist; locking elbow; figure of eight harness; fair lead cable control; usmc or equal pylon; no cover; molded to patient model','Elbow fair lead cable molded','L6584','3','','1','0','','','','0','1','0','0'),
('15247','Preparatory; elbow disarticulation or above elbow; single wall socket; friction wrist; locking elbow; figure of eight harness; fair lead cable control; usmc or equal pylon; no cover; direct formed','Elbow fair lead cable dir fo','L6586','3','','1','0','','','','0','1','0','0'),
('15248','Preparatory; shoulder disarticulation or interscapular thoracic; single wall plastic socket; shoulder joint; locking elbow; friction wrist; chest strap; fair lead cable control; usmc or equal pylon; no cover; molded to patient model','Shdr fair lead cable molded','L6588','3','','1','0','','','','0','1','0','0'),
('15249','Preparatory; shoulder disarticulation or interscapular thoracic; single wall socket; shoulder joint; locking elbow; friction wrist; chest strap; fair lead cable control; usmc or equal pylon; no cover; direct formed','Shdr fair lead cable direct','L6590','3','','1','0','','','','0','1','0','0'),
('15250','Upper extremity additions; polycentric hinge; pair','Polycentric hinge pair','L6600','3','','1','0','','','','0','1','0','0'),
('15251','Upper extremity additions; single pivot hinge; pair','Single pivot hinge pair','L6605','3','','1','0','','','','0','1','0','0'),
('15252','Upper extremity additions; flexible metal hinge; pair','Flexible metal hinge pair','L6610','3','','1','0','','','','0','1','0','0'),
('15253','Addition to upper extremity prosthesis; external powered; additional switch; any type','Additional switch; ext power','L6611','3','','1','0','','','','0','1','0','0'),
('15254','Upper extremity addition; disconnect locking wrist unit','Disconnect locking wrist uni','L6615','3','','1','0','','','','0','1','0','0'),
('15255','Upper extremity addition; additional disconnect insert for locking wrist unit; each','Disconnect insert locking wr','L6616','3','','1','0','','','','0','1','0','0'),
('15256','Upper extremity addition; flexion/extension wrist unit; with or without friction','Flexion/extension wrist unit','L6620','3','','1','0','','','','0','1','0','0'),
('15257','Upper extremity prosthesis addition; flexion/extension wrist with or without friction; for use with external powered terminal device','Flex/ext wrist w/wo friction','L6621','3','','1','0','','','','0','1','0','0'),
('15258','Upper extremity addition; spring assisted rotational wrist unit with latch release','Spring-ass rot wrst w/ latch','L6623','3','','1','0','','','','0','1','0','0'),
('15259','Upper extremity addition; flexion/extension and rotation wrist unit','Flex/ext/rotation wrist unit','L6624','3','','1','0','','','','0','1','0','0'),
('15260','Upper extremity addition; rotation wrist unit with cable lock','Rotation wrst w/ cable lock','L6625','3','','1','0','','','','0','1','0','0'),
('15261','Upper extremity addition; quick disconnect hook adapter; otto bock or equal','Quick disconn hook adapter o','L6628','3','','1','0','','','','0','1','0','0'),
('15262','Upper extremity addition; quick disconnect lamination collar with coupling piece; otto bock or equal','Lamination collar w/ couplin','L6629','3','','1','0','','','','0','1','0','0'),
('15263','Upper extremity addition; stainless steel; any wrist','Stainless steel any wrist','L6630','3','','1','0','','','','0','1','0','0'),
('15264','Upper extremity addition; latex suspension sleeve; each','Latex suspension sleeve each','L6632','3','','1','0','','','','0','1','0','0'),
('15265','Upper extremity addition; lift assist for elbow','Lift assist for elbow','L6635','3','','1','0','','','','0','1','0','0'),
('15266','Upper extremity addition; nudge control elbow lock','Nudge control elbow lock','L6637','3','','1','0','','','','0','1','0','0'),
('15267','Upper extremity addition to prosthesis; electric locking feature; only for use with manually powered elbow','Elec lock on manual pw elbow','L6638','3','','1','0','','','','0','1','0','0'),
('15268','Upper extremity additions; shoulder abduction joint; pair','Shoulder abduction joint pai','L6640','3','','1','0','','','','0','1','0','0'),
('15269','Upper extremity addition; excursion amplifier; pulley type','Excursion amplifier pulley t','L6641','3','','1','0','','','','0','1','0','0'),
('15270','Upper extremity addition; excursion amplifier; lever type','Excursion amplifier lever ty','L6642','3','','1','0','','','','0','1','0','0'),
('15271','Upper extremity addition; shoulder flexion-abduction joint; each','Shoulder flexion-abduction j','L6645','3','','1','0','','','','0','1','0','0'),
('15272','Upper extremity addition; shoulder joint; multipositional locking; flexion; adjustable abduction friction control; for use with body powered or external powered system','Multipo locking shoulder jnt','L6646','3','','1','0','','','','0','1','0','0'),
('15273','Upper extremity addition; shoulder lock mechanism; body powered actuator','Shoulder lock actuator','L6647','3','','1','0','','','','0','1','0','0'),
('15274','Upper extremity addition; shoulder lock mechanism; external powered actuator','Ext pwrd shlder lock/unlock','L6648','3','','1','0','','','','0','1','0','0'),
('15275','Upper extremity addition; shoulder universal joint; each','Shoulder universal joint','L6650','3','','1','0','','','','0','1','0','0'),
('15276','Upper extremity addition; standard control cable; extra','Standard control cable extra','L6655','3','','1','0','','','','0','1','0','0'),
('15277','Upper extremity addition; heavy duty control cable','Heavy duty control cable','L6660','3','','1','0','','','','0','1','0','0'),
('15278','Upper extremity addition; teflon; or equal; cable lining','Teflon or equal cable lining','L6665','3','','1','0','','','','0','1','0','0'),
('15279','Upper extremity addition; hook to hand; cable adapter','Hook to hand cable adapter','L6670','3','','1','0','','','','0','1','0','0'),
('15280','Upper extremity addition; harness; chest or shoulder; saddle type','Harness chest/shlder saddle','L6672','3','','1','0','','','','0','1','0','0'),
('15281','Upper extremity addition; harness; (e.g.; figure of eight type); single cable design','Harness figure of 8 sing con','L6675','3','','1','0','','','','0','1','0','0'),
('15282','Upper extremity addition; harness; (e.g.; figure of eight type); dual cable design','Harness figure of 8 dual con','L6676','3','','1','0','','','','0','1','0','0'),
('15283','Upper extremity addition; harness; triple control; simultaneous operation of terminal device and elbow','Ue triple control harness','L6677','3','','1','0','','','','0','1','0','0'),
('15284','Upper extremity addition; test socket; wrist disarticulation or below elbow','Test sock wrist disart/bel e','L6680','3','','1','0','','','','0','1','0','0'),
('15285','Upper extremity addition; test socket; elbow disarticulation or above elbow','Test sock elbw disart/above','L6682','3','','1','0','','','','0','1','0','0'),
('15286','Upper extremity addition; test socket; shoulder disarticulation or interscapular thoracic','Test socket shldr disart/tho','L6684','3','','1','0','','','','0','1','0','0'),
('15287','Upper extremity addition; suction socket','Suction socket','L6686','3','','1','0','','','','0','1','0','0'),
('15288','Upper extremity addition; frame type socket; below elbow or wrist disarticulation','Frame typ socket bel elbow/w','L6687','3','','1','0','','','','0','1','0','0'),
('15289','Upper extremity addition; frame type socket; above elbow or elbow disarticulation','Frame typ sock above elb/dis','L6688','3','','1','0','','','','0','1','0','0'),
('15290','Upper extremity addition; frame type socket; shoulder disarticulation','Frame typ socket shoulder di','L6689','3','','1','0','','','','0','1','0','0'),
('15291','Upper extremity addition; frame type socket; interscapular-thoracic','Frame typ sock interscap-tho','L6690','3','','1','0','','','','0','1','0','0'),
('15292','Upper extremity addition; removable insert; each','Removable insert each','L6691','3','','1','0','','','','0','1','0','0'),
('15293','Upper extremity addition; silicone gel insert or equal; each','Silicone gel insert or equal','L6692','3','','1','0','','','','0','1','0','0'),
('15294','Upper extremity addition; locking elbow; forearm counterbalance','Lockingelbow forearm cntrbal','L6693','3','','1','0','','','','0','1','0','0'),
('15295','Addition to upper extremity prosthesis; below elbow/above elbow; custom fabricated from existing mold or prefabricated; socket insert; silicone gel; elastomeric or equal; for use with locking mechanism','Elbow socket ins use w/lock','L6694','3','','1','0','','','','0','1','0','0'),
('15296','Addition to upper extremity prosthesis; below elbow/above elbow; custom fabricated from existing mold or prefabricated; socket insert; silicone gel; elastomeric or equal; not for use with locking mechanism','Elbow socket ins use w/o lck','L6695','3','','1','0','','','','0','1','0','0'),
('15297','Addition to upper extremity prosthesis; below elbow/above elbow; custom fabricated socket insert for congenital or atypical traumatic amputee; silicone gel; elastomeric or equal; for use with or without locking mechanism; initial only (for other than initial; use code l6694 or l6695)','Cus elbo skt in for con/atyp','L6696','3','','1','0','','','','0','1','0','0'),
('15298','Addition to upper extremity prosthesis; below elbow/above elbow; custom fabricated socket insert for other than congenital or atypical traumatic amputee; silicone gel; elastomeric or equal; for use with or without locking mechanism; initial only (for other than initial; use code l6694 or l6695)','Cus elbo skt in not con/atyp','L6697','3','','1','0','','','','0','1','0','0'),
('15299','Addition to upper extremity prosthesis; below elbow/above elbow; lock mechanism; excludes socket insert','Below/above elbow lock mech','L6698','3','','1','0','','','','0','1','0','0'),
('15300','Terminal device; passive hand/mitt; any material; any size','Term dev; passive hand mitt','L6703','3','','1','0','','','','0','1','0','0'),
('15301','Terminal device; sport/recreational/work attachment; any material; any size','Term dev; sport/rec/work att','L6704','3','','1','0','','','','0','1','0','0'),
('15302','Terminal device; hook; mechanical; voluntary opening; any material; any size; lined or unlined','Term dev mech hook vol open','L6706','3','','1','0','','','','0','1','0','0'),
('15303','Terminal device; hook; mechanical; voluntary closing; any material; any size; lined or unlined','Term dev mech hook vol close','L6707','3','','1','0','','','','0','1','0','0'),
('15304','Terminal device; hand; mechanical; voluntary opening; any material; any size','Term dev mech hand vol open','L6708','3','','1','0','','','','0','1','0','0'),
('15305','Terminal device; hand; mechanical; voluntary closing; any material; any size','Term dev mech hand vol close','L6709','3','','1','0','','','','0','1','0','0'),
('15306','Terminal device; hook; mechanical; voluntary opening; any material; any size; lined or unlined; pediatric','Ped term dev; hook; vol open','L6711','3','','1','0','','','','0','1','0','0'),
('15307','Terminal device; hook; mechanical; voluntary closing; any material; any size; lined or unlined; pediatric','Ped term dev; hook; vol clos','L6712','3','','1','0','','','','0','1','0','0'),
('15308','Terminal device; hand; mechanical; voluntary opening; any material; any size; pediatric','Ped term dev; hand; vol open','L6713','3','','1','0','','','','0','1','0','0'),
('15309','Terminal device; hand; mechanical; voluntary closing; any material; any size; pediatric','Ped term dev; hand; vol clos','L6714','3','','1','0','','','','0','1','0','0'),
('15310','Terminal device; multiple articulating digit; includes motor(s); initial issue or replacement','Term device; multi art digit','L6715','3','','1','0','','','','0','1','0','0'),
('15311','Terminal device; hook or hand; heavy duty; mechanical; voluntary opening; any material; any size; lined or unlined','Hook/hand; hvy dty; vol open','L6721','3','','1','0','','','','0','1','0','0'),
('15312','Terminal device; hook or hand; heavy duty; mechanical; voluntary closing; any material; any size; lined or unlined','Hook/hand; hvy dty; vol clos','L6722','3','','1','0','','','','0','1','0','0'),
('15313','Addition to terminal device; modifier wrist unit','Term dev modifier wrist unit','L6805','3','','1','0','','','','0','1','0','0'),
('15314','Addition to terminal device; precision pinch device','Term dev precision pinch dev','L6810','3','','1','0','','','','0','1','0','0'),
('15315','Electric hand; switch or myoelectric controlled; independently articulating digits; any grasp pattern or combination of grasp patterns; includes motor(s)','Elec hand ind art digits','L6880','3','','1','0','','','','0','1','0','0'),
('15316','Automatic grasp feature; addition to upper limb electric prosthetic terminal device','Term dev auto grasp feature','L6881','3','','1','0','','','','0','1','0','0'),
('15317','Microprocessor control feature; addition to upper limb prosthetic terminal device','Microprocessor control uplmb','L6882','3','','1','0','','','','0','1','0','0'),
('15318','Replacement socket; below elbow/wrist disarticulation; molded to patient model; for use with or without external power','Replc sockt below e/w disa','L6883','3','','1','0','','','','0','1','0','0'),
('15319','Replacement socket; above elbow/elbow disarticulation; molded to patient model; for use with or without external power','Replc sockt above elbow disa','L6884','3','','1','0','','','','0','1','0','0'),
('15320','Replacement socket; shoulder disarticulation/interscapular thoracic; molded to patient model; for use with or without external power','Replc sockt shldr dis/interc','L6885','3','','1','0','','','','0','1','0','0'),
('15321','Addition to upper extremity prosthesis; glove for terminal device; any material; prefabricated; includes fitting and adjustment','Prefab glove for term device','L6890','3','','1','0','','','','0','1','0','0'),
('15322','Addition to upper extremity prosthesis; glove for terminal device; any material; custom fabricated','Custom glove for term device','L6895','3','','1','0','','','','0','1','0','0'),
('15323','Hand restoration (casts; shading and measurements included); partial hand; with glove; thumb or one finger remaining','Hand restorat thumb/1 finger','L6900','3','','1','0','','','','0','1','0','0'),
('15324','Hand restoration (casts; shading and measurements included); partial hand; with glove; multiple fingers remaining','Hand restoration multiple fi','L6905','3','','1','0','','','','0','1','0','0'),
('15325','Hand restoration (casts; shading and measurements included); partial hand; with glove; no fingers remaining','Hand restoration no fingers','L6910','3','','1','0','','','','0','1','0','0'),
('15326','Hand restoration (shading; and measurements included); replacement glove for above','Hand restoration replacmnt g','L6915','3','','1','0','','','','0','1','0','0'),
('15327','Wrist disarticulation; external power; self-suspended inner socket; removable forearm shell; otto bock or equal; switch; cables; two batteries and one charger; switch control of terminal device','Wrist disarticul switch ctrl','L6920','3','','1','0','','','','0','1','0','0'),
('15328','Wrist disarticulation; external power; self-suspended inner socket; removable forearm shell; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Wrist disart myoelectronic c','L6925','3','','1','0','','','','0','1','0','0'),
('15329','Below elbow; external power; self-suspended inner socket; removable forearm shell; otto bock or equal switch; cables; two batteries and one charger; switch control of terminal device','Below elbow switch control','L6930','3','','1','0','','','','0','1','0','0'),
('15330','Below elbow; external power; self-suspended inner socket; removable forearm shell; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Below elbow myoelectronic ct','L6935','3','','1','0','','','','0','1','0','0'),
('15331','Elbow disarticulation; external power; molded inner socket; removable humeral shell; outside locking hinges; forearm; otto bock or equal switch; cables; two batteries and one charger; switch control of terminal device','Elbow disarticulation switch','L6940','3','','1','0','','','','0','1','0','0'),
('15332','Elbow disarticulation; external power; molded inner socket; removable humeral shell; outside locking hinges; forearm; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Elbow disart myoelectronic c','L6945','3','','1','0','','','','0','1','0','0'),
('15333','Above elbow; external power; molded inner socket; removable humeral shell; internal locking elbow; forearm; otto bock or equal switch; cables; two batteries and one charger; switch control of terminal device','Above elbow switch control','L6950','3','','1','0','','','','0','1','0','0'),
('15334','Above elbow; external power; molded inner socket; removable humeral shell; internal locking elbow; forearm; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Above elbow myoelectronic ct','L6955','3','','1','0','','','','0','1','0','0'),
('15335','Shoulder disarticulation; external power; molded inner socket; removable shoulder shell; shoulder bulkhead; humeral section; mechanical elbow; forearm; otto bock or equal switch; cables; two batteries and one charger; switch control of terminal device','Shldr disartic switch contro','L6960','3','','1','0','','','','0','1','0','0'),
('15336','Shoulder disarticulation; external power; molded inner socket; removable shoulder shell; shoulder bulkhead; humeral section; mechanical elbow; forearm; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Shldr disartic myoelectronic','L6965','3','','1','0','','','','0','1','0','0'),
('15337','Interscapular-thoracic; external power; molded inner socket; removable shoulder shell; shoulder bulkhead; humeral section; mechanical elbow; forearm; otto bock or equal switch; cables; two batteries and one charger; switch control of terminal device','Interscapular-thor switch ct','L6970','3','','1','0','','','','0','1','0','0'),
('15338','Interscapular-thoracic; external power; molded inner socket; removable shoulder shell; shoulder bulkhead; humeral section; mechanical elbow; forearm; otto bock or equal electrodes; cables; two batteries and one charger; myoelectronic control of terminal device','Interscap-thor myoelectronic','L6975','3','','1','0','','','','0','1','0','0'),
('15339','Electric hand; switch or myoelectric controlled; adult','Adult electric hand','L7007','3','','1','0','','','','0','1','0','0'),
('15340','Electric hand; switch or myoelectric; controlled; pediatric','Pediatric electric hand','L7008','3','','1','0','','','','0','1','0','0'),
('15341','Electric hook; switch or myoelectric controlled; adult','Adult electric hook','L7009','3','','1','0','','','','0','1','0','0'),
('15342','Prehensile actuator; switch controlled','Prehensile actuator','L7040','3','','1','0','','','','0','1','0','0'),
('15343','Electric hook; switch or myoelectric controlled; pediatric','Pediatric electric hook','L7045','3','','1','0','','','','0','1','0','0'),
('15344','Electronic elbow; hosmer or equal; switch controlled','Electronic elbow hosmer swit','L7170','3','','1','0','','','','0','1','0','0'),
('15345','Electronic elbow; microprocessor sequential control of elbow and terminal device','Electronic elbow sequential','L7180','3','','1','0','','','','0','1','0','0'),
('15346','Electronic elbow; microprocessor simultaneous control of elbow and terminal device','Electronic elbo simultaneous','L7181','3','','1','0','','','','0','1','0','0'),
('15347','Electronic elbow; adolescent; variety village or equal; switch controlled','Electron elbow adolescent sw','L7185','3','','1','0','','','','0','1','0','0'),
('15348','Electronic elbow; child; variety village or equal; switch controlled','Electron elbow child switch','L7186','3','','1','0','','','','0','1','0','0'),
('15349','Electronic elbow; adolescent; variety village or equal; myoelectronically controlled','Elbow adolescent myoelectron','L7190','3','','1','0','','','','0','1','0','0'),
('15350','Electronic elbow; child; variety village or equal; myoelectronically controlled','Elbow child myoelectronic ct','L7191','3','','1','0','','','','0','1','0','0'),
('15351','Electronic wrist rotator; any type','Electronic wrist rotator any','L7259','3','','1','0','','','','0','1','0','0'),
('15352','Electronic wrist rotator; otto bock or equal','Electron wrist rotator otto','L7260','3','','1','0','','','','0','1','0','0'),
('15353','Electronic wrist rotator; for utah arm','Electron wrist rotator utah','L7261','3','','1','0','','','','0','1','0','0'),
('15354','Six volt battery; each','Six volt bat otto bock/eq ea','L7360','3','','1','0','','','','0','1','0','0'),
('15355','Battery charger; six volt; each','Battery chrgr six volt otto','L7362','3','','1','0','','','','0','1','0','0'),
('15356','Twelve volt battery; each','Twelve volt battery utah/equ','L7364','3','','1','0','','','','0','1','0','0'),
('15357','Battery charger; twelve volt; each','Battery chrgr 12 volt utah/e','L7366','3','','1','0','','','','0','1','0','0'),
('15358','Lithium ion battery; rechargeable; replacement','Replacemnt lithium ionbatter','L7367','3','','1','0','','','','0','1','0','0'),
('15359','Lithium ion battery charger; replacement only','Lithium ion battery charger','L7368','3','','1','0','','','','0','1','0','0'),
('15360','Addition to upper extremity prosthesis; below elbow/wrist disarticulation; ultralight material (titanium; carbon fiber or equal)','Add ue prost be/wd; ultlite','L7400','3','','1','0','','','','0','1','0','0'),
('15361','Addition to upper extremity prosthesis; above elbow disarticulation; ultralight material (titanium; carbon fiber or equal)','Add ue prost a/e ultlite mat','L7401','3','','1','0','','','','0','1','0','0'),
('15362','Addition to upper extremity prosthesis; shoulder disarticulation/interscapular thoracic; ultralight material (titanium; carbon fiber or equal)','Add ue prost s/d ultlite mat','L7402','3','','1','0','','','','0','1','0','0'),
('15363','Addition to upper extremity prosthesis; below elbow/wrist disarticulation; acrylic material','Add ue prost b/e acrylic','L7403','3','','1','0','','','','0','1','0','0'),
('15364','Addition to upper extremity prosthesis; above elbow disarticulation; acrylic material','Add ue prost a/e acrylic','L7404','3','','1','0','','','','0','1','0','0'),
('15365','Addition to upper extremity prosthesis; shoulder disarticulation/interscapular thoracic; acrylic material','Add ue prost s/d acrylic','L7405','3','','1','0','','','','0','1','0','0'),
('15366','Upper extremity prosthesis; not otherwise specified','Upper extremity prosthes nos','L7499','3','','1','0','','','','0','1','0','0'),
('15367','Repair of prosthetic device; repair or replace minor parts','Prosthetic device repair rep','L7510','3','','1','0','','','','0','1','0','0'),
('15368','Repair prosthetic device; labor component; per 15 minutes','Repair prosthesis per 15 min','L7520','3','','1','0','','','','0','1','0','0'),
('15369','Prosthetic donning sleeve; any material; each','Prosthetic donning sleeve','L7600','3','','1','0','','','','0','1','0','0'),
('15370','Male vacuum erection system','Male vacuum erection system','L7900','3','','1','0','','','','0','1','0','0'),
('15371','Tension ring; for vacuum erection device; any type; replacement only; each','Tension ring; vac erect dev','L7902','3','','1','0','','','','0','1','0','0'),
('15372','Breast prosthesis; mastectomy bra; without integrated breast prosthesis form; any size; any type','Mastectomy bra','L8000','3','','1','0','','','','0','1','0','0'),
('15373','Breast prosthesis; mastectomy bra; with integrated breast prosthesis form; unilateral; any size; any type','Breast prosthesis bra & form','L8001','3','','1','0','','','','0','1','0','0'),
('15374','Breast prosthesis; mastectomy bra; with integrated breast prosthesis form; bilateral; any size; any type','Brst prsth bra & bilat form','L8002','3','','1','0','','','','0','1','0','0'),
('15375','Breast prosthesis; mastectomy sleeve','Mastectomy sleeve','L8010','3','','1','0','','','','0','1','0','0'),
('15376','External breast prosthesis garment; with mastectomy form; post mastectomy','Ext breastprosthesis garment','L8015','3','','1','0','','','','0','1','0','0'),
('15377','Breast prosthesis; mastectomy form','Mastectomy form','L8020','3','','1','0','','','','0','1','0','0'),
('15378','Breast prosthesis; silicone or equal; without integral adhesive','Breast prosthes w/o adhesive','L8030','3','','1','0','','','','0','1','0','0'),
('15379','Breast prosthesis; silicone or equal; with integral adhesive','Breast prosthesis w adhesive','L8031','3','','1','0','','','','0','1','0','0'),
('15380','Nipple prosthesis; reusable; any type; each','Reusable nipple prosthesis','L8032','3','','1','0','','','','0','1','0','0'),
('15381','Custom breast prosthesis; post mastectomy; molded to patient model','Custom breast prosthesis','L8035','3','','1','0','','','','0','1','0','0'),
('15382','Breast prosthesis; not otherwise specified','Breast prosthesis nos','L8039','3','','1','0','','','','0','1','0','0'),
('15383','Nasal prosthesis; provided by a non-physician','Nasal prosthesis','L8040','3','','1','0','','','','0','1','0','0'),
('15384','Midfacial prosthesis; provided by a non-physician','Midfacial prosthesis','L8041','3','','1','0','','','','0','1','0','0'),
('15385','Orbital prosthesis; provided by a non-physician','Orbital prosthesis','L8042','3','','1','0','','','','0','1','0','0'),
('15386','Upper facial prosthesis; provided by a non-physician','Upper facial prosthesis','L8043','3','','1','0','','','','0','1','0','0'),
('15387','Hemi-facial prosthesis; provided by a non-physician','Hemi-facial prosthesis','L8044','3','','1','0','','','','0','1','0','0'),
('15388','Auricular prosthesis; provided by a non-physician','Auricular prosthesis','L8045','3','','1','0','','','','0','1','0','0'),
('15389','Partial facial prosthesis; provided by a non-physician','Partial facial prosthesis','L8046','3','','1','0','','','','0','1','0','0'),
('15390','Nasal septal prosthesis; provided by a non-physician','Nasal septal prosthesis','L8047','3','','1','0','','','','0','1','0','0'),
('15391','Unspecified maxillofacial prosthesis; by report; provided by a non-physician','Unspec maxillofacial prosth','L8048','3','','1','0','','','','0','1','0','0'),
('15392','Repair or modification of maxillofacial prosthesis; labor component; 15 minute increments; provided by a non-physician','Repair maxillofacial prosth','L8049','3','','1','0','','','','0','1','0','0'),
('15393','Truss; single with standard pad','Truss single w/ standard pad','L8300','3','','1','0','','','','0','1','0','0'),
('15394','Truss; double with standard pads','Truss double w/ standard pad','L8310','3','','1','0','','','','0','1','0','0'),
('15395','Truss; addition to standard pad; water pad','Truss addition to std pad wa','L8320','3','','1','0','','','','0','1','0','0'),
('15396','Truss; addition to standard pad; scrotal pad','Truss add to std pad scrotal','L8330','3','','1','0','','','','0','1','0','0'),
('15397','Prosthetic sheath; below knee; each','Sheath below knee','L8400','3','','1','0','','','','0','1','0','0'),
('15398','Prosthetic sheath; above knee; each','Sheath above knee','L8410','3','','1','0','','','','0','1','0','0'),
('15399','Prosthetic sheath; upper limb; each','Sheath upper limb','L8415','3','','1','0','','','','0','1','0','0'),
('15400','Prosthetic sheath/sock; including a gel cushion layer; below knee or above knee; each','Pros sheath/sock w gel cushn','L8417','3','','1','0','','','','0','1','0','0'),
('15401','Prosthetic sock; multiple ply; below knee; each','Prosthetic sock multi ply bk','L8420','3','','1','0','','','','0','1','0','0'),
('15402','Prosthetic sock; multiple ply; above knee; each','Prosthetic sock multi ply ak','L8430','3','','1','0','','','','0','1','0','0'),
('15403','Prosthetic sock; multiple ply; upper limb; each','Pros sock multi ply upper lm','L8435','3','','1','0','','','','0','1','0','0'),
('15404','Prosthetic shrinker; below knee; each','Shrinker below knee','L8440','3','','1','0','','','','0','1','0','0'),
('15405','Prosthetic shrinker; above knee; each','Shrinker above knee','L8460','3','','1','0','','','','0','1','0','0'),
('15406','Prosthetic shrinker; upper limb; each','Shrinker upper limb','L8465','3','','1','0','','','','0','1','0','0'),
('15407','Prosthetic sock; single ply; fitting; below knee; each','Pros sock single ply bk','L8470','3','','1','0','','','','0','1','0','0'),
('15408','Prosthetic sock; single ply; fitting; above knee; each','Pros sock single ply ak','L8480','3','','1','0','','','','0','1','0','0'),
('15409','Prosthetic sock; single ply; fitting; upper limb; each','Pros sock single ply upper l','L8485','3','','1','0','','','','0','1','0','0'),
('15410','Unlisted procedure for miscellaneous prosthetic services','Unlisted misc prosthetic ser','L8499','3','','1','0','','','','0','1','0','0'),
('15411','Artificial larynx; any type','Artificial larynx','L8500','3','','1','0','','','','0','1','0','0'),
('15412','Tracheostomy speaking valve','Tracheostomy speaking valve','L8501','3','','1','0','','','','0','1','0','0'),
('15413','Artificial larynx replacement battery / accessory; any type','Artificial larynx; accessory','L8505','3','','1','0','','','','0','1','0','0'),
('15414','Tracheo-esophageal voice prosthesis; patient inserted; any type; each','Trach-esoph voice pros pt in','L8507','3','','1','0','','','','0','1','0','0'),
('15415','Tracheo-esophageal voice prosthesis; inserted by a licensed health care provider; any type','Trach-esoph voice pros md in','L8509','3','','1','0','','','','0','1','0','0'),
('15416','Voice amplifier','Voice amplifier','L8510','3','','1','0','','','','0','1','0','0'),
('15417','Insert for indwelling tracheoesophageal prosthesis; with or without valve; replacement only; each','Indwelling trach insert','L8511','3','','1','0','','','','0','1','0','0'),
('15418','Gelatin capsules or equivalent; for use with tracheoesophageal voice prosthesis; replacement only; per 10','Gel cap for trach voice pros','L8512','3','','1','0','','','','0','1','0','0'),
('15419','Cleaning device used with tracheoesophageal voice prosthesis; pipet; brush; or equal; replacement only; each','Trach pros cleaning device','L8513','3','','1','0','','','','0','1','0','0'),
('15420','Tracheoesophageal puncture dilator; replacement only; each','Repl trach puncture dilator','L8514','3','','1','0','','','','0','1','0','0'),
('15421','Gelatin capsule; application device for use with tracheoesophageal voice prosthesis; each','Gel cap app device for trach','L8515','3','','1','0','','','','0','1','0','0'),
('15422','Implantable breast prosthesis; silicone or equal','Implant breast silicone/eq','L8600','3','','1','0','','','','0','1','0','0'),
('15423','Injectable bulking agent; collagen implant; urinary tract; 2.5 ml syringe; includes shipping and necessary supplies','Collagen imp urinary 2.5 ml','L8603','3','','1','0','','','','0','1','0','0'),
('15424','Injectable bulking agent; dextranomer/hyaluronic acid copolymer implant; urinary tract; 1 ml; includes shipping and necessary supplies','Dextranomer/hyaluronic acid','L8604','3','','1','0','','','','0','1','0','0'),
('15425','Injectable bulking agent; dextranomer/hyaluronic acid copolymer implant; anal canal; 1 ml; includes shipping and necessary supplies','Inj bulking agent anal canal','L8605','3','','1','0','','','','0','1','0','0'),
('15426','Injectable bulking agent; synthetic implant; urinary tract; 1 ml syringe; includes shipping and necessary supplies','Synthetic implnt urinary 1ml','L8606','3','','1','0','','','','0','1','0','0'),
('15427','Injectable bulking agent for vocal cord medialization; 0.1 ml; includes shipping and necessary supplies','Inj vocal cord bulking agent','L8607','3','','1','0','','','','0','1','0','0'),
('15428','Artificial cornea','Artificial cornea','L8609','3','','1','0','','','','0','1','0','0'),
('15429','Ocular implant','Ocular implant','L8610','3','','1','0','','','','0','1','0','0'),
('15430','Aqueous shunt','Aqueous shunt prosthesis','L8612','3','','1','0','','','','0','1','0','0'),
('15431','Ossicula implant','Ossicular implant','L8613','3','','1','0','','','','0','1','0','0'),
('15432','Cochlear device; includes all internal and external components','Cochlear device','L8614','3','','1','0','','','','0','1','0','0'),
('15433','Headset/headpiece for use with cochlear implant device; replacement','Coch implant headset replace','L8615','3','','1','0','','','','0','1','0','0'),
('15434','Microphone for use with cochlear implant device; replacement','Coch implant microphone repl','L8616','3','','1','0','','','','0','1','0','0'),
('15435','Transmitting coil for use with cochlear implant device; replacement','Coch implant trans coil repl','L8617','3','','1','0','','','','0','1','0','0'),
('15436','Transmitter cable for use with cochlear implant device; replacement','Coch implant tran cable repl','L8618','3','','1','0','','','','0','1','0','0'),
('15437','Cochlear implant; external speech processor and controller; integrated system; replacement','Coch imp ext proc/contr rplc','L8619','3','','1','0','','','','0','1','0','0'),
('15438','Zinc air battery for use with cochlear implant device and auditory osseointegrated sound processors; replacement; each','Repl zinc air battery','L8621','3','','1','0','','','','0','1','0','0'),
('15439','Alkaline battery for use with cochlear implant device; any size; replacement; each','Repl alkaline battery','L8622','3','','1','0','','','','0','1','0','0'),
('15440','Lithium ion battery for use with cochlear implant device speech processor; other than ear level; replacement; each','Lith ion batt cid;non-earlvl','L8623','3','','1','0','','','','0','1','0','0'),
('15441','Lithium ion battery for use with cochlear implant device speech processor; ear level; replacement; each','Lith ion batt cid; ear level','L8624','3','','1','0','','','','0','1','0','0'),
('15442','Cochlear implant; external speech processor; component; replacement','Cid ext speech process repl','L8627','3','','1','0','','','','0','1','0','0'),
('15443','Cochlear implant; external controller component; replacement','Cid ext controller repl','L8628','3','','1','0','','','','0','1','0','0'),
('15444','Transmitting coil and cable; integrated; for use with cochlear implant device; replacement','Cid transmit coil and cable','L8629','3','','1','0','','','','0','1','0','0'),
('15445','Metacarpophalangeal joint implant','Metacarpophalangeal implant','L8630','3','','1','0','','','','0','1','0','0'),
('15446','Metacarpal phalangeal joint replacement; two or more pieces; metal (e.g.; stainless steel or cobalt chrome); ceramic-like material (e.g.; pyrocarbon); for surgical implantation (all sizes; includes entire system)','Mcp joint repl 2 pc or more','L8631','3','','1','0','','','','0','1','0','0'),
('15447','Metatarsal joint implant','Metatarsal joint implant','L8641','3','','1','0','','','','0','1','0','0'),
('15448','Hallux implant','Hallux implant','L8642','3','','1','0','','','','0','1','0','0'),
('15449','Interphalangeal joint spacer; silicone or equal; each','Interphalangeal joint spacer','L8658','3','','1','0','','','','0','1','0','0'),
('15450','Interphalangeal finger joint replacement; 2 or more pieces; metal (e.g.; stainless steel or cobalt chrome); ceramic-like material (e.g.; pyrocarbon) for surgical implantation; any size','Interphalangeal joint repl','L8659','3','','1','0','','','','0','1','0','0'),
('15451','Vascular graft material; synthetic; implant','Vascular graft; synthetic','L8670','3','','1','0','','','','0','1','0','0'),
('15452','Implantable neurostimulator; pulse generator; any type','Imp neurosti pls gn any type','L8679','3','','1','0','','','','0','1','0','0'),
('15453','Implantable neurostimulator electrode; each','Implt neurostim elctr each','L8680','3','','1','0','','','','0','1','0','0'),
('15454','Patient programmer (external) for use with implantable programmable neurostimulator pulse generator; replacement only','Pt prgrm for implt neurostim','L8681','3','','1','0','','','','0','1','0','0'),
('15455','Implantable neurostimulator radiofrequency receiver','Implt neurostim radiofq rec','L8682','3','','1','0','','','','0','1','0','0'),
('15456','Radiofrequency transmitter (external) for use with implantable neurostimulator radiofrequency receiver','Radiofq trsmtr for implt neu','L8683','3','','1','0','','','','0','1','0','0'),
('15457','Radiofrequency transmitter (external) for use with implantable sacral root neurostimulator receiver for bowel and bladder management; replacement','Radiof trsmtr implt scrl neu','L8684','3','','1','0','','','','0','1','0','0'),
('15458','Implantable neurostimulator pulse generator; single array; rechargeable; includes extension','Implt nrostm pls gen sng rec','L8685','3','','1','0','','','','0','1','0','0'),
('15459','Implantable neurostimulator pulse generator; single array; non-rechargeable; includes extension','Implt nrostm pls gen sng non','L8686','3','','1','0','','','','0','1','0','0'),
('15460','Implantable neurostimulator pulse generator; dual array; rechargeable; includes extension','Implt nrostm pls gen dua rec','L8687','3','','1','0','','','','0','1','0','0'),
('15461','Implantable neurostimulator pulse generator; dual array; non-rechargeable; includes extension','Implt nrostm pls gen dua non','L8688','3','','1','0','','','','0','1','0','0'),
('15462','External recharging system for battery (internal) for use with implantable neurostimulator; replacement only','External recharg sys intern','L8689','3','','1','0','','','','0','1','0','0'),
('15463','Auditory osseointegrated device; includes all internal and external components','Aud osseo dev; int/ext comp','L8690','3','','1','0','','','','0','1','0','0'),
('15464','Auditory osseointegrated device; external sound processor; replacement','Osseointegrated snd proc rpl','L8691','3','','1','0','','','','0','1','0','0'),
('15465','Auditory osseointegrated device; external sound processor; used without osseointegration; body worn; includes headband or other means of external attachment','Non-osseointegrated snd proc','L8692','3','','1','0','','','','0','1','0','0'),
('15466','Auditory osseointegrated device abutment; any length; replacement only','Aud osseo dev; abutment','L8693','3','','1','0','','','','0','1','0','0'),
('15467','External recharging system for battery (external) for use with implantable neurostimulator; replacement only','External recharg sys extern','L8695','3','','1','0','','','','0','1','0','0'),
('15468','Antenna (external) for use with implantable diaphragmatic/phrenic nerve stimulation device; replacement; each','Ext antenna phren nerve stim','L8696','3','','1','0','','','','0','1','0','0'),
('15469','Prosthetic implant; not otherwise specified','Prosthetic implant nos','L8699','3','','1','0','','','','0','1','0','0'),
('15470','Orthotic and prosthetic supply; accessory; and/or service component of another hcpcs ''l'' code','O&p supply/accessory/service','L9900','3','','1','0','','','','0','1','0','0'),
('15471','Brief office visit for the sole purpose of monitoring or changing drug prescriptions used in the treatment of mental psychoneurotic and personality disorders','Visit for drug monitoring','M0064','3','','1','0','','','','0','1','0','0'),
('15472','Cellular therapy','Cellular therapy','M0075','3','','1','0','','','','0','1','0','0'),
('15473','Prolotherapy','Prolotherapy','M0076','3','','1','0','','','','0','1','0','0'),
('15474','Intragastric hypothermia using gastric freezing','Intragastric hypothermia','M0100','3','','1','0','','','','0','1','0','0'),
('15475','Iv chelation therapy (chemical endarterectomy)','Iv chelationtherapy','M0300','3','','1','0','','','','0','1','0','0'),
('15476','Fabric wrapping of abdominal aneurysm','Fabric wrapping of aneurysm','M0301','3','','1','0','','','','0','1','0','0'),
('15477','Cephalin floculation; blood','Cephalin floculation test','P2028','3','','1','0','','','','0','1','0','0'),
('15478','Congo red; blood','Congo red blood test','P2029','3','','1','0','','','','0','1','0','0'),
('15479','Hair analysis (excluding arsenic)','Hair analysis','P2031','3','','1','0','','','','0','1','0','0'),
('15480','Thymol turbidity; blood','Blood thymol turbidity','P2033','3','','1','0','','','','0','1','0','0'),
('15481','Mucoprotein; blood (seromucoid) (medical necessity procedure)','Blood mucoprotein','P2038','3','','1','0','','','','0','1','0','0'),
('15482','Screening papanicolaou smear; cervical or vaginal; up to three smears; by technician under physician supervision','Screen pap by tech w md supv','P3000','3','','1','0','','','','0','1','0','0'),
('15483','Screening papanicolaou smear; cervical or vaginal; up to three smears; requiring interpretation by physician','Screening pap smear by phys','P3001','3','','1','0','','','','0','1','0','0'),
('15484','Culture; bacterial; urine; quantitative; sensitivity study','Culture bacterial urine','P7001','3','','1','0','','','','0','1','0','0'),
('15485','Blood (whole); for transfusion; per unit','Whole blood for transfusion','P9010','3','','1','0','','','','0','1','0','0'),
('15486','Blood; split unit','Blood split unit','P9011','3','','1','0','','','','0','1','0','0'),
('15487','Cryoprecipitate; each unit','Cryoprecipitate each unit','P9012','3','','1','0','','','','0','1','0','0'),
('15488','Red blood cells; leukocytes reduced; each unit','Rbc leukocytes reduced','P9016','3','','1','0','','','','0','1','0','0'),
('15489','Fresh frozen plasma (single donor); frozen within 8 hours of collection; each unit','Plasma 1 donor frz w/in 8 hr','P9017','3','','1','0','','','','0','1','0','0'),
('15490','Platelets; each unit','Platelets; each unit','P9019','3','','1','0','','','','0','1','0','0'),
('15491','Platelet rich plasma; each unit','Plaelet rich plasma unit','P9020','3','','1','0','','','','0','1','0','0'),
('15492','Red blood cells; each unit','Red blood cells unit','P9021','3','','1','0','','','','0','1','0','0'),
('15493','Red blood cells; washed; each unit','Washed red blood cells unit','P9022','3','','1','0','','','','0','1','0','0'),
('15494','Plasma; pooled multiple donor; solvent/detergent treated; frozen; each unit','Frozen plasma; pooled; sd','P9023','3','','1','0','','','','0','1','0','0'),
('15495','Platelets; leukocytes reduced; each unit','Platelets leukocytes reduced','P9031','3','','1','0','','','','0','1','0','0'),
('15496','Platelets; irradiated; each unit','Platelets; irradiated','P9032','3','','1','0','','','','0','1','0','0'),
('15497','Platelets; leukocytes reduced; irradiated; each unit','Platelets leukoreduced irrad','P9033','3','','1','0','','','','0','1','0','0'),
('15498','Platelets; pheresis; each unit','Platelets; pheresis','P9034','3','','1','0','','','','0','1','0','0'),
('15499','Platelets; pheresis; leukocytes reduced; each unit','Platelet pheres leukoreduced','P9035','3','','1','0','','','','0','1','0','0'),
('15500','Platelets; pheresis; irradiated; each unit','Platelet pheresis irradiated','P9036','3','','1','0','','','','0','1','0','0'),
('15501','Platelets; pheresis; leukocytes reduced; irradiated; each unit','Plate pheres leukoredu irrad','P9037','3','','1','0','','','','0','1','0','0'),
('15502','Red blood cells; irradiated; each unit','Rbc irradiated','P9038','3','','1','0','','','','0','1','0','0'),
('15503','Red blood cells; deglycerolized; each unit','Rbc deglycerolized','P9039','3','','1','0','','','','0','1','0','0'),
('15504','Red blood cells; leukocytes reduced; irradiated; each unit','Rbc leukoreduced irradiated','P9040','3','','1','0','','','','0','1','0','0'),
('15505','Infusion; albumin (human); 5%; 50 ml','Albumin (human);5%; 50ml','P9041','3','','1','0','','','','0','1','0','0'),
('15506','Infusion; plasma protein fraction (human); 5%; 50 ml','Plasma protein fract;5%;50ml','P9043','3','','1','0','','','','0','1','0','0'),
('15507','Plasma; cryoprecipitate reduced; each unit','Cryoprecipitatereducedplasma','P9044','3','','1','0','','','','0','1','0','0'),
('15508','Infusion; albumin (human); 5%; 250 ml','Albumin (human); 5%; 250 ml','P9045','3','','1','0','','','','0','1','0','0'),
('15509','Infusion; albumin (human); 25%; 20 ml','Albumin (human); 25%; 20 ml','P9046','3','','1','0','','','','0','1','0','0'),
('15510','Infusion; albumin (human); 25%; 50 ml','Albumin (human); 25%; 50ml','P9047','3','','1','0','','','','0','1','0','0'),
('15511','Infusion; plasma protein fraction (human); 5%; 250 ml','Plasmaprotein fract;5%;250ml','P9048','3','','1','0','','','','0','1','0','0'),
('15512','Granulocytes; pheresis; each unit','Granulocytes; pheresis unit','P9050','3','','1','0','','','','0','1','0','0'),
('15513','Whole blood or red blood cells; leukocytes reduced; cmv-negative; each unit','Blood; l/r; cmv-neg','P9051','3','','1','0','','','','0','1','0','0'),
('15514','Platelets; hla-matched leukocytes reduced; apheresis/pheresis; each unit','Platelets; hla-m; l/r; unit','P9052','3','','1','0','','','','0','1','0','0'),
('15515','Platelets; pheresis; leukocytes reduced; cmv-negative; irradiated; each unit','Plt; pher; l/r cmv-neg; irr','P9053','3','','1','0','','','','0','1','0','0'),
('15516','Whole blood or red blood cells; leukocytes reduced; frozen; deglycerol; washed; each unit','Blood; l/r; froz/degly/wash','P9054','3','','1','0','','','','0','1','0','0'),
('15517','Platelets; leukocytes reduced; cmv-negative; apheresis/pheresis; each unit','Plt; aph/pher; l/r; cmv-neg','P9055','3','','1','0','','','','0','1','0','0'),
('15518','Whole blood; leukocytes reduced; irradiated; each unit','Blood; l/r; irradiated','P9056','3','','1','0','','','','0','1','0','0'),
('15519','Red blood cells; frozen/deglycerolized/washed; leukocytes reduced; irradiated; each unit','Rbc; frz/deg/wsh; l/r; irrad','P9057','3','','1','0','','','','0','1','0','0'),
('15520','Red blood cells; leukocytes reduced; cmv-negative; irradiated; each unit','Rbc; l/r; cmv-neg; irrad','P9058','3','','1','0','','','','0','1','0','0'),
('15521','Fresh frozen plasma between 8-24 hours of collection; each unit','Plasma; frz between 8-24hour','P9059','3','','1','0','','','','0','1','0','0'),
('15522','Fresh frozen plasma; donor retested; each unit','Fr frz plasma donor retested','P9060','3','','1','0','','','','0','1','0','0'),
('15523','Plasma; pooled multiple donor; pathogen reduced; frozen; each unit','Pathogen reduced plasma pool','P9070','3','','1','0','','','','0','1','0','0'),
('15524','Plasma (single donor); pathogen reduced; frozen; each unit','Pathogen reduced plasma sing','P9071','3','','1','0','','','','0','1','0','0'),
('15525','Platelets; pheresis; pathogen reduced or rapid bacterial tested; each unit','Plate path red/rapid bac tes','P9072','3','','1','0','','','','0','1','0','0'),
('15526','Travel allowance one way in connection with medically necessary laboratory specimen collection drawn from home bound or nursing home bound patient; prorated miles actually travelled','One-way allow prorated miles','P9603','3','','1','0','','','','0','1','0','0'),
('15527','Travel allowance one way in connection with medically necessary laboratory specimen collection drawn from home bound or nursing home bound patient; prorated trip charge','One-way allow prorated trip','P9604','3','','1','0','','','','0','1','0','0'),
('15528','Catheterization for collection of specimen; single patient; all places of service','Catheterize for urine spec','P9612','3','','1','0','','','','0','1','0','0'),
('15529','Catheterization for collection of specimen(s) (multiple patients)','Urine specimen collect mult','P9615','3','','1','0','','','','0','1','0','0'),
('15530','Cardiokymography','Cardiokymography','Q0035','3','','1','0','','','','0','1','0','0'),
('15531','Infusion therapy; using other than chemotherapeutic drugs; per visit','Infusion ther other than che','Q0081','3','','1','0','','','','0','1','0','0'),
('15532','Chemotherapy administration by other than infusion technique only (e.g.; subcutaneous; intramuscular; push); per visit','Chemo by other than infusion','Q0083','3','','1','0','','','','0','1','0','0'),
('15533','Chemotherapy administration by infusion technique only; per visit','Chemotherapy by infusion','Q0084','3','','1','0','','','','0','1','0','0'),
('15534','Chemotherapy administration by both infusion technique and other technique(s) (e.g.; subcutaneous; intramuscular; push); per visit','Chemo by both infusion and o','Q0085','3','','1','0','','','','0','1','0','0'),
('15535','Levonorgestrel-releasing intrauterine contraceptive system; (skyla); 13.5 mg','Skyla 13.5mg','Q0090','3','','1','0','','','','0','1','0','0'),
('15536','Screening papanicolaou smear; obtaining; preparing and conveyance of cervical or vaginal smear to laboratory','Obtaining screen pap smear','Q0091','3','','1','0','','','','0','1','0','0'),
('15537','Set-up portable x-ray equipment','Set up port xray equipment','Q0092','3','','1','0','','','','0','1','0','0'),
('15538','Wet mounts; including preparations of vaginal; cervical or skin specimens','Wet mounts/ w preparations','Q0111','3','','1','0','','','','0','1','0','0'),
('15539','All potassium hydroxide (koh) preparations','Potassium hydroxide preps','Q0112','3','','1','0','','','','0','1','0','0'),
('15540','Pinworm examinations','Pinworm examinations','Q0113','3','','1','0','','','','0','1','0','0'),
('15541','Fern test','Fern test','Q0114','3','','1','0','','','','0','1','0','0'),
('15542','Post-coital direct; qualitative examinations of vaginal or cervical mucous','Post-coital mucous exam','Q0115','3','','1','0','','','','0','1','0','0'),
('15543','Injection; ferumoxytol; for treatment of iron deficiency anemia; 1 mg (non-esrd use)','Ferumoxytol; non-esrd','Q0138','3','','1','0','','','','0','1','0','0'),
('15544','Injection; ferumoxytol; for treatment of iron deficiency anemia; 1 mg (for esrd on dialysis)','Ferumoxytol; esrd use','Q0139','3','','1','0','','','','0','1','0','0'),
('15545','Azithromycin dihydrate; oral; capsules/powder; 1 gram','Azithromycin dihydrate; oral','Q0144','3','','1','0','','','','0','1','0','0'),
('15546','Chlorpromazine hydrochloride; 5 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Chlorpromazine hcl 5mg oral','Q0161','3','','1','0','','','','0','1','0','0'),
('15547','Ondansetron 1 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Ondansetron oral','Q0162','3','','1','0','','','','0','1','0','0'),
('15548','Diphenhydramine hydrochloride; 50 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at time of chemotherapy treatment not to exceed a 48 hour dosage regimen','Diphenhydramine hcl 50mg','Q0163','3','','1','0','','','','0','1','0','0'),
('15549','Prochlorperazine maleate; 5 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Prochlorperazine maleate 5mg','Q0164','3','','1','0','','','','0','1','0','0'),
('15550','Prochlorperazine maleate; 10  mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Prochlorperazine maleate10mg','Q0165','3','','1','0','','','','0','1','0','0'),
('15551','Granisetron hydrochloride; 1 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 24 hour dosage regimen','Granisetron hcl 1 mg oral','Q0166','3','','1','0','','','','0','1','0','0'),
('15552','Dronabinol; 2.5 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Dronabinol 2.5mg oral','Q0167','3','','1','0','','','','0','1','0','0'),
('15553','Dronabinol; 5 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Dronabinol 5mg oral','Q0168','3','','1','0','','','','0','1','0','0'),
('15554','Promethazine hydrochloride; 12.5 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Promethazine hcl 12.5mg oral','Q0169','3','','1','0','','','','0','1','0','0'),
('15555','Promethazine hydrochloride; 25  mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Promethazine hcl 25 mg oral','Q0170','3','','1','0','','','','0','1','0','0'),
('15556','Chlorpromazine hydrochloride; 10  mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Chlorpromazine hcl 10mg oral','Q0171','3','','1','0','','','','0','1','0','0'),
('15557','Chlorpromazine hydrochloride; 25 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Chlorpromazine hcl 25mg oral','Q0172','3','','1','0','','','','0','1','0','0'),
('15558','Trimethobenzamide hydrochloride; 250 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Trimethobenzamide hcl 250mg','Q0173','3','','1','0','','','','0','1','0','0'),
('15559','Thiethylperazine maleate; 10 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Thiethylperazine maleate10mg','Q0174','3','','1','0','','','','0','1','0','0'),
('15560','Perphenazine; 4 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Perphenazine 4mg oral','Q0175','3','','1','0','','','','0','1','0','0'),
('15561','Perphenazine; 8mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Perphenazine 8mg oral','Q0176','3','','1','0','','','','0','1','0','0'),
('15562','Hydroxyzine pamoate; 25 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Hydroxyzine pamoate 25mg','Q0177','3','','1','0','','','','0','1','0','0'),
('15563','Hydroxyzine pamoate; 50 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Hydroxyzine pamoate 50mg','Q0178','3','','1','0','','','','0','1','0','0'),
('15564','Dolasetron mesylate; 100 mg; oral; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for an iv anti-emetic at the time of chemotherapy treatment; not to exceed a 24 hour dosage regimen','Dolasetron mesylate oral','Q0180','3','','1','0','','','','0','1','0','0'),
('15565','Unspecified oral dosage form; fda approved prescription anti-emetic; for use as a complete therapeutic substitute for a iv anti-emetic at the time of chemotherapy treatment; not to exceed a 48 hour dosage regimen','Unspecified oral anti-emetic','Q0181','3','','1','0','','','','0','1','0','0'),
('15566','Power adapter for use with electric or electric/pneumatic ventricular assist device; vehicle type','Power adapter; combo vad','Q0478','3','','1','0','','','','0','1','0','0'),
('15567','Power module for use with electric or electric/pneumatic ventricular assist device; replacement only','Power module combo vad; rep','Q0479','3','','1','0','','','','0','1','0','0'),
('15568','Driver for use with pneumatic ventricular assist device; replacement only','Driver pneumatic vad; rep','Q0480','3','','1','0','','','','0','1','0','0'),
('15569','Microprocessor control unit for use with electric ventricular assist device; replacement only','Microprcsr cu elec vad; rep','Q0481','3','','1','0','','','','0','1','0','0'),
('15570','Microprocessor control unit for use with electric/pneumatic combination ventricular assist device; replacement only','Microprcsr cu combo vad; rep','Q0482','3','','1','0','','','','0','1','0','0'),
('15571','Monitor/display module for use with electric ventricular assist device; replacement only','Monitor elec vad; rep','Q0483','3','','1','0','','','','0','1','0','0'),
('15572','Monitor/display module for use with electric or electric/pneumatic ventricular assist device; replacement only','Monitor elec or comb vad rep','Q0484','3','','1','0','','','','0','1','0','0'),
('15573','Monitor control cable for use with electric ventricular assist device; replacement only','Monitor cable elec vad; rep','Q0485','3','','1','0','','','','0','1','0','0'),
('15574','Monitor control cable for use with electric/pneumatic ventricular assist device; replacement only','Mon cable elec/pneum vad rep','Q0486','3','','1','0','','','','0','1','0','0'),
('15575','Leads (pneumatic/electrical) for use with any type electric/pneumatic ventricular assist device; replacement only','Leads any type vad; rep only','Q0487','3','','1','0','','','','0','1','0','0'),
('15576','Power pack base for use with electric ventricular assist device; replacement only','Pwr pack base elec vad; rep','Q0488','3','','1','0','','','','0','1','0','0'),
('15577','Power pack base for use with electric/pneumatic ventricular assist device; replacement only','Pwr pck base combo vad; rep','Q0489','3','','1','0','','','','0','1','0','0'),
('15578','Emergency power source for use with electric ventricular assist device; replacement only','Emr pwr source elec vad; rep','Q0490','3','','1','0','','','','0','1','0','0'),
('15579','Emergency power source for use with electric/pneumatic ventricular assist device; replacement only','Emr pwr source combo vad rep','Q0491','3','','1','0','','','','0','1','0','0'),
('15580','Emergency power supply cable for use with electric ventricular assist device; replacement only','Emr pwr cbl elec vad; rep','Q0492','3','','1','0','','','','0','1','0','0'),
('15581','Emergency power supply cable for use with electric/pneumatic ventricular assist device; replacement only','Emr pwr cbl combo vad; rep','Q0493','3','','1','0','','','','0','1','0','0'),
('15582','Emergency hand pump for use with electric or electric/pneumatic ventricular assist device; replacement only','Emr hd pmp elec/combo; rep','Q0494','3','','1','0','','','','0','1','0','0'),
('15583','Battery/power pack charger for use with electric or electric/pneumatic ventricular assist device; replacement only','Charger elec/combo vad; rep','Q0495','3','','1','0','','','','0','1','0','0'),
('15584','Battery; other than lithium-ion; for use with electric or electric/pneumatic ventricular assist device; replacement only','Battery elec/combo vad; rep','Q0496','3','','1','0','','','','0','1','0','0'),
('15585','Battery clips for use with electric or electric/pneumatic ventricular assist device; replacement only','Bat clps elec/comb vad; rep','Q0497','3','','1','0','','','','0','1','0','0'),
('15586','Holster for use with electric or electric/pneumatic ventricular assist device; replacement only','Holster elec/combo vad; rep','Q0498','3','','1','0','','','','0','1','0','0'),
('15587','Belt/vest/bag for use to carry external peripheral components of any type ventricular assist device; replacement only','Belt/vest elec/combo vad rep','Q0499','3','','1','0','','','','0','1','0','0'),
('15588','Filters for use with electric or electric/pneumatic ventricular assist device; replacement only','Filters elec/combo vad; rep','Q0500','3','','1','0','','','','0','1','0','0'),
('15589','Shower cover for use with electric or electric/pneumatic ventricular assist device; replacement only','Shwr cov elec/combo vad; rep','Q0501','3','','1','0','','','','0','1','0','0'),
('15590','Mobility cart for pneumatic ventricular assist device; replacement only','Mobility cart pneum vad; rep','Q0502','3','','1','0','','','','0','1','0','0'),
('15591','Battery for pneumatic ventricular assist device; replacement only; each','Battery pneum vad replacemnt','Q0503','3','','1','0','','','','0','1','0','0'),
('15592','Power adapter for pneumatic ventricular assist device; replacement only; vehicle type','Pwr adpt pneum vad; rep veh','Q0504','3','','1','0','','','','0','1','0','0'),
('15593','Miscellaneous supply or accessory for use with ventricular assist device','Miscl supply/accessory vad','Q0505','3','','1','0','','','','0','1','0','0'),
('15594','Battery; lithium-ion; for use with electric or electric/pneumatic ventricular assist device; replacement only','Lith-ion batt elec/pneum vad','Q0506','3','','1','0','','','','0','1','0','0'),
('15595','Miscellaneous supply or accessory for use with an external ventricular assist device','Misc sup/acc ext vad','Q0507','3','','1','0','','','','0','1','0','0'),
('15596','Miscellaneous supply or accessory for use with an implanted ventricular assist device','Mis sup/acc imp vad','Q0508','3','','1','0','','','','0','1','0','0'),
('15597','Miscellaneous supply or accessory for use with any implanted ventricular assist device for which payment was not made under medicare part a','Mis sup/ac imp vad nopay med','Q0509','3','','1','0','','','','0','1','0','0'),
('15598','Pharmacy supply fee for initial immunosuppressive drug(s); first month following transplant','Dispens fee immunosupressive','Q0510','3','','1','0','','','','0','1','0','0'),
('15599','Pharmacy supply fee for oral anti-cancer; oral anti-emetic or immunosuppressive drug(s); for the first prescription in a 30-day period','Sup fee antiem;antica;immuno','Q0511','3','','1','0','','','','0','1','0','0'),
('15600','Pharmacy supply fee for oral anti-cancer; oral anti-emetic or immunosuppressive drug(s); for a subsequent prescription in a 30-day period','Px sup fee anti-can sub pres','Q0512','3','','1','0','','','','0','1','0','0'),
('15601','Pharmacy dispensing fee for inhalation drug(s); per 30 days','Disp fee inhal drugs/30 days','Q0513','3','','1','0','','','','0','1','0','0'),
('15602','Pharmacy dispensing fee for inhalation drug(s); per 90 days','Disp fee inhal drugs/90 days','Q0514','3','','1','0','','','','0','1','0','0'),
('15603','Injection; sermorelin acetate; 1 microgram','Sermorelin acetate injection','Q0515','3','','1','0','','','','0','1','0','0'),
('15604','New technology intraocular lens category 4 as defined in federal register notice','Ntiol category 4','Q1004','3','','1','0','','','','0','1','0','0'),
('15605','New technology intraocular lens category 5 as defined in federal register notice','Ntiol category 5','Q1005','3','','1','0','','','','0','1','0','0'),
('15606','Irrigation solution for treatment of bladder calculi; for example renacidin; per 500 ml','Bladder calculi irrig sol','Q2004','3','','1','0','','','','0','1','0','0'),
('15607','Injection; fosphenytoin; 50 mg phenytoin equivalent','Fosphenytoin inj pe','Q2009','3','','1','0','','','','0','1','0','0'),
('15608','Injection; teniposide; 50 mg','Teniposide; 50 mg','Q2017','3','','1','0','','','','0','1','0','0'),
('15609','Injection; radiesse; 0.1 ml','Radiesse injection','Q2026','3','','1','0','','','','0','1','0','0'),
('15610','Injection; sculptra; 0.1 ml','Sculptra injection','Q2027','3','','1','0','','','','0','1','0','0'),
('15611','Injection; sculptra; 0.5 mg','Inj; sculptra; 0.5mg','Q2028','3','','1','0','','','','0','1','0','0'),
('15612','Influenza vaccine; recombinant hemagglutinin antigens; for intramuscular use (flublok)','Influenza vaccine; (flublok)','Q2033','3','','1','0','','','','0','1','0','0'),
('15613','Influenza virus vaccine; split virus; for intramuscular use (agriflu)','Agriflu vaccine','Q2034','3','','1','0','','','','0','1','0','0'),
('15614','Influenza virus vaccine; split virus; when administered to individuals 3 years of age and older; for intramuscular use (afluria)','Afluria vacc; 3 yrs & >; im','Q2035','3','','1','0','','','','0','1','0','0'),
('15615','Influenza virus vaccine; split virus; when administered to individuals 3 years of age and older; for intramuscular use (flulaval)','Flulaval vacc; 3 yrs & >; im','Q2036','3','','1','0','','','','0','1','0','0'),
('15616','Influenza virus vaccine; split virus; when administered to individuals 3 years of age and older; for intramuscular use (fluvirin)','Fluvirin vacc; 3 yrs & >; im','Q2037','3','','1','0','','','','0','1','0','0'),
('15617','Influenza virus vaccine; split virus; when administered to individuals 3 years of age and older; for intramuscular use (fluzone)','Fluzone vacc; 3 yrs & >; im','Q2038','3','','1','0','','','','0','1','0','0'),
('15618','Influenza virus vaccine; not otherwise specified','Influenza virus vaccine; nos','Q2039','3','','1','0','','','','0','1','0','0'),
('15619','Sipuleucel-t; minimum of 50 million autologous cd54+ cells activated with pap-gm-csf; including leukapheresis and all other preparatory procedures; per infusion','Sipuleucel-t auto cd54+','Q2043','3','','1','0','','','','0','1','0','0'),
('15620','Injection; doxorubicin hydrochloride; liposomal; imported lipodox; 10 mg','Imported lipodox inj','Q2049','3','','1','0','','','','0','1','0','0'),
('15621','Injection; doxorubicin hydrochloride; liposomal; not otherwise specified; 10 mg','Doxorubicin inj 10mg','Q2050','3','','1','0','','','','0','1','0','0'),
('15622','Injection; zoledronic acid; not otherwise specified; 1mg','Zoldedronic acid 1mg','Q2051','3','','1','0','','','','0','1','0','0'),
('15623','Services; supplies and accessories used in the home under the medicare intravenous immune globulin (ivig) demonstration','Ivig demo; services/supplies','Q2052','3','','1','0','','','','0','1','0','0'),
('15624','Radioelements for brachytherapy; any type; each','Brachytherapy radioelements','Q3001','3','','1','0','','','','0','1','0','0'),
('15625','Telehealth originating site facility fee','Telehealth facility fee','Q3014','3','','1','0','','','','0','1','0','0'),
('15626','Injection; interferon beta-1a; 11 mcg for intramuscular use','Im inj interferon beta 1-a','Q3025','3','','1','0','','','','0','1','0','0'),
('15627','Injection; interferon beta-1a; 11 mcg for subcutaneous use','Subc inj interferon beta-1a','Q3026','3','','1','0','','','','0','1','0','0'),
('15628','Injection; interferon beta-1a; 1 mcg for intramuscular use','Inj beta interferon im 1 mcg','Q3027','3','','1','0','','','','0','1','0','0'),
('15629','Injection; interferon beta-1a; 1 mcg for subcutaneous use','Inj beta interferon sq 1 mcg','Q3028','3','','1','0','','','','0','1','0','0'),
('15630','Collagen skin test','Collagen skin test','Q3031','3','','1','0','','','','0','1','0','0'),
('15631','Casting supplies; body cast adult; with or without head; plaster','Cast sup body cast plaster','Q4001','3','','1','0','','','','0','1','0','0'),
('15632','Cast supplies; body cast adult; with or without head; fiberglass','Cast sup body cast fiberglas','Q4002','3','','1','0','','','','0','1','0','0'),
('15633','Cast supplies; shoulder cast; adult (11 years +); plaster','Cast sup shoulder cast plstr','Q4003','3','','1','0','','','','0','1','0','0'),
('15634','Cast supplies; shoulder cast; adult (11 years +); fiberglass','Cast sup shoulder cast fbrgl','Q4004','3','','1','0','','','','0','1','0','0'),
('15635','Cast supplies; long arm cast; adult (11 years +); plaster','Cast sup long arm adult plst','Q4005','3','','1','0','','','','0','1','0','0'),
('15636','Cast supplies; long arm cast; adult (11 years +); fiberglass','Cast sup long arm adult fbrg','Q4006','3','','1','0','','','','0','1','0','0'),
('15637','Cast supplies; long arm cast; pediatric (0-10 years); plaster','Cast sup long arm ped plster','Q4007','3','','1','0','','','','0','1','0','0'),
('15638','Cast supplies; long arm cast; pediatric (0-10 years); fiberglass','Cast sup long arm ped fbrgls','Q4008','3','','1','0','','','','0','1','0','0'),
('15639','Cast supplies; short arm cast; adult (11 years +); plaster','Cast sup sht arm adult plstr','Q4009','3','','1','0','','','','0','1','0','0'),
('15640','Cast supplies; short arm cast; adult (11 years +); fiberglass','Cast sup sht arm adult fbrgl','Q4010','3','','1','0','','','','0','1','0','0'),
('15641','Cast supplies; short arm cast; pediatric (0-10 years); plaster','Cast sup sht arm ped plaster','Q4011','3','','1','0','','','','0','1','0','0'),
('15642','Cast supplies; short arm cast; pediatric (0-10 years); fiberglass','Cast sup sht arm ped fbrglas','Q4012','3','','1','0','','','','0','1','0','0'),
('15643','Cast supplies; gauntlet cast (includes lower forearm and hand); adult (11 years +); plaster','Cast sup gauntlet plaster','Q4013','3','','1','0','','','','0','1','0','0'),
('15644','Cast supplies; gauntlet cast (includes lower forearm and hand); adult (11 years +); fiberglass','Cast sup gauntlet fiberglass','Q4014','3','','1','0','','','','0','1','0','0'),
('15645','Cast supplies; gauntlet cast (includes lower forearm and hand); pediatric (0-10 years); plaster','Cast sup gauntlet ped plster','Q4015','3','','1','0','','','','0','1','0','0'),
('15646','Cast supplies; gauntlet cast (includes lower forearm and hand); pediatric (0-10 years); fiberglass','Cast sup gauntlet ped fbrgls','Q4016','3','','1','0','','','','0','1','0','0'),
('15647','Cast supplies; long arm splint; adult (11 years +); plaster','Cast sup lng arm splint plst','Q4017','3','','1','0','','','','0','1','0','0'),
('15648','Cast supplies; long arm splint; adult (11 years +); fiberglass','Cast sup lng arm splint fbrg','Q4018','3','','1','0','','','','0','1','0','0'),
('15649','Cast supplies; long arm splint; pediatric (0-10 years); plaster','Cast sup lng arm splnt ped p','Q4019','3','','1','0','','','','0','1','0','0'),
('15650','Cast supplies; long arm splint; pediatric (0-10 years); fiberglass','Cast sup lng arm splnt ped f','Q4020','3','','1','0','','','','0','1','0','0'),
('15651','Cast supplies; short arm splint; adult (11 years +); plaster','Cast sup sht arm splint plst','Q4021','3','','1','0','','','','0','1','0','0'),
('15652','Cast supplies; short arm splint; adult (11 years +); fiberglass','Cast sup sht arm splint fbrg','Q4022','3','','1','0','','','','0','1','0','0'),
('15653','Cast supplies; short arm splint; pediatric (0-10 years); plaster','Cast sup sht arm splnt ped p','Q4023','3','','1','0','','','','0','1','0','0'),
('15654','Cast supplies; short arm splint; pediatric (0-10 years); fiberglass','Cast sup sht arm splnt ped f','Q4024','3','','1','0','','','','0','1','0','0'),
('15655','Cast supplies; hip spica (one or both legs); adult (11 years +); plaster','Cast sup hip spica plaster','Q4025','3','','1','0','','','','0','1','0','0'),
('15656','Cast supplies; hip spica (one or both legs); adult (11 years +); fiberglass','Cast sup hip spica fiberglas','Q4026','3','','1','0','','','','0','1','0','0'),
('15657','Cast supplies; hip spica (one or both legs); pediatric (0-10 years); plaster','Cast sup hip spica ped plstr','Q4027','3','','1','0','','','','0','1','0','0'),
('15658','Cast supplies; hip spica (one or both legs); pediatric (0-10 years); fiberglass','Cast sup hip spica ped fbrgl','Q4028','3','','1','0','','','','0','1','0','0'),
('15659','Cast supplies; long leg cast; adult (11 years +); plaster','Cast sup long leg plaster','Q4029','3','','1','0','','','','0','1','0','0'),
('15660','Cast supplies; long leg cast; adult (11 years +); fiberglass','Cast sup long leg fiberglass','Q4030','3','','1','0','','','','0','1','0','0'),
('15661','Cast supplies; long leg cast; pediatric (0-10 years); plaster','Cast sup lng leg ped plaster','Q4031','3','','1','0','','','','0','1','0','0'),
('15662','Cast supplies; long leg cast; pediatric (0-10 years); fiberglass','Cast sup lng leg ped fbrgls','Q4032','3','','1','0','','','','0','1','0','0'),
('15663','Cast supplies; long leg cylinder cast; adult (11 years +); plaster','Cast sup lng leg cylinder pl','Q4033','3','','1','0','','','','0','1','0','0'),
('15664','Cast supplies; long leg cylinder cast; adult (11 years +); fiberglass','Cast sup lng leg cylinder fb','Q4034','3','','1','0','','','','0','1','0','0'),
('15665','Cast supplies; long leg cylinder cast; pediatric (0-10 years); plaster','Cast sup lngleg cylndr ped p','Q4035','3','','1','0','','','','0','1','0','0'),
('15666','Cast supplies; long leg cylinder cast; pediatric (0-10 years); fiberglass','Cast sup lngleg cylndr ped f','Q4036','3','','1','0','','','','0','1','0','0'),
('15667','Cast supplies; short leg cast; adult (11 years +); plaster','Cast sup shrt leg plaster','Q4037','3','','1','0','','','','0','1','0','0'),
('15668','Cast supplies; short leg cast; adult (11 years +); fiberglass','Cast sup shrt leg fiberglass','Q4038','3','','1','0','','','','0','1','0','0'),
('15669','Cast supplies; short leg cast; pediatric (0-10 years); plaster','Cast sup shrt leg ped plster','Q4039','3','','1','0','','','','0','1','0','0'),
('15670','Cast supplies; short leg cast; pediatric (0-10 years); fiberglass','Cast sup shrt leg ped fbrgls','Q4040','3','','1','0','','','','0','1','0','0'),
('15671','Cast supplies; long leg splint; adult (11 years +); plaster','Cast sup lng leg splnt plstr','Q4041','3','','1','0','','','','0','1','0','0'),
('15672','Cast supplies; long leg splint; adult (11 years +); fiberglass','Cast sup lng leg splnt fbrgl','Q4042','3','','1','0','','','','0','1','0','0'),
('15673','Cast supplies; long leg splint; pediatric (0-10 years); plaster','Cast sup lng leg splnt ped p','Q4043','3','','1','0','','','','0','1','0','0'),
('15674','Cast supplies; long leg splint; pediatric (0-10 years); fiberglass','Cast sup lng leg splnt ped f','Q4044','3','','1','0','','','','0','1','0','0'),
('15675','Cast supplies; short leg splint; adult (11 years +); plaster','Cast sup sht leg splnt plstr','Q4045','3','','1','0','','','','0','1','0','0'),
('15676','Cast supplies; short leg splint; adult (11 years +); fiberglass','Cast sup sht leg splnt fbrgl','Q4046','3','','1','0','','','','0','1','0','0'),
('15677','Cast supplies; short leg splint; pediatric (0-10 years); plaster','Cast sup sht leg splnt ped p','Q4047','3','','1','0','','','','0','1','0','0'),
('15678','Cast supplies; short leg splint; pediatric (0-10 years); fiberglass','Cast sup sht leg splnt ped f','Q4048','3','','1','0','','','','0','1','0','0'),
('15679','Finger splint; static','Finger splint; static','Q4049','3','','1','0','','','','0','1','0','0'),
('15680','Cast supplies; for unlisted types and materials of casts','Cast supplies unlisted','Q4050','3','','1','0','','','','0','1','0','0'),
('15681','Splint supplies; miscellaneous (includes thermoplastics; strapping; fasteners; padding and other supplies)','Splint supplies misc','Q4051','3','','1','0','','','','0','1','0','0'),
('15682','Iloprost; inhalation solution; fda-approved final product; non-compounded; administered through dme; unit dose form; up to 20 micrograms','Iloprost non-comp unit dose','Q4074','3','','1','0','','','','0','1','0','0'),
('15683','Injection; epoetin alfa; 100 units (for esrd on dialysis)','Epoetin alfa; 100 units esrd','Q4081','3','','1','0','','','','0','1','0','0'),
('15684','Drug or biological; not otherwise classified; part b drug competitive acquisition program (cap)','Drug/bio noc part b drug cap','Q4082','3','','1','0','','','','0','1','0','0'),
('15685','Skin substitute; not otherwise specified','Skin substitute; nos','Q4100','3','','1','0','','','','0','1','0','0'),
('15686','Apligraf; per square centimeter','Apligraf','Q4101','3','','1','0','','','','0','1','0','0'),
('15687','Oasis wound matrix; per square centimeter','Oasis wound matrix','Q4102','3','','1','0','','','','0','1','0','0'),
('15688','Oasis burn matrix; per square centimeter','Oasis burn matrix','Q4103','3','','1','0','','','','0','1','0','0'),
('15689','Integra bilayer matrix wound dressing (bmwd); per square centimeter','Integra bmwd','Q4104','3','','1','0','','','','0','1','0','0'),
('15690','Integra dermal regeneration template (drt) or integra omnigraft dermal regeneration matrix; per square centimeter','Integra drt or omnigraft','Q4105','3','','1','0','','','','0','1','0','0'),
('15691','Dermagraft; per square centimeter','Dermagraft','Q4106','3','','1','0','','','','0','1','0','0'),
('15692','Graftjacket; per square centimeter','Graftjacket','Q4107','3','','1','0','','','','0','1','0','0'),
('15693','Integra matrix; per square centimeter','Integra matrix','Q4108','3','','1','0','','','','0','1','0','0'),
('15694','Primatrix; per square centimeter','Primatrix','Q4110','3','','1','0','','','','0','1','0','0'),
('15695','Gammagraft; per square centimeter','Gammagraft','Q4111','3','','1','0','','','','0','1','0','0'),
('15696','Cymetra; injectable; 1 cc','Cymetra injectable','Q4112','3','','1','0','','','','0','1','0','0'),
('15697','Graftjacket xpress; injectable; 1 cc','Graftjacket xpress','Q4113','3','','1','0','','','','0','1','0','0'),
('15698','Integra flowable wound matrix; injectable; 1 cc','Integra flowable wound matri','Q4114','3','','1','0','','','','0','1','0','0'),
('15699','Alloskin; per square centimeter','Alloskin','Q4115','3','','1','0','','','','0','1','0','0'),
('15700','Alloderm; per square centimeter','Alloderm','Q4116','3','','1','0','','','','0','1','0','0'),
('15701','Hyalomatrix; per square centimeter','Hyalomatrix','Q4117','3','','1','0','','','','0','1','0','0'),
('15702','Matristem micromatrix; 1 mg','Matristem micromatrix','Q4118','3','','1','0','','','','0','1','0','0'),
('15703','Matristem wound matrix; per square centimeter','Matristem wound matrix','Q4119','3','','1','0','','','','0','1','0','0'),
('15704','Matristem burn matrix; per square centimeter','Matristem burn matrix','Q4120','3','','1','0','','','','0','1','0','0'),
('15705','Theraskin; per square centimeter','Theraskin','Q4121','3','','1','0','','','','0','1','0','0'),
('15706','Dermacell; per square centimeter','Dermacell','Q4122','3','','1','0','','','','0','1','0','0'),
('15707','Alloskin rt; per square centimeter','Alloskin','Q4123','3','','1','0','','','','0','1','0','0'),
('15708','Oasis ultra tri-layer wound matrix; per square centimeter','Oasis tri-layer wound matrix','Q4124','3','','1','0','','','','0','1','0','0'),
('15709','Arthroflex; per square centimeter','Arthroflex','Q4125','3','','1','0','','','','0','1','0','0'),
('15710','Memoderm; dermaspan; tranzgraft or integuply; per square centimeter','Memoderm/derma/tranz/integup','Q4126','3','','1','0','','','','0','1','0','0'),
('15711','Talymed; per square centimeter','Talymed','Q4127','3','','1','0','','','','0','1','0','0'),
('15712','Flex hd; allopatch hd; or matrix hd; per square centimeter','Flexhd/allopatchhd/matrixhd','Q4128','3','','1','0','','','','0','1','0','0'),
('15713','Unite biomatrix; per square centimeter','Unite biomatrix','Q4129','3','','1','0','','','','0','1','0','0'),
('15714','Strattice tm; per square centimeter','Strattice tm','Q4130','3','','1','0','','','','0','1','0','0'),
('15715','Epifix or epicord; per square centimeter','Epifix or epicord','Q4131','3','','1','0','','','','0','1','0','0'),
('15716','Grafix core; per square centimeter','Grafix core','Q4132','3','','1','0','','','','0','1','0','0'),
('15717','Grafix prime; per square centimeter','Grafix prime','Q4133','3','','1','0','','','','0','1','0','0'),
('15718','Hmatrix; per square centimeter','Hmatrix','Q4134','3','','1','0','','','','0','1','0','0'),
('15719','Mediskin; per square centimeter','Mediskin','Q4135','3','','1','0','','','','0','1','0','0'),
('15720','Ez-derm; per square centimeter','Ezderm','Q4136','3','','1','0','','','','0','1','0','0'),
('15721','Amnioexcel or biodexcel; per square centimeter','Amnioexcel or biodexcel; 1cm','Q4137','3','','1','0','','','','0','1','0','0'),
('15722','Biodfence dryflex; per square centimeter','Biodfence dryflex; 1cm','Q4138','3','','1','0','','','','0','1','0','0'),
('15723','Amniomatrix or biodmatrix; injectable; 1 cc','Amnio or biodmatrix; inj 1cc','Q4139','3','','1','0','','','','0','1','0','0'),
('15724','Biodfence; per square centimeter','Biodfence 1cm','Q4140','3','','1','0','','','','0','1','0','0'),
('15725','Alloskin ac; per square centimeter','Alloskin ac; 1 cm','Q4141','3','','1','0','','','','0','1','0','0'),
('15726','Xcm biologic tissue matrix; per square centimeter','Xcm biologic tiss matrix 1cm','Q4142','3','','1','0','','','','0','1','0','0'),
('15727','Repriza; per square centimeter','Repriza; 1cm','Q4143','3','','1','0','','','','0','1','0','0'),
('15728','Epifix; injectable; 1 mg','Epifix; inj; 1mg','Q4145','3','','1','0','','','','0','1','0','0'),
('15729','Tensix; per square centimeter','Tensix; 1cm','Q4146','3','','1','0','','','','0','1','0','0'),
('15730','Architect; architect px; or architect fx; extracellular matrix; per square centimeter','Architect ecm px fx 1 sq cm','Q4147','3','','1','0','','','','0','1','0','0'),
('15731','Neox 1k; per square centimeter','Neox 1k; 1cm','Q4148','3','','1','0','','','','0','1','0','0'),
('15732','Excellagen; 0.1 cc','Excellagen; 0.1 cc','Q4149','3','','1','0','','','','0','1','0','0'),
('15733','Allowrap ds or dry; per square centimeter','Allowrap ds or dry 1 sq cm','Q4150','3','','1','0','','','','0','1','0','0'),
('15734','Amnioband or guardian; per square centimeter','Amnioband; guardian 1 sq cm','Q4151','3','','1','0','','','','0','1','0','0'),
('15735','Dermapure; per square centimeter','Dermapure 1 square cm','Q4152','3','','1','0','','','','0','1','0','0'),
('15736','Dermavest and plurivest; per square centimeter','Dermavest; plurivest sq cm','Q4153','3','','1','0','','','','0','1','0','0'),
('15737','Biovance; per square centimeter','Biovance 1 square cm','Q4154','3','','1','0','','','','0','1','0','0'),
('15738','Neoxflo or clarixflo; 1 mg','Neoxflo or clarixflo 1 mg','Q4155','3','','1','0','','','','0','1','0','0'),
('15739','Neox 100; per square centimeter','Neox 100 1 square cm','Q4156','3','','1','0','','','','0','1','0','0'),
('15740','Revitalon; per square centimeter','Revitalon 1 square cm','Q4157','3','','1','0','','','','0','1','0','0'),
('15741','Marigen; per square centimeter','Marigen 1 square cm','Q4158','3','','1','0','','','','0','1','0','0'),
('15742','Affinity; per square centimeter','Affinity1 square cm','Q4159','3','','1','0','','','','0','1','0','0'),
('15743','Nushield; per square centimeter','Nushield 1 square cm','Q4160','3','','1','0','','','','0','1','0','0'),
('15744','Bio-connekt wound matrix; per square centimeter','Bio-connekt per square cm','Q4161','3','','1','0','','','','0','1','0','0'),
('15745','Amniopro flow; bioskin flow; biorenew flow; woundex flow; amniogen-a; amniogen-c; 0.5 cc','Amnio bio and woundex flow','Q4162','3','','1','0','','','','0','1','0','0'),
('15746','Amniopro; bioskin; biorenew; woundex; amniogen-45; amniogen-200; per square centimeter','Amnio bio and woundex sq cm','Q4163','3','','1','0','','','','0','1','0','0'),
('15747','Helicoll; per square centimeter','Helicoll; per square cm','Q4164','3','','1','0','','','','0','1','0','0'),
('15748','Keramatrix; per square centimeter','Keramatrix; per square cm','Q4165','3','','1','0','','','','0','1','0','0'),
('15749','Cytal; per square centimeter','Cytal; per square centimeter','Q4166','3','','1','0','','','','0','1','0','0'),
('15750','Truskin; per square centimeter','Truskin; per sq centimeter','Q4167','3','','1','0','','','','0','1','0','0'),
('15751','Amnioband; 1 mg','Amnioband; 1 mg','Q4168','3','','1','0','','','','0','1','0','0'),
('15752','Artacent wound; per square centimeter','Artacent wound; per sq cm','Q4169','3','','1','0','','','','0','1','0','0'),
('15753','Cygnus; per square centimeter','Cygnus; per sq cm','Q4170','3','','1','0','','','','0','1','0','0'),
('15754','Interfyl; 1 mg','Interfyl; 1 mg','Q4171','3','','1','0','','','','0','1','0','0'),
('15755','Puraply or puraply am; per square centimeter','Puraply or puraply am','Q4172','3','','1','0','','','','0','1','0','0'),
('15756','Palingen or palingen xplus; per square centimeter','Palingen or palingen xplus','Q4173','3','','1','0','','','','0','1','0','0'),
('15757','Palingen or promatrx; 0.36 mg per 0.25 cc','Palingen or promatrx','Q4174','3','','1','0','','','','0','1','0','0'),
('15758','Miroderm; per square centimeter','Miroderm','Q4175','3','','1','0','','','','0','1','0','0'),
('15759','Hospice or home health care provided in patients home/residence','Hospice or home hlth in home','Q5001','3','','1','0','','','','0','1','0','0'),
('15760','Hospice or home health care provided in assisted living facility','Hospice/home hlth in asst lv','Q5002','3','','1','0','','','','0','1','0','0'),
('15761','Hospice care provided in nursing long term care facility (ltc) or non-skilled nursing facility (nf)','Hospice in lt/non-skilled nf','Q5003','3','','1','0','','','','0','1','0','0'),
('15762','Hospice care provided in skilled nursing facility (snf)','Hospice in snf','Q5004','3','','1','0','','','','0','1','0','0'),
('15763','Hospice care provided in inpatient hospital','Hospice; inpatient hospital','Q5005','3','','1','0','','','','0','1','0','0'),
('15764','Hospice care provided in inpatient hospice facility','Hospice in hospice facility','Q5006','3','','1','0','','','','0','1','0','0'),
('15765','Hospice care provided in long term care facility','Hospice in ltch','Q5007','3','','1','0','','','','0','1','0','0'),
('15766','Hospice care provided in inpatient psychiatric facility','Hospice in inpatient psych','Q5008','3','','1','0','','','','0','1','0','0'),
('15767','Hospice or home health care provided in place not otherwise specified (nos)','Hospice/home hlth; place nos','Q5009','3','','1','0','','','','0','1','0','0'),
('15768','Hospice home care provided in a hospice facility','Hospice home care in hospice','Q5010','3','','1','0','','','','0','1','0','0'),
('15769','Injection; filgrastim (g-csf); biosimilar; 1 microgram','Inj filgrastim gcsf biosimil','Q5101','3','','1','0','','','','0','1','0','0'),
('15770','Injection; infliximab; biosimilar; 10 mg','Inj.; infliximab biosimilar','Q5102','3','','1','0','','','','0','1','0','0'),
('15771','Injection; sulfur hexafluoride lipid microspheres; per ml','Inj sulf hexa lipid microsph','Q9950','3','','1','0','','','','0','1','0','0'),
('15772','Low osmolar contrast material; 400 or greater mg/ml iodine concentration; per ml','Locm >= 400 mg/ml iodine;1ml','Q9951','3','','1','0','','','','0','1','0','0'),
('15773','Injection; iron-based magnetic resonance contrast agent; per ml','Inj fe-based mr contrast;1ml','Q9953','3','','1','0','','','','0','1','0','0'),
('15774','Oral magnetic resonance contrast agent; per 100 ml','Oral mr contrast; 100 ml','Q9954','3','','1','0','','','','0','1','0','0'),
('15775','Injection; perflexane lipid microspheres; per ml','Inj perflexane lip micros;ml','Q9955','3','','1','0','','','','0','1','0','0'),
('15776','Injection; octafluoropropane microspheres; per ml','Inj octafluoropropane mic;ml','Q9956','3','','1','0','','','','0','1','0','0'),
('15777','Injection; perflutren lipid microspheres; per ml','Inj perflutren lip micros;ml','Q9957','3','','1','0','','','','0','1','0','0'),
('15778','High osmolar contrast material; up to 149 mg/ml iodine concentration; per ml','Hocm <=149 mg/ml iodine; 1ml','Q9958','3','','1','0','','','','0','1','0','0'),
('15779','High osmolar contrast material; 150-199 mg/ml iodine concentration; per ml','Hocm 150-199mg/ml iodine;1ml','Q9959','3','','1','0','','','','0','1','0','0'),
('15780','High osmolar contrast material; 200-249 mg/ml iodine concentration; per ml','Hocm 200-249mg/ml iodine;1ml','Q9960','3','','1','0','','','','0','1','0','0'),
('15781','High osmolar contrast material; 250-299 mg/ml iodine concentration; per ml','Hocm 250-299mg/ml iodine;1ml','Q9961','3','','1','0','','','','0','1','0','0'),
('15782','High osmolar contrast material; 300-349 mg/ml iodine concentration; per ml','Hocm 300-349mg/ml iodine;1ml','Q9962','3','','1','0','','','','0','1','0','0'),
('15783','High osmolar contrast material; 350-399 mg/ml iodine concentration; per ml','Hocm 350-399mg/ml iodine;1ml','Q9963','3','','1','0','','','','0','1','0','0'),
('15784','High osmolar contrast material; 400 or greater mg/ml iodine concentration; per ml','Hocm>= 400mg/ml iodine; 1ml','Q9964','3','','1','0','','','','0','1','0','0'),
('15785','Low osmolar contrast material; 100-199 mg/ml iodine concentration; per ml','Locm 100-199mg/ml iodine;1ml','Q9965','3','','1','0','','','','0','1','0','0'),
('15786','Low osmolar contrast material; 200-299 mg/ml iodine concentration; per ml','Locm 200-299mg/ml iodine;1ml','Q9966','3','','1','0','','','','0','1','0','0'),
('15787','Low osmolar contrast material; 300-399 mg/ml iodine concentration; per ml','Locm 300-399mg/ml iodine;1ml','Q9967','3','','1','0','','','','0','1','0','0'),
('15788','Injection; non-radioactive; non-contrast; visualization adjunct (e.g.; methylene blue; isosulfan blue); 1 mg','Visualization adjunct','Q9968','3','','1','0','','','','0','1','0','0'),
('15789','Tc-99m from non-highly enriched uranium source; full cost recovery add-on; per study dose','Non-heu tc-99m add-on/dose','Q9969','3','','1','0','','','','0','1','0','0'),
('15790','Injection; ferric carboxymaltose; 1mg','Inj ferric carboxymaltos 1mg','Q9970','3','','1','0','','','','0','1','0','0'),
('15791','Injection; epoetin beta; 1 microgram; (for esrd on dialysis)','Epoetin beta esrd use','Q9972','3','','1','0','','','','0','1','0','0'),
('15792','Injection; epoetin beta; 1 microgram; (non-esrd use)','Epoetin beta non esrd','Q9973','3','','1','0','','','','0','1','0','0'),
('15793','Injection; morphine sulfate; preservative-free for epidural or intrathecal use; 10 mg','Morphine epidural/intratheca','Q9974','3','','1','0','','','','0','1','0','0'),
('15794','Injection; factor viii fc fusion protein (recombinant); per iu','Factor viii fc fusion recomb','Q9975','3','','1','0','','','','0','1','0','0'),
('15795','Injection; ferric pyrophosphate citrate solution; 0.1 mg of iron','Inj ferric pyrophosphate cit','Q9976','3','','1','0','','','','0','1','0','0'),
('15796','Compounded drug; not otherwise classified','Compounded drug noc','Q9977','3','','1','0','','','','0','1','0','0'),
('15797','Netupitant 300 mg and palonosetron 0.5 mg','Netupitant palonosetron oral','Q9978','3','','1','0','','','','0','1','0','0'),
('15798','Injection; alemtuzumab; 1 mg','Injection; alemtuzumab','Q9979','3','','1','0','','','','0','1','0','0'),
('15799','Hyaluronan or derivative; genvisc 850; for intra-articular injection; 1 mg','Genvisc; inj; 1mg','Q9980','3','','1','0','','','','0','1','0','0'),
('15800','Rolapitant; oral; 1 mg','Rolapitant; oral; 1mg','Q9981','3','','1','0','','','','0','1','0','0'),
('15801','Flutemetamol f18; diagnostic; per study dose; up to 5 millicuries','Flutemetamol f18 diagnostic','Q9982','3','','1','0','','','','0','1','0','0'),
('15802','Florbetaben f18; diagnostic; per study dose; up to 8.1 millicuries','Florbetaben f18 diagnostic','Q9983','3','','1','0','','','','0','1','0','0'),
('15803','Transportation of portable x-ray equipment and personnel to home or nursing home; per trip to facility or location; one patient seen','Transport portable x-ray','R0070','3','','1','0','','','','0','1','0','0'),
('15804','Transportation of portable x-ray equipment and personnel to home or nursing home; per trip to facility or location; more than one patient seen','Transport port x-ray multipl','R0075','3','','1','0','','','','0','1','0','0'),
('15805','Transportation of portable ekg to facility or location; per patient','Transport portable ekg','R0076','3','','1','0','','','','0','1','0','0'),
('15806','Butorphanol tartrate; nasal spray; 25 mg','Butorphanol tartrate; nasal','S0012','3','','1','0','','','','0','1','0','0'),
('15807','Tacrine hydrochloride; 10 mg','Tacrine hydrochloride; 10 mg','S0014','3','','1','0','','','','0','1','0','0'),
('15808','Injection; aminocaproic acid; 5 grams','Injection; aminocaproic acid','S0017','3','','1','0','','','','0','1','0','0'),
('15809','Injection; bupivicaine hydrochloride; 30 ml','Injection; bupivicaine hydro','S0020','3','','1','0','','','','0','1','0','0'),
('15810','Injection; cefoperazone sodium; 1 gram','Injection; cefoperazone sod','S0021','3','','1','0','','','','0','1','0','0'),
('15811','Injection; cimetidine hydrochloride; 300 mg','Injection; cimetidine hydroc','S0023','3','','1','0','','','','0','1','0','0'),
('15812','Injection; famotidine; 20 mg','Injection; famotidine; 20 mg','S0028','3','','1','0','','','','0','1','0','0'),
('15813','Injection; metronidazole; 500 mg','Injection; metronidazole','S0030','3','','1','0','','','','0','1','0','0'),
('15814','Injection; nafcillin sodium; 2 grams','Injection; nafcillin sodium','S0032','3','','1','0','','','','0','1','0','0'),
('15815','Injection; ofloxacin; 400 mg','Injection; ofloxacin; 400 mg','S0034','3','','1','0','','','','0','1','0','0'),
('15816','Injection; sulfamethoxazole and trimethoprim; 10 ml','Injection; sulfamethoxazole','S0039','3','','1','0','','','','0','1','0','0'),
('15817','Injection; ticarcillin disodium and clavulanate potassium; 3.1 grams','Injection; ticarcillin disod','S0040','3','','1','0','','','','0','1','0','0'),
('15818','Injection; aztreonam; 500 mg','Injection; aztreonam; 500 mg','S0073','3','','1','0','','','','0','1','0','0'),
('15819','Injection; cefotetan disodium; 500 mg','Injection; cefotetan disodiu','S0074','3','','1','0','','','','0','1','0','0'),
('15820','Injection; clindamycin phosphate; 300 mg','Injection; clindamycin phosp','S0077','3','','1','0','','','','0','1','0','0'),
('15821','Injection; fosphenytoin sodium; 750 mg','Injection; fosphenytoin sodi','S0078','3','','1','0','','','','0','1','0','0'),
('15822','Injection; pentamidine isethionate; 300 mg','Injection; pentamidine iseth','S0080','3','','1','0','','','','0','1','0','0'),
('15823','Injection; piperacillin sodium; 500 mg','Injection; piperacillin sodi','S0081','3','','1','0','','','','0','1','0','0'),
('15824','Imatinib; 100 mg','Imatinib 100 mg','S0088','3','','1','0','','','','0','1','0','0'),
('15825','Sildenafil citrate; 25 mg','Sildenafil citrate; 25 mg','S0090','3','','1','0','','','','0','1','0','0'),
('15826','Granisetron hydrochloride; 1 mg (for circumstances falling under the medicare statute; use q0166)','Granisetron 1mg','S0091','3','','1','0','','','','0','1','0','0'),
('15827','Injection; hydromorphone hydrochloride; 250 mg (loading dose for infusion pump)','Hydromorphone 250 mg','S0092','3','','1','0','','','','0','1','0','0'),
('15828','Injection; morphine sulfate; 500 mg (loading dose for infusion pump)','Morphine 500 mg','S0093','3','','1','0','','','','0','1','0','0'),
('15829','Zidovudine; oral; 100 mg','Zidovudine; oral; 100 mg','S0104','3','','1','0','','','','0','1','0','0'),
('15830','Bupropion hcl sustained release tablet; 150 mg; per bottle of 60 tablets','Bupropion hcl sr 60 tablets','S0106','3','','1','0','','','','0','1','0','0'),
('15831','Mercaptopurine; oral; 50 mg','Mercaptopurine 50 mg','S0108','3','','1','0','','','','0','1','0','0'),
('15832','Methadone; oral; 5 mg','Methadone oral 5mg','S0109','3','','1','0','','','','0','1','0','0'),
('15833','Tretinoin; topical; 5 grams','Tretinoin topical 5 g','S0117','3','','1','0','','','','0','1','0','0'),
('15834','Ondansetron; oral; 4 mg (for circumstances falling under the medicare statute; use hcpcs q code)','Ondansetron 4 mg','S0119','3','','1','0','','','','0','1','0','0'),
('15835','Injection; menotropins; 75 iu','Inj menotropins 75 iu','S0122','3','','1','0','','','','0','1','0','0'),
('15836','Injection; follitropin alfa; 75 iu','Inj follitropin alfa 75 iu','S0126','3','','1','0','','','','0','1','0','0'),
('15837','Injection; follitropin beta; 75 iu','Inj follitropin beta 75 iu','S0128','3','','1','0','','','','0','1','0','0'),
('15838','Injection; ganirelix acetate; 250 mcg','Inj ganirelix acetat 250 mcg','S0132','3','','1','0','','','','0','1','0','0'),
('15839','Clozapine; 25 mg','Clozapine; 25 mg','S0136','3','','1','0','','','','0','1','0','0'),
('15840','Didanosine (ddi); 25 mg','Didanosine; 25 mg','S0137','3','','1','0','','','','0','1','0','0'),
('15841','Finasteride; 5 mg','Finasteride; 5 mg','S0138','3','','1','0','','','','0','1','0','0'),
('15842','Minoxidil; 10 mg','Minoxidil; 10 mg','S0139','3','','1','0','','','','0','1','0','0'),
('15843','Saquinavir; 200 mg','Saquinavir; 200 mg','S0140','3','','1','0','','','','0','1','0','0'),
('15844','Colistimethate sodium; inhalation solution administered through dme; concentrated form; per mg','Colistimethate inh sol mg','S0142','3','','1','0','','','','0','1','0','0'),
('15845','Injection; propofol; 10 mg','Inj; propofol; 10 mg','S0144','3','','1','0','','','','0','1','0','0'),
('15846','Injection; pegylated interferon alfa-2a; 180 mcg per ml','Peg interferon alfa-2a/180','S0145','3','','1','0','','','','0','1','0','0'),
('15847','Injection; pegylated interferon alfa-2b; 10 mcg','Peg interferon alfa-2b/10','S0148','3','','1','0','','','','0','1','0','0'),
('15848','Sterile dilutant for epoprostenol; 50 ml','Epoprostenol dilutant','S0155','3','','1','0','','','','0','1','0','0'),
('15849','Exemestane; 25 mg','Exemestane; 25 mg','S0156','3','','1','0','','','','0','1','0','0'),
('15850','Becaplermin gel 0.01%; 0.5 gm','Becaplermin gel 1%; 0.5 gm','S0157','3','','1','0','','','','0','1','0','0'),
('15851','Dextroamphetamine sulfate; 5 mg','Dextroamphetamine','S0160','3','','1','0','','','','0','1','0','0'),
('15852','Injection; pantoprazole sodium; 40 mg','Injection pantroprazole','S0164','3','','1','0','','','','0','1','0','0'),
('15853','Injection; olanzapine; 2.5 mg','Inj olanzapine 2.5mg','S0166','3','','1','0','','','','0','1','0','0'),
('15854','Calcitrol; 0.25 microgram','Calcitrol','S0169','3','','1','0','','','','0','1','0','0'),
('15855','Anastrozole; oral; 1 mg','Anastrozole 1 mg','S0170','3','','1','0','','','','0','1','0','0'),
('15856','Injection; bumetanide; 0.5 mg','Bumetanide 0.5 mg','S0171','3','','1','0','','','','0','1','0','0'),
('15857','Chlorambucil; oral; 2 mg','Chlorambucil 2 mg','S0172','3','','1','0','','','','0','1','0','0'),
('15858','Dolasetron mesylate; oral 50 mg (for circumstances falling under the medicare statute; use q0180),','Dolasetron 50 mg','S0174','3','','1','0','','','','0','1','0','0'),
('15859','Flutamide; oral; 125 mg','Flutamide 125 mg','S0175','3','','1','0','','','','0','1','0','0'),
('15860','Hydroxyurea; oral; 500 mg','Hydroxyurea 500 mg','S0176','3','','1','0','','','','0','1','0','0'),
('15861','Levamisole hydrochloride; oral; 50 mg','Levamisole 50 mg','S0177','3','','1','0','','','','0','1','0','0'),
('15862','Lomustine; oral; 10 mg','Lomustine 10 mg','S0178','3','','1','0','','','','0','1','0','0'),
('15863','Megestrol acetate; oral; 20 mg','Megestrol 20 mg','S0179','3','','1','0','','','','0','1','0','0'),
('15864','Procarbazine hydrochloride; oral; 50 mg','Procarbazine; oral','S0182','3','','1','0','','','','0','1','0','0'),
('15865','Prochlorperazine maleate; oral; 5 mg (for circumstances falling under the medicare statute; use q0164)','Prochlorperazine 5 mg','S0183','3','','1','0','','','','0','1','0','0'),
('15866','Tamoxifen citrate; oral; 10 mg','Tamoxifen 10 mg','S0187','3','','1','0','','','','0','1','0','0'),
('15867','Testosterone pellet; 75 mg','Testosterone pellet 75 mg','S0189','3','','1','0','','','','0','1','0','0'),
('15868','Mifepristone; oral; 200 mg','Mifepristone; oral; 200 mg','S0190','3','','1','0','','','','0','1','0','0'),
('15869','Misoprostol; oral; 200 mcg','Misoprostol; oral; 200 mcg','S0191','3','','1','0','','','','0','1','0','0'),
('15870','Dialysis/stress vitamin supplement; oral; 100 capsules','Vitamin suppl 100 caps','S0194','3','','1','0','','','','0','1','0','0'),
('15871','Pneumococcal conjugate vaccine; polyvalent; intramuscular; for children from five years to nine years of age who have not previously received the vaccine','Pneumo vaccine 5-9 yrs','S0195','3','','1','0','','','','0','1','0','0'),
('15872','Prenatal vitamins; 30-day supply','Prenatal vitamins 30 day','S0197','3','','1','0','','','','0','1','0','0'),
('15873','Medically induced abortion by oral ingestion of medication including all associated services and supplies (e.g.; patient counseling; office visits; confirmation of pregnancy by hcg; ultrasound to confirm duration of pregnancy; ultrasound to confirm completion of abortion) except drugs','Med abortion inc all ex drug','S0199','3','','1','0','','','','0','1','0','0'),
('15874','Partial hospitalization services; less than 24 hours; per diem','Partial hospitalization serv','S0201','3','','1','0','','','','0','1','0','0'),
('15875','Paramedic intercept; non-hospital-based als service (non-voluntary); non-transport','Paramedicintercep nonhospals','S0207','3','','1','0','','','','0','1','0','0'),
('15876','Paramedic intercept; hospital-based als service (non-voluntary); non-transport','Paramed intrcept nonvol','S0208','3','','1','0','','','','0','1','0','0'),
('15877','Wheelchair van; mileage; per mile','Wc van mileage per mi','S0209','3','','1','0','','','','0','1','0','0'),
('15878','Non-emergency transportation; mileage; per mile','Nonemerg transp mileage','S0215','3','','1','0','','','','0','1','0','0'),
('15879','Medical conference by a physician with interdisciplinary team of health professionals or representatives of community agencies to coordinate activities of patient care (patient is present); approximately 30 minutes','Medical conference by physic','S0220','3','','1','0','','','','0','1','0','0'),
('15880','Medical conference by a physician with interdisciplinary team of health professionals or representatives of community agencies to coordinate activities of patient care (patient is present); approximately 60 minutes','Medical conference; 60 min','S0221','3','','1','0','','','','0','1','0','0'),
('15881','Comprehensive geriatric assessment and treatment planning performed by assessment team','Comp geriatr assmt team','S0250','3','','1','0','','','','0','1','0','0'),
('15882','Hospice referral visit (advising patient and family of care options) performed by nurse; social worker; or other designated staff','Hospice refer visit nonmd','S0255','3','','1','0','','','','0','1','0','0'),
('15883','Counseling and discussion regarding advance directives or end of life care planning and decisions; with patient and/or surrogate (list separately in addition to code for appropriate evaluation and management service)','End of life counseling','S0257','3','','1','0','','','','0','1','0','0'),
('15884','History and physical (outpatient or office) related to surgical procedure (list separately in addition to code for appropriate evaluation and management service)','H&p for surgery','S0260','3','','1','0','','','','0','1','0','0'),
('15885','Genetic counseling; under physician supervision; each 15 minutes','Genetic counsel 15 mins','S0265','3','','1','0','','','','0','1','0','0'),
('15886','Physician management of patient home care; standard monthly case rate (per 30 days)','Home std case rate 30 days','S0270','3','','1','0','','','','0','1','0','0'),
('15887','Physician management of patient home care; hospice monthly case rate (per 30 days)','Home hospice case 30 days','S0271','3','','1','0','','','','0','1','0','0'),
('15888','Physician management of patient home care; episodic care monthly case rate (per 30 days)','Home episodic case 30 days','S0272','3','','1','0','','','','0','1','0','0'),
('15889','Physician visit at members home; outside of a capitation arrangement','Md home visit outside cap','S0273','3','','1','0','','','','0','1','0','0'),
('15890','Nurse practitioner visit at members home; outside of a capitation arrangement','Nurse practr visit outs cap','S0274','3','','1','0','','','','0','1','0','0'),
('15891','Medical home program; comprehensive care coordination and planning; initial plan','Medical home; initial plan','S0280','3','','1','0','','','','0','1','0','0'),
('15892','Medical home program; comprehensive care coordination and planning; maintenance of plan','Medical home; maintenance','S0281','3','','1','0','','','','0','1','0','0'),
('15893','Colonoscopy consultation performed prior to a screening colonoscopy procedure','Cnslt before screen colonosc','S0285','3','','1','0','','','','0','1','0','0'),
('15894','Completed early periodic screening diagnosis and treatment (epsdt) service (list in addition to code for appropriate evaluation and management service)','Completed epsdt','S0302','3','','1','0','','','','0','1','0','0'),
('15895','Hospitalist services (list separately in addition to code for appropriate evaluation and management service)','Hospitalist visit','S0310','3','','1','0','','','','0','1','0','0'),
('15896','Comprehensive management and care coordination for advanced illness; per calendar month','Comp mgmt care coord adv ill','S0311','3','','1','0','','','','0','1','0','0'),
('15897','Disease management program; initial assessment and initiation of the program','Disease management program','S0315','3','','1','0','','','','0','1','0','0'),
('15898','Disease management program; follow-up/reassessment','Follow-up/reassessment','S0316','3','','1','0','','','','0','1','0','0'),
('15899','Disease management program; per diem','Disease mgmt per diem','S0317','3','','1','0','','','','0','1','0','0'),
('15900','Telephone calls by a registered nurse to a disease management program member for monitoring purposes; per month','Rn telephone calls to dmp','S0320','3','','1','0','','','','0','1','0','0'),
('15901','Lifestyle modification program for management of coronary artery disease; including all supportive services; first quarter / stage','Lifestyle mod 1st stage','S0340','3','','1','0','','','','0','1','0','0'),
('15902','Lifestyle modification program for management of coronary artery disease; including all supportive services; second or third quarter / stage','Lifestyle mod 2 or 3 stage','S0341','3','','1','0','','','','0','1','0','0'),
('15903','Lifestyle modification program for management of coronary artery disease; including all supportive services; fourth quarter / stage','Lifestyle mod 4th stage','S0342','3','','1','0','','','','0','1','0','0'),
('15904','Treatment planning and care coordination management for cancer; initial treatment','Cancer treatmentplan initial','S0353','3','','1','0','','','','0','1','0','0'),
('15905','Treatment planning and care coordination management for cancer; established patient with a change of regimen','Cancer treatment plan change','S0354','3','','1','0','','','','0','1','0','0'),
('15906','Routine foot care; removal and/or trimming of corns; calluses and/or nails and preventive maintenance in specific medical conditions (e.g.; diabetes); per visit','Rout foot care per visit','S0390','3','','1','0','','','','0','1','0','0'),
('15907','Impression casting of a foot performed by a practitioner other than the manufacturer of the orthotic','Impression casting ft','S0395','3','','1','0','','','','0','1','0','0'),
('15908','Global fee for extracorporeal shock wave lithotripsy treatment of kidney stone(s)','Global eswl kidney','S0400','3','','1','0','','','','0','1','0','0'),
('15909','Disposable contact lens; per lens','Dispos cont lens','S0500','3','','1','0','','','','0','1','0','0'),
('15910','Single vision prescription lens (safety; athletic; or sunglass); per lens','Singl prscrp lens','S0504','3','','1','0','','','','0','1','0','0'),
('15911','Bifocal vision prescription lens (safety; athletic; or sunglass); per lens','Bifoc prscp lens','S0506','3','','1','0','','','','0','1','0','0'),
('15912','Trifocal vision prescription lens (safety; athletic; or sunglass); per lens','Trifoc prscrp lens','S0508','3','','1','0','','','','0','1','0','0'),
('15913','Non-prescription lens (safety; athletic; or sunglass); per lens','Non-prscrp lens','S0510','3','','1','0','','','','0','1','0','0'),
('15914','Daily wear specialty contact lens; per lens','Daily cont lens','S0512','3','','1','0','','','','0','1','0','0'),
('15915','Color contact lens; per lens','Color cont lens','S0514','3','','1','0','','','','0','1','0','0'),
('15916','Scleral lens; liquid bandage device; per lens','Scleral lens liquid bandage','S0515','3','','1','0','','','','0','1','0','0'),
('15917','Safety eyeglass frames','Safety frames','S0516','3','','1','0','','','','0','1','0','0'),
('15918','Sunglasses frames','Sunglass frames','S0518','3','','1','0','','','','0','1','0','0'),
('15919','Polycarbonate lens (list this code in addition to the basic code for the lens)','Polycarb lens','S0580','3','','1','0','','','','0','1','0','0'),
('15920','Nonstandard lens (list this code in addition to the basic code for the lens)','Nonstnd lens','S0581','3','','1','0','','','','0','1','0','0'),
('15921','Integral lens service; miscellaneous services reported separately','Misc integral lens serv','S0590','3','','1','0','','','','0','1','0','0'),
('15922','Comprehensive contact lens evaluation','Comp cont lens eval','S0592','3','','1','0','','','','0','1','0','0'),
('15923','Dispensing new spectacle lenses for patient supplied frame','New lenses in pts old frame','S0595','3','','1','0','','','','0','1','0','0'),
('15924','Phakic intraocular lens for correction of refractive error','Phakic iol refractive error','S0596','3','','1','0','','','','0','1','0','0'),
('15925','Screening proctoscopy','Screening proctoscopy','S0601','3','','1','0','','','','0','1','0','0'),
('15926','Annual gynecological examination; new patient','Annual gynecological examina','S0610','3','','1','0','','','','0','1','0','0'),
('15927','Annual gynecological examination; established patient','Annual gynecological examina','S0612','3','','1','0','','','','0','1','0','0'),
('15928','Annual gynecological examination; clinical breast examination without pelvic evaluation','Ann breast exam','S0613','3','','1','0','','','','0','1','0','0'),
('15929','Audiometry for hearing aid evaluation to determine the level and degree of hearing loss','Audiometry for hearing aid','S0618','3','','1','0','','','','0','1','0','0'),
('15930','Routine ophthalmological examination including refraction; new patient','Routine ophthalmological exa','S0620','3','','1','0','','','','0','1','0','0'),
('15931','Routine ophthalmological examination including refraction; established patient','Routine ophthalmological exa','S0621','3','','1','0','','','','0','1','0','0'),
('15932','Physical exam for college; new or established patient (list separately in addition to appropriate evaluation and management code)','Phys exam for college','S0622','3','','1','0','','','','0','1','0','0'),
('15933','Removal of sutures; by a physician other than the physician who originally closed the wound','Removal of sutures','S0630','3','','1','0','','','','0','1','0','0'),
('15934','Laser in situ keratomileusis (lasik)','Laser in situ keratomileusis','S0800','3','','1','0','','','','0','1','0','0'),
('15935','Photorefractive keratectomy (prk)','Photorefractive keratectomy','S0810','3','','1','0','','','','0','1','0','0'),
('15936','Phototherapeutic keratectomy (ptk)','Phototherap keratect','S0812','3','','1','0','','','','0','1','0','0'),
('15937','Deluxe item; patient aware (list in addition to code for basic item)','Deluxe item','S1001','3','','1','0','','','','0','1','0','0'),
('15938','Customized item (list in addition to code for basic item)','Custom item','S1002','3','','1','0','','','','0','1','0','0'),
('15939','Iv tubing extension set','Iv tubing extension set','S1015','3','','1','0','','','','0','1','0','0'),
('15940','Non-pvc (polyvinyl chloride) intravenous administration set; for use with drugs that are not stable in pvc e.g.; paclitaxel','Non-pvc intravenous administ','S1016','3','','1','0','','','','0','1','0','0'),
('15941','Continuous noninvasive glucose monitoring device; purchase (for physician interpretation of data; use cpt code)','Gluc monitor purchase','S1030','3','','1','0','','','','0','1','0','0'),
('15942','Continuous noninvasive glucose monitoring device; rental; including sensor; sensor replacement; and download to monitor (for physician interpretation of data; use cpt code)','Gluc monitor rental','S1031','3','','1','0','','','','0','1','0','0'),
('15943','Artificial pancreas device system (e.g.; low glucose suspend (lgs) feature) including continuous glucose monitor; blood glucose device; insulin pump and computer algorithm that communicates with all of the devices','Art pancreas system','S1034','3','','1','0','','','','0','1','0','0'),
('15944','Sensor; invasive (e.g.; subcutaneous); disposable; for use with artificial pancreas device system','Art pancreas inv disp sensor','S1035','3','','1','0','','','','0','1','0','0'),
('15945','Transmitter; external; for use with artificial pancreas device system','Art pancreas ext transmitter','S1036','3','','1','0','','','','0','1','0','0'),
('15946','Receiver (monitor); external; for use with artificial pancreas device system','Art pancreas ext receiver','S1037','3','','1','0','','','','0','1','0','0'),
('15947','Cranial remolding orthosis; pediatric; rigid; with soft interface material; custom fabricated; includes fitting and adjustment(s)','Cranial remolding orthosis','S1040','3','','1','0','','','','0','1','0','0'),
('15948','Mometasone furoate sinus implant; 370 micrograms','Mometasone sinus implant','S1090','3','','1','0','','','','0','1','0','0'),
('15949','Transplantation of small intestine and liver allografts','Transplantation of small int','S2053','3','','1','0','','','','0','1','0','0'),
('15950','Transplantation of multivisceral organs','Transplantation of multivisc','S2054','3','','1','0','','','','0','1','0','0'),
('15951','Harvesting of donor multivisceral organs; with preparation and maintenance of allografts; from cadaver donor','Harvesting of donor multivis','S2055','3','','1','0','','','','0','1','0','0'),
('15952','Lobar lung transplantation','Lobar lung transplantation','S2060','3','','1','0','','','','0','1','0','0'),
('15953','Donor lobectomy (lung) for transplantation; living donor','Donor lobectomy (lung)','S2061','3','','1','0','','','','0','1','0','0'),
('15954','Simultaneous pancreas kidney transplantation','Simult panc kidn trans','S2065','3','','1','0','','','','0','1','0','0'),
('15955','Breast reconstruction with gluteal artery perforator (gap) flap; including harvesting of the flap; microvascular transfer; closure of donor site and shaping the flap into a breast; unilateral','Breast gap flap reconst','S2066','3','','1','0','','','','0','1','0','0'),
('15956','Breast reconstruction of a single breast with ''stacked'' deep inferior epigastric perforator (diep) flap(s) and/or gluteal artery perforator (gap) flap(s); including harvesting of the flap(s); microvascular transfer; closure of donor site(s) and shaping the flap into a breast; unilateral','Breast ''stacked'' diep/gap','S2067','3','','1','0','','','','0','1','0','0'),
('15957','Breast reconstruction with deep inferior epigastric perforator (diep) flap or superficial inferior epigastric artery (siea) flap; including harvesting of the flap; microvascular transfer; closure of donor site and shaping the flap into a breast; unilateral','Breast diep or siea flap','S2068','3','','1','0','','','','0','1','0','0'),
('15958','Cystourethroscopy; with ureteroscopy and/or pyeloscopy; with endoscopic laser treatment of ureteral calculi (includes ureteral catheterization)','Cysto laser tx ureteral calc','S2070','3','','1','0','','','','0','1','0','0'),
('15959','Laparoscopic esophagomyotomy (heller type)','Lap esophagomyotomy','S2079','3','','1','0','','','','0','1','0','0'),
('15960','Laser-assisted uvulopalatoplasty (laup)','Laup','S2080','3','','1','0','','','','0','1','0','0'),
('15961','Adjustment of gastric band diameter via subcutaneous port by injection or aspiration of saline','Adjustment gastric band','S2083','3','','1','0','','','','0','1','0','0'),
('15962','Transcatheter occlusion or embolization for tumor destruction; percutaneous; any method; using yttrium-90 microspheres','Transcath emboliz microspher','S2095','3','','1','0','','','','0','1','0','0'),
('15963','Islet cell tissue transplant from pancreas; allogeneic','Islet cell tissue transplant','S2102','3','','1','0','','','','0','1','0','0'),
('15964','Adrenal tissue transplant to brain','Adrenal tissue transplant','S2103','3','','1','0','','','','0','1','0','0'),
('15965','Adoptive immunotherapy i.e. development of specific anti-tumor reactivity (e.g.; tumor-infiltrating lymphocyte therapy) per course of treatment','Adoptive immunotherapy','S2107','3','','1','0','','','','0','1','0','0'),
('15966','Arthroscopy; knee; surgical for harvesting of cartilage (chondrocyte cells)','Knee arthroscp harv','S2112','3','','1','0','','','','0','1','0','0'),
('15967','Osteotomy; periacetabular; with internal fixation','Periacetabular osteotomy','S2115','3','','1','0','','','','0','1','0','0'),
('15968','Arthroereisis; subtalar','Arthroereisis; subtalar','S2117','3','','1','0','','','','0','1','0','0'),
('15969','Metal-on-metal total hip resurfacing; including acetabular and femoral components','Total hip resurfacing','S2118','3','','1','0','','','','0','1','0','0'),
('15970','Low density lipoprotein (ldl) apheresis using heparin-induced extracorporeal ldl precipitation','Low density lipoprotein(ldl)','S2120','3','','1','0','','','','0','1','0','0'),
('15971','Cord blood harvesting for transplantation; allogeneic','Cord blood harvesting','S2140','3','','1','0','','','','0','1','0','0'),
('15972','Cord blood-derived stem-cell transplantation; allogeneic','Cord blood-derived stem-cell','S2142','3','','1','0','','','','0','1','0','0'),
('15973','Bone marrow or blood-derived stem cells (peripheral or umbilical); allogeneic or autologous; harvesting; transplantation; and related complications; including: pheresis and cell preparation/storage; marrow ablative therapy; drugs; supplies; hospitalization with outpatient follow-up; medical/surgical; diagnostic; emergency; and rehabilitative services; and the number of days of pre-and post-transplant care in the global definition','Bmt harv/transpl 28d pkg','S2150','3','','1','0','','','','0','1','0','0'),
('15974','Solid organ(s); complete or segmental; single organ or combination of organs; deceased or living donor(s); procurement; transplantation; and related complications; including: drugs; supplies; hospitalization with outpatient follow-up; medical/surgical; diagnostic; emergency; and rehabilitative services; and the number of days of pre- and post-transplant care in the global definition','Solid organ transpl pkg','S2152','3','','1','0','','','','0','1','0','0'),
('15975','Echosclerotherapy','Echosclerotherapy','S2202','3','','1','0','','','','0','1','0','0'),
('15976','Minimally invasive direct coronary artery bypass surgery involving mini-thoracotomy or mini-sternotomy surgery; performed under direct vision; using arterial graft(s); single coronary arterial graft','Minimally invasive direct co','S2205','3','','1','0','','','','0','1','0','0'),
('15977','Minimally invasive direct coronary artery bypass surgery involving mini-thoracotomy or mini-sternotomy surgery; performed under direct vision; using arterial graft(s); two coronary arterial grafts','Minimally invasive direct co','S2206','3','','1','0','','','','0','1','0','0'),
('15978','Minimally invasive direct coronary artery bypass surgery involving mini-thoracotomy or mini-sternotomy surgery; performed under direct vision; using venous graft only; single coronary venous graft','Minimally invasive direct co','S2207','3','','1','0','','','','0','1','0','0'),
('15979','Minimally invasive direct coronary artery bypass surgery involving mini-thoracotomy or mini-sternotomy surgery; performed under direct vision; using single arterial and venous graft(s); single venous graft','Minimally invasive direct co','S2208','3','','1','0','','','','0','1','0','0'),
('15980','Minimally invasive direct coronary artery bypass surgery involving mini-thoracotomy or mini-sternotomy surgery; performed under direct vision; using two arterial grafts and single venous graft','Minimally invasive direct co','S2209','3','','1','0','','','','0','1','0','0'),
('15981','Myringotomy; laser-assisted','Myringotomy laser-assist','S2225','3','','1','0','','','','0','1','0','0'),
('15982','Implantation of magnetic component of semi-implantable hearing device on ossicles in middle ear','Implant semi-imp hear','S2230','3','','1','0','','','','0','1','0','0'),
('15983','Implantation of auditory brain stem implant','Implant auditory brain imp','S2235','3','','1','0','','','','0','1','0','0'),
('15984','Induced abortion; 17 to 24 weeks','Induced abortion 17-24 weeks','S2260','3','','1','0','','','','0','1','0','0'),
('15985','Induced abortion; 25 to 28 weeks','Induced abortion 25-28 wks','S2265','3','','1','0','','','','0','1','0','0'),
('15986','Induced abortion; 29 to 31 weeks','Induced abortion 29-31 wks','S2266','3','','1','0','','','','0','1','0','0'),
('15987','Induced abortion; 32 weeks or greater','Induced abortion 32 or more','S2267','3','','1','0','','','','0','1','0','0'),
('15988','Arthroscopy; shoulder; surgical; with thermally-induced capsulorrhaphy','Arthroscopy; shoulder; surgi','S2300','3','','1','0','','','','0','1','0','0'),
('15989','Hip core decompression','Hip core decompression','S2325','3','','1','0','','','','0','1','0','0'),
('15990','Chemodenervation of abductor muscle(s) of vocal cord','Chemodenervation of abductor','S2340','3','','1','0','','','','0','1','0','0'),
('15991','Chemodenervation of adductor muscle(s) of vocal cord','Chemodenerv adduct vocal','S2341','3','','1','0','','','','0','1','0','0'),
('15992','Nasal endoscopy for post-operative debridement following functional endoscopic sinus surgery; nasal and/or sinus cavity(s); unilateral or bilateral','Nasal endoscop po debrid','S2342','3','','1','0','','','','0','1','0','0'),
('15993','Decompression procedure; percutaneous; of nucleus pulposus of intervertebral disc; using radiofrequency energy; single or multiple levels; lumbar','Decompress disc rf lumbar','S2348','3','','1','0','','','','0','1','0','0'),
('15994','Diskectomy; anterior; with decompression of spinal cord and/or nerve root(s); including osteophytectomy; lumbar; single interspace','Diskectomy; anterior; with d','S2350','3','','1','0','','','','0','1','0','0'),
('15995','Diskectomy; anterior; with decompression of spinal cord and/or nerve root(s); including osteophytectomy; lumbar; each additional interspace (list separately in addition to code for primary procedure)','Diskectomy; anterior; with d','S2351','3','','1','0','','','','0','1','0','0'),
('15996','Percutaneous vertebroplasty; one vertebral body; unilateral or bilateral injection; cervical','Vertebroplast cerv 1st','S2360','3','','1','0','','','','0','1','0','0'),
('15997','Each additional cervical vertebral body (list separately in addition to code for primary procedure)','Vertebroplast cerv addl','S2361','3','','1','0','','','','0','1','0','0'),
('15998','Repair; congenital diaphragmatic hernia in the fetus using temporary tracheal occlusion; procedure performed in utero','Fetal surg congen hernia','S2400','3','','1','0','','','','0','1','0','0'),
('15999','Repair; urinary tract obstruction in the fetus; procedure performed in utero','Fetal surg urin trac obstr','S2401','3','','1','0','','','','0','1','0','0'),
('16000','Repair; congenital cystic adenomatoid malformation in the fetus; procedure performed in utero','Fetal surg cong cyst malf','S2402','3','','1','0','','','','0','1','0','0'),
('16001','Repair; extralobar pulmonary sequestration in the fetus; procedure performed in utero','Fetal surg pulmon sequest','S2403','3','','1','0','','','','0','1','0','0'),
('16002','Repair; myelomeningocele in the fetus; procedure performed in utero','Fetal surg myelomeningo','S2404','3','','1','0','','','','0','1','0','0'),
('16003','Repair of sacrococcygeal teratoma in the fetus; procedure performed in utero','Fetal surg sacrococ teratoma','S2405','3','','1','0','','','','0','1','0','0'),
('16004','Repair; congenital malformation of fetus; procedure performed in utero; not otherwise classified','Fetal surg noc','S2409','3','','1','0','','','','0','1','0','0'),
('16005','Fetoscopic laser therapy for treatment of twin-to-twin transfusion syndrome','Fetoscop laser ther ttts','S2411','3','','1','0','','','','0','1','0','0'),
('16006','Surgical techniques requiring use of robotic surgical system (list separately in addition to code for primary procedure)','Robotic surgical system','S2900','3','','1','0','','','','0','1','0','0'),
('16007','Diabetic indicator; retinal eye exam; dilated; bilateral','Bilat dil retinal exam','S3000','3','','1','0','','','','0','1','0','0'),
('16008','Performance measurement; evaluation of patient self assessment; depression','Eval self-assess depression','S3005','3','','1','0','','','','0','1','0','0'),
('16009','Stat laboratory request (situations other than s3601)','Stat lab','S3600','3','','1','0','','','','0','1','0','0'),
('16010','Emergency stat laboratory charge for patient who is homebound or residing in a nursing facility','Stat lab home/nf','S3601','3','','1','0','','','','0','1','0','0'),
('16011','Newborn metabolic screening panel; includes test kit; postage and the laboratory tests specified by the state for inclusion in this panel (e.g.; galactose; hemoglobin; electrophoresis;  hydroxyprogesterone; 17-d; phenylalanine (pku); and thyroxine; total)','Newborn metabolic screening','S3620','3','','1','0','','','','0','1','0','0'),
('16012','Maternal serum triple marker screen including alpha-fetoprotein (afp); estriol; and human chorionic gonadotropin (hcg)','Maternal triple screen test','S3625','3','','1','0','','','','0','1','0','0'),
('16013','Maternal serum quadruple marker screen including alpha-fetoprotein (afp); estriol; human chorionic gonadotropin (hcg) and inhibin a','Maternal serum quad screen','S3626','3','','1','0','','','','0','1','0','0'),
('16014','Eosinophil count; blood; direct','Eosinophil blood count','S3630','3','','1','0','','','','0','1','0','0'),
('16015','Hiv-1 antibody testing of oral mucosal transudate','Hiv-1 antibody testing of or','S3645','3','','1','0','','','','0','1','0','0'),
('16016','Saliva test; hormone level; during menopause','Saliva test; hormone level;','S3650','3','','1','0','','','','0','1','0','0'),
('16017','Saliva test; hormone level; to assess preterm labor risk','Saliva test; hormone level;','S3652','3','','1','0','','','','0','1','0','0'),
('16018','Antisperm antibodies test (immunobead)','Antisperm antibodies test','S3655','3','','1','0','','','','0','1','0','0'),
('16019','Gastrointestinal fat absorption study','Gastrointestinal fat absorpt','S3708','3','','1','0','','','','0','1','0','0'),
('16020','Prostate cancer antigen 3 (pca3) testing','Pca3 testing','S3721','3','','1','0','','','','0','1','0','0'),
('16021','Dose optimization by area under the curve (auc) analysis; for infusional 5-fluorouracil','Dose optimization auc - 5fu','S3722','3','','1','0','','','','0','1','0','0'),
('16022','Genetic testing for amyotrophic lateral sclerosis (als)','Genetic testing als','S3800','3','','1','0','','','','0','1','0','0'),
('16023','Complete apc gene sequence analysis for susceptibility to familial adenomatous polyposis (fap) and attenuated fap','Comp apc sequence','S3833','3','','1','0','','','','0','1','0','0'),
('16024','Single-mutation analysis (in individual with a known apc mutation in the family) for susceptibility to familial adenomatous polyposis (fap) and attenuated fap','Sing mutation apc','S3834','3','','1','0','','','','0','1','0','0'),
('16025','Dna analysis for germline mutations of the ret proto-oncogene for susceptibility to multiple endocrine neoplasia type 2','Dna analysis ret-oncogene','S3840','3','','1','0','','','','0','1','0','0'),
('16026','Genetic testing for retinoblastoma','Gene test retinoblastoma','S3841','3','','1','0','','','','0','1','0','0'),
('16027','Genetic testing for von hippel-lindau disease','Gene test hippel-lindau','S3842','3','','1','0','','','','0','1','0','0'),
('16028','Dna analysis of the connexin 26 gene (gjb2) for susceptibility to congenital; profound deafness','Dna analysis deafness','S3844','3','','1','0','','','','0','1','0','0'),
('16029','Genetic testing for alpha-thalassemia','Gene test alpha-thalassemia','S3845','3','','1','0','','','','0','1','0','0'),
('16030','Genetic testing for hemoglobin e beta-thalassemia','Gene test beta-thalassemia','S3846','3','','1','0','','','','0','1','0','0'),
('16031','Genetic testing for niemann-pick disease','Gene test niemann-pick','S3849','3','','1','0','','','','0','1','0','0'),
('16032','Genetic testing for sickle cell anemia','Gene test sickle cell','S3850','3','','1','0','','','','0','1','0','0'),
('16033','Dna analysis for apoe epsilon 4 allele for susceptibility to alzheimers disease','Dna analysis apoe alzheimer','S3852','3','','1','0','','','','0','1','0','0'),
('16034','Genetic testing for myotonic muscular dystrophy','Gene test myo musclr dyst','S3853','3','','1','0','','','','0','1','0','0'),
('16035','Gene expression profiling panel for use in the management of breast cancer treatment','Gene profile panel breast','S3854','3','','1','0','','','','0','1','0','0'),
('16036','Genetic testing for detection of mutations in the presenilin - 1 gene','Gene test presenilin-1 gene','S3855','3','','1','0','','','','0','1','0','0'),
('16037','Genetic testing; sodium channel; voltage-gated; type v; alpha subunit (scn5a) and variants for suspected brugada syndrome','Genetic test brugada','S3861','3','','1','0','','','','0','1','0','0'),
('16038','Comprehensive gene sequence analysis for hypertrophic cardiomyopathy','Comp genet test hyp cardiomy','S3865','3','','1','0','','','','0','1','0','0'),
('16039','Genetic analysis for a specific gene mutation for hypertrophic cardiomyopathy (hcm) in an individual with a known hcm mutation in the family','Spec gene test hyp cardiomy','S3866','3','','1','0','','','','0','1','0','0'),
('16040','Comparative genomic hybridization (cgh) microarray testing for developmental delay; autism spectrum disorder and/or intellectual disability','Cgh test developmental delay','S3870','3','','1','0','','','','0','1','0','0'),
('16041','Dna analysis; fecal; for colorectal cancer screening','Fecal dna analysis','S3890','3','','1','0','','','','0','1','0','0'),
('16042','Surface electromyography (emg)','Surface emg','S3900','3','','1','0','','','','0','1','0','0'),
('16043','Ballistocardiogram','Ballistocardiogram','S3902','3','','1','0','','','','0','1','0','0'),
('16044','Masters two step','Masters two step','S3904','3','','1','0','','','','0','1','0','0'),
('16045','Interim labor facility global (labor occurring but not resulting in delivery)','Interim labor facility globa','S4005','3','','1','0','','','','0','1','0','0'),
('16046','In vitro fertilization; including but not limited to identification and incubation of mature oocytes; fertilization with sperm; incubation of embryo(s); and subsequent visualization for determination of development','Ivf package','S4011','3','','1','0','','','','0','1','0','0'),
('16047','Complete cycle; gamete intrafallopian transfer (gift); case rate','Compl gift case rate','S4013','3','','1','0','','','','0','1','0','0'),
('16048','Complete cycle; zygote intrafallopian transfer (zift); case rate','Compl zift case rate','S4014','3','','1','0','','','','0','1','0','0'),
('16049','Complete in vitro fertilization cycle; not otherwise specified; case rate','Complete ivf nos case rate','S4015','3','','1','0','','','','0','1','0','0'),
('16050','Frozen in vitro fertilization cycle; case rate','Frozen ivf case rate','S4016','3','','1','0','','','','0','1','0','0'),
('16051','Incomplete cycle; treatment cancelled prior to stimulation; case rate','Ivf canc a stim case rate','S4017','3','','1','0','','','','0','1','0','0'),
('16052','Frozen embryo transfer procedure cancelled before transfer; case rate','F emb trns canc case rate','S4018','3','','1','0','','','','0','1','0','0'),
('16053','In vitro fertilization procedure cancelled before aspiration; case rate','Ivf canc a aspir case rate','S4020','3','','1','0','','','','0','1','0','0'),
('16054','In vitro fertilization procedure cancelled after aspiration; case rate','Ivf canc p aspir case rate','S4021','3','','1','0','','','','0','1','0','0'),
('16055','Assisted oocyte fertilization; case rate','Asst oocyte fert case rate','S4022','3','','1','0','','','','0','1','0','0'),
('16056','Donor egg cycle; incomplete; case rate','Incompl donor egg case rate','S4023','3','','1','0','','','','0','1','0','0'),
('16057','Donor services for in vitro fertilization (sperm or embryo); case rate','Donor serv ivf case rate','S4025','3','','1','0','','','','0','1','0','0'),
('16058','Procurement of donor sperm from sperm bank','Procure donor sperm','S4026','3','','1','0','','','','0','1','0','0'),
('16059','Storage of previously frozen embryos','Store prev froz embryos','S4027','3','','1','0','','','','0','1','0','0'),
('16060','Microsurgical epididymal sperm aspiration (mesa)','Microsurg epi sperm asp','S4028','3','','1','0','','','','0','1','0','0'),
('16061','Sperm procurement and cryopreservation services; initial visit','Sperm procure init visit','S4030','3','','1','0','','','','0','1','0','0'),
('16062','Sperm procurement and cryopreservation services; subsequent visit','Sperm procure subs visit','S4031','3','','1','0','','','','0','1','0','0'),
('16063','Stimulated intrauterine insemination (iui); case rate','Stimulated iui case rate','S4035','3','','1','0','','','','0','1','0','0'),
('16064','Cryopreserved embryo transfer; case rate','Cryo embryo transf case rate','S4037','3','','1','0','','','','0','1','0','0'),
('16065','Monitoring and storage of cryopreserved embryos; per 30 days','Monit store cryo embryo 30 d','S4040','3','','1','0','','','','0','1','0','0'),
('16066','Management of ovulation induction (interpretation of diagnostic tests and studies; non-face-to-face medical management of the patient); per cycle','Ovulation mgmt per cycle','S4042','3','','1','0','','','','0','1','0','0'),
('16067','Insertion of levonorgestrel-releasing intrauterine system','Insert levonorgestrel ius','S4981','3','','1','0','','','','0','1','0','0'),
('16068','Contraceptive intrauterine device (e.g.; progestacert iud); including implants and supplies','Contracept iud','S4989','3','','1','0','','','','0','1','0','0'),
('16069','Nicotine patches; legend','Nicotine patch legend','S4990','3','','1','0','','','','0','1','0','0'),
('16070','Nicotine patches; non-legend','Nicotine patch nonlegend','S4991','3','','1','0','','','','0','1','0','0'),
('16071','Contraceptive pills for birth control','Contraceptive pills for bc','S4993','3','','1','0','','','','0','1','0','0'),
('16072','Smoking cessation gum','Smoking cessation gum','S4995','3','','1','0','','','','0','1','0','0'),
('16073','Prescription drug; generic','Prescription drug; generic','S5000','3','','1','0','','','','0','1','0','0'),
('16074','Prescription drug; brand name','Prescription drug;brand name','S5001','3','','1','0','','','','0','1','0','0'),
('16075','5% dextrose and 0.45% normal saline; 1000 ml','5% dextrose and 0.45% saline','S5010','3','','1','0','','','','0','1','0','0'),
('16076','5% dextrose in lactated ringers; 1000 ml','5% dextrose in lactated ring','S5011','3','','1','0','','','','0','1','0','0'),
('16077','5% dextrose with potassium chloride; 1000 ml','5% dextrose with potassium','S5012','3','','1','0','','','','0','1','0','0'),
('16078','5% dextrose/0.45% normal saline with potassium chloride and magnesium sulfate; 1000 ml','5%dextrose/0.45%saline1000ml','S5013','3','','1','0','','','','0','1','0','0'),
('16079','5% dextrose/0.45% normal saline with potassium chloride and magnesium sulfate; 1500 ml','D5w/0.45ns w kcl and mgs04','S5014','3','','1','0','','','','0','1','0','0'),
('16080','Home infusion therapy; routine service of infusion device (e.g.; pump maintenance)','Hit routine device maint','S5035','3','','1','0','','','','0','1','0','0'),
('16081','Home infusion therapy; repair of infusion device (e.g.; pump repair)','Hit device repair','S5036','3','','1','0','','','','0','1','0','0'),
('16082','Day care services; adult; per 15 minutes','Adult daycare services 15min','S5100','3','','1','0','','','','0','1','0','0'),
('16083','Day care services; adult; per half day','Adult day care per half day','S5101','3','','1','0','','','','0','1','0','0'),
('16084','Day care services; adult; per diem','Adult day care per diem','S5102','3','','1','0','','','','0','1','0','0'),
('16085','Day care services; center-based; services not included in program fee; per diem','Centerbased day care perdiem','S5105','3','','1','0','','','','0','1','0','0'),
('16086','Home care training to home care client; per 15 minutes','Homecare train pt 15 min','S5108','3','','1','0','','','','0','1','0','0'),
('16087','Home care training to home care client; per session','Homecare train pt session','S5109','3','','1','0','','','','0','1','0','0'),
('16088','Home care training; family; per 15 minutes','Family homecare training 15m','S5110','3','','1','0','','','','0','1','0','0'),
('16089','Home care training; family; per session','Family homecare train/sessio','S5111','3','','1','0','','','','0','1','0','0'),
('16090','Home care training; non-family; per 15 minutes','Nonfamily homecare train/15m','S5115','3','','1','0','','','','0','1','0','0'),
('16091','Home care training; non-family; per session','Nonfamily hc train/session','S5116','3','','1','0','','','','0','1','0','0'),
('16092','Chore services; per 15 minutes','Chore services per 15 min','S5120','3','','1','0','','','','0','1','0','0'),
('16093','Chore services; per diem','Chore services per diem','S5121','3','','1','0','','','','0','1','0','0'),
('16094','Attendant care services; per 15 minutes','Attendant care service /15m','S5125','3','','1','0','','','','0','1','0','0'),
('16095','Attendant care services; per diem','Attendant care service /diem','S5126','3','','1','0','','','','0','1','0','0'),
('16096','Homemaker service; nos; per 15 minutes','Homaker service nos per 15m','S5130','3','','1','0','','','','0','1','0','0'),
('16097','Homemaker service; nos; per diem','Homemaker service nos /diem','S5131','3','','1','0','','','','0','1','0','0'),
('16098','Companion care; adult (e.g.; iadl/adl); per 15 minutes','Adult companioncare per 15m','S5135','3','','1','0','','','','0','1','0','0'),
('16099','Companion care; adult (e.g.; iadl/adl); per diem','Adult companioncare per diem','S5136','3','','1','0','','','','0','1','0','0'),
('16100','Foster care; adult; per diem','Adult foster care per diem','S5140','3','','1','0','','','','0','1','0','0'),
('16101','Foster care; adult; per month','Adult foster care per month','S5141','3','','1','0','','','','0','1','0','0'),
('16102','Foster care; therapeutic; child; per diem','Child fostercare th per diem','S5145','3','','1','0','','','','0','1','0','0'),
('16103','Foster care; therapeutic; child; per month','Ther fostercare child /month','S5146','3','','1','0','','','','0','1','0','0'),
('16104','Unskilled respite care; not hospice; per 15 minutes','Unskilled respite care /15m','S5150','3','','1','0','','','','0','1','0','0'),
('16105','Unskilled respite care; not hospice; per diem','Unskilled respitecare /diem','S5151','3','','1','0','','','','0','1','0','0'),
('16106','Emergency response system; installation and testing','Emer response sys instal&tst','S5160','3','','1','0','','','','0','1','0','0'),
('16107','Emergency response system; service fee; per month (excludes installation and testing)','Emer rspns sys serv permonth','S5161','3','','1','0','','','','0','1','0','0'),
('16108','Emergency response system; purchase only','Emer rspns system purchase','S5162','3','','1','0','','','','0','1','0','0'),
('16109','Home modifications; per service','Home modifications per serv','S5165','3','','1','0','','','','0','1','0','0'),
('16110','Home delivered meals; including preparation; per meal','Homedelivered prepared meal','S5170','3','','1','0','','','','0','1','0','0'),
('16111','Laundry service; external; professional; per order','Laundry serv;ext;prof;/order','S5175','3','','1','0','','','','0','1','0','0'),
('16112','Home health respiratory therapy; initial evaluation','Hh respiratory thrpy in eval','S5180','3','','1','0','','','','0','1','0','0'),
('16113','Home health respiratory therapy; nos; per diem','Hh respiratory thrpy nos/day','S5181','3','','1','0','','','','0','1','0','0'),
('16114','Medication reminder service; non-face-to-face; per month','Med reminder serv per month','S5185','3','','1','0','','','','0','1','0','0'),
('16115','Wellness assessment; performed by non-physician','Wellness assessment by nonph','S5190','3','','1','0','','','','0','1','0','0'),
('16116','Personal care item; nos; each','Personal care item nos each','S5199','3','','1','0','','','','0','1','0','0'),
('16117','Home infusion therapy; catheter care / maintenance; not otherwise classified; includes administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit cath care noc','S5497','3','','1','0','','','','0','1','0','0'),
('16118','Home infusion therapy; catheter care / maintenance; simple (single lumen); includes administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment; (drugs and nursing visits coded separately); per diem','Hit simple cath care','S5498','3','','1','0','','','','0','1','0','0'),
('16119','Home infusion therapy; catheter care / maintenance; complex (more than one lumen); includes administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit complex cath care','S5501','3','','1','0','','','','0','1','0','0'),
('16120','Home infusion therapy; catheter care / maintenance; implanted access device; includes administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment; (drugs and nursing visits coded separately); per diem (use this code for interim maintenance of vascular access not currently in use)','Hit interim cath care','S5502','3','','1','0','','','','0','1','0','0'),
('16121','Home infusion therapy; all supplies necessary for restoration of catheter patency or declotting','Hit declotting kit','S5517','3','','1','0','','','','0','1','0','0'),
('16122','Home infusion therapy; all supplies necessary for catheter repair','Hit cath repair kit','S5518','3','','1','0','','','','0','1','0','0'),
('16123','Home infusion therapy; all supplies (including catheter) necessary for a peripherally inserted central venous catheter (picc) line insertion','Hit picc insert kit','S5520','3','','1','0','','','','0','1','0','0'),
('16124','Home infusion therapy; all supplies (including catheter) necessary for a midline catheter insertion','Hit midline cath insert kit','S5521','3','','1','0','','','','0','1','0','0'),
('16125','Home infusion therapy; insertion of peripherally inserted central venous catheter (picc); nursing services only (no supplies or catheter included)','Hit picc insert no supp','S5522','3','','1','0','','','','0','1','0','0'),
('16126','Home infusion therapy; insertion of midline venous catheter; nursing services only (no supplies or catheter included)','Hip midline cath insert kit','S5523','3','','1','0','','','','0','1','0','0'),
('16127','Insulin; rapid onset; 5 units','Insulin rapid 5 u','S5550','3','','1','0','','','','0','1','0','0'),
('16128','Insulin; most rapid onset (lispro or aspart); 5 units','Insulin most rapid 5 u','S5551','3','','1','0','','','','0','1','0','0'),
('16129','Insulin; intermediate acting (nph or lente); 5 units','Insulin intermed 5 u','S5552','3','','1','0','','','','0','1','0','0'),
('16130','Insulin; long acting; 5 units','Insulin long acting 5 u','S5553','3','','1','0','','','','0','1','0','0'),
('16131','Insulin delivery device; reusable pen; 1.5 ml size','Insulin reuse pen 1.5 ml','S5560','3','','1','0','','','','0','1','0','0'),
('16132','Insulin delivery device; reusable pen; 3 ml size','Insulin reuse pen 3 ml','S5561','3','','1','0','','','','0','1','0','0'),
('16133','Insulin cartridge for use in insulin delivery device other than pump; 150 units','Insulin cartridge 150 u','S5565','3','','1','0','','','','0','1','0','0'),
('16134','Insulin cartridge for use in insulin delivery device other than pump; 300 units','Insulin cartridge 300 u','S5566','3','','1','0','','','','0','1','0','0'),
('16135','Insulin delivery device; disposable pen (including insulin); 1.5 ml size','Insulin dispos pen 1.5 ml','S5570','3','','1','0','','','','0','1','0','0'),
('16136','Insulin delivery device; disposable pen (including insulin); 3 ml size','Insulin dispos pen 3 ml','S5571','3','','1','0','','','','0','1','0','0'),
('16137','Scleral application of tantalum ring(s) for localization of lesions for proton beam therapy','Tantalum ring application','S8030','3','','1','0','','','','0','1','0','0'),
('16138','Low-dose computed tomography for lung cancer screening','Low dose ct lung screening','S8032','3','','1','0','','','','0','1','0','0'),
('16139','Magnetic source imaging','Magnetic source imaging','S8035','3','','1','0','','','','0','1','0','0'),
('16140','Magnetic resonance cholangiopancreatography (mrcp)','Mrcp','S8037','3','','1','0','','','','0','1','0','0'),
('16141','Topographic brain mapping','Topographic brain mapping','S8040','3','','1','0','','','','0','1','0','0'),
('16142','Magnetic resonance imaging (mri); low-field','Mri low field','S8042','3','','1','0','','','','0','1','0','0'),
('16143','Ultrasound guidance for multifetal pregnancy reduction(s); technical component (only to be used when the physician doing the reduction procedure does not perform the ultrasound; guidance is included in the cpt code for multifetal pregnancy reduction - 59866)','Us guidance fetal reduct','S8055','3','','1','0','','','','0','1','0','0'),
('16144','Scintimammography (radioimmunoscintigraphy of the breast); unilateral; including supply of radiopharmaceutical','Scintimammography','S8080','3','','1','0','','','','0','1','0','0'),
('16145','Fluorine-18 fluorodeoxyglucose (f-18 fdg) imaging using dual-head coincidence detection system (non-dedicated pet scan)','Fluorine-18 fluorodeoxygluco','S8085','3','','1','0','','','','0','1','0','0'),
('16146','Electron beam computed tomography (also known as ultrafast ct; cine ct)','Electron beam computed tomog','S8092','3','','1','0','','','','0','1','0','0'),
('16147','Portable peak flow meter','Portable peak flow meter','S8096','3','','1','0','','','','0','1','0','0'),
('16148','Asthma kit (including but not limited to portable peak expiratory flow meter; instructional video; brochure; and/or spacer)','Asthma kit','S8097','3','','1','0','','','','0','1','0','0'),
('16149','Holding chamber or spacer for use with an inhaler or nebulizer; without mask','Spacer without mask','S8100','3','','1','0','','','','0','1','0','0'),
('16150','Holding chamber or spacer for use with an inhaler or nebulizer; with mask','Spacer with mask','S8101','3','','1','0','','','','0','1','0','0'),
('16151','Peak expiratory flow rate (physician services)','Peak expiratory flow rate (p','S8110','3','','1','0','','','','0','1','0','0'),
('16152','Oxygen contents; gaseous; 1 unit equals 1 cubic foot','O2 contents gas cubic ft','S8120','3','','1','0','','','','0','1','0','0'),
('16153','Oxygen contents; liquid; 1 unit equals 1 pound','O2 contents liquid lb','S8121','3','','1','0','','','','0','1','0','0'),
('16154','Interferential current stimulator; 2 channel','Interferential stim 2 chan','S8130','3','','1','0','','','','0','1','0','0'),
('16155','Interferential current stimulator; 4 channel','Interferential stim 4 chan','S8131','3','','1','0','','','','0','1','0','0'),
('16156','Flutter device','Flutter device','S8185','3','','1','0','','','','0','1','0','0'),
('16157','Swivel adapter','Swivel adaptor','S8186','3','','1','0','','','','0','1','0','0'),
('16158','Tracheostomy supply; not otherwise classified','Trach supply noc','S8189','3','','1','0','','','','0','1','0','0'),
('16159','Mucus trap','Mucus trap','S8210','3','','1','0','','','','0','1','0','0'),
('16160','Mandibular orthopedic repositioning device; each','Mandib ortho repos device','S8262','3','','1','0','','','','0','1','0','0'),
('16161','Haberman feeder for cleft lip/palate','Haberman feeder','S8265','3','','1','0','','','','0','1','0','0'),
('16162','Enuresis alarm; using auditory buzzer and/or vibration device','Enuresis alarm','S8270','3','','1','0','','','','0','1','0','0'),
('16163','Infection control supplies; not otherwise specified','Infect control supplies nos','S8301','3','','1','0','','','','0','1','0','0'),
('16164','Supplies for home delivery of infant','Supplies for home delivery','S8415','3','','1','0','','','','0','1','0','0'),
('16165','Gradient pressure aid (sleeve and glove combination); custom made','Custom gradient sleev/glov','S8420','3','','1','0','','','','0','1','0','0'),
('16166','Gradient pressure aid (sleeve and glove combination); ready made','Ready gradient sleev/glov','S8421','3','','1','0','','','','0','1','0','0'),
('16167','Gradient pressure aid (sleeve); custom made; medium weight','Custom grad sleeve med','S8422','3','','1','0','','','','0','1','0','0'),
('16168','Gradient pressure aid (sleeve); custom made; heavy weight','Custom grad sleeve heavy','S8423','3','','1','0','','','','0','1','0','0'),
('16169','Gradient pressure aid (sleeve); ready made','Ready gradient sleeve','S8424','3','','1','0','','','','0','1','0','0'),
('16170','Gradient pressure aid (glove); custom made; medium weight','Custom grad glove med','S8425','3','','1','0','','','','0','1','0','0'),
('16171','Gradient pressure aid (glove); custom made; heavy weight','Custom grad glove heavy','S8426','3','','1','0','','','','0','1','0','0'),
('16172','Gradient pressure aid (glove); ready made','Ready gradient glove','S8427','3','','1','0','','','','0','1','0','0'),
('16173','Gradient pressure aid (gauntlet); ready made','Ready gradient gauntlet','S8428','3','','1','0','','','','0','1','0','0'),
('16174','Gradient pressure exterior wrap','Gradient pressure wrap','S8429','3','','1','0','','','','0','1','0','0'),
('16175','Padding for compression bandage; roll','Padding for comprssn bdg','S8430','3','','1','0','','','','0','1','0','0'),
('16176','Compression bandage; roll','Compression bandage','S8431','3','','1','0','','','','0','1','0','0'),
('16177','Splint; prefabricated; digit (specify digit by use of modifier)','Splint digit','S8450','3','','1','0','','','','0','1','0','0'),
('16178','Splint; prefabricated; wrist or ankle','Splint wrist or ankle','S8451','3','','1','0','','','','0','1','0','0'),
('16179','Splint; prefabricated; elbow','Splint elbow','S8452','3','','1','0','','','','0','1','0','0'),
('16180','Camisole; post-mastectomy','Camisole post-mast','S8460','3','','1','0','','','','0','1','0','0'),
('16181','Insulin syringes (100 syringes; any size)','100 insulin syringes','S8490','3','','1','0','','','','0','1','0','0'),
('16182','Electrical stimulation of auricular acupuncture points; each 15 minutes of personal one-on-one contact with the patient','Auricular electrostimulation','S8930','3','','1','0','','','','0','1','0','0'),
('16183','Equestrian/hippotherapy; per session','Hippotherapy per session','S8940','3','','1','0','','','','0','1','0','0'),
('16184','Application of a modality (requiring constant provider attendance) to one or more areas; low-level laser; each 15 minutes','Low-level laser trmt 15 min','S8948','3','','1','0','','','','0','1','0','0'),
('16185','Complex lymphedema therapy; each 15 minutes','Complex lymphedema therapy;','S8950','3','','1','0','','','','0','1','0','0'),
('16186','Physical or manipulative therapy performed for maintenance rather than restoration','Pt or manip for maint','S8990','3','','1','0','','','','0','1','0','0'),
('16187','Resuscitation bag (for use by patient on artificial respiration during power failure or other catastrophic event)','Resuscitation bag','S8999','3','','1','0','','','','0','1','0','0'),
('16188','Home uterine monitor with or without associated nursing services','Home uterine monitor with or','S9001','3','','1','0','','','','0','1','0','0'),
('16189','Ultrafiltration monitor','Ultrafiltration monitor','S9007','3','','1','0','','','','0','1','0','0'),
('16190','Automated eeg monitoring','Automated eeg monitoring','S9015','3','','1','0','','','','0','1','0','0'),
('16191','Paranasal sinus ultrasound','Paranasal sinus ultrasound','S9024','3','','1','0','','','','0','1','0','0'),
('16192','Omnicardiogram/cardiointegram','Omnicardiogram/cardiointegra','S9025','3','','1','0','','','','0','1','0','0'),
('16193','Extracorporeal shockwave lithotripsy for gall stones (if performed with ercp; use 43265)','Eswl for gallstones','S9034','3','','1','0','','','','0','1','0','0'),
('16194','Procuren or other growth factor preparation to promote wound healing','Procuren or other growth fac','S9055','3','','1','0','','','','0','1','0','0'),
('16195','Coma stimulation per diem','Coma stimulation per diem','S9056','3','','1','0','','','','0','1','0','0'),
('16196','Home administration of aerosolized drug therapy (e.g.; pentamidine); administrative services; professional pharmacy services; care coordination; all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Medical supplies and equipme','S9061','3','','1','0','','','','0','1','0','0'),
('16197','Global fee urgent care centers','Urgent care center global','S9083','3','','1','0','','','','0','1','0','0'),
('16198','Services provided in an urgent care center (list in addition to code for service)','Services provided in urgent','S9088','3','','1','0','','','','0','1','0','0'),
('16199','Vertebral axial decompression; per session','Vertebral axial decompressio','S9090','3','','1','0','','','','0','1','0','0'),
('16200','Home visit for wound care','Home visit wound care','S9097','3','','1','0','','','','0','1','0','0'),
('16201','Home visit; phototherapy services (e.g.; bili-lite); including equipment rental; nursing services; blood draw; supplies; and other services; per diem','Home phototherapy visit','S9098','3','','1','0','','','','0','1','0','0'),
('16202','Telemonitoring of patient in their home; including all necessary equipment; computer system; connections; and software; maintenance; patient education and support; per month','Telemonitoring/home per mnth','S9110','3','','1','0','','','','0','1','0','0'),
('16203','Back school; per visit','Back school visit','S9117','3','','1','0','','','','0','1','0','0'),
('16204','Home health aide or certified nurse assistant; providing care in the home; per hour','Home health aide or certifie','S9122','3','','1','0','','','','0','1','0','0'),
('16205','Nursing care; in the home; by registered nurse; per hour (use for general nursing care only; not to be used when cpt codes 99500-99602 can be used)','Nursing care in home rn','S9123','3','','1','0','','','','0','1','0','0'),
('16206','Nursing care; in the home; by licensed practical nurse; per hour','Nursing care; in the home; b','S9124','3','','1','0','','','','0','1','0','0'),
('16207','Respite care; in the home; per diem','Respite care; in the home; p','S9125','3','','1','0','','','','0','1','0','0'),
('16208','Hospice care; in the home; per diem','Hospice care; in the home; p','S9126','3','','1','0','','','','0','1','0','0'),
('16209','Social work visit; in the home; per diem','Social work visit; in the ho','S9127','3','','1','0','','','','0','1','0','0'),
('16210','Speech therapy; in the home; per diem','Speech therapy; in the home;','S9128','3','','1','0','','','','0','1','0','0'),
('16211','Occupational therapy; in the home; per diem','Occupational therapy; in the','S9129','3','','1','0','','','','0','1','0','0'),
('16212','Physical therapy; in the home; per diem','Pt in the home per diem','S9131','3','','1','0','','','','0','1','0','0'),
('16213','Diabetic management program; follow-up visit to non-md provider','Diabetic management program;','S9140','3','','1','0','','','','0','1','0','0'),
('16214','Diabetic management program; follow-up visit to md provider','Diabetic management program;','S9141','3','','1','0','','','','0','1','0','0'),
('16215','Insulin pump initiation; instruction in initial use of pump (pump not included)','Insulin pump initiation','S9145','3','','1','0','','','','0','1','0','0'),
('16216','Evaluation by ocularist','Evaluation by ocularist','S9150','3','','1','0','','','','0','1','0','0'),
('16217','Speech therapy; re-evaluation','Speech therapy; re-eval','S9152','3','','1','0','','','','0','1','0','0'),
('16218','Home management of preterm labor; including administrative services; professional pharmacy services; care coordination; and all necessary supplies or equipment (drugs and nursing visits coded separately); per diem (do not use this code with any home infusion per diem code)','Home mgmt preterm labor','S9208','3','','1','0','','','','0','1','0','0'),
('16219','Home management of preterm premature rupture of membranes (pprom); including administrative services; professional pharmacy services; care coordination; and all necessary supplies or equipment (drugs and nursing visits coded separately); per diem (do not use this code with any home infusion per diem code)','Home mgmt pprom','S9209','3','','1','0','','','','0','1','0','0'),
('16220','Home management of gestational hypertension; includes administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code with any home infusion per diem code)','Home mgmt gest hypertension','S9211','3','','1','0','','','','0','1','0','0'),
('16221','Home management of postpartum hypertension; includes administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code with any home infusion per diem code)','Hm postpar hyper per diem','S9212','3','','1','0','','','','0','1','0','0'),
('16222','Home management of preeclampsia; includes administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing services coded separately); per diem (do not use this code with any home infusion per diem code)','Hm preeclamp per diem','S9213','3','','1','0','','','','0','1','0','0'),
('16223','Home management of gestational diabetes; includes administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code with any home infusion per diem code)','Hm gest dm per diem','S9214','3','','1','0','','','','0','1','0','0'),
('16224','Home infusion therapy; pain management infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment; (drugs and nursing visits coded separately); per diem (do not use this code with s9326; s9327 or s9328)','Hit pain mgmt per diem','S9325','3','','1','0','','','','0','1','0','0'),
('16225','Home infusion therapy; continuous (twenty-four hours or more) pain management infusion; administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit cont pain per diem','S9326','3','','1','0','','','','0','1','0','0'),
('16226','Home infusion therapy; intermittent (less than twenty-four hours) pain management infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit int pain per diem','S9327','3','','1','0','','','','0','1','0','0'),
('16227','Home infusion therapy; implanted pump pain management infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit pain imp pump diem','S9328','3','','1','0','','','','0','1','0','0'),
('16228','Home infusion therapy; chemotherapy infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code with s9330 or s9331)','Hit chemo per diem','S9329','3','','1','0','','','','0','1','0','0'),
('16229','Home infusion therapy; continuous (twenty-four hours or more) chemotherapy infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit cont chem diem','S9330','3','','1','0','','','','0','1','0','0'),
('16230','Home infusion therapy; intermittent (less than twenty-four hours) chemotherapy infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit intermit chemo diem','S9331','3','','1','0','','','','0','1','0','0'),
('16231','Home therapy; hemodialysis; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing services coded separately); per diem','Ht hemodialysis diem','S9335','3','','1','0','','','','0','1','0','0'),
('16232','Home infusion therapy; continuous anticoagulant infusion therapy (e.g.; heparin); administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit cont anticoag diem','S9336','3','','1','0','','','','0','1','0','0'),
('16233','Home infusion therapy; immunotherapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit immunotherapy diem','S9338','3','','1','0','','','','0','1','0','0'),
('16234','Home therapy; peritoneal dialysis; administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit periton dialysis diem','S9339','3','','1','0','','','','0','1','0','0'),
('16235','Home therapy; enteral nutrition; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (enteral formula and nursing visits coded separately); per diem','Hit enteral per diem','S9340','3','','1','0','','','','0','1','0','0'),
('16236','Home therapy; enteral nutrition via gravity; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (enteral formula and nursing visits coded separately); per diem','Hit enteral grav diem','S9341','3','','1','0','','','','0','1','0','0'),
('16237','Home therapy; enteral nutrition via pump; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (enteral formula and nursing visits coded separately); per diem','Hit enteral pump diem','S9342','3','','1','0','','','','0','1','0','0'),
('16238','Home therapy; enteral nutrition via bolus; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (enteral formula and nursing visits coded separately); per diem','Hit enteral bolus nurs','S9343','3','','1','0','','','','0','1','0','0'),
('16239','Home infusion therapy; anti-hemophilic agent infusion therapy (e.g.; factor viii); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit anti-hemophil diem','S9345','3','','1','0','','','','0','1','0','0'),
('16240','Home infusion therapy; alpha-1-proteinase inhibitor (e.g.; prolastin); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit alpha-1-proteinas diem','S9346','3','','1','0','','','','0','1','0','0'),
('16241','Home infusion therapy; uninterrupted; long-term; controlled rate intravenous or subcutaneous infusion therapy (e.g.; epoprostenol); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit longterm infusion diem','S9347','3','','1','0','','','','0','1','0','0'),
('16242','Home infusion therapy; sympathomimetic/inotropic agent infusion therapy (e.g.; dobutamine); administrative services; professional pharmacy services; care coordination; all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit sympathomim diem','S9348','3','','1','0','','','','0','1','0','0'),
('16243','Home infusion therapy; tocolytic infusion therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit tocolysis diem','S9349','3','','1','0','','','','0','1','0','0'),
('16244','Home infusion therapy; continuous or intermittent anti-emetic infusion therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and visits coded separately); per diem','Hit cont antiemetic diem','S9351','3','','1','0','','','','0','1','0','0'),
('16245','Home infusion therapy; continuous insulin infusion therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit cont insulin diem','S9353','3','','1','0','','','','0','1','0','0'),
('16246','Home infusion therapy; chelation therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit chelation diem','S9355','3','','1','0','','','','0','1','0','0'),
('16247','Home infusion therapy; enzyme replacement intravenous therapy; (e.g.; imiglucerase); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit enzyme replace diem','S9357','3','','1','0','','','','0','1','0','0'),
('16248','Home infusion therapy; anti-tumor necrosis factor intravenous therapy; (e.g.; infliximab); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit anti-tnf per diem','S9359','3','','1','0','','','','0','1','0','0'),
('16249','Home infusion therapy; diuretic intravenous therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit diuretic infus diem','S9361','3','','1','0','','','','0','1','0','0'),
('16250','Home infusion therapy; anti-spasmotic therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit anti-spasmotic diem','S9363','3','','1','0','','','','0','1','0','0'),
('16251','Home infusion therapy; total parenteral nutrition (tpn); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment including standard tpn formula (lipids; specialty amino acid formulas; drugs other than in standard formula and nursing visits coded separately); per diem (do not use with home infusion codes s9365-s9368 using daily volume scales)','Hit tpn total diem','S9364','3','','1','0','','','','0','1','0','0'),
('16252','Home infusion therapy; total parenteral nutrition (tpn); one liter per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment including standard tpn formula (lipids; specialty amino acid formulas; drugs other than in standard formula and nursing visits coded separately); per diem','Hit tpn 1 liter diem','S9365','3','','1','0','','','','0','1','0','0'),
('16253','Home infusion therapy; total parenteral nutrition (tpn); more than one liter but no more than two liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment including standard tpn formula (lipids; specialty amino acid formulas; drugs other than in standard formula and nursing visits coded separately); per diem','Hit tpn 2 liter diem','S9366','3','','1','0','','','','0','1','0','0'),
('16254','Home infusion therapy; total parenteral nutrition (tpn); more than two liters but no more than three liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment including standard tpn formula (lipids; specialty amino acid formulas; drugs other than in standard formula and nursing visits coded separately); per diem','Hit tpn 3 liter diem','S9367','3','','1','0','','','','0','1','0','0'),
('16255','Home infusion therapy; total parenteral nutrition (tpn); more than three liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment including standard tpn formula (lipids; specialty amino acid formulas; drugs other than in standard formula and nursing visits coded separately); per diem','Hit tpn over 3l diem','S9368','3','','1','0','','','','0','1','0','0'),
('16256','Home therapy; intermittent anti-emetic injection therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht inj antiemetic diem','S9370','3','','1','0','','','','0','1','0','0'),
('16257','Home therapy; intermittent anticoagulant injection therapy (e.g.; heparin); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code for flushing of infusion devices with heparin to maintain patency)','Ht inj anticoag diem','S9372','3','','1','0','','','','0','1','0','0'),
('16258','Home infusion therapy; hydration therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use with hydration therapy codes s9374-s9377 using daily volume scales)','Hit hydra total diem','S9373','3','','1','0','','','','0','1','0','0'),
('16259','Home infusion therapy; hydration therapy; one liter per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit hydra 1 liter diem','S9374','3','','1','0','','','','0','1','0','0'),
('16260','Home infusion therapy; hydration therapy; more than one liter but no more than two liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit hydra 2 liter diem','S9375','3','','1','0','','','','0','1','0','0'),
('16261','Home infusion therapy; hydration therapy; more than two liters but no more than three liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit hydra 3 liter diem','S9376','3','','1','0','','','','0','1','0','0'),
('16262','Home infusion therapy; hydration therapy; more than three liters per day; administrative services; professional pharmacy services; care coordination; and all necessary supplies (drugs and nursing visits coded separately); per diem','Hit hydra over 3l diem','S9377','3','','1','0','','','','0','1','0','0'),
('16263','Home infusion therapy; infusion therapy; not otherwise classified; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit noc per diem','S9379','3','','1','0','','','','0','1','0','0'),
('16264','Delivery or service to high risk areas requiring escort or extra protection; per visit','Hit high risk/escort','S9381','3','','1','0','','','','0','1','0','0'),
('16265','Anticoagulation clinic; inclusive of all services except laboratory tests; per session','Anticoag clinic per session','S9401','3','','1','0','','','','0','1','0','0'),
('16266','Pharmacy compounding and dispensing services','Pharmacy comp/disp serv','S9430','3','','1','0','','','','0','1','0','0'),
('16267','Medical food nutritionally complete; administered orally; providing 100% of nutritional intake','Medical food oral 100% nutr','S9433','3','','1','0','','','','0','1','0','0'),
('16268','Modified solid food supplements for inborn errors of metabolism','Mod solid food suppl','S9434','3','','1','0','','','','0','1','0','0'),
('16269','Medical foods for inborn errors of metabolism','Medical foods for inborn err','S9435','3','','1','0','','','','0','1','0','0'),
('16270','Childbirth preparation/lamaze classes; non-physician provider; per session','Lamaze class','S9436','3','','1','0','','','','0','1','0','0'),
('16271','Childbirth refresher classes; non-physician provider; per session','Childbirth refresher class','S9437','3','','1','0','','','','0','1','0','0'),
('16272','Cesarean birth classes; non-physician provider; per session','Cesarean birth class','S9438','3','','1','0','','','','0','1','0','0'),
('16273','Vbac (vaginal birth after cesarean) classes; non-physician provider; per session','Vbac class','S9439','3','','1','0','','','','0','1','0','0'),
('16274','Asthma education; non-physician provider; per session','Asthma education','S9441','3','','1','0','','','','0','1','0','0'),
('16275','Birthing classes; non-physician provider; per session','Birthing class','S9442','3','','1','0','','','','0','1','0','0'),
('16276','Lactation classes; non-physician provider; per session','Lactation class','S9443','3','','1','0','','','','0','1','0','0'),
('16277','Parenting classes; non-physician provider; per session','Parenting class','S9444','3','','1','0','','','','0','1','0','0'),
('16278','Patient education; not otherwise classified; non-physician provider; individual; per session','Pt education noc individ','S9445','3','','1','0','','','','0','1','0','0'),
('16279','Patient education; not otherwise classified; non-physician provider; group; per session','Pt education noc group','S9446','3','','1','0','','','','0','1','0','0'),
('16280','Infant safety (including cpr) classes; non-physician provider; per session','Infant safety class','S9447','3','','1','0','','','','0','1','0','0'),
('16281','Weight management classes; non-physician provider; per session','Weight mgmt class','S9449','3','','1','0','','','','0','1','0','0'),
('16282','Exercise classes; non-physician provider; per session','Exercise class','S9451','3','','1','0','','','','0','1','0','0'),
('16283','Nutrition classes; non-physician provider; per session','Nutrition class','S9452','3','','1','0','','','','0','1','0','0'),
('16284','Smoking cessation classes; non-physician provider; per session','Smoking cessation class','S9453','3','','1','0','','','','0','1','0','0'),
('16285','Stress management classes; non-physician provider; per session','Stress mgmt class','S9454','3','','1','0','','','','0','1','0','0'),
('16286','Diabetic management program; group session','Diabetic management program;','S9455','3','','1','0','','','','0','1','0','0'),
('16287','Diabetic management program; nurse visit','Diabetic management program;','S9460','3','','1','0','','','','0','1','0','0'),
('16288','Diabetic management program; dietitian visit','Diabetic management program;','S9465','3','','1','0','','','','0','1','0','0'),
('16289','Nutritional counseling; dietitian visit','Nutritional counseling; diet','S9470','3','','1','0','','','','0','1','0','0'),
('16290','Cardiac rehabilitation program; non-physician provider; per diem','Cardiac rehabilitation progr','S9472','3','','1','0','','','','0','1','0','0'),
('16291','Pulmonary rehabilitation program; non-physician provider; per diem','Pulmonary rehabilitation pro','S9473','3','','1','0','','','','0','1','0','0'),
('16292','Enterostomal therapy by a registered nurse certified in enterostomal therapy; per diem','Enterostomal therapy by a re','S9474','3','','1','0','','','','0','1','0','0'),
('16293','Ambulatory setting substance abuse treatment or detoxification services; per diem','Ambulatory setting substance','S9475','3','','1','0','','','','0','1','0','0'),
('16294','Vestibular rehabilitation program; non-physician provider; per diem','Vestibular rehab per diem','S9476','3','','1','0','','','','0','1','0','0'),
('16295','Intensive outpatient psychiatric services; per diem','Intensive outpatient psychia','S9480','3','','1','0','','','','0','1','0','0'),
('16296','Family stabilization services; per 15 minutes','Family stabilization 15 min','S9482','3','','1','0','','','','0','1','0','0'),
('16297','Crisis intervention mental health services; per hour','Crisis intervention per hour','S9484','3','','1','0','','','','0','1','0','0'),
('16298','Crisis intervention mental health services; per diem','Crisis intervention mental h','S9485','3','','1','0','','','','0','1','0','0'),
('16299','Home infusion therapy; corticosteroid infusion; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit corticosteroid/diem','S9490','3','','1','0','','','','0','1','0','0'),
('16300','Home infusion therapy; antibiotic; antiviral; or antifungal therapy; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem (do not use this code with home infusion codes for hourly dosing schedules s9497-s9504)','Hit antibiotic total diem','S9494','3','','1','0','','','','0','1','0','0'),
('16301','Home infusion therapy; antibiotic; antiviral; or antifungal therapy; once every 3 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q3h diem','S9497','3','','1','0','','','','0','1','0','0'),
('16302','Home infusion therapy; antibiotic; antiviral; or antifungal therapy; once every 24 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q24h diem','S9500','3','','1','0','','','','0','1','0','0'),
('16303','Home infusion therapy; antibiotic; antiviral; or antifungal therapy; once every 12 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q12h diem','S9501','3','','1','0','','','','0','1','0','0'),
('16304','Home infusion therapy; antibiotic; antiviral; or antifungal therapy; once every 8 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q8h diem','S9502','3','','1','0','','','','0','1','0','0'),
('16305','Home infusion therapy; antibiotic; antiviral; or antifungal; once every 6 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q6h diem','S9503','3','','1','0','','','','0','1','0','0'),
('16306','Home infusion therapy; antibiotic; antiviral; or antifungal; once every 4 hours; administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit antibiotic q4h diem','S9504','3','','1','0','','','','0','1','0','0'),
('16307','Routine venipuncture for collection of specimen(s); single home bound; nursing home; or skilled nursing facility patient','Venipuncture home/snf','S9529','3','','1','0','','','','0','1','0','0'),
('16308','Home therapy; hematopoietic hormone injection therapy (e.g.; erythropoietin; g-csf; gm-csf); administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht hem horm inj diem','S9537','3','','1','0','','','','0','1','0','0'),
('16309','Home transfusion of blood product(s); administrative services; professional pharmacy services; care coordination and all necessary supplies and equipment (blood products; drugs; and nursing visits coded separately); per diem','Hit blood products diem','S9538','3','','1','0','','','','0','1','0','0'),
('16310','Home injectable therapy; not otherwise classified; including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht inj noc per diem','S9542','3','','1','0','','','','0','1','0','0'),
('16311','Home injectable therapy; growth hormone; including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht inj growth horm diem','S9558','3','','1','0','','','','0','1','0','0'),
('16312','Home injectable therapy; interferon; including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Hit inj interferon diem','S9559','3','','1','0','','','','0','1','0','0'),
('16313','Home injectable therapy; hormonal therapy (e.g.; leuprolide; goserelin); including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht inj hormone diem','S9560','3','','1','0','','','','0','1','0','0'),
('16314','Home injectable therapy; palivizumab; including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht inj palivizumab diem','S9562','3','','1','0','','','','0','1','0','0'),
('16315','Home therapy; irrigation therapy (e.g.; sterile irrigation of an organ or anatomical cavity); including administrative services; professional pharmacy services; care coordination; and all necessary supplies and equipment (drugs and nursing visits coded separately); per diem','Ht irrigation diem','S9590','3','','1','0','','','','0','1','0','0'),
('16316','Home therapy; professional pharmacy services for provision of infusion; specialty drug administration; and/or disease state management; not otherwise classified; per hour (do not use this code with any per diem code)','Ht pharm per hour','S9810','3','','1','0','','','','0','1','0','0'),
('16317','Services by a journal-listed christian science practitioner for the purpose of healing; per diem','Christian sci pract visit','S9900','3','','1','0','','','','0','1','0','0'),
('16318','Services by a journal-listed christian science nurse; per hour','Christian sci nurse visit','S9901','3','','1','0','','','','0','1','0','0'),
('16319','Ambulance service; conventional air service; nonemergency transport; one way (fixed wing)','Air ambulanc nonemerg fixed','S9960','3','','1','0','','','','0','1','0','0'),
('16320','Ambulance service; conventional air service; nonemergency transport; one way (rotary wing)','Air ambulan nonemerg rotary','S9961','3','','1','0','','','','0','1','0','0'),
('16321','Health club membership; annual','Health club membership yr','S9970','3','','1','0','','','','0','1','0','0'),
('16322','Transplant related lodging; meals and transportation; per diem','Transplant related per diem','S9975','3','','1','0','','','','0','1','0','0'),
('16323','Lodging; per diem; not otherwise classified','Lodging per diem','S9976','3','','1','0','','','','0','1','0','0'),
('16324','Meals; per diem; not otherwise specified','Meals per diem','S9977','3','','1','0','','','','0','1','0','0'),
('16325','Medical records copying fee; administrative','Med record copy admin','S9981','3','','1','0','','','','0','1','0','0'),
('16326','Medical records copying fee; per page','Med record copy per page','S9982','3','','1','0','','','','0','1','0','0'),
('16327','Not medically necessary service (patient is aware that service not medically necessary)','Not medically necessary svc','S9986','3','','1','0','','','','0','1','0','0'),
('16328','Services provided as part of a phase i clinical trial','Serv part of phase i trial','S9988','3','','1','0','','','','0','1','0','0'),
('16329','Services provided outside of the united states of america (list in addition to code(s) for service(s))','Services outside us','S9989','3','','1','0','','','','0','1','0','0'),
('16330','Services provided as part of a phase ii clinical trial','Services provided as part of','S9990','3','','1','0','','','','0','1','0','0'),
('16331','Services provided as part of a phase iii clinical trial','Services provided as part of','S9991','3','','1','0','','','','0','1','0','0'),
('16332','Transportation costs to and from trial location and local transportation costs (e.g.; fares for taxicab or bus) for clinical trial participant and one caregiver/companion','Transportation costs to and','S9992','3','','1','0','','','','0','1','0','0'),
('16333','Lodging costs (e.g.; hotel charges) for clinical trial participant and one caregiver/companion','Lodging costs (e.g. hotel ch','S9994','3','','1','0','','','','0','1','0','0'),
('16334','Meals for clinical trial participant and one caregiver/companion','Meals for clinical trial par','S9996','3','','1','0','','','','0','1','0','0'),
('16335','Sales tax','Sales tax','S9999','3','','1','0','','','','0','1','0','0'),
('16336','Private duty / independent nursing service(s) - licensed; up to 15 minutes','Private duty/independent nsg','T1000','3','','1','0','','','','0','1','0','0'),
('16337','Nursing assessment / evaluation','Nursing assessment/evaluatn','T1001','3','','1','0','','','','0','1','0','0'),
('16338','Rn services; up to 15 minutes','Rn services up to 15 minutes','T1002','3','','1','0','','','','0','1','0','0'),
('16339','Lpn/lvn services; up to 15 minutes','Lpn/lvn services up to 15min','T1003','3','','1','0','','','','0','1','0','0'),
('16340','Services of a qualified nursing aide; up to 15 minutes','Nsg aide service up to 15min','T1004','3','','1','0','','','','0','1','0','0'),
('16341','Respite care services; up to 15 minutes','Respite care service 15 min','T1005','3','','1','0','','','','0','1','0','0'),
('16342','Alcohol and/or substance abuse services; family/couple counseling','Family/couple counseling','T1006','3','','1','0','','','','0','1','0','0'),
('16343','Alcohol and/or substance abuse services; treatment plan development and/or modification','Treatment plan development','T1007','3','','1','0','','','','0','1','0','0'),
('16344','Child sitting services for children of the individual receiving alcohol and/or substance abuse services','Child sitting services','T1009','3','','1','0','','','','0','1','0','0'),
('16345','Meals for individuals receiving alcohol and/or substance abuse services (when meals not included in the program)','Meals when receive services','T1010','3','','1','0','','','','0','1','0','0'),
('16346','Alcohol and/or substance abuse services; skills development','Alcohol/substance abuse skil','T1012','3','','1','0','','','','0','1','0','0'),
('16347','Sign language or oral interpretive services; per 15 minutes','Sign lang/oral interpreter','T1013','3','','1','0','','','','0','1','0','0'),
('16348','Telehealth transmission; per minute; professional services bill separately','Telehealth transmit; per min','T1014','3','','1','0','','','','0','1','0','0'),
('16349','Clinic visit/encounter; all-inclusive','Clinic service','T1015','3','','1','0','','','','0','1','0','0'),
('16350','Case management; each 15 minutes','Case management','T1016','3','','1','0','','','','0','1','0','0'),
('16351','Targeted case management; each 15 minutes','Targeted case management','T1017','3','','1','0','','','','0','1','0','0'),
('16352','School-based individualized education program (iep) services; bundled','School-based iep ser bundled','T1018','3','','1','0','','','','0','1','0','0'),
('16353','Personal care services; per 15 minutes; not for an inpatient or resident of a hospital; nursing facility; icf/mr or imd; part of the individualized plan of treatment (code may not be used to identify services provided by home health aide or certified nurse assistant)','Personal care ser per 15 min','T1019','3','','1','0','','','','0','1','0','0'),
('16354','Personal care services; per diem; not for an inpatient or resident of a hospital; nursing facility; icf/mr or imd; part of the individualized plan of treatment (code may not be used to identify services provided by home health aide or certified nurse assistant)','Personal care ser per diem','T1020','3','','1','0','','','','0','1','0','0'),
('16355','Home health aide or certified nurse assistant; per visit','Hh aide or cn aide per visit','T1021','3','','1','0','','','','0','1','0','0'),
('16356','Contracted home health agency services; all services provided under contract; per day','Contracted services per day','T1022','3','','1','0','','','','0','1','0','0'),
('16357','Screening to determine the appropriateness of consideration of an individual for participation in a specified program; project or treatment protocol; per encounter','Program intake assessment','T1023','3','','1','0','','','','0','1','0','0'),
('16358','Evaluation and treatment by an integrated; specialty team contracted to provide coordinated care to multiple or severely handicapped children; per encounter','Team evaluation & management','T1024','3','','1','0','','','','0','1','0','0'),
('16359','Intensive; extended multidisciplinary services provided in a clinic setting to children with complex medical; physical; mental and psychosocial impairments; per diem','Ped compr care pkg; per diem','T1025','3','','1','0','','','','0','1','0','0'),
('16360','Intensive; extended multidisciplinary services provided in a clinic setting to children with complex medical; physical; medical and psychosocial impairments; per hour','Ped compr care pkg; per hour','T1026','3','','1','0','','','','0','1','0','0'),
('16361','Family training and counseling for child development; per 15 minutes','Family training & counseling','T1027','3','','1','0','','','','0','1','0','0'),
('16362','Assessment of home; physical and family environment; to determine suitability to meet patients medical needs','Home environment assessment','T1028','3','','1','0','','','','0','1','0','0'),
('16363','Comprehensive environmental lead investigation; not including laboratory analysis; per dwelling','Dwelling lead investigation','T1029','3','','1','0','','','','0','1','0','0'),
('16364','Nursing care; in the home; by registered nurse; per diem','Rn home care per diem','T1030','3','','1','0','','','','0','1','0','0'),
('16365','Nursing care; in the home; by licensed practical nurse; per diem','Lpn home care per diem','T1031','3','','1','0','','','','0','1','0','0'),
('16366','Medicaid certified community behavioral health clinic services; per diem','Comm bh clinic svc per diem','T1040','3','','1','0','','','','0','1','0','0'),
('16367','Medicaid certified community behavioral health clinic services; per month','Comm bh clinic svc per month','T1041','3','','1','0','','','','0','1','0','0'),
('16368','Administration of oral; intramuscular and/or subcutaneous medication by health care agency/professional; per visit','Medication admin visit','T1502','3','','1','0','','','','0','1','0','0'),
('16369','Administration of medication; other than oral and/or injectable; by a health care agency/professional; per visit','Med admin; not oral/inject','T1503','3','','1','0','','','','0','1','0','0'),
('16370','Electronic medication compliance management device; includes all components and accessories; not otherwise classified','Elec med comp dev; noc','T1505','3','','1','0','','','','0','1','0','0'),
('16371','Miscellaneous therapeutic items and supplies; retail purchases; not otherwise classified; identify product in ''remarks''','Noc retail items andsupplies','T1999','3','','1','0','','','','0','1','0','0'),
('16372','Non-emergency transportation; patient attendant/escort','N-et; patient attend/escort','T2001','3','','1','0','','','','0','1','0','0'),
('16373','Non-emergency transportation; per diem','N-et; per diem','T2002','3','','1','0','','','','0','1','0','0'),
('16374','Non-emergency transportation; encounter/trip','N-et; encounter/trip','T2003','3','','1','0','','','','0','1','0','0'),
('16375','Non-emergency transport; commercial carrier; multi-pass','N-et; commerc carrier pass','T2004','3','','1','0','','','','0','1','0','0'),
('16376','Non-emergency transportation; stretcher van','N-et; stretcher van','T2005','3','','1','0','','','','0','1','0','0'),
('16377','Transportation waiting time; air ambulance and non-emergency vehicle; one-half (1/2) hour increments','Non-emer transport wait time','T2007','3','','1','0','','','','0','1','0','0'),
('16378','Preadmission screening and resident review (pasrr) level i identification screening; per screen','Pasrr level i','T2010','3','','1','0','','','','0','1','0','0'),
('16379','Preadmission screening and resident review (pasrr) level ii evaluation; per evaluation','Pasrr level ii','T2011','3','','1','0','','','','0','1','0','0'),
('16380','Habilitation; educational; waiver; per diem','Habil ed waiver; per diem','T2012','3','','1','0','','','','0','1','0','0'),
('16381','Habilitation; educational; waiver; per hour','Habil ed waiver per hour','T2013','3','','1','0','','','','0','1','0','0'),
('16382','Habilitation; prevocational; waiver; per diem','Habil prevoc waiver; per d','T2014','3','','1','0','','','','0','1','0','0'),
('16383','Habilitation; prevocational; waiver; per hour','Habil prevoc waiver per hr','T2015','3','','1','0','','','','0','1','0','0'),
('16384','Habilitation; residential; waiver; per diem','Habil res waiver per diem','T2016','3','','1','0','','','','0','1','0','0'),
('16385','Habilitation; residential; waiver; 15 minutes','Habil res waiver 15 min','T2017','3','','1','0','','','','0','1','0','0'),
('16386','Habilitation; supported employment; waiver; per diem','Habil sup empl waiver/diem','T2018','3','','1','0','','','','0','1','0','0'),
('16387','Habilitation; supported employment; waiver; per 15 minutes','Habil sup empl waiver 15min','T2019','3','','1','0','','','','0','1','0','0'),
('16388','Day habilitation; waiver; per diem','Day habil waiver per diem','T2020','3','','1','0','','','','0','1','0','0'),
('16389','Day habilitation; waiver; per 15 minutes','Day habil waiver per 15 min','T2021','3','','1','0','','','','0','1','0','0'),
('16390','Case management; per month','Case management; per month','T2022','3','','1','0','','','','0','1','0','0'),
('16391','Targeted case management; per month','Targeted case mgmt per month','T2023','3','','1','0','','','','0','1','0','0'),
('16392','Service assessment/plan of care development; waiver','Serv asmnt/care plan waiver','T2024','3','','1','0','','','','0','1','0','0'),
('16393','Waiver services; not otherwise specified (nos)','Waiver service; nos','T2025','3','','1','0','','','','0','1','0','0'),
('16394','Specialized childcare; waiver; per diem','Special childcare waiver/d','T2026','3','','1','0','','','','0','1','0','0'),
('16395','Specialized childcare; waiver; per 15 minutes','Spec childcare waiver 15 min','T2027','3','','1','0','','','','0','1','0','0'),
('16396','Specialized supply; not otherwise specified; waiver','Special supply; nos waiver','T2028','3','','1','0','','','','0','1','0','0'),
('16397','Specialized medical equipment; not otherwise specified; waiver','Special med equip; noswaiver','T2029','3','','1','0','','','','0','1','0','0'),
('16398','Assisted living; waiver; per month','Assist living waiver/month','T2030','3','','1','0','','','','0','1','0','0'),
('16399','Assisted living; waiver; per diem','Assist living waiver/diem','T2031','3','','1','0','','','','0','1','0','0'),
('16400','Residential care; not otherwise specified (nos); waiver; per month','Res care; nos waiver/month','T2032','3','','1','0','','','','0','1','0','0'),
('16401','Residential care; not otherwise specified (nos); waiver; per diem','Res; nos waiver per diem','T2033','3','','1','0','','','','0','1','0','0'),
('16402','Crisis intervention; waiver; per diem','Crisis interven waiver/diem','T2034','3','','1','0','','','','0','1','0','0'),
('16403','Utility services to support medical equipment and assistive technology/devices; waiver','Utility services waiver','T2035','3','','1','0','','','','0','1','0','0'),
('16404','Therapeutic camping; overnight; waiver; each session','Camp overnite waiver/session','T2036','3','','1','0','','','','0','1','0','0'),
('16405','Therapeutic camping; day; waiver; each session','Camp day waiver/session','T2037','3','','1','0','','','','0','1','0','0'),
('16406','Community transition; waiver; per service','Comm trans waiver/service','T2038','3','','1','0','','','','0','1','0','0'),
('16407','Vehicle modifications; waiver; per service','Vehicle mod waiver/service','T2039','3','','1','0','','','','0','1','0','0'),
('16408','Financial management; self-directed; waiver; per 15 minutes','Financial mgt waiver/15min','T2040','3','','1','0','','','','0','1','0','0'),
('16409','Supports brokerage; self-directed; waiver; per 15 minutes','Support broker waiver/15 min','T2041','3','','1','0','','','','0','1','0','0'),
('16410','Hospice routine home care; per diem','Hospice routine home care','T2042','3','','1','0','','','','0','1','0','0'),
('16411','Hospice continuous home care; per hour','Hospice continuous home care','T2043','3','','1','0','','','','0','1','0','0'),
('16412','Hospice inpatient respite care; per diem','Hospice respite care','T2044','3','','1','0','','','','0','1','0','0'),
('16413','Hospice general inpatient care; per diem','Hospice general care','T2045','3','','1','0','','','','0','1','0','0'),
('16414','Hospice long term care; room and board only; per diem','Hospice long term care; r&b','T2046','3','','1','0','','','','0','1','0','0'),
('16415','Behavioral health; long-term care residential (non-acute care in a residential treatment program where stay is typically longer than 30 days); with room and board; per diem','Bh ltc res r&b; per diem','T2048','3','','1','0','','','','0','1','0','0'),
('16416','Non-emergency transportation; stretcher van; mileage; per mile','N-et; stretcher van; mileage','T2049','3','','1','0','','','','0','1','0','0'),
('16417','Human breast milk processing; storage and distribution only','Breast milk proc/store/dist','T2101','3','','1','0','','','','0','1','0','0'),
('16418','Adult sized disposable incontinence product; brief/diaper; small; each','Adult size brief/diaper sm','T4521','3','','1','0','','','','0','1','0','0'),
('16419','Adult sized disposable incontinence product; brief/diaper; medium; each','Adult size brief/diaper med','T4522','3','','1','0','','','','0','1','0','0'),
('16420','Adult sized disposable incontinence product; brief/diaper; large; each','Adult size brief/diaper lg','T4523','3','','1','0','','','','0','1','0','0'),
('16421','Adult sized disposable incontinence product; brief/diaper; extra large; each','Adult size brief/diaper xl','T4524','3','','1','0','','','','0','1','0','0'),
('16422','Adult sized disposable incontinence product; protective underwear/pull-on; small size; each','Adult size pull-on sm','T4525','3','','1','0','','','','0','1','0','0'),
('16423','Adult sized disposable incontinence product; protective underwear/pull-on; medium size; each','Adult size pull-on med','T4526','3','','1','0','','','','0','1','0','0'),
('16424','Adult sized disposable incontinence product; protective underwear/pull-on; large size; each','Adult size pull-on lg','T4527','3','','1','0','','','','0','1','0','0'),
('16425','Adult sized disposable incontinence product; protective underwear/pull-on; extra large size; each','Adult size pull-on xl','T4528','3','','1','0','','','','0','1','0','0'),
('16426','Pediatric sized disposable incontinence product; brief/diaper; small/medium size; each','Ped size brief/diaper sm/med','T4529','3','','1','0','','','','0','1','0','0'),
('16427','Pediatric sized disposable incontinence product; brief/diaper; large size; each','Ped size brief/diaper lg','T4530','3','','1','0','','','','0','1','0','0'),
('16428','Pediatric sized disposable incontinence product; protective underwear/pull-on; small/medium size; each','Ped size pull-on sm/med','T4531','3','','1','0','','','','0','1','0','0'),
('16429','Pediatric sized disposable incontinence product; protective underwear/pull-on; large size; each','Ped size pull-on lg','T4532','3','','1','0','','','','0','1','0','0'),
('16430','Youth sized disposable incontinence product; brief/diaper; each','Youth size brief/diaper','T4533','3','','1','0','','','','0','1','0','0'),
('16431','Youth sized disposable incontinence product; protective underwear/pull-on; each','Youth size pull-on','T4534','3','','1','0','','','','0','1','0','0'),
('16432','Disposable liner/shield/guard/pad/undergarment; for incontinence; each','Disposable liner/shield/pad','T4535','3','','1','0','','','','0','1','0','0'),
('16433','Incontinence product; protective underwear/pull-on; reusable; any size; each','Reusable pull-on any size','T4536','3','','1','0','','','','0','1','0','0'),
('16434','Incontinence product; protective underpad; reusable; bed size; each','Reusable underpad bed size','T4537','3','','1','0','','','','0','1','0','0'),
('16435','Diaper service; reusable diaper; each diaper','Diaper serv reusable diaper','T4538','3','','1','0','','','','0','1','0','0'),
('16436','Incontinence product; diaper/brief; reusable; any size; each','Reuse diaper/brief any size','T4539','3','','1','0','','','','0','1','0','0'),
('16437','Incontinence product; protective underpad; reusable; chair size; each','Reusable underpad chair size','T4540','3','','1','0','','','','0','1','0','0'),
('16438','Incontinence product; disposable underpad; large; each','Large disposable underpad','T4541','3','','1','0','','','','0','1','0','0'),
('16439','Incontinence product; disposable underpad; small size; each','Small disposable underpad','T4542','3','','1','0','','','','0','1','0','0'),
('16440','Adult sized disposable incontinence product; protective brief/diaper; above extra large; each','Adult disp brief/diap abv xl','T4543','3','','1','0','','','','0','1','0','0'),
('16441','Adult sized disposable incontinence product; protective underwear/pull-on; above extra large; each','Adlt disp und/pull on abv xl','T4544','3','','1','0','','','','0','1','0','0'),
('16442','Positioning seat for persons with special orthopedic needs','Position seat spec orth need','T5001','3','','1','0','','','','0','1','0','0'),
('16443','Supply; not otherwise specified','Supply; nos','T5999','3','','1','0','','','','0','1','0','0'),
('16444','Frames; purchases','Vision svcs frames purchases','V2020','3','','1','0','','','','0','1','0','0'),
('16445','Deluxe frame','Eyeglasses delux frames','V2025','3','','1','0','','','','0','1','0','0'),
('16446','Sphere; single vision; plano to plus or minus 4.00; per lens','Lens spher single plano 4.00','V2100','3','','1','0','','','','0','1','0','0'),
('16447','Sphere; single vision; plus or minus 4.12 to plus or minus 7.00d; per lens','Single visn sphere 4.12-7.00','V2101','3','','1','0','','','','0','1','0','0'),
('16448','Sphere; single vision; plus or minus 7.12 to plus or minus 20.00d; per lens','Singl visn sphere 7.12-20.00','V2102','3','','1','0','','','','0','1','0','0'),
('16449','Spherocylinder; single vision; plano to plus or minus 4.00d sphere; .12 to 2.00d cylinder; per lens','Spherocylindr 4.00d/12-2.00d','V2103','3','','1','0','','','','0','1','0','0'),
('16450','Spherocylinder; single vision; plano to plus or minus 4.00d sphere; 2.12 to 4.00d cylinder; per lens','Spherocylindr 4.00d/2.12-4d','V2104','3','','1','0','','','','0','1','0','0'),
('16451','Spherocylinder; single vision; plano to plus or minus 4.00d sphere; 4.25 to 6.00d cylinder; per lens','Spherocylinder 4.00d/4.25-6d','V2105','3','','1','0','','','','0','1','0','0'),
('16452','Spherocylinder; single vision; plano to plus or minus 4.00d sphere; over 6.00d cylinder; per lens','Spherocylinder 4.00d/>6.00d','V2106','3','','1','0','','','','0','1','0','0'),
('16453','Spherocylinder; single vision; plus or minus 4.25 to plus or minus 7.00 sphere; .12 to 2.00d cylinder; per lens','Spherocylinder 4.25d/12-2d','V2107','3','','1','0','','','','0','1','0','0'),
('16454','Spherocylinder; single vision; plus or minus 4.25d to plus or minus 7.00d sphere; 2.12 to 4.00d cylinder; per lens','Spherocylinder 4.25d/2.12-4d','V2108','3','','1','0','','','','0','1','0','0'),
('16455','Spherocylinder; single vision; plus or minus 4.25 to plus or minus 7.00d sphere; 4.25 to 6.00d cylinder; per lens','Spherocylinder 4.25d/4.25-6d','V2109','3','','1','0','','','','0','1','0','0'),
('16456','Spherocylinder; single vision; plus or minus 4.25 to 7.00d sphere; over 6.00d cylinder; per lens','Spherocylinder 4.25d/over 6d','V2110','3','','1','0','','','','0','1','0','0'),
('16457','Spherocylinder; single vision; plus or minus 7.25 to plus or minus 12.00d sphere; .25 to 2.25d cylinder; per lens','Spherocylindr 7.25d/.25-2.25','V2111','3','','1','0','','','','0','1','0','0'),
('16458','Spherocylinder; single vision; plus or minus 7.25 to plus or minus 12.00d sphere; 2.25d to 4.00d cylinder; per lens','Spherocylindr 7.25d/2.25-4d','V2112','3','','1','0','','','','0','1','0','0'),
('16459','Spherocylinder; single vision; plus or minus 7.25 to plus or minus 12.00d sphere; 4.25 to 6.00d cylinder; per lens','Spherocylindr 7.25d/4.25-6d','V2113','3','','1','0','','','','0','1','0','0'),
('16460','Spherocylinder; single vision; sphere over plus or minus 12.00d; per lens','Spherocylinder over 12.00d','V2114','3','','1','0','','','','0','1','0','0'),
('16461','Lenticular; (myodisc); per lens; single vision','Lens lenticular bifocal','V2115','3','','1','0','','','','0','1','0','0'),
('16462','Aniseikonic lens; single vision','Lens aniseikonic single','V2118','3','','1','0','','','','0','1','0','0'),
('16463','Lenticular lens; per lens; single','Lenticular lens; single','V2121','3','','1','0','','','','0','1','0','0'),
('16464','Not otherwise classified; single vision lens','Lens single vision not oth c','V2199','3','','1','0','','','','0','1','0','0'),
('16465','Sphere; bifocal; plano to plus or minus 4.00d; per lens','Lens spher bifoc plano 4.00d','V2200','3','','1','0','','','','0','1','0','0'),
('16466','Sphere; bifocal; plus or minus 4.12 to plus or minus 7.00d; per lens','Lens sphere bifocal 4.12-7.0','V2201','3','','1','0','','','','0','1','0','0'),
('16467','Sphere; bifocal; plus or minus 7.12 to plus or minus 20.00d; per lens','Lens sphere bifocal 7.12-20.','V2202','3','','1','0','','','','0','1','0','0'),
('16468','Spherocylinder; bifocal; plano to plus or minus 4.00d sphere; .12 to 2.00d cylinder; per lens','Lens sphcyl bifocal 4.00d/.1','V2203','3','','1','0','','','','0','1','0','0'),
('16469','Spherocylinder; bifocal; plano to plus or minus 4.00d sphere; 2.12 to 4.00d cylinder; per lens','Lens sphcy bifocal 4.00d/2.1','V2204','3','','1','0','','','','0','1','0','0'),
('16470','Spherocylinder; bifocal; plano to plus or minus 4.00d sphere; 4.25 to 6.00d cylinder; per lens','Lens sphcy bifocal 4.00d/4.2','V2205','3','','1','0','','','','0','1','0','0'),
('16471','Spherocylinder; bifocal; plano to plus or minus 4.00d sphere; over 6.00d cylinder; per lens','Lens sphcy bifocal 4.00d/ove','V2206','3','','1','0','','','','0','1','0','0'),
('16472','Spherocylinder; bifocal; plus or minus 4.25 to plus or minus 7.00d sphere;.12 to 2.00d cylinder; per lens','Lens sphcy bifocal 4.25-7d/.','V2207','3','','1','0','','','','0','1','0','0'),
('16473','Spherocylinder; bifocal; plus or minus 4.25 to plus or minus 7.00d sphere; 2.12 to 4.00d cylinder; per lens','Lens sphcy bifocal 4.25-7/2.','V2208','3','','1','0','','','','0','1','0','0'),
('16474','Spherocylinder; bifocal; plus or minus 4.25 to plus or minus 7.00d sphere; 4.25 to 6.00d cylinder; per lens','Lens sphcy bifocal 4.25-7/4.','V2209','3','','1','0','','','','0','1','0','0'),
('16475','Spherocylinder; bifocal; plus or minus 4.25 to plus or minus 7.00d sphere; over 6.00d cylinder; per lens','Lens sphcy bifocal 4.25-7/ov','V2210','3','','1','0','','','','0','1','0','0'),
('16476','Spherocylinder; bifocal; plus or minus 7.25 to plus or minus 12.00d sphere; .25 to 2.25d cylinder; per lens','Lens sphcy bifo 7.25-12/.25-','V2211','3','','1','0','','','','0','1','0','0'),
('16477','Spherocylinder; bifocal; plus or minus 7.25 to plus or minus 12.00d sphere; 2.25 to 4.00d cylinder; per lens','Lens sphcyl bifo 7.25-12/2.2','V2212','3','','1','0','','','','0','1','0','0'),
('16478','Spherocylinder; bifocal; plus or minus 7.25 to plus or minus 12.00d sphere; 4.25 to 6.00d cylinder; per lens','Lens sphcyl bifo 7.25-12/4.2','V2213','3','','1','0','','','','0','1','0','0'),
('16479','Spherocylinder; bifocal; sphere over plus or minus 12.00d; per lens','Lens sphcyl bifocal over 12.','V2214','3','','1','0','','','','0','1','0','0'),
('16480','Lenticular (myodisc); per lens; bifocal','Lens lenticular bifocal','V2215','3','','1','0','','','','0','1','0','0'),
('16481','Aniseikonic; per lens; bifocal','Lens aniseikonic bifocal','V2218','3','','1','0','','','','0','1','0','0'),
('16482','Bifocal seg width over 28 mm','Lens bifocal seg width over','V2219','3','','1','0','','','','0','1','0','0'),
('16483','Bifocal add over 3.25d','Lens bifocal add over 3.25d','V2220','3','','1','0','','','','0','1','0','0'),
('16484','Lenticular lens; per lens; bifocal','Lenticular lens; bifocal','V2221','3','','1','0','','','','0','1','0','0'),
('16485','Specialty bifocal (by report)','Lens bifocal speciality','V2299','3','','1','0','','','','0','1','0','0'),
('16486','Sphere; trifocal; plano to plus or minus 4.00d; per lens','Lens sphere trifocal 4.00d','V2300','3','','1','0','','','','0','1','0','0'),
('16487','Sphere; trifocal; plus or minus 4.12 to plus or minus 7.00d; per lens','Lens sphere trifocal 4.12-7.','V2301','3','','1','0','','','','0','1','0','0'),
('16488','Sphere; trifocal; plus or minus 7.12 to plus or minus 20.00; per lens','Lens sphere trifocal 7.12-20','V2302','3','','1','0','','','','0','1','0','0'),
('16489','Spherocylinder; trifocal; plano to plus or minus 4.00d sphere; .12-2.00d cylinder; per lens','Lens sphcy trifocal 4.0/.12-','V2303','3','','1','0','','','','0','1','0','0'),
('16490','Spherocylinder; trifocal; plano to plus or minus 4.00d sphere; 2.25-4.00d cylinder; per lens','Lens sphcy trifocal 4.0/2.25','V2304','3','','1','0','','','','0','1','0','0'),
('16491','Spherocylinder; trifocal; plano to plus or minus 4.00d sphere; 4.25 to 6.00 cylinder; per lens','Lens sphcy trifocal 4.0/4.25','V2305','3','','1','0','','','','0','1','0','0'),
('16492','Spherocylinder; trifocal; plano to plus or minus 4.00d sphere; over 6.00d cylinder; per lens','Lens sphcyl trifocal 4.00/>6','V2306','3','','1','0','','','','0','1','0','0'),
('16493','Spherocylinder; trifocal; plus or minus 4.25 to plus or minus 7.00d sphere; .12 to 2.00d cylinder; per lens','Lens sphcy trifocal 4.25-7/.','V2307','3','','1','0','','','','0','1','0','0'),
('16494','Spherocylinder; trifocal; plus or minus 4.25 to plus or minus 7.00d sphere; 2.12 to 4.00d cylinder; per lens','Lens sphc trifocal 4.25-7/2.','V2308','3','','1','0','','','','0','1','0','0'),
('16495','Spherocylinder; trifocal; plus or minus 4.25 to plus or minus 7.00d sphere; 4.25 to 6.00d cylinder; per lens','Lens sphc trifocal 4.25-7/4.','V2309','3','','1','0','','','','0','1','0','0'),
('16496','Spherocylinder; trifocal; plus or minus 4.25 to plus or minus 7.00d sphere; over 6.00d cylinder; per lens','Lens sphc trifocal 4.25-7/>6','V2310','3','','1','0','','','','0','1','0','0'),
('16497','Spherocylinder; trifocal; plus or minus 7.25 to plus or minus 12.00d sphere; .25 to 2.25d cylinder; per lens','Lens sphc trifo 7.25-12/.25-','V2311','3','','1','0','','','','0','1','0','0'),
('16498','Spherocylinder; trifocal; plus or minus 7.25 to plus or minus 12.00d sphere; 2.25 to 4.00d cylinder; per lens','Lens sphc trifo 7.25-12/2.25','V2312','3','','1','0','','','','0','1','0','0'),
('16499','Spherocylinder; trifocal; plus or minus 7.25 to plus or minus 12.00d sphere; 4.25 to 6.00d cylinder; per lens','Lens sphc trifo 7.25-12/4.25','V2313','3','','1','0','','','','0','1','0','0'),
('16500','Spherocylinder; trifocal; sphere over plus or minus 12.00d; per lens','Lens sphcyl trifocal over 12','V2314','3','','1','0','','','','0','1','0','0'),
('16501','Lenticular; (myodisc); per lens; trifocal','Lens lenticular trifocal','V2315','3','','1','0','','','','0','1','0','0'),
('16502','Aniseikonic lens; trifocal','Lens aniseikonic trifocal','V2318','3','','1','0','','','','0','1','0','0'),
('16503','Trifocal seg width over 28 mm','Lens trifocal seg width > 28','V2319','3','','1','0','','','','0','1','0','0'),
('16504','Trifocal add over 3.25d','Lens trifocal add over 3.25d','V2320','3','','1','0','','','','0','1','0','0'),
('16505','Lenticular lens; per lens; trifocal','Lenticular lens; trifocal','V2321','3','','1','0','','','','0','1','0','0'),
('16506','Specialty trifocal (by report)','Lens trifocal speciality','V2399','3','','1','0','','','','0','1','0','0'),
('16507','Variable asphericity lens; single vision; full field; glass or plastic; per lens','Lens variab asphericity sing','V2410','3','','1','0','','','','0','1','0','0'),
('16508','Variable asphericity lens; bifocal; full field; glass or plastic; per lens','Lens variable asphericity bi','V2430','3','','1','0','','','','0','1','0','0'),
('16509','Variable sphericity lens; other type','Variable asphericity lens','V2499','3','','1','0','','','','0','1','0','0'),
('16510','Contact lens; pmma; spherical; per lens','Contact lens pmma spherical','V2500','3','','1','0','','','','0','1','0','0'),
('16511','Contact lens; pmma; toric or prism ballast; per lens','Cntct lens pmma-toric/prism','V2501','3','','1','0','','','','0','1','0','0'),
('16512','Contact lens; pmma; bifocal; per lens','Contact lens pmma bifocal','V2502','3','','1','0','','','','0','1','0','0'),
('16513','Contact lens; pmma; color vision deficiency; per lens','Cntct lens pmma color vision','V2503','3','','1','0','','','','0','1','0','0'),
('16514','Contact lens; gas permeable; spherical; per lens','Cntct gas permeable sphericl','V2510','3','','1','0','','','','0','1','0','0'),
('16515','Contact lens; gas permeable; toric; prism ballast; per lens','Cntct toric prism ballast','V2511','3','','1','0','','','','0','1','0','0'),
('16516','Contact lens; gas permeable; bifocal; per lens','Cntct lens gas permbl bifocl','V2512','3','','1','0','','','','0','1','0','0'),
('16517','Contact lens; gas permeable; extended wear; per lens','Contact lens extended wear','V2513','3','','1','0','','','','0','1','0','0'),
('16518','Contact lens; hydrophilic; spherical; per lens','Contact lens hydrophilic','V2520','3','','1','0','','','','0','1','0','0'),
('16519','Contact lens; hydrophilic; toric; or prism ballast; per lens','Cntct lens hydrophilic toric','V2521','3','','1','0','','','','0','1','0','0'),
('16520','Contact lens; hydrophilic; bifocal; per lens','Cntct lens hydrophil bifocl','V2522','3','','1','0','','','','0','1','0','0'),
('16521','Contact lens; hydrophilic; extended wear; per lens','Cntct lens hydrophil extend','V2523','3','','1','0','','','','0','1','0','0'),
('16522','Contact lens; scleral; gas impermeable; per lens (for contact lens modification; see 92325)','Contact lens gas impermeable','V2530','3','','1','0','','','','0','1','0','0'),
('16523','Contact lens; scleral; gas permeable; per lens (for contact lens modification; see 92325)','Contact lens gas permeable','V2531','3','','1','0','','','','0','1','0','0'),
('16524','Contact lens; other type','Contact lens/es other type','V2599','3','','1','0','','','','0','1','0','0'),
('16525','Hand held low vision aids and other nonspectacle mounted aids','Hand held low vision aids','V2600','3','','1','0','','','','0','1','0','0'),
('16526','Single lens spectacle mounted low vision aids','Single lens spectacle mount','V2610','3','','1','0','','','','0','1','0','0'),
('16527','Telescopic and other compound lens system; including distance vision telescopic; near vision telescopes and compound microscopic lens system','Telescop/othr compound lens','V2615','3','','1','0','','','','0','1','0','0'),
('16528','Prosthetic eye; plastic; custom','Plastic eye prosth custom','V2623','3','','1','0','','','','0','1','0','0'),
('16529','Polishing/resurfacing of ocular prosthesis','Polishing artifical eye','V2624','3','','1','0','','','','0','1','0','0'),
('16530','Enlargement of ocular prosthesis','Enlargemnt of eye prosthesis','V2625','3','','1','0','','','','0','1','0','0'),
('16531','Reduction of ocular prosthesis','Reduction of eye prosthesis','V2626','3','','1','0','','','','0','1','0','0'),
('16532','Scleral cover shell','Scleral cover shell','V2627','3','','1','0','','','','0','1','0','0'),
('16533','Fabrication and fitting of ocular conformer','Fabrication & fitting','V2628','3','','1','0','','','','0','1','0','0'),
('16534','Prosthetic eye; other type','Prosthetic eye other type','V2629','3','','1','0','','','','0','1','0','0'),
('16535','Anterior chamber intraocular lens','Anter chamber intraocul lens','V2630','3','','1','0','','','','0','1','0','0'),
('16536','Iris supported intraocular lens','Iris support intraoclr lens','V2631','3','','1','0','','','','0','1','0','0'),
('16537','Posterior chamber intraocular lens','Post chmbr intraocular lens','V2632','3','','1','0','','','','0','1','0','0'),
('16538','Balance lens; per lens','Balance lens','V2700','3','','1','0','','','','0','1','0','0'),
('16539','Deluxe lens feature','Deluxe lens feature','V2702','3','','1','0','','','','0','1','0','0'),
('16540','Slab off prism; glass or plastic; per lens','Glass/plastic slab off prism','V2710','3','','1','0','','','','0','1','0','0'),
('16541','Prism; per lens','Prism lens/es','V2715','3','','1','0','','','','0','1','0','0'),
('16542','Press-on lens; fresnell prism; per lens','Fresnell prism press-on lens','V2718','3','','1','0','','','','0','1','0','0'),
('16543','Special base curve; glass or plastic; per lens','Special base curve','V2730','3','','1','0','','','','0','1','0','0'),
('16544','Tint; photochromatic; per lens','Tint photochromatic lens/es','V2744','3','','1','0','','','','0','1','0','0'),
('16545','Addition to lens; tint; any color; solid; gradient or equal; excludes photochromatic; any lens material; per lens','Tint; any color/solid/grad','V2745','3','','1','0','','','','0','1','0','0'),
('16546','Anti-reflective coating; per lens','Anti-reflective coating','V2750','3','','1','0','','','','0','1','0','0'),
('16547','U-v lens; per lens','Uv lens/es','V2755','3','','1','0','','','','0','1','0','0'),
('16548','Eye glass case','Eye glass case','V2756','3','','1','0','','','','0','1','0','0'),
('16549','Scratch resistant coating; per lens','Scratch resistant coating','V2760','3','','1','0','','','','0','1','0','0'),
('16550','Mirror coating; any type; solid; gradient or equal; any lens material; per lens','Mirror coating','V2761','3','','1','0','','','','0','1','0','0'),
('16551','Polarization; any lens material; per lens','Polarization; any lens','V2762','3','','1','0','','','','0','1','0','0'),
('16552','Occluder lens; per lens','Occluder lens/es','V2770','3','','1','0','','','','0','1','0','0'),
('16553','Oversize lens; per lens','Oversize lens/es','V2780','3','','1','0','','','','0','1','0','0'),
('16554','Progressive lens; per lens','Progressive lens per lens','V2781','3','','1','0','','','','0','1','0','0'),
('16555','Lens; index 1.54 to 1.65 plastic or 1.60 to 1.79 glass; excludes polycarbonate; per lens','Lens; 1.54-1.65 p/1.60-1.79g','V2782','3','','1','0','','','','0','1','0','0'),
('16556','Lens; index greater than or equal to 1.66 plastic or greater than or equal to 1.80 glass; excludes polycarbonate; per lens','Lens; >= 1.66 p/>=1.80 g','V2783','3','','1','0','','','','0','1','0','0'),
('16557','Lens; polycarbonate or equal; any index; per lens','Lens polycarb or equal','V2784','3','','1','0','','','','0','1','0','0'),
('16558','Processing; preserving and transporting corneal tissue','Corneal tissue processing','V2785','3','','1','0','','','','0','1','0','0'),
('16559','Specialty occupational multifocal lens; per lens','Occupational multifocal lens','V2786','3','','1','0','','','','0','1','0','0'),
('16560','Astigmatism correcting function of intraocular lens','Astigmatism-correct function','V2787','3','','1','0','','','','0','1','0','0'),
('16561','Presbyopia correcting function of intraocular lens','Presbyopia-correct function','V2788','3','','1','0','','','','0','1','0','0'),
('16562','Amniotic membrane for surgical reconstruction; per procedure','Amniotic membrane','V2790','3','','1','0','','','','0','1','0','0'),
('16563','Vision supply; accessory and/or service component of another hcpcs vision code','Vis item/svc in other code','V2797','3','','1','0','','','','0','1','0','0'),
('16564','Vision item or service; miscellaneous','Misc vision item or service','V2799','3','','1','0','','','','0','1','0','0'),
('16565','Hearing screening','Hearing screening','V5008','3','','1','0','','','','0','1','0','0'),
('16566','Assessment for hearing aid','Assessment for hearing aid','V5010','3','','1','0','','','','0','1','0','0'),
('16567','Fitting/orientation/checking of hearing aid','Hearing aid fitting/checking','V5011','3','','1','0','','','','0','1','0','0'),
('16568','Repair/modification of a hearing aid','Hearing aid repair/modifying','V5014','3','','1','0','','','','0','1','0','0'),
('16569','Conformity evaluation','Conformity evaluation','V5020','3','','1','0','','','','0','1','0','0'),
('16570','Hearing aid; monaural; body worn; air conduction','Body-worn hearing aid air','V5030','3','','1','0','','','','0','1','0','0'),
('16571','Hearing aid; monaural; body worn; bone conduction','Body-worn hearing aid bone','V5040','3','','1','0','','','','0','1','0','0'),
('16572','Hearing aid; monaural; in the ear','Hearing aid monaural in ear','V5050','3','','1','0','','','','0','1','0','0'),
('16573','Hearing aid; monaural; behind the ear','Behind ear hearing aid','V5060','3','','1','0','','','','0','1','0','0'),
('16574','Glasses; air conduction','Glasses air conduction','V5070','3','','1','0','','','','0','1','0','0'),
('16575','Glasses; bone conduction','Glasses bone conduction','V5080','3','','1','0','','','','0','1','0','0'),
('16576','Dispensing fee; unspecified hearing aid','Hearing aid dispensing fee','V5090','3','','1','0','','','','0','1','0','0'),
('16577','Semi-implantable middle ear hearing prosthesis','Implant mid ear hearing pros','V5095','3','','1','0','','','','0','1','0','0'),
('16578','Hearing aid; bilateral; body worn','Body-worn bilat hearing aid','V5100','3','','1','0','','','','0','1','0','0'),
('16579','Dispensing fee; bilateral','Hearing aid dispensing fee','V5110','3','','1','0','','','','0','1','0','0'),
('16580','Binaural; body','Body-worn binaur hearing aid','V5120','3','','1','0','','','','0','1','0','0'),
('16581','Binaural; in the ear','In ear binaural hearing aid','V5130','3','','1','0','','','','0','1','0','0'),
('16582','Binaural; behind the ear','Behind ear binaur hearing ai','V5140','3','','1','0','','','','0','1','0','0'),
('16583','Binaural; glasses','Glasses binaural hearing aid','V5150','3','','1','0','','','','0','1','0','0'),
('16584','Dispensing fee; binaural','Dispensing fee binaural','V5160','3','','1','0','','','','0','1','0','0'),
('16585','Hearing aid; cros; in the ear','Within ear cros hearing aid','V5170','3','','1','0','','','','0','1','0','0'),
('16586','Hearing aid; cros; behind the ear','Behind ear cros hearing aid','V5180','3','','1','0','','','','0','1','0','0'),
('16587','Hearing aid; cros; glasses','Glasses cros hearing aid','V5190','3','','1','0','','','','0','1','0','0'),
('16588','Dispensing fee; cros','Cros hearing aid dispens fee','V5200','3','','1','0','','','','0','1','0','0'),
('16589','Hearing aid; bicros; in the ear','In ear bicros hearing aid','V5210','3','','1','0','','','','0','1','0','0'),
('16590','Hearing aid; bicros; behind the ear','Behind ear bicros hearing ai','V5220','3','','1','0','','','','0','1','0','0'),
('16591','Hearing aid; bicros; glasses','Glasses bicros hearing aid','V5230','3','','1','0','','','','0','1','0','0'),
('16592','Dispensing fee; bicros','Dispensing fee bicros','V5240','3','','1','0','','','','0','1','0','0'),
('16593','Dispensing fee; monaural hearing aid; any type','Dispensing fee; monaural','V5241','3','','1','0','','','','0','1','0','0'),
('16594','Hearing aid; analog; monaural; cic (completely in the ear canal)','Hearing aid; monaural; cic','V5242','3','','1','0','','','','0','1','0','0'),
('16595','Hearing aid; analog; monaural; itc (in the canal)','Hearing aid; monaural; itc','V5243','3','','1','0','','','','0','1','0','0'),
('16596','Hearing aid; digitally programmable analog; monaural; cic','Hearing aid; prog; mon; cic','V5244','3','','1','0','','','','0','1','0','0'),
('16597','Hearing aid; digitally programmable; analog; monaural; itc','Hearing aid; prog; mon; itc','V5245','3','','1','0','','','','0','1','0','0'),
('16598','Hearing aid; digitally programmable analog; monaural; ite (in the ear)','Hearing aid; prog; mon; ite','V5246','3','','1','0','','','','0','1','0','0'),
('16599','Hearing aid; digitally programmable analog; monaural; bte (behind the ear)','Hearing aid; prog; mon; bte','V5247','3','','1','0','','','','0','1','0','0'),
('16600','Hearing aid; analog; binaural; cic','Hearing aid; binaural; cic','V5248','3','','1','0','','','','0','1','0','0'),
('16601','Hearing aid; analog; binaural; itc','Hearing aid; binaural; itc','V5249','3','','1','0','','','','0','1','0','0'),
('16602','Hearing aid; digitally programmable analog; binaural; cic','Hearing aid; prog; bin; cic','V5250','3','','1','0','','','','0','1','0','0'),
('16603','Hearing aid; digitally programmable analog; binaural; itc','Hearing aid; prog; bin; itc','V5251','3','','1','0','','','','0','1','0','0'),
('16604','Hearing aid; digitally programmable; binaural; ite','Hearing aid; prog; bin; ite','V5252','3','','1','0','','','','0','1','0','0'),
('16605','Hearing aid; digitally programmable; binaural; bte','Hearing aid; prog; bin; bte','V5253','3','','1','0','','','','0','1','0','0'),
('16606','Hearing aid; digital; monaural; cic','Hearing id; digit; mon; cic','V5254','3','','1','0','','','','0','1','0','0'),
('16607','Hearing aid; digital; monaural; itc','Hearing aid; digit; mon; itc','V5255','3','','1','0','','','','0','1','0','0'),
('16608','Hearing aid; digital; monaural; ite','Hearing aid; digit; mon; ite','V5256','3','','1','0','','','','0','1','0','0'),
('16609','Hearing aid; digital; monaural; bte','Hearing aid; digit; mon; bte','V5257','3','','1','0','','','','0','1','0','0'),
('16610','Hearing aid; digital; binaural; cic','Hearing aid; digit; bin; cic','V5258','3','','1','0','','','','0','1','0','0'),
('16611','Hearing aid; digital; binaural; itc','Hearing aid; digit; bin; itc','V5259','3','','1','0','','','','0','1','0','0'),
('16612','Hearing aid; digital; binaural; ite','Hearing aid; digit; bin; ite','V5260','3','','1','0','','','','0','1','0','0'),
('16613','Hearing aid; digital; binaural; bte','Hearing aid; digit; bin; bte','V5261','3','','1','0','','','','0','1','0','0'),
('16614','Hearing aid; disposable; any type; monaural','Hearing aid; disp; monaural','V5262','3','','1','0','','','','0','1','0','0'),
('16615','Hearing aid; disposable; any type; binaural','Hearing aid; disp; binaural','V5263','3','','1','0','','','','0','1','0','0'),
('16616','Ear mold/insert; not disposable; any type','Ear mold/insert','V5264','3','','1','0','','','','0','1','0','0'),
('16617','Ear mold/insert; disposable; any type','Ear mold/insert; disp','V5265','3','','1','0','','','','0','1','0','0'),
('16618','Battery for use in hearing device','Battery for hearing device','V5266','3','','1','0','','','','0','1','0','0'),
('16619','Hearing aid or assistive listening device/supplies/accessories; not otherwise specified','Hearing aid sup/access/dev','V5267','3','','1','0','','','','0','1','0','0'),
('16620','Assistive listening device; telephone amplifier; any type','Ald telephone amplifier','V5268','3','','1','0','','','','0','1','0','0'),
('16621','Assistive listening device; alerting; any type','Alerting device; any type','V5269','3','','1','0','','','','0','1','0','0'),
('16622','Assistive listening device; television amplifier; any type','Ald; tv amplifier; any type','V5270','3','','1','0','','','','0','1','0','0'),
('16623','Assistive listening device; television caption decoder','Ald; tv caption decoder','V5271','3','','1','0','','','','0','1','0','0'),
('16624','Assistive listening device; tdd','Tdd','V5272','3','','1','0','','','','0','1','0','0'),
('16625','Assistive listening device; for use with cochlear implant','Ald for cochlear implant','V5273','3','','1','0','','','','0','1','0','0'),
('16626','Assistive listening device; not otherwise specified','Ald unspecified','V5274','3','','1','0','','','','0','1','0','0'),
('16627','Ear impression; each','Ear impression','V5275','3','','1','0','','','','0','1','0','0'),
('16628','Assistive listening device; personal fm/dm system; monaural; (1 receiver; transmitter; microphone); any type','Ald fm/dm system; monaural','V5281','3','','1','0','','','','0','1','0','0'),
('16629','Assistive listening device; personal fm/dm system; binaural; (2 receivers; transmitter; microphone); any type','Ald fm/dm system binaural','V5282','3','','1','0','','','','0','1','0','0'),
('16630','Assistive listening device; personal fm/dm neck; loop induction receiver','Ald neck; loop ind receiver','V5283','3','','1','0','','','','0','1','0','0'),
('16631','Assistive listening device; personal fm/dm; ear level receiver','Ald fm/dm ear level receiver','V5284','3','','1','0','','','','0','1','0','0'),
('16632','Assistive listening device; personal fm/dm; direct audio input receiver','Ald fm/dm aud input receiver','V5285','3','','1','0','','','','0','1','0','0'),
('16633','Assistive listening device; personal blue tooth fm/dm receiver','Ald blu tooth fm/dm receiver','V5286','3','','1','0','','','','0','1','0','0'),
('16634','Assistive listening device; personal fm/dm receiver; not otherwise specified','Ald fm/dm receiver; nos','V5287','3','','1','0','','','','0','1','0','0'),
('16635','Assistive listening device; personal fm/dm transmitter assistive listening device','Ald fm/dm transmitter ald','V5288','3','','1','0','','','','0','1','0','0'),
('16636','Assistive listening device; personal fm/dm adapter/boot coupling device for receiver; any type','Ald fm/dm adapt/boot couplin','V5289','3','','1','0','','','','0','1','0','0'),
('16637','Assistive listening device; transmitter microphone; any type','Ald transmitter microphone','V5290','3','','1','0','','','','0','1','0','0'),
('16638','Hearing aid; not otherwise classified','Hearing aid noc','V5298','3','','1','0','','','','0','1','0','0'),
('16639','Hearing service; miscellaneous','Hearing service','V5299','3','','1','0','','','','0','1','0','0'),
('16640','Repair/modification of augmentative communicative system or device (excludes adaptive hearing aid)','Repair communication device','V5336','3','','1','0','','','','0','1','0','0'),
('16641','Speech screening','Speech screening','V5362','3','','1','0','','','','0','1','0','0'),
('16642','Language screening','Language screening','V5363','3','','1','0','','','','0','1','0','0'),
('16643','Dysphagia screening','Dysphagia screening','V5364','3','','1','0','','','','0','1','0','0');
